(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   3253021,      85191]
NotebookOptionsPosition[   3211586,      84605]
NotebookOutlinePosition[   3211993,      84621]
CellTagsIndexPosition[   3211950,      84618]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["WWP Benjamin-Feir Instability in Finite Depth", "Title",
 CellChangeTimes->{{3.8192388728325577`*^9, 3.8192388826940904`*^9}, {
  3.8193909848370275`*^9, 3.819390986613413*^9}, {3.8359739435520277`*^9, 
  3.83597394405205*^9}, {3.836575147121694*^9, 3.836575154204263*^9}, {
  3.863191501367612*^9, 
  3.8631915072967973`*^9}},ExpressionUUID->"32f0f396-b58c-47d4-86c2-\
4e692fba1a5a"],

Cell["\<\

CONTACT INFORMATION :
  
Ryan P. Creedon
Department of Applied Mathematics
University of Washington, Seattle, WA

DIRECTIONS:

To evaluate this file, click the Evaluation tab above and then Evaluate \
Notebook from the drop-down menu. \
\>", "Text",
 CellChangeTimes->{{3.8359739788280864`*^9, 3.8359739993363094`*^9}, {
  3.8359748293243628`*^9, 3.8359748316548395`*^9}, {3.8360662583760843`*^9, 
  3.8360663650634575`*^9}, {3.8631913412631083`*^9, 
  3.8631913415443387`*^9}},ExpressionUUID->"ff3b8547-2164-4482-a681-\
083ad2e88a22"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"0.", "Notation"}], "Section"]}]], "Input",
 CellChangeTimes->{{3.835974027162642*^9, 
  3.8359740334637904`*^9}},ExpressionUUID->"1a9ce881-903c-404d-8739-\
0103abd212d2"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   StyleBox[
    RowBox[{"STOKES", "  ", "WAVES"}], "Subsubsection"], 
   StyleBox["\[IndentingNewLine]", "Subsubsection"], 
   StyleBox["\[IndentingNewLine]", "Subsubsection"], 
   RowBox[{
    RowBox[{"\[Alpha]", " ", ":", " ", 
     RowBox[{
     "aspect", " ", "ratio", " ", "of", " ", "dimensional", " ", "Stokes", 
      " ", "waves"}]}], ",", " ", 
    RowBox[{">", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"specified", " ", "by", " ", "user"}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]", " ", ":", " ", 
     RowBox[{"small", "-", 
      RowBox[{"amplitude", " ", "parameter"}]}]}], ",", 
    RowBox[{">", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"specified", " ", "by", " ", "user"}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "0"], " ", ":", " ", 
     RowBox[{"zero", "-", 
      RowBox[{"amplitude", " ", "Stokes", " ", "wave", " ", "velocity"}]}]}], 
    ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "0"], " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Omega]", " ", ":", " ", 
     RowBox[{
     "dispersion", " ", "relation", " ", "of", " ", "nondimensional", " ", 
      "Euler", " ", "equations", " ", "in", " ", "stationary", " ", 
      "frame"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", "k", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Sign", "[", "k", "]"}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"k", "*", 
         RowBox[{"Tanh", "[", 
          RowBox[{"\[Alpha]", "*", "k"}], "]"}]}], "]"}]}]}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", " ", ":", " ", 
     RowBox[{
     "dispersion", " ", "relation", " ", "of", " ", "nondimensional", " ", 
      "Euler", " ", "equations", " ", "in", " ", "traveling", " ", 
      "frame"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"k", ",", "\[Sigma]"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["c", "0"]}], "*", "k"}], "+", 
       RowBox[{"\[Sigma]", "*", 
        RowBox[{"\[Omega]", "[", "k", "]"}]}]}]}], " ", ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]", " ", ":", " ", 
     RowBox[{
     "indicates", " ", "branch", " ", "of", " ", "dispersion", " ", 
      "relation"}]}], ",", " ", 
    RowBox[{
     RowBox[{"\[Sigma]", " ", "=", " ", 
      RowBox[{"+", 
       RowBox[{"/", 
        RowBox[{"-", " ", "1"}]}]}]}], ";"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "g"], " ", ":", " ", 
     RowBox[{
     "group", " ", "velocity", " ", "of", " ", "nondimensional", " ", "Euler",
       " ", "equations", " ", "in", " ", "traveling", " ", "frame"}]}], ",", 
    " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["c", "g"], "[", 
       RowBox[{"k", ",", "\[Sigma]"}], "]"}], " ", "=", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[CapitalOmega]", "[", 
         RowBox[{"k", ",", "\[Sigma]"}], "]"}], ",", "k"}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "correction", " ", "of", 
      " ", "Stokes", " ", "wave", " ", "velocity"}]}], ",", " ", 
    RowBox[{
     RowBox[{"see", " ", "Appendix", " ", "A", " ", "in", " ", "manuscript"}],
      ";"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Eta]", 
      SubscriptBox["S", "j"]], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "correction", " ", "of", 
      " ", "Stokes", " ", "wave", " ", "surface", " ", "displacement"}]}], 
    ",", " ", 
    RowBox[{
     RowBox[{"see", " ", "Appendix", " ", "A", " ", "in", " ", "manuscript"}],
      ";"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["N", 
      RowBox[{"j", ",", "k"}]], ":", " ", 
     RowBox[{
     "kth", " ", "complex", " ", "Fourier", " ", "series", " ", "coefficient",
       " ", "of", " ", 
      SubscriptBox["\[Eta]", 
       SubscriptBox["S", "j"]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", 
      SubscriptBox["S", "j"]], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "correction", " ", "of", 
      " ", "Stokes", " ", "wave", " ", "horizontal", " ", "velocity", " ", 
      "potential", " ", "along", " ", "surface", " ", "displacement"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{
     "kth", " ", "complex", " ", "Fourier", " ", "cosine", " ", "series", " ",
       "coefficient", " ", "of", " ", 
      SubscriptBox["q", 
       SubscriptBox["S", "j"]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"BENJAMIN", "-", 
     RowBox[{"FEIR", " ", "FIGURE"}], "-", "EIGHT"}], "Subsubsection"], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Lambda]", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "eigenvalue", " ", 
      "correction"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "eigenfunction", " ", 
      "correction"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"j", ",", "\[Nu]"}]], " ", ":", " ", 
     RowBox[{
     "coefficient", " ", "of", " ", "nullspace", " ", "component", " ", "of", 
      " ", 
      SubscriptBox["w", "j"], " ", 
      RowBox[{"(", 
       RowBox[{"here", ",", " ", 
        RowBox[{
         RowBox[{"\[Nu]", " ", "can", " ", "be", " ", "zero", " ", "or"}], 
         " ", "+", 
         RowBox[{"/", 
          RowBox[{"-", "1"}]}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Mu]", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "Floquet", " ", 
      "exponent", " ", "correction"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", "j"], " ", ":", " ", 
     RowBox[{
     "inhomogeneous", " ", "forcing", " ", "terms", " ", "in", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "spectral", " ", 
      "problem"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{"gives", " ", "terms", " ", "proportional", " ", "to", " ", 
      RowBox[{"Exp", "[", "\[ImaginaryI]kx", "]"}], " ", "from", " ", 
      SubscriptBox["IHT", "j"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      RowBox[{
       SubscriptBox["g", 
        RowBox[{"\[Sigma]", ",", "k"}]], " "}]], ":", " ", 
     RowBox[{
      SubscriptBox["c", "g"], "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", "0"], "+", "k"}], ",", "\[Sigma]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["FA", "k"], " ", ":", " ", 
     RowBox[{
     "vector", " ", "given", " ", "by", " ", "Fredholm", " ", "alternative", 
      " ", "to", " ", "enforce", " ", "solvability", " ", "condition", " ", 
      "k"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["s", "k"], " ", ":", " ", 
     RowBox[{"Sinh", "[", 
      RowBox[{"\[Alpha]", "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Mu]", "0"], "+", "k"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["C", "k"], " ", ":", " ", 
     RowBox[{"Cosh", "[", 
      RowBox[{"\[Alpha]", "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Mu]", "0"], "+", "k"}], ")"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "j"], " ", ":", " ", 
     RowBox[{"\[Omega]", "[", 
      RowBox[{
       SubscriptBox["\[Mu]", "0"], "+", "j"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{"solvability", " ", "condition", " ", "k", " ", "at", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["partsoln", "j"], " ", ":", " ", 
     RowBox[{"gives", " ", "particular", " ", "solution", " ", "to", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "spectral", " ", 
      "problem", " ", "as", " ", "list", " ", "of", " ", "Fourier", " ", 
      "coefficients"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{
     "1", "st", " ", "component", " ", "of", " ", "the", " ", "kth", " ", 
      "complex", " ", "Fourier", " ", "mode", " ", "of", " ", "the", " ", 
      "particular", " ", "solution", " ", "at", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{
     "2", "nd", " ", "component", " ", "of", " ", "the", " ", "kth", " ", 
      "complex", " ", "Fourier", " ", "mode", " ", "of", " ", "the", " ", 
      "particular", " ", "solution", " ", "at", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"NOTE", ":", " ", 
    RowBox[{
    "There", " ", "are", " ", "intermediate", " ", "variables", " ", 
     "introduced", " ", "throughout", " ", "the", " ", 
     RowBox[{"notebook", "."}]}]}]}]}]], "Text",
 CellChangeTimes->{{3.835967494378304*^9, 3.8359678405664425`*^9}, {
  3.8359679064696054`*^9, 3.8359684755830774`*^9}, {3.8359685203027396`*^9, 
  3.835968532292381*^9}, {3.835968716470956*^9, 3.8359687271398926`*^9}, {
  3.8359688136680813`*^9, 3.835968832022024*^9}, {3.835968989245056*^9, 
  3.835969023242552*^9}, {3.8359692057747917`*^9, 3.835969236915213*^9}, {
  3.835969284709839*^9, 3.835969294947506*^9}, {3.83596939832705*^9, 
  3.8359695644186897`*^9}, {3.83596961519704*^9, 3.8359696679086685`*^9}, {
  3.835971565845647*^9, 3.835971593456355*^9}, {3.835972280078453*^9, 
  3.835972281565465*^9}, {3.8359740599094815`*^9, 3.8359740601148305`*^9}, {
  3.86318389854415*^9, 3.863184003771593*^9}, {3.863184044776894*^9, 
  3.863184051142346*^9}, {3.8631845798794107`*^9, 3.86318459432565*^9}, {
  3.8631913570395746`*^9, 
  3.8631913806485662`*^9}},ExpressionUUID->"10a3943b-13f9-458e-82bd-\
611a36f68f39"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"I", ".", " ", "Useful"}], " ", "Functions"}], 
   "Section"]}]], "Input",
 CellChangeTimes->{{3.819238884200651*^9, 3.8192389095370846`*^9}, {
  3.8224001988803053`*^9, 3.8224002008840256`*^9}, {3.822401321523795*^9, 
  3.8224013249174266`*^9}},ExpressionUUID->"61b489d5-7900-4c42-8362-\
0bd039a8a29f"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Linearized", " ", "dispersion", " ", "relation", " ", "of", " ", "WWP"}],
     ",", " ", 
    RowBox[{
     SubscriptBox["c", "0"], " ", "=", " ", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalOmega]", "[", 
      RowBox[{"k_", ",", "\[Sigma]_"}], "]"}], ":=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "0"]}], "*", "k"}], "+", 
      RowBox[{"\[Sigma]", "*", 
       RowBox[{"\[Omega]", "[", "k", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "k_", "]"}], " ", ":=", " ", 
     RowBox[{
      RowBox[{"Sign", "[", "k", "]"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"k", "*", 
        RowBox[{"Tanh", "[", 
         RowBox[{"\[Alpha]", "*", "k"}], "]"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "*", " ", "nth", " ", "order", " ", "Floquet", " ", "differentiation", 
      " ", "of", " ", 
      RowBox[{"f", ".", " ", "Computes"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Mu]", "0"], "+", 
         SubscriptBox["D", "x"]}], ")"}], "^", 
       RowBox[{"n", "[", 
        RowBox[{"f", "[", "x", "]"}], "]"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"where", " ", 
       SubscriptBox["D", "x"]}], " ", "=", " ", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[ImaginaryI]d", "x"], "."}]}]}]}], " ", "**)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Fdiff", "[", 
      RowBox[{"f_", ",", "n_"}], "]"}], " ", ":=", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"n", "\[Equal]", "0"}], ",", "f", ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Nu]", "-", 
               RowBox[{"\[ImaginaryI]", "*", "diff"}]}], ")"}], "^", "n"}], 
            "]"}], " ", "/.", " ", 
           RowBox[{
            RowBox[{"diff", "^", "j_"}], " ", "\[RuleDelayed]", " ", 
            RowBox[{"D", "[", 
             RowBox[{"f", ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "j"}], "}"}]}], "]"}]}]}], " ", "//.", " ", 
          RowBox[{"diff", " ", "\[Rule]", " ", 
           RowBox[{"D", "[", 
            RowBox[{"f", ",", "x"}], "]"}]}]}], "//.", " ", 
         RowBox[{
          RowBox[{"\[Nu]", "^", "n"}], " ", "\[Rule]", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "^", "n"}], "*", "f"}]}]}], " ", "//.",
         " ", 
        RowBox[{"\[Nu]", " ", "\[Rule]", " ", 
         SubscriptBox["\[Mu]", "0"]}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Expand", " ", "q", " ", "into", " ", "a", " ", "complex", " ", 
     "Fourier", " ", 
     RowBox[{"sum", ".", " ", "Useful"}], " ", "when", " ", "q", " ", "is", 
     " ", "a", " ", "product", " ", "of", " ", "sinusoidal", " ", 
     RowBox[{"functions", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FourierSum", "[", "q_", "]"}], " ", ":=", " ", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"TrigToExp", "[", "q", "]"}], "]"}], " ", "/.", " ", 
      RowBox[{
       RowBox[{"Exp", "[", "\[Theta]_", "]"}], "\[RuleDelayed]", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"Simplify", "[", "\[Theta]", "]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "*", " ", "Creates", " ", "list", " ", "of", " ", "complex", " ", 
      "Fourier", " ", "coefficients", " ", "of", " ", "a", " ", "generic", 
      " ", "function", " ", "q", " ", "without", " ", "using", " ", "the", 
      " ", "expensive", " ", "built"}], "-", 
     RowBox[{"in", " ", "FourierCoefficient", " ", "Mathematica", " ", 
      RowBox[{"function", ".", " ", "Must"}], " ", "provide", " ", "a", " ", 
      "list", " ", "of", " ", "desired", " ", "Fourier", " ", "modes", " ", 
      RowBox[{"k", ".", " ", "List"}], " ", "must", "\[IndentingNewLine]", 
      "be", " ", "ordered", " ", "from", " ", "least", " ", "to", " ", 
      RowBox[{"greatest", "."}]}]}], "  ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NCoefficient", "[", 
      RowBox[{"q_", ",", "k_"}], "]"}], " ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"vecpoly", "=", 
        RowBox[{"Expand", "[", " ", 
         RowBox[{
          RowBox[{"z", "^", 
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"k", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"TrigToExp", "[", "q", "]"}], " ", "/.", " ", 
             RowBox[{
              RowBox[{"Exp", "[", "\[Theta]_", "]"}], "\[RuleDelayed]", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"Simplify", "[", "\[Theta]", "]"}], "]"}]}]}], "/.", 
            " ", 
            RowBox[{
             RowBox[{"Exp", "[", "y_", "]"}], " ", "\[RuleDelayed]", " ", 
             RowBox[{"z", "^", 
              RowBox[{"(", 
               RowBox[{"Simplify", "[", 
                RowBox[{
                 RowBox[{"y", "/", "\[ImaginaryI]"}], "/", "x"}], "]"}], 
               ")"}]}]}]}], ")"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FourierCoeff", " ", "=", " ", 
        RowBox[{
         RowBox[{"{", "vecpoly", "}"}], " ", "//.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "2"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"FourierCoeffj", " ", "=", " ", 
           RowBox[{"Coefficient", "[", 
            RowBox[{"vecpoly", ",", 
             RowBox[{"z", "^", 
              RowBox[{"(", 
               RowBox[{"j", "-", "1"}], ")"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"FourierCoeff", " ", "=", " ", 
           RowBox[{"Append", "[", 
            RowBox[{"FourierCoeff", ",", "FourierCoeffj"}], "]"}]}]}]}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "q", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", ">", " ", "1"}], ",", 
         RowBox[{"FinalFourierCoeff", "=", 
          RowBox[{"Transpose", "[", "FourierCoeff", "]"}]}], ",", 
         RowBox[{"FinalFourierCoeff", " ", "=", " ", "FourierCoeff"}]}], 
        "]"}], ";", "\[IndentingNewLine]", "FinalFourierCoeff"}], ")"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "q", " ", "must", " ", "be", " ", "a", " ", 
     RowBox[{"vector", ".", " ", "k"}], " ", "must", " ", "be", " ", "a", " ",
      "vector", " ", "of", " ", "sequential", " ", 
     RowBox[{"integers", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Generate", " ", "the", " ", "nth", " ", "order", " ", 
     "modulation", " ", "of", " ", "a", " ", "list", " ", "of", " ", 
     "wavenumbers", " ", 
     RowBox[{"k", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GenModulate", "[", 
      RowBox[{"k_", ",", "n_"}], "]"}], " ", ":=", "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"Smat", ",", "Pmat"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Smat", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Pmat", " ", "=", " ", 
           RowBox[{"Union", "[", 
            RowBox[{"Smat", ",", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "+", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"-", "n"}], ",", "n"}], "]"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Smat", " ", "=", " ", "Pmat"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "Pmat"}], ")"}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
      "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ",
        "of", " ", "nth"}], "-", 
      RowBox[{"order", " ", 
       RowBox[{"problem", ".", " ", "Importantly"}]}]}], ",", " ", 
     RowBox[{
     "IHT", " ", "are", " ", "the", " ", "inhomogeneous", " ", "terms", " ", 
      "after", " ", "applying", " ", "the", " ", "row", " ", "operation", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", 
            SubscriptBox["C", 
             RowBox[{"k", "[", 
              RowBox[{"[", "j", "]"}], "]"}]]}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "."}]}]}], "**)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"partsoln", "[", 
      RowBox[{"IHT_", ",", "k_", ",", "n_"}], "]"}], ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "Smat", "]"}], ";", " ", 
       RowBox[{"Smat", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{"j", " ", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Amat", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", "*", 
                  SubscriptBox["c", "0"], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["\[Mu]", "0"], "+", 
                    RowBox[{"k", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], "-", 
                 SubscriptBox["\[Lambda]", "0"]}], ")"}], ",", 
               RowBox[{
                SubscriptBox["\[Omega]", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]], "^", "2"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", "*", 
                 SubscriptBox["c", "0"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "0"], "+", 
                   RowBox[{"k", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], "-", 
                SubscriptBox["\[Lambda]", "0"]}]}], "}"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           SubscriptBox["w", 
            RowBox[{"n", ",", 
             RowBox[{"k", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]], " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"n", ",", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]], ",", 
             SubscriptBox["\[Phi]", 
              RowBox[{"n", ",", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           SubscriptBox["soln", "j"], " ", "=", " ", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Simplify", "[", 
             RowBox[{"Solve", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Amat", ".", 
                  SubscriptBox["w", 
                   RowBox[{"n", ",", 
                    RowBox[{"k", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]]}], " ", "-", " ", 
                 RowBox[{"IHT", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "j"}], "]"}], "]"}]}], "\[Equal]", 
                "0"}], ",", 
               SubscriptBox["w", 
                RowBox[{"n", ",", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]]}], "]"}], "]"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"Smat", "=", 
           RowBox[{"Append", "[", 
            RowBox[{"Smat", ",", 
             SubscriptBox["soln", "j"]}], "]"}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "Smat"}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.819238914040369*^9, 3.819238931335683*^9}, {
   3.8195464364800186`*^9, 3.819546437366968*^9}, {3.822400204731432*^9, 
   3.822400265579567*^9}, {3.822400376288105*^9, 3.8224004688432393`*^9}, {
   3.822400513730723*^9, 3.8224005238869734`*^9}, {3.8224005614484057`*^9, 
   3.8224005806500664`*^9}, {3.8224006437796993`*^9, 3.82240064763846*^9}, {
   3.822400796629356*^9, 3.8224008397709475`*^9}, {3.822400968234866*^9, 
   3.822401143844735*^9}, {3.822401191960985*^9, 3.8224012005366144`*^9}, {
   3.8224012747947936`*^9, 3.8224013172608485`*^9}, {3.822401400212161*^9, 
   3.822401412422224*^9}, {3.8224029097501497`*^9, 3.822402940200775*^9}, {
   3.822402983006024*^9, 3.822403105862302*^9}, {3.8224031750596266`*^9, 
   3.822403212563414*^9}, {3.8224034468734493`*^9, 3.82240349363069*^9}, {
   3.8224036573242817`*^9, 3.822403793330802*^9}, {3.822403846361758*^9, 
   3.8224039801203933`*^9}, {3.822404018451494*^9, 3.822404020980733*^9}, {
   3.8224049152297297`*^9, 3.8224049303591084`*^9}, {3.822405839781583*^9, 
   3.8224058611767483`*^9}, {3.8224066746439667`*^9, 3.822406737839921*^9}, {
   3.822406789771857*^9, 3.8224068397005253`*^9}, {3.8224120420444183`*^9, 
   3.8224120468615227`*^9}, {3.8224120830427165`*^9, 3.8224121492771597`*^9}, 
   3.8224122038556404`*^9, {3.822412269171126*^9, 3.822412298934534*^9}, {
   3.8224131826171837`*^9, 3.822413182913395*^9}, {3.8224133316649065`*^9, 
   3.822413383852585*^9}, {3.822413450419058*^9, 3.82241346196122*^9}, 
   3.822417682769392*^9, {3.8224944861133146`*^9, 3.8224944961760607`*^9}, {
   3.823723706653502*^9, 3.8237237191919727`*^9}, {3.82372378891661*^9, 
   3.8237238688079653`*^9}, {3.823724130870166*^9, 3.8237242041876087`*^9}, {
   3.8237245046062384`*^9, 3.823724594830293*^9}, {3.823724711792119*^9, 
   3.823724734967276*^9}, {3.823724771614996*^9, 3.823724775651231*^9}, {
   3.823725148180735*^9, 3.823725151117918*^9}, 3.823725181684894*^9, {
   3.8237252268556104`*^9, 3.8237252479182115`*^9}, {3.823725367375496*^9, 
   3.8237253956901608`*^9}, {3.823726006652844*^9, 3.8237260363304825`*^9}, {
   3.824491256633321*^9, 3.824491373689952*^9}, {3.824491419554398*^9, 
   3.8244914384867983`*^9}, {3.8245034379100485`*^9, 
   3.8245034381813707`*^9}, {3.8359740806924005`*^9, 3.835974081461605*^9}, {
   3.8365847844020863`*^9, 3.836584790220801*^9}, {3.836584827350713*^9, 
   3.836584836404088*^9}, {3.836585140177179*^9, 3.8365851430963326`*^9}, {
   3.836604490590989*^9, 3.83660461636343*^9}, {3.83660470424998*^9, 
   3.8366048377514863`*^9}, 3.836604892670024*^9, {3.8366050492332945`*^9, 
   3.8366050610037947`*^9}, {3.836605820953572*^9, 3.836605826007352*^9}, {
   3.836605917961069*^9, 3.836605948509991*^9}, 3.836606418193098*^9, {
   3.836606492402521*^9, 3.836606549159972*^9}, {3.8366065846974983`*^9, 
   3.836606656416557*^9}, {3.836606759498496*^9, 3.8366067871708856`*^9}, {
   3.8366071352611895`*^9, 3.83660715646146*^9}, {3.858890026546306*^9, 
   3.8588901045293665`*^9}, {3.8588901794449267`*^9, 
   3.8588901796674833`*^9}, {3.8588902361473956`*^9, 
   3.8588902467489004`*^9}, {3.863191396976606*^9, 
   3.8631914127917547`*^9}},ExpressionUUID->"26298b66-70e7-4ed1-b515-\
cf00a80d42c4"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"II", ".", " ", "Zeroth"}], "-", 
    RowBox[{"Order", " ", "Problem"}]}], "Section"]}]], "Input",
 CellChangeTimes->{{3.8192416971429358`*^9, 3.8192417128465366`*^9}, {
   3.81939072279646*^9, 3.8193907230712976`*^9}, 
   3.8359740999354234`*^9},ExpressionUUID->"6f25681d-cf72-41ce-9312-\
ef38a2cb0065"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Collided", " ", "eigenvalue", " ", "and", " ", "Floquet", " ", 
    "exponent"}], " ", "**)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Lambda]", "0"], " ", "=", " ", "0"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Mu]", "0"], " ", "=", "0"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Collided", " ", "eigenfunction"}], " ", "**)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "0"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        FractionBox["\[ImaginaryI]", 
         SubscriptBox["c", "0"]]}], "}"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]], "*", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "+", " ", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "*", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        FractionBox[
         RowBox[{"-", "\[ImaginaryI]"}], 
         SubscriptBox["c", "0"]]}], "}"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["FA", 
     RowBox[{"-", "1"}]], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["c", "0"]}]}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["FA", "0"], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["FA", "1"], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", 
       SubscriptBox["c", "0"]}]}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "the", " ", 
     SubscriptBox["L", "0"], " ", "operator", " ", "for", " ", 
     RowBox[{"computations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumL", "0"], "[", 
      RowBox[{"w_", ",", "k_"}], "]"}], " ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FCoeff", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{"w", ",", "k"}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Mu]", "0"], "+", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "*", 
              SubscriptBox["C", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]], "*", 
              RowBox[{"FCoeff", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "j"}], "]"}], "]"}], "*", 
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}]}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Mu]", "0"], "+", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "*", 
             SubscriptBox["s", 
              RowBox[{"k", "[", 
               RowBox[{"[", "j", "]"}], "]"}]], "*", 
             RowBox[{"FCoeff", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "j"}], "]"}], "]"}], "*", 
             RowBox[{"Exp", "[", 
              RowBox[{"\[ImaginaryI]", "*", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "1", ",", 
              RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{"Fdiff", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], 
        "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "the", " ", 
     SubscriptBox["R", "0"], " ", "operator", " ", "for", " ", 
     RowBox[{"computations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumR", "0"], "[", 
      RowBox[{"w_", ",", "k_"}], "]"}], "  ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FCoeff", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{"w", ",", "k"}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["C", 
             RowBox[{"k", "[", 
              RowBox[{"[", "j", "]"}], "]"}]], "*", 
            RowBox[{"FCoeff", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "j"}], "]"}], "]"}], "*", 
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"k", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"w", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "the", " ", 
     SuperscriptBox[
      SubscriptBox["R", "0"], 
      RowBox[{"-", "1"}]], " ", "operator", " ", "for", " ", 
     RowBox[{"computations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumInvR", "0"], "[", 
      RowBox[{"w_", ",", "k_"}], "]"}], "  ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FCoeff", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{"w", ",", "k"}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{"(", 
              SubscriptBox["C", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]], ")"}]}], "*", 
            RowBox[{"FCoeff", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "j"}], "]"}], "]"}], "*", 
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"k", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"w", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.819241725315444*^9, 3.819241780317752*^9}, {
   3.819241820909971*^9, 3.819241880767762*^9}, {3.81924193786286*^9, 
   3.819242004007763*^9}, {3.8192420767412663`*^9, 3.819242265022035*^9}, {
   3.8192424497358303`*^9, 3.8192424847329297`*^9}, {3.819242527149505*^9, 
   3.8192425297975416`*^9}, {3.8192425896535316`*^9, 3.819242589900633*^9}, {
   3.8192426405493617`*^9, 3.8192427228933077`*^9}, 3.819243090465315*^9, {
   3.819243966027495*^9, 3.8192441850177164`*^9}, {3.8192442233623295`*^9, 
   3.8192443454060345`*^9}, {3.8192451593399415`*^9, 3.819245168971573*^9}, {
   3.8192453376221175`*^9, 3.819245530286437*^9}, 3.8193860160488167`*^9, 
   3.8193862575714035`*^9, {3.8193934714913263`*^9, 3.8193934818381205`*^9}, {
   3.819393612432806*^9, 3.819393659366683*^9}, {3.8193936969108567`*^9, 
   3.8193937321746206`*^9}, {3.8193937781981564`*^9, 
   3.8193937844859223`*^9}, {3.819393884837757*^9, 3.819393897500101*^9}, {
   3.8193942219969997`*^9, 3.81939424345294*^9}, {3.819394334069317*^9, 
   3.819394340621751*^9}, {3.8193944729643064`*^9, 3.819394479732456*^9}, {
   3.8193945564125004`*^9, 3.8193947452843237`*^9}, {3.819394779724778*^9, 
   3.819394807531539*^9}, {3.819394844108669*^9, 3.8193948462432384`*^9}, {
   3.8193948826311717`*^9, 3.819394935005147*^9}, {3.819394966796569*^9, 
   3.8193954904674807`*^9}, {3.8193955261707487`*^9, 3.819395531162109*^9}, {
   3.819395564217187*^9, 3.819395591039777*^9}, {3.81939564534703*^9, 
   3.8193957109615936`*^9}, {3.8193970275927553`*^9, 3.819397156072828*^9}, {
   3.8193971918036613`*^9, 3.8193972066234303`*^9}, {3.8193974646958485`*^9, 
   3.8193974662069902`*^9}, {3.8193978756394124`*^9, 
   3.8193978892054744`*^9}, {3.8193979205189404`*^9, 3.819397929326214*^9}, {
   3.8193979768349285`*^9, 3.8193980236286283`*^9}, {3.819398087755932*^9, 
   3.819398094249878*^9}, {3.8193982008704767`*^9, 3.8193982793351336`*^9}, {
   3.8193983389502335`*^9, 3.819398417954151*^9}, {3.8193984609410615`*^9, 
   3.819398461243624*^9}, {3.8193985407425766`*^9, 3.819398541086712*^9}, {
   3.8193985799271455`*^9, 3.8193985892298875`*^9}, {3.8193987468121357`*^9, 
   3.819398766172119*^9}, {3.8193989662617044`*^9, 3.8193989677593946`*^9}, {
   3.8193997606060686`*^9, 3.8193997670043573`*^9}, {3.8193998123887386`*^9, 
   3.8193999166597643`*^9}, {3.8193999739829693`*^9, 
   3.8194000091778994`*^9}, {3.8194000701000175`*^9, 3.819400264466553*^9}, {
   3.8194003037622395`*^9, 3.8194003516021223`*^9}, {3.819400593733073*^9, 
   3.819400611272956*^9}, {3.819400727297849*^9, 3.8194008447434497`*^9}, {
   3.819401275286027*^9, 3.819401275441537*^9}, {3.819401314365915*^9, 
   3.8194013147369623`*^9}, {3.8194023849549513`*^9, 
   3.8194024008597975`*^9}, {3.819404250984436*^9, 3.8194042610146008`*^9}, {
   3.819476965164923*^9, 3.8194769660286555`*^9}, {3.8194770026877775`*^9, 
   3.819477117859742*^9}, {3.819477265406021*^9, 3.819477308718108*^9}, {
   3.8194780514124784`*^9, 3.8194780540653524`*^9}, {3.819478527963314*^9, 
   3.8194785319452143`*^9}, {3.8195005102511263`*^9, 
   3.8195005239531126`*^9}, {3.8195009724493413`*^9, 3.819500999481338*^9}, {
   3.819557746711507*^9, 3.8195577743964424`*^9}, {3.8195808523771687`*^9, 
   3.8195808567371273`*^9}, {3.823723489928599*^9, 3.82372359530783*^9}, {
   3.8237249708067093`*^9, 3.8237250677365975`*^9}, {3.823725111276389*^9, 
   3.8237251307475595`*^9}, 3.823725307458025*^9, {3.8237253457045956`*^9, 
   3.8237253512635527`*^9}, {3.8237254234278216`*^9, 
   3.8237254240511613`*^9}, {3.8237254874378753`*^9, 3.823725491347413*^9}, {
   3.823725673717486*^9, 3.8237256743208785`*^9}, {3.8237260654765463`*^9, 
   3.8237260725931845`*^9}, {3.8237261226204233`*^9, 3.8237261648418756`*^9}, 
   3.8237263322948494`*^9, {3.82372652961141*^9, 3.8237265311453238`*^9}, {
   3.8237265776380863`*^9, 3.8237266520875063`*^9}, {3.8237266920911384`*^9, 
   3.823726695093218*^9}, {3.8237268115809174`*^9, 3.8237268230539618`*^9}, {
   3.823726994237191*^9, 3.8237270503894405`*^9}, {3.823727085904131*^9, 
   3.8237271649755945`*^9}, {3.8237272223356905`*^9, 
   3.8237272246285973`*^9}, {3.823727289388541*^9, 3.82372729080871*^9}, {
   3.823727456486214*^9, 3.823727532611391*^9}, {3.8237276233388605`*^9, 
   3.823727656394708*^9}, {3.823727725597249*^9, 3.8237277258286057`*^9}, {
   3.8237280287677436`*^9, 3.823728054772077*^9}, {3.823728100591852*^9, 
   3.8237281767708983`*^9}, {3.8237282514942336`*^9, 3.823728298289312*^9}, {
   3.823728336951212*^9, 3.8237283903888693`*^9}, {3.8237284706927943`*^9, 
   3.8237285010280075`*^9}, 3.823728701431844*^9, {3.8237333651666155`*^9, 
   3.82373336532323*^9}, {3.824222377622967*^9, 3.8242225554769125`*^9}, {
   3.824222614564618*^9, 3.8242226313960934`*^9}, {3.8242235899894223`*^9, 
   3.824223716980404*^9}, {3.824224071549379*^9, 3.824224202040768*^9}, {
   3.824309675709446*^9, 3.8243096995506935`*^9}, {3.8243098528120003`*^9, 
   3.824309875685455*^9}, {3.8245036045742826`*^9, 3.824503605103162*^9}, {
   3.8245054021703*^9, 3.824505402656122*^9}, {3.824505511842555*^9, 
   3.824505538125615*^9}, {3.835974109858841*^9, 3.8359741376892676`*^9}, {
   3.836581105254405*^9, 3.8365812646448736`*^9}, {3.836581479425105*^9, 
   3.8365814832604265`*^9}, {3.8365845399059563`*^9, 
   3.8365845586625633`*^9}, {3.8365920462990603`*^9, 
   3.8365920606611843`*^9}, {3.8366041382250233`*^9, 
   3.8366041383675156`*^9}, {3.8366052910455484`*^9, 3.8366052912431755`*^9}, 
   3.836605644374127*^9, {3.8568995706156154`*^9, 3.8568995895111237`*^9}, 
   3.8569109282001424`*^9, {3.863184105491251*^9, 3.863184119921829*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"bb7ca26d-39a4-42ca-8009-40625df1efdb"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, 3.8544769695634966`*^9, 
   3.8544809125166826`*^9, 3.854489782813448*^9, 3.8557501145218997`*^9, 
   3.8568696295368013`*^9, 3.8568696612923574`*^9, 3.856899614533121*^9, 
   3.856910937439107*^9, 3.8569649377597036`*^9, 3.857066739373487*^9, 
   3.858086032706713*^9, {3.858093392860924*^9, 3.8580934135954895`*^9}, 
   3.8586895262163124`*^9, 3.85877457077141*^9, 3.858867888235429*^9, 
   3.8588901529171686`*^9, 3.85889018651398*^9, 3.8589477408441324`*^9, 
   3.858966818411413*^9, 3.8589791884237385`*^9, 3.859027101432434*^9, 
   3.859040745930163*^9, 3.859047862491076*^9, 3.859389291053173*^9, 
   3.860107244203229*^9, 3.860107467501151*^9, 3.860781928085486*^9, 
   3.860870048333398*^9, 3.8609542473992662`*^9, 3.8610292539956756`*^9, 
   3.861135207488555*^9, 3.8631841250820837`*^9, 3.863187231841095*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"ae085246-2917-4add-81f7-10ee42bce23f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, 3.8544769695634966`*^9, 
   3.8544809125166826`*^9, 3.854489782813448*^9, 3.8557501145218997`*^9, 
   3.8568696295368013`*^9, 3.8568696612923574`*^9, 3.856899614533121*^9, 
   3.856910937439107*^9, 3.8569649377597036`*^9, 3.857066739373487*^9, 
   3.858086032706713*^9, {3.858093392860924*^9, 3.8580934135954895`*^9}, 
   3.8586895262163124`*^9, 3.85877457077141*^9, 3.858867888235429*^9, 
   3.8588901529171686`*^9, 3.85889018651398*^9, 3.8589477408441324`*^9, 
   3.858966818411413*^9, 3.8589791884237385`*^9, 3.859027101432434*^9, 
   3.859040745930163*^9, 3.859047862491076*^9, 3.859389291053173*^9, 
   3.860107244203229*^9, 3.860107467501151*^9, 3.860781928085486*^9, 
   3.860870048333398*^9, 3.8609542473992662`*^9, 3.8610292539956756`*^9, 
   3.861135207488555*^9, 3.8631841250820837`*^9, 3.8631872318567133`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"ad931708-56c8-4920-898b-ea4fe474c915"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], 
     SubscriptBox["c", "0"]], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "0"}]], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], 
     SubscriptBox["c", "0"]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, 3.8544769695634966`*^9, 
   3.8544809125166826`*^9, 3.854489782813448*^9, 3.8557501145218997`*^9, 
   3.8568696295368013`*^9, 3.8568696612923574`*^9, 3.856899614533121*^9, 
   3.856910937439107*^9, 3.8569649377597036`*^9, 3.857066739373487*^9, 
   3.858086032706713*^9, {3.858093392860924*^9, 3.8580934135954895`*^9}, 
   3.8586895262163124`*^9, 3.85877457077141*^9, 3.858867888235429*^9, 
   3.8588901529171686`*^9, 3.85889018651398*^9, 3.8589477408441324`*^9, 
   3.858966818411413*^9, 3.8589791884237385`*^9, 3.859027101432434*^9, 
   3.859040745930163*^9, 3.859047862491076*^9, 3.859389291053173*^9, 
   3.860107244203229*^9, 3.860107467501151*^9, 3.860781928085486*^9, 
   3.860870048333398*^9, 3.8609542473992662`*^9, 3.8610292539956756`*^9, 
   3.861135207488555*^9, 3.8631841250820837`*^9, 3.8631872318723326`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"a66bab6a-6bf2-421f-b51e-38a3af4ab86f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["c", "0"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, 3.8544769695634966`*^9, 
   3.8544809125166826`*^9, 3.854489782813448*^9, 3.8557501145218997`*^9, 
   3.8568696295368013`*^9, 3.8568696612923574`*^9, 3.856899614533121*^9, 
   3.856910937439107*^9, 3.8569649377597036`*^9, 3.857066739373487*^9, 
   3.858086032706713*^9, {3.858093392860924*^9, 3.8580934135954895`*^9}, 
   3.8586895262163124`*^9, 3.85877457077141*^9, 3.858867888235429*^9, 
   3.8588901529171686`*^9, 3.85889018651398*^9, 3.8589477408441324`*^9, 
   3.858966818411413*^9, 3.8589791884237385`*^9, 3.859027101432434*^9, 
   3.859040745930163*^9, 3.859047862491076*^9, 3.859389291053173*^9, 
   3.860107244203229*^9, 3.860107467501151*^9, 3.860781928085486*^9, 
   3.860870048333398*^9, 3.8609542473992662`*^9, 3.8610292539956756`*^9, 
   3.861135207488555*^9, 3.8631841250820837`*^9, 3.8631872318879533`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"1c21aef7-ef9a-4e6a-835d-797d069f45c4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, 3.8544769695634966`*^9, 
   3.8544809125166826`*^9, 3.854489782813448*^9, 3.8557501145218997`*^9, 
   3.8568696295368013`*^9, 3.8568696612923574`*^9, 3.856899614533121*^9, 
   3.856910937439107*^9, 3.8569649377597036`*^9, 3.857066739373487*^9, 
   3.858086032706713*^9, {3.858093392860924*^9, 3.8580934135954895`*^9}, 
   3.8586895262163124`*^9, 3.85877457077141*^9, 3.858867888235429*^9, 
   3.8588901529171686`*^9, 3.85889018651398*^9, 3.8589477408441324`*^9, 
   3.858966818411413*^9, 3.8589791884237385`*^9, 3.859027101432434*^9, 
   3.859040745930163*^9, 3.859047862491076*^9, 3.859389291053173*^9, 
   3.860107244203229*^9, 3.860107467501151*^9, 3.860781928085486*^9, 
   3.860870048333398*^9, 3.8609542473992662`*^9, 3.8610292539956756`*^9, 
   3.861135207488555*^9, 3.8631841250820837`*^9, 3.8631872318879533`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"090d13ec-2a18-43f0-bad9-3497cdd9c2c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    SubscriptBox["c", "0"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, 3.8544769695634966`*^9, 
   3.8544809125166826`*^9, 3.854489782813448*^9, 3.8557501145218997`*^9, 
   3.8568696295368013`*^9, 3.8568696612923574`*^9, 3.856899614533121*^9, 
   3.856910937439107*^9, 3.8569649377597036`*^9, 3.857066739373487*^9, 
   3.858086032706713*^9, {3.858093392860924*^9, 3.8580934135954895`*^9}, 
   3.8586895262163124`*^9, 3.85877457077141*^9, 3.858867888235429*^9, 
   3.8588901529171686`*^9, 3.85889018651398*^9, 3.8589477408441324`*^9, 
   3.858966818411413*^9, 3.8589791884237385`*^9, 3.859027101432434*^9, 
   3.859040745930163*^9, 3.859047862491076*^9, 3.859389291053173*^9, 
   3.860107244203229*^9, 3.860107467501151*^9, 3.860781928085486*^9, 
   3.860870048333398*^9, 3.8609542473992662`*^9, 3.8610292539956756`*^9, 
   3.861135207488555*^9, 3.8631841250820837`*^9, 3.8631872319035716`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"2698a9ba-0584-4517-91e0-ba10d44064f3"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"III", ".", " ", "First"}], "-", 
   RowBox[{"Order", " ", "Problem"}]}], "Section"]], "Input",
 CellChangeTimes->{{3.819386261393108*^9, 3.819386340323662*^9}, {
  3.8193863767831154`*^9, 3.819386406608477*^9}, {3.819386445647776*^9, 
  3.819386467276102*^9}, {3.8193865065371904`*^9, 3.819386513284619*^9}, {
  3.81938661082977*^9, 3.8193866286717334`*^9}, {3.8193869302444153`*^9, 
  3.8193869465465*^9}, {3.81939077649224*^9, 3.8193907810907793`*^9}, {
  3.8193908442990108`*^9, 3.8193908519618716`*^9}, {3.8359741464224243`*^9, 
  3.835974148141134*^9}},ExpressionUUID->"d7bf25bc-27e6-4b59-a0f4-\
230ee6d5c3b8"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Define", " ", "operator", " ", 
    SubscriptBox["L", "1"], " ", "for", " ", "numerical", " ", 
    RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumL", "1"], "[", 
      RowBox[{"w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", "=", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", "*", 
                 SubscriptBox["c", "0"], "*", 
                 SubscriptBox["\[Mu]", "1"], "*", 
                 SubscriptBox["C", "\[Kappa]"]}], "+", 
                RowBox[{"\[Kappa]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    SubscriptBox["C", "\[Kappa]"], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["c", "0"], "*", 
                    SubscriptBox["s", "\[Kappa]"], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}]}], ")"}]}]}], 
               ")"}], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "+", 
             RowBox[{
              SubscriptBox["c", "0"], "*", 
              SubscriptBox["s", "\[Kappa]"], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Alpha]", "*", 
                 SubscriptBox["\[Mu]", "1"]}], "+", 
                RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["s", "\[Kappa]"], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "-", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["C", "\[Kappa]"], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Alpha]", "*", 
                 SubscriptBox["\[Mu]", "1"]}], "+", 
                RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}],
            ",", "kmod"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[ImaginaryI]", "*", 
            RowBox[{
             SubscriptBox["c", "0"], "^", "2"}], "*", 
            RowBox[{"D", "[", 
             RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], ")"}], 
          "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["c", "0"], "*", "\[ImaginaryI]", "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", 
            RowBox[{"\[ImaginaryI]", "*", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}], "*", 
             RowBox[{"Fdiff", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}], 
           ")"}]}]}], "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Define", " ", "operator", " ", 
     SubscriptBox["R", "1"], " ", "for", " ", "numerical", " ", 
     RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumR", "1"], "[", 
      RowBox[{"w_", ",", "k_", ",", "\[Eta]1_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["s", "\[Kappa]"], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Alpha]", "*", 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Kappa]", "+", 
                  SubscriptBox["\[Mu]", "0"]}], ")"}], "*", "\[Eta]1"}]}], 
              ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], " ", ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "*", 
          RowBox[{"D", "[", 
           RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.823730120763512*^9, 3.823730235597124*^9}, {
   3.823730297873085*^9, 3.823730569851227*^9}, {3.8237307437952037`*^9, 
   3.8237309187067013`*^9}, {3.82373101994392*^9, 3.8237310701656094`*^9}, {
   3.8237311040267525`*^9, 3.8237311568496213`*^9}, {3.823731222739846*^9, 
   3.823731301577722*^9}, {3.823731407874816*^9, 3.8237314419051375`*^9}, {
   3.823731490744588*^9, 3.823731566025501*^9}, {3.823731651889974*^9, 
   3.82373170288583*^9}, {3.8237318562493715`*^9, 3.823731890439183*^9}, {
   3.823731969804457*^9, 3.8237319698982053`*^9}, {3.823732130622611*^9, 
   3.8237321449286795`*^9}, {3.823732498530941*^9, 3.823732567507845*^9}, {
   3.82373319656919*^9, 3.823733263743413*^9}, {3.823733307261401*^9, 
   3.8237333169853935`*^9}, 3.823733350270734*^9, {3.823778905764366*^9, 
   3.823778905900287*^9}, {3.823778971432044*^9, 3.8237789733499284`*^9}, {
   3.823779284442354*^9, 3.8237794124203863`*^9}, {3.823779468524021*^9, 
   3.823779482016163*^9}, {3.8237795210944524`*^9, 3.8237795212081895`*^9}, {
   3.8237797260782633`*^9, 3.8237797682668257`*^9}, {3.8237798155819445`*^9, 
   3.8237798318159637`*^9}, {3.823779863124403*^9, 3.8237798860378265`*^9}, {
   3.8237800945585055`*^9, 3.8237801583974743`*^9}, {3.823780247668363*^9, 
   3.823780310751878*^9}, {3.8237804987338796`*^9, 3.8237806693453407`*^9}, {
   3.823780806984108*^9, 3.823780869645839*^9}, {3.823780902834598*^9, 
   3.82378092715761*^9}, {3.8237810305569916`*^9, 3.823781032573603*^9}, {
   3.823781062842615*^9, 3.8237810737424707`*^9}, {3.823781158719718*^9, 
   3.823781211679963*^9}, {3.823781275077838*^9, 3.8237813942151756`*^9}, {
   3.8237814721516333`*^9, 3.8237814778141394`*^9}, {3.8237816997165055`*^9, 
   3.8237818523151846`*^9}, {3.8237819199033303`*^9, 3.823781939755807*^9}, {
   3.824221025685725*^9, 3.8242210553413143`*^9}, {3.8242246308362293`*^9, 
   3.824224641698037*^9}, {3.8245056056072392`*^9, 3.8245056146543536`*^9}, {
   3.8245056764583616`*^9, 3.8245056768794117`*^9}, {3.8245057170375443`*^9, 
   3.8245057174478517`*^9}, {3.82450576157229*^9, 3.8245057977911625`*^9}, {
   3.824506594937441*^9, 3.8245066627037077`*^9}, {3.8245066987020693`*^9, 
   3.8245067107178335`*^9}, {3.8248232555500517`*^9, 3.824823260218587*^9}, {
   3.8248233009515095`*^9, 3.8248235907565207`*^9}, {3.8248236644271393`*^9, 
   3.824823828149666*^9}, {3.8248247875976887`*^9, 3.824824815037686*^9}, {
   3.824825190319507*^9, 3.8248251906328773`*^9}, {3.8248259284296775`*^9, 
   3.824825943533414*^9}, {3.824826329039048*^9, 3.8248263426086006`*^9}, {
   3.8248265478309298`*^9, 3.8248265489529634`*^9}, {3.8248266406751366`*^9, 
   3.8248266708063064`*^9}, {3.8248268540555153`*^9, 3.824826869778305*^9}, {
   3.8248271091350684`*^9, 3.824827119016425*^9}, {3.8248281864093695`*^9, 
   3.824828197460701*^9}, {3.8359741657780495`*^9, 3.83597417684361*^9}, {
   3.8366072505658493`*^9, 3.8366073002317853`*^9}, {3.8366074283029184`*^9, 
   3.836607469713769*^9}, {3.854477016764945*^9, 3.8544770556152134`*^9}, {
   3.8544770872083364`*^9, 3.8544771551001167`*^9}, {3.8544771897014*^9, 
   3.8544773727677145`*^9}, {3.8544775441699886`*^9, 3.854477545471423*^9}, {
   3.8544805160044365`*^9, 3.8544805294035554`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"72c1437f-4d3a-4b90-9561-e7fa4c6ad3a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", "of", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["A", "0"], "-", 
        SubscriptBox["\[Lambda]", "0"]}], ")"}], 
      SubscriptBox["w", "1"]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], "*", 
       SubscriptBox["w", "0"]}], " ", "+", " ", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["R", "0"], 
        RowBox[{"-", "1"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "0"], 
          SubscriptBox["R", "1"]}], " ", "-", " ", 
         SubscriptBox["L", "1"]}], ")"}], 
       SubscriptBox["w", "0"]}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"where", " ", 
      SubscriptBox["A", "0"]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["R", "0"], 
       RowBox[{"-", "1"}]], 
      RowBox[{
       SubscriptBox["L", "0"], "."}]}]}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["IHT", "1"], "=", 
   RowBox[{"NCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], "*", 
       SubscriptBox["w", "0"]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["NumInvR", "0"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "0"], "*", 
          RowBox[{
           SubscriptBox["NumR", "1"], "[", 
           RowBox[{
            SubscriptBox["w", "0"], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", " ", 
            RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], " ", "-", " ", 
         RowBox[{
          SubscriptBox["NumL", "1"], "[", 
          RowBox[{
           SubscriptBox["w", "0"], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}]}], "]"}]}], " ", ",", 
     RowBox[{"GenModulate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], "]"}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8237317383835154`*^9, 3.823731836881159*^9}, {
   3.823731947571501*^9, 3.8237319781405544`*^9}, {3.8237320364913483`*^9, 
   3.823732045213525*^9}, {3.823732261943244*^9, 3.823732431022925*^9}, {
   3.8237332351411076`*^9, 3.8237332388450155`*^9}, 3.8237789030127716`*^9, {
   3.823779552040561*^9, 3.8237795523108463`*^9}, {3.8237796487870264`*^9, 
   3.823779654983917*^9}, {3.8242208460712194`*^9, 3.8242208497894497`*^9}, {
   3.824220880781387*^9, 3.824221001378784*^9}, {3.8242210864388375`*^9, 
   3.8242211436059675`*^9}, {3.8242212719810658`*^9, 
   3.8242214650057497`*^9}, {3.8242215039419847`*^9, 
   3.8242215477569914`*^9}, {3.8242216586200705`*^9, 
   3.8242216685083485`*^9}, {3.8242220109968233`*^9, 
   3.8242220169249897`*^9}, {3.8242221330660095`*^9, 
   3.8242221335553837`*^9}, {3.824222167255204*^9, 3.8242221677645664`*^9}, {
   3.824222764890852*^9, 3.824222775331682*^9}, {3.8242246737384863`*^9, 
   3.824224703570613*^9}, {3.824224792644012*^9, 3.8242248224024887`*^9}, {
   3.8242249222652297`*^9, 3.824225029964205*^9}, {3.8242262982997694`*^9, 
   3.8242263003123837`*^9}, {3.8248280626165934`*^9, 
   3.8248280668879795`*^9}, {3.835974182025835*^9, 3.835974192586668*^9}, {
   3.836581588538974*^9, 3.8365816072594953`*^9}, 3.8631872175705357`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"8c8a6821-12f1-4f94-8982-29a51960d00f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], 
        SubscriptBox["c", "0"]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       SubscriptBox["C", "0"]]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Lambda]", "1"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], 
        SubscriptBox["c", "0"]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8631872321847315`*^9, 3.8631872323096905`*^9}},
 CellLabel->"Out[20]=",ExpressionUUID->"d7b2f2b3-c2d3-4400-b2ab-6ac87874e587"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", 
    "proportional", " ", "to", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"\[ImaginaryI]", "*", "n", "*", "x"}], "]"}], " ", "and", " ", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{"n", "+", "p"}], ")"}], "*", "x"}], "]"}], "."}]}], " ", 
   "**)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"1", ",", "0"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"1", ",", "1"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8242216715744386`*^9, 3.824221730843285*^9}, {
   3.8242221162148485`*^9, 3.824222124011792*^9}, {3.824222187213083*^9, 
   3.824222252407871*^9}, {3.824222968111846*^9, 3.8242229952590322`*^9}, 
   3.8242268005315742`*^9, 3.8242287250331883`*^9, {3.824231360445175*^9, 
   3.8242313890706234`*^9}, 3.824825466933957*^9, {3.8248255287992907`*^9, 
   3.8248255304825277`*^9}, 3.8248281668796005`*^9, {3.8365816749176326`*^9, 
   3.836581695824127*^9}, {3.863187220616914*^9, 3.8631872226943436`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"3cd7ef22-8d0d-4fbb-9585-e45f2d3b22c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Dot", "[", 
      RowBox[{
       SubscriptBox["IHT", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", 
           RowBox[{"-", "1"}]], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "//.", " ", 
     RowBox[{
      SubscriptBox["s", 
       RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}], "*", 
       SuperscriptBox[
        SubscriptBox["c", "0"], "2"]}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Dot", "[", 
       RowBox[{
        SubscriptBox["IHT", 
         RowBox[{"1", ",", "0"}]], ",", 
        RowBox[{"Refine", "[", 
         RowBox[{
          RowBox[{"Conjugate", "[", 
           SubscriptBox["FA", "0"], "]"}], ",", 
          RowBox[{
           SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
       "]"}], "//.", 
      RowBox[{
       SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["C", "0"], " ", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Dot", "[", 
      RowBox[{
       SubscriptBox["IHT", 
        RowBox[{"1", ",", "1"}]], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", "1"], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "//.", " ", 
     RowBox[{
      SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
      RowBox[{
       SubscriptBox["C", "1"], "*", 
       SuperscriptBox[
        SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.836581752719364*^9, 3.836581832360428*^9}, {
   3.8365818651948013`*^9, 3.836581901782962*^9}, {3.8365821239507875`*^9, 
   3.836582154338666*^9}, {3.836582203014144*^9, 3.836582242250846*^9}, {
   3.836582331899331*^9, 3.836582335293679*^9}, 3.8365852182712235`*^9, {
   3.854489799607934*^9, 3.8544898021537976`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"2acf2d76-8ff7-4cc6-8991-96a6685fcaba"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"]}], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "4"], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", 
      RowBox[{"-", "1"}]}]]}], 
   SubscriptBox["c", "0"]]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+IzN0P/bpr6xrGwk51pM5BmEPWVB9EnPu7QBNGayn/N
QbQJX+2CLUDa+XDsGhCdNk+0fT+QPr/aSfLq9jeOO05yyoPolcs2HLkGpIUk
0iVvA2kn85Y6p11vHP/80lVL3fPGkaXszMliIC3W9i2iEkgv/ndi9WQgvZO3
MOEokLZwOii+fd8bxxKBE2t3Ael3ay0O3N3/xvHZpl1u7AfeOIZJrLhuAqQ7
V2zaZQ+kd7l8vxINpG22mqimAmmFeZ/1soF0zoLyqU1AOsrhtV0nkD6l9GF7
D5DWLxMuMj74xtHt8zrpSYfeONrtOp13+/AbR7Vn2iVsR944SqSFTdIH0hq2
akYhQNpiXdu7diB9fX1fUsGJN44iL0SeFAJpAJpzqsM=
  "],
 CellLabel->"Out[24]=",ExpressionUUID->"65d2b6bc-897b-47aa-807f-c52d82cfe29e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+IzN0P/bpr6xrGwk51pM5BmEPWVB9EnPu7QBNGayn/N
QbQJX+2CLUDa+XDsGhCdNk+0fT+QPr/aSfLq9jeOO05yyoPolcs2HLkGpIUk
0iVvA2kn85Y6p11vHP/80lVL3fPGkaXszMliIC3W9i2iEkgv/ndi9WQgvZO3
MOEokLZwOii+fd8bxxKBE2t3Ael3ay0O3N3/xvHZpl1u7AfeOIZJrLhuAqQ7
V2zaZQ+kd7l8vxINpG22mqimAmmFeZ/1soF0zoLyqU1AOsrhtV0nkD6l9GF7
D5DWLxMuMj74xtHt8zrpSYfeONrtOp13+/AbR7Vn2iVsR944SqSFTdIH0hq2
akYhQNpiXdu7diB9fX1fUsGJN448GaJPCoE0AJa5qjw=
  "],
 CellLabel->"Out[25]=",ExpressionUUID->"834eefa8-6181-45fb-95bd-147c746c22bc"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"]}], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "4"], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "1"}]]}], 
   SubscriptBox["c", "0"]]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+IzN0P/bpr6xrGwk51pM5BmEPWVB9EnPu7QBNGayn/N
QbQJX+2CLUDa+XDsGhCdNk+0fT+QPr/aSfLq9jeOO05yyoPolcs2HLkGpIUk
0iVvA2kn85Y6p11vHP/80lVL3fPGkaXszMliIC3W9i2iEkgv/ndi9WQgvZO3
MOEokLZwOii+fd8bxxKBE2t3Ael3ay0O3N3/xvHZpl1u7AfeOIZJrLhuAqQ7
V2zaZQ+kd7l8vxINpG22mqimAmmFeZ/1soF0zoLyqU1AOsrhtV0nkD6l9GF7
D5DWLxMuMj74xtHt8zrpSYfeONrtOp13+/AbR7Vn2iVsR944SqSFTdIH0hq2
akYhQNpiXdu7diB9fX1fUsGJN46sL0SfFAJpAJoBqrU=
  "],
 CellLabel->"Out[26]=",ExpressionUUID->"e6f425be-4ffd-4d5c-8034-14293c9f8c9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Group", " ", 
    RowBox[{"velocities", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["c", 
     SubscriptBox["g", 
      RowBox[{"1", ",", "1"}]]], "=", "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"\[CapitalOmega]", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Sign", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
           "0"}]}], " ", "//.", " ", 
         RowBox[{"k", " ", "\[Rule]", " ", "1"}]}], " ", "//.", " ", 
        RowBox[{
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
         SuperscriptBox[
          SubscriptBox["c", "0"], "2"]}]}], " ", "//.", " ", 
       RowBox[{
        RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", "-", 
          SuperscriptBox[
           SubscriptBox["c", "0"], "4"]}], "]"}]}]}], "]"}], "]"}]}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]], "=", "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[CapitalOmega]", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["Sign", "\[Prime]",
               MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ",
              "0"}]}], " ", "//.", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{"k", " ", "\[Rule]", " ", 
           RowBox[{"-", "1"}]}]}], " ", "//.", " ", 
         RowBox[{
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
          SuperscriptBox[
           SubscriptBox["c", "0"], "2"]}]}], " ", "//.", " ", 
        RowBox[{
         RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "4"]}], "]"}]}]}], "]"}], "]"}]}], " ", 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}]]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[CapitalOmega]", "[", 
               RowBox[{"k", ",", 
                RowBox[{"-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["Sign", "\[Prime]",
               MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ",
              "0"}]}], " ", "//.", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{"k", " ", "\[Rule]", " ", "1"}]}], " ", "//.", " ", 
         RowBox[{
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
          SuperscriptBox[
           SubscriptBox["c", "0"], "2"]}]}], " ", "//.", " ", 
        RowBox[{
         RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "4"]}], "]"}]}]}], "]"}], "]"}]}], " ", 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}]]], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[CapitalOmega]", "[", 
               RowBox[{"k", ",", 
                RowBox[{"-", "1"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["Sign", "\[Prime]",
               MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ",
              "0"}]}], " ", "//.", " ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{"k", " ", "\[Rule]", " ", 
           RowBox[{"-", "1"}]}]}], " ", "//.", " ", 
         RowBox[{
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
          SuperscriptBox[
           SubscriptBox["c", "0"], "2"]}]}], " ", "//.", " ", 
        RowBox[{
         RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", "\[Rule]", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "4"]}], "]"}]}]}], "]"}], "]"}]}], " ", 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.836582398598183*^9, 3.8365824049908524`*^9}, {
  3.836582457792816*^9, 3.836582621785325*^9}, {3.8365826743470926`*^9, 
  3.836582703285268*^9}, {3.836582783409891*^9, 3.836582828357714*^9}, {
  3.83658286744064*^9, 3.836582872640882*^9}, {3.836582910741265*^9, 
  3.8365829261769195`*^9}, {3.836582983626109*^9, 3.8365830883293867`*^9}, {
  3.836583286578891*^9, 3.8365833113323755`*^9}, {3.836583346952676*^9, 
  3.8365833541905766`*^9}, {3.836583388598711*^9, 3.836583405758993*^9}, {
  3.8365853850054216`*^9, 3.8365853980858016`*^9}, {3.8631841577751045`*^9, 
  3.863184176592404*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"69da2b8c-9366-444c-a49e-0377597252c8"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "\[Alpha]"}], "+", 
    SubsuperscriptBox["c", "0", "2"], "+", 
    RowBox[{"\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "4"]}]}], 
   RowBox[{"2", " ", 
    SubscriptBox["c", "0"]}]]}]], "Output",
 CellChangeTimes->{{3.8365824627656145`*^9, 3.8365826225257907`*^9}, {
   3.836582681426772*^9, 3.8365826909993334`*^9}, 3.8365828308937874`*^9, {
   3.8365828679833493`*^9, 3.8365828738043013`*^9}, 3.8365829270063195`*^9, 
   3.836582995192747*^9, {3.8365830687315016`*^9, 3.8365830902119293`*^9}, 
   3.836583311942136*^9, 3.8365833554727645`*^9, 3.8365848496485233`*^9, 
   3.8365852318533077`*^9, 3.8365853927165995`*^9, 3.8366075513686953`*^9, 
   3.8544775660571423`*^9, 3.8544809364882445`*^9, 3.854489811756353*^9, 
   3.855750137946585*^9, 3.8568696861697397`*^9, 3.8568996944250836`*^9, 
   3.8569110511081295`*^9, 3.8569649614301586`*^9, 3.8570667590816035`*^9, 
   3.8580860796779547`*^9, 3.8580934235172257`*^9, 3.8586895396300144`*^9, 
   3.8587745836097555`*^9, 3.8588679036896806`*^9, 3.858890199842325*^9, 
   3.8589477536615114`*^9, 3.858966828947503*^9, 3.8589791941903567`*^9, 
   3.8590271182231913`*^9, 3.859040761538402*^9, 3.8590478730446243`*^9, 
   3.859389331950571*^9, 3.860107256352744*^9, 3.860107487531872*^9, 
   3.860781946911194*^9, 3.860870049668623*^9, 3.860954260401606*^9, 
   3.8610292667100983`*^9, 3.861135222455783*^9, {3.8631841594324837`*^9, 
   3.8631841776081495`*^9}, 3.863187232903249*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"0aef7135-53d2-495d-88da-24ad74f7d372"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", "Solvability", " ", "conditions"}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{"2", "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["c", "g"]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"1", ",", "1"}]], " ", "=", " ", 
     RowBox[{"2", "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "*", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["c", "g"]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]], " ", "-", " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Dot", "[", 
         RowBox[{
          SubscriptBox["IHT", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], ",", 
          RowBox[{"Refine", "[", 
           RowBox[{
            RowBox[{"Conjugate", "[", 
             SubscriptBox["FA", 
              RowBox[{"-", "1"}]], "]"}], ",", 
            RowBox[{
             SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
         "]"}], "//.", " ", 
        RowBox[{
         SubscriptBox["s", 
          RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["C", 
            RowBox[{"-", "1"}]]}], "*", 
          SuperscriptBox[
           SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"1", ",", "1"}]], " ", "-", " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Dot", "[", 
         RowBox[{
          SubscriptBox["IHT", 
           RowBox[{"1", ",", "1"}]], ",", 
          RowBox[{"Refine", "[", 
           RowBox[{
            RowBox[{"Conjugate", "[", 
             SubscriptBox["FA", "1"], "]"}], ",", 
            RowBox[{
             SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
         "]"}], "//.", " ", 
        RowBox[{
         SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
         RowBox[{
          SubscriptBox["C", "1"], "*", 
          SuperscriptBox[
           SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.836583439607668*^9, 3.8365835949439764`*^9}, 
   3.8365836796547976`*^9, {3.836583755442839*^9, 3.836583768451266*^9}, {
   3.8365850121883926`*^9, 3.836585111392171*^9}, 3.8365852426538963`*^9, {
   3.8365853556649723`*^9, 3.8365853700888042`*^9}, {3.8365856697650404`*^9, 
   3.8365856898831234`*^9}, 3.836585830138629*^9, {3.836586108475399*^9, 
   3.836586149829177*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"f1639467-ce46-425d-974d-6c441f8f5f14"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8365835629728355`*^9, 3.8365835954065886`*^9}, 
   3.8365836802838306`*^9, {3.836583757375491*^9, 3.8365837690849705`*^9}, {
   3.836585037954858*^9, 3.836585059173772*^9}, {3.836585101095063*^9, 
   3.8365851119324284`*^9}, {3.836585234666058*^9, 3.836585243094597*^9}, {
   3.8365853565982018`*^9, 3.8365853704086695`*^9}, {3.8365856815487595`*^9, 
   3.836585690307869*^9}, 3.8365861312271523`*^9, 3.836607557125615*^9, 
   3.8544775706068916`*^9, 3.8544809396768*^9, 3.854489814724163*^9, 
   3.8557501422762957`*^9, 3.856869689188157*^9, 3.8568997001317453`*^9, 
   3.8569110557018147`*^9, 3.856964964192211*^9, 3.8570667613308983`*^9, 
   3.8580860811366773`*^9, 3.8580934247199645`*^9, 3.8586895412701225`*^9, 
   3.8587745852570667`*^9, 3.8588679339265738`*^9, 3.8588902035686235`*^9, 
   3.8589477568194504`*^9, 3.858966832243127*^9, 3.858979198302148*^9, 
   3.859027121536728*^9, 3.859040764463193*^9, 3.8590478756318736`*^9, 
   3.859389337023181*^9, 3.860107259601699*^9, 3.8601074897186685`*^9, 
   3.8607819551522675`*^9, 3.8607828181329913`*^9, 3.8608700498248224`*^9, 
   3.860954265607438*^9, 3.8610292687875724`*^9, 3.861135225023363*^9, 
   3.8631841858659983`*^9, 3.863187233090691*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"99abbdf3-b64e-49db-8faa-f12571ad7a80"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8365835629728355`*^9, 3.8365835954065886`*^9}, 
   3.8365836802838306`*^9, {3.836583757375491*^9, 3.8365837690849705`*^9}, {
   3.836585037954858*^9, 3.836585059173772*^9}, {3.836585101095063*^9, 
   3.8365851119324284`*^9}, {3.836585234666058*^9, 3.836585243094597*^9}, {
   3.8365853565982018`*^9, 3.8365853704086695`*^9}, {3.8365856815487595`*^9, 
   3.836585690307869*^9}, 3.8365861312271523`*^9, 3.836607557125615*^9, 
   3.8544775706068916`*^9, 3.8544809396768*^9, 3.854489814724163*^9, 
   3.8557501422762957`*^9, 3.856869689188157*^9, 3.8568997001317453`*^9, 
   3.8569110557018147`*^9, 3.856964964192211*^9, 3.8570667613308983`*^9, 
   3.8580860811366773`*^9, 3.8580934247199645`*^9, 3.8586895412701225`*^9, 
   3.8587745852570667`*^9, 3.8588679339265738`*^9, 3.8588902035686235`*^9, 
   3.8589477568194504`*^9, 3.858966832243127*^9, 3.858979198302148*^9, 
   3.859027121536728*^9, 3.859040764463193*^9, 3.8590478756318736`*^9, 
   3.859389337023181*^9, 3.860107259601699*^9, 3.8601074897186685`*^9, 
   3.8607819551522675`*^9, 3.8607828181329913`*^9, 3.8608700498248224`*^9, 
   3.860954265607438*^9, 3.8610292687875724`*^9, 3.861135225023363*^9, 
   3.8631841858659983`*^9, 3.863187233106311*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"2fd45600-c769-4cbd-8a53-1d4e5322fcf2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "The", " ", "solvability", " ", "conditions", " ", "imply", " ", 
     SubscriptBox["\[Lambda]", "1"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[ImaginaryI]\[Mu]", "1"]}], 
     RowBox[{
      SubscriptBox["c", "g"], "."}]}]}], " ", "**)"}]}]], "Input",
 CellChangeTimes->{{3.836586166535922*^9, 3.836586218860746*^9}, {
  3.836586263721674*^9, 3.8365862642442474`*^9}, {3.8631842103469296`*^9, 
  3.8631842143488836`*^9}},ExpressionUUID->"74ede51c-1bb2-48fb-bfac-\
d209dcd89d15"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Remove", " ", "hyperbolic", " ", "sinh", " ", "from", " ", 
    "inhomogeneous", " ", 
    RowBox[{"terms", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["partIHT", "1"], "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["IHT", "1"], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}]}], "]"}], "]"}], "/.", " ", 
      RowBox[{
       SubscriptBox["s", "j_"], "\[RuleDelayed]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Omega]", "j"], "2"], "*", 
        RowBox[{
         SubscriptBox["C", "j"], "/", "j"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ", 
     "at", " ", "this", " ", 
     RowBox[{"order", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", "1"], " ", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"partsoln", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["IHT", "1"], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "5"}], "}"}]}], "]"}], "]"}], "/.", " ", 
        RowBox[{
         SubscriptBox["s", "j_"], "\[RuleDelayed]", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Omega]", "j"], "^", "2"}], "*", 
          RowBox[{
           SubscriptBox["C", "j"], "/", 
           RowBox[{"(", "j", ")"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}], "]"}], "]"}], ",", "1"}], "]"}], 
     "]"}], " "}]}]}]], "Input",
 CellChangeTimes->{{3.8242363620454884`*^9, 3.824236430147499*^9}, {
   3.824236478483627*^9, 3.8242364954275956`*^9}, {3.824236626766796*^9, 
   3.8242366605112877`*^9}, {3.8242440868414907`*^9, 
   3.8242440903540964`*^9}, {3.8242443402081003`*^9, 3.824244369151651*^9}, {
   3.8242444163694906`*^9, 3.824244431187025*^9}, {3.824244485304977*^9, 
   3.8242445172152805`*^9}, {3.8242445500340548`*^9, 3.824244589494547*^9}, {
   3.824245530784767*^9, 3.8242455552340937`*^9}, {3.8245086764695807`*^9, 
   3.8245086857291894`*^9}, {3.824508882492077*^9, 3.8245088901707954`*^9}, {
   3.8359742335258236`*^9, 3.8359742511064196`*^9}, {3.836586317054388*^9, 
   3.836586360695044*^9}, 3.8365864263946757`*^9, {3.836586479409106*^9, 
   3.836586547246324*^9}, 3.8568930337092357`*^9, {3.8588902619353123`*^9, 
   3.8588902634579363`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"95aad231-b3cb-4020-9ace-25d6164643aa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["c", "0"]}], "-", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["c", "0", "3"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["c", "0", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        RowBox[{"8", " ", 
         SubsuperscriptBox["c", "0", "3"]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["c", "0"], " ", 
         SubsuperscriptBox["\[Omega]", 
          RowBox[{"-", "2"}], "2"]}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SubsuperscriptBox["c", "0", "4"], "-", 
          RowBox[{
           SubsuperscriptBox["c", "0", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["c", "0"], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        RowBox[{"4", " ", 
         SubsuperscriptBox["c", "0", "3"]}], "-", 
        RowBox[{
         SubscriptBox["c", "0"], " ", 
         SubsuperscriptBox["\[Omega]", 
          RowBox[{"-", "2"}], "2"]}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["c", "0"]}], "-", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["c", "0", "3"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["c", "0", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        RowBox[{"8", " ", 
         SubsuperscriptBox["c", "0", "3"]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["c", "0"], " ", 
         SubsuperscriptBox["\[Omega]", "2", "2"]}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SubsuperscriptBox["c", "0", "4"], "-", 
           RowBox[{
            SubsuperscriptBox["c", "0", "2"], " ", 
            SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["c", "0"], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], 
        RowBox[{
         RowBox[{"4", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}]}]]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.824244597120138*^9, 3.824245560508648*^9, {3.8245087331647005`*^9, 
   3.8245087485375953`*^9}, 3.8245088917527523`*^9, 3.824828218506803*^9, 
   3.8293037323566217`*^9, 3.829473876857999*^9, 3.8298258187551813`*^9, 
   3.829830835947282*^9, 3.8298502799776087`*^9, {3.8315178778131638`*^9, 
   3.8315178927068176`*^9}, 3.8325029440944085`*^9, 3.8327674920706964`*^9, 
   3.8343222995870414`*^9, 3.8346727466921926`*^9, 3.8359742526046567`*^9, 
   3.8360642473251905`*^9, 3.8360650882879505`*^9, 3.8360655406974907`*^9, 
   3.8365865647413087`*^9, 3.8366075831398945`*^9, 3.854477574955365*^9, 
   3.8544809433199263`*^9, 3.854489817868662*^9, 3.855750146259408*^9, 
   3.856869693481039*^9, 3.856899715714036*^9, 3.8569110636229444`*^9, 
   3.8569649672029753`*^9, 3.8570667650356975`*^9, 3.8580860839951005`*^9, 
   3.8580934275658207`*^9, 3.858689543600338*^9, 3.8587745876867228`*^9, 
   3.858867936506159*^9, 3.858890206978772*^9, {3.858890259025082*^9, 
   3.8588902645282197`*^9}, 3.8589477591692176`*^9, 3.858966836377178*^9, 
   3.8589792023345785`*^9, 3.859027137007587*^9, 3.8590407669155416`*^9, 
   3.8590478775709667`*^9, 3.859389341481905*^9, 3.860107264259943*^9, 
   3.860107492268036*^9, 3.8607828207879896`*^9, 3.8608700500903625`*^9, {
   3.860954267868126*^9, 3.8609542699379063`*^9}, 3.8610292715256433`*^9, 
   3.8611352276086507`*^9, 3.8631842187416515`*^9, 3.8631872357304688`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"c4dfc6ee-1f39-471a-aae3-1f9f910fd568"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            SuperscriptBox[
             SubscriptBox["c", "0"], "2"]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["s", 
           RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["C", 
             RowBox[{"-", "1"}]]}], "*", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"1", ",", "0"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", " ", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["IHT", 
               RowBox[{"1", ",", "0"}]], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], "*", 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
            SubscriptBox["c", 
             SubscriptBox["g", 
              RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
         " ", 
         RowBox[{
          SubscriptBox["C", "0"], "\[Rule]", " ", "1"}]}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]], " ", "\[Rule]", " ", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"1", ",", "1"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", " ", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"1", ",", "1"}]], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            SuperscriptBox[
             SubscriptBox["c", "0"], "2"]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
          RowBox[{
           SubscriptBox["C", "1"], "*", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8365880076359816`*^9, {3.836588842831197*^9, 3.8365889437154408`*^9}, {
   3.836589052672431*^9, 3.836589076699498*^9}, 3.836589106784465*^9, {
   3.8365891730454283`*^9, 3.8365891937634892`*^9}, {3.8365893459850783`*^9, 
   3.8365893618543243`*^9}, {3.8365897979176674`*^9, 3.836589899951764*^9}, {
   3.836589959261092*^9, 3.836589964054367*^9}, {3.836590063290547*^9, 
   3.836590114078697*^9}, {3.836590147641199*^9, 3.836590196020345*^9}, {
   3.836590259698617*^9, 3.836590280598693*^9}, {3.8365908966317225`*^9, 
   3.8365909211454525`*^9}, {3.85696301327742*^9, 3.8569630138739324`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"a13ff59b-7856-43ac-baf3-44714ddd570c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", 
         SubsuperscriptBox["c", "0", "2"], "+", 
         RowBox[{"\[Alpha]", " ", 
          SubsuperscriptBox["c", "0", "4"]}]}], ")"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "3"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8365888726659355`*^9, 3.836588944007207*^9}, {
   3.8365890557377787`*^9, 3.8365890770288906`*^9}, 3.8365891071636095`*^9, {
   3.836589174411733*^9, 3.8365891942755413`*^9}, {3.8365893497583046`*^9, 
   3.8365893630692616`*^9}, 3.8365898031714225`*^9, {3.836589835168369*^9, 
   3.8365898462460546`*^9}, 3.8365899007611675`*^9, 3.836589964645814*^9, 
   3.836590114535653*^9, 3.8365901652992086`*^9, 3.8365902022941923`*^9, 
   3.836590281905922*^9, 3.8365909227882233`*^9, 3.83660760619059*^9, 
   3.854477591577776*^9, 3.8544809542765045`*^9, 3.8544898303562126`*^9, 
   3.8557501572101955`*^9, 3.856869703767147*^9, 3.856899876784734*^9, 
   3.856912133010225*^9, 3.8569630148317175`*^9, 3.85696497358992*^9, 
   3.8570667699589224`*^9, 3.8580860882177086`*^9, 3.8580934315977936`*^9, 
   3.858689547523082*^9, 3.8587745929250684`*^9, 3.8588679422869368`*^9, 
   3.8588902700573907`*^9, 3.8589478070076737`*^9, 3.8589668418721886`*^9, 
   3.858979227449771*^9, 3.85902714208696*^9, 3.8590407706986313`*^9, 
   3.859047881184892*^9, 3.859389361129918*^9, 3.8601072698518634`*^9, 
   3.860107497659567*^9, 3.8607828251261263`*^9, 3.86087005360093*^9, 
   3.8609542730015144`*^9, 3.861029274449402*^9, 3.861135231616561*^9, 
   3.8631842359898586`*^9, 3.863187237874439*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"d9a99597-d084-4f55-83ae-16657d648029"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"1", ",", "0"}]], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]], "+", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]], "+", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], ")"}]}]}], 
     RowBox[{"2", " ", 
      SubscriptBox["c", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8365888726659355`*^9, 3.836588944007207*^9}, {
   3.8365890557377787`*^9, 3.8365890770288906`*^9}, 3.8365891071636095`*^9, {
   3.836589174411733*^9, 3.8365891942755413`*^9}, {3.8365893497583046`*^9, 
   3.8365893630692616`*^9}, 3.8365898031714225`*^9, {3.836589835168369*^9, 
   3.8365898462460546`*^9}, 3.8365899007611675`*^9, 3.836589964645814*^9, 
   3.836590114535653*^9, 3.8365901652992086`*^9, 3.8365902022941923`*^9, 
   3.836590281905922*^9, 3.8365909227882233`*^9, 3.83660760619059*^9, 
   3.854477591577776*^9, 3.8544809542765045`*^9, 3.8544898303562126`*^9, 
   3.8557501572101955`*^9, 3.856869703767147*^9, 3.856899876784734*^9, 
   3.856912133010225*^9, 3.8569630148317175`*^9, 3.85696497358992*^9, 
   3.8570667699589224`*^9, 3.8580860882177086`*^9, 3.8580934315977936`*^9, 
   3.858689547523082*^9, 3.8587745929250684`*^9, 3.8588679422869368`*^9, 
   3.8588902700573907`*^9, 3.8589478070076737`*^9, 3.8589668418721886`*^9, 
   3.858979227449771*^9, 3.85902714208696*^9, 3.8590407706986313`*^9, 
   3.859047881184892*^9, 3.859389361129918*^9, 3.8601072698518634`*^9, 
   3.860107497659567*^9, 3.8607828251261263`*^9, 3.86087005360093*^9, 
   3.8609542730015144`*^9, 3.861029274449402*^9, 3.861135231616561*^9, 
   3.8631842359898586`*^9, 3.8631872380462503`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"b0e50b63-a607-46dd-83ed-e53df9fda397"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", 
         SubsuperscriptBox["c", "0", "2"], "+", 
         RowBox[{"\[Alpha]", " ", 
          SubsuperscriptBox["c", "0", "4"]}]}], ")"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "3"]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8365888726659355`*^9, 3.836588944007207*^9}, {
   3.8365890557377787`*^9, 3.8365890770288906`*^9}, 3.8365891071636095`*^9, {
   3.836589174411733*^9, 3.8365891942755413`*^9}, {3.8365893497583046`*^9, 
   3.8365893630692616`*^9}, 3.8365898031714225`*^9, {3.836589835168369*^9, 
   3.8365898462460546`*^9}, 3.8365899007611675`*^9, 3.836589964645814*^9, 
   3.836590114535653*^9, 3.8365901652992086`*^9, 3.8365902022941923`*^9, 
   3.836590281905922*^9, 3.8365909227882233`*^9, 3.83660760619059*^9, 
   3.854477591577776*^9, 3.8544809542765045`*^9, 3.8544898303562126`*^9, 
   3.8557501572101955`*^9, 3.856869703767147*^9, 3.856899876784734*^9, 
   3.856912133010225*^9, 3.8569630148317175`*^9, 3.85696497358992*^9, 
   3.8570667699589224`*^9, 3.8580860882177086`*^9, 3.8580934315977936`*^9, 
   3.858689547523082*^9, 3.8587745929250684`*^9, 3.8588679422869368`*^9, 
   3.8588902700573907`*^9, 3.8589478070076737`*^9, 3.8589668418721886`*^9, 
   3.858979227449771*^9, 3.85902714208696*^9, 3.8590407706986313`*^9, 
   3.859047881184892*^9, 3.859389361129918*^9, 3.8601072698518634`*^9, 
   3.860107497659567*^9, 3.8607828251261263`*^9, 3.86087005360093*^9, 
   3.8609542730015144`*^9, 3.861029274449402*^9, 3.861135231616561*^9, 
   3.8631842359898586`*^9, 3.8631872380462503`*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"5244f60d-3cd9-4245-ab32-d70b288d5892"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Check", " ", "that", " ", "the", " ", "particular", " ", 
    "solutions", " ", "are", " ", 
    RowBox[{"correct", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SubscriptBox["NumInvR", "0"], "[", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "x"}], 
                    "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "]"}], ")"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "2"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "2"}], "}"}]}], "]"}], "-", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["IHT", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], "*", 
                   RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "x"}], 
                    "]"}]}]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "/.", " ", 
               RowBox[{
                SubscriptBox["s", "j_"], "\[RuleDelayed]", 
                RowBox[{
                 SuperscriptBox[
                  SubscriptBox["\[Omega]", "j"], "2"], "*", 
                 RowBox[{
                  SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", "*", 
                   RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"16", "*", 
                  RowBox[{
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                 ")"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], " ", "->", " ", 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "2"}]}], 
                ")"}]}]}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "->", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", "*", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["c", "2"], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "0"], " ", "->", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "j_"], ":>", " ", 
         RowBox[{"\[Omega]", "[", 
          RowBox[{"j", "+", 
           SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
       RowBox[{
        SubscriptBox["C", "j_"], ":>", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Alpha]", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
       " ", 
      RowBox[{
       SubscriptBox["s", "j_"], ":>", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SubscriptBox["NumInvR", "0"], "[", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"2", "*", "\[ImaginaryI]", "*", "x"}], "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "]"}], ")"}], 
                    ",", 
                    RowBox[{"{", "2", "}"}]}], "]"}], ",", 
                    RowBox[{"{", "2", "}"}]}], "]"}], "-", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["IHT", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "5"}], "]"}], "]"}], "*", 
                   RowBox[{"Exp", "[", 
                    RowBox[{"2", "*", "\[ImaginaryI]", "*", "x"}], "]"}]}]}], 
                 "//.", " ", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "/.", " ", 
               RowBox[{
                SubscriptBox["s", "j_"], "\[RuleDelayed]", 
                RowBox[{
                 SuperscriptBox[
                  SubscriptBox["\[Omega]", "j"], "2"], "*", 
                 RowBox[{
                  SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", "*", 
                   RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"16", "*", 
                  RowBox[{
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                 ")"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], " ", "->", " ", 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", 
                 RowBox[{
                  RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "2"}]}], 
                ")"}]}]}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "->", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", "*", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["c", "2"], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "0"], " ", "->", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "j_"], ":>", " ", 
         RowBox[{"\[Omega]", "[", 
          RowBox[{"j", "+", 
           SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
       RowBox[{
        SubscriptBox["C", "j_"], ":>", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Alpha]", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
       " ", 
      RowBox[{
       SubscriptBox["s", "j_"], ":>", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["NumInvR", "0"], "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["NumL", "0"], "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]], ",", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]]}], "}"}], "*", 
               RowBox[{"Exp", "[", 
                RowBox[{
                 RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "//.", 
              SubscriptBox["partsoln", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}], ",", 
            RowBox[{"{", 
             RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"-", "1"}], "}"}]}], "]"}], "-", 
        RowBox[{
         SubscriptBox["IHT", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
       SubscriptBox["c", 
        SubscriptBox["g", 
         RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["s", 
       RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}], "*", 
       SuperscriptBox[
        SubscriptBox["c", "0"], "2"]}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["NumInvR", "0"], "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["NumL", "0"], "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "0"}]], ",", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"1", ",", "0"}]]}], "}"}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"1", ",", "0"}]]}], ")"}], ",", 
             RowBox[{"{", "0", "}"}]}], "]"}], ",", 
           RowBox[{"{", "0", "}"}]}], "]"}], "-", 
         SubscriptBox["IHT", 
          RowBox[{"1", ",", "0"}]]}], "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "*", 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
        SubscriptBox["c", 
         SubscriptBox["g", 
          RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["C", "0"], " ", "\[Rule]", " ", "1"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["NumInvR", "0"], "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["NumL", "0"], "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "1"}]], ",", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"1", ",", "1"}]]}], "}"}], "*", 
               RowBox[{"Exp", "[", 
                RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "//.", 
              SubscriptBox["partsoln", 
               RowBox[{"1", ",", "1"}]]}], ")"}], ",", 
            RowBox[{"{", "1", "}"}]}], "]"}], ",", 
          RowBox[{"{", "1", "}"}]}], "]"}], "-", 
        RowBox[{
         SubscriptBox["IHT", 
          RowBox[{"1", ",", "1"}]], "*", 
         RowBox[{"Exp", "[", 
          RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
       SubscriptBox["c", 
        SubscriptBox["g", 
         RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
      RowBox[{
       SubscriptBox["C", "1"], "*", 
       SuperscriptBox[
        SubscriptBox["c", "0"], "2"]}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8365909987605596`*^9, 3.8365910804344215`*^9}, {
   3.8365911246646566`*^9, 3.8365911855547876`*^9}, {3.8365912639813385`*^9, 
   3.8365912642472577`*^9}, 3.8366076266578507`*^9, {3.8366077099212093`*^9, 
   3.8366077291092587`*^9}, {3.836607941192624*^9, 3.8366079711339717`*^9}, {
   3.836608004750267*^9, 3.8366082535781136`*^9}, {3.8568919449565716`*^9, 
   3.856891966294133*^9}, {3.856892004526177*^9, 3.8568920990702887`*^9}, {
   3.8568921776386085`*^9, 3.856892200823654*^9}, {3.856892320255252*^9, 
   3.856892321145583*^9}, {3.85689250684515*^9, 3.856892507344967*^9}, {
   3.856892597618478*^9, 3.8568926016542654`*^9}, {3.856892637268693*^9, 
   3.856892639770773*^9}, {3.856893078704153*^9, 3.8568931379817066`*^9}, 
   3.863184246566803*^9},
 CellLabel->"In[40]:=",ExpressionUUID->"93f2e2e1-69ac-40ad-9c13-bf0b0646ebbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, 3.854477597242933*^9, 3.854480958851514*^9, 
   3.85448983354533*^9, 3.855750161731307*^9, 3.8568697062820406`*^9, {
   3.856892048171756*^9, 3.85689206818734*^9}, 3.856892099991905*^9, 
   3.85689218168478*^9, 3.8568922207022395`*^9, 3.8568923221608615`*^9, 
   3.8568925106937685`*^9, 3.8568926021074305`*^9, 3.8568930813751483`*^9, {
   3.856893124185241*^9, 3.8568931390310035`*^9}, 3.856899883971177*^9, 
   3.8569121395163636`*^9, 3.8569649859701166`*^9, 3.8570667758826413`*^9, 
   3.85808609615504*^9, 3.858093437942514*^9, 3.8586895537580376`*^9, 
   3.858774603841378*^9, 3.8588679461955595`*^9, 3.8588902743702183`*^9, 
   3.858947843052919*^9, 3.858966847587043*^9, 3.8589792333938985`*^9, 
   3.85902714621766*^9, 3.859040777621257*^9, 3.8590478846389985`*^9, {
   3.859389353284477*^9, 3.8593893645714684`*^9}, 3.860107279697117*^9, 
   3.8601075035048466`*^9, 3.8607828288936253`*^9, 3.8608700571254053`*^9, 
   3.860954276189712*^9, 3.861029277573394*^9, 3.8611352351615944`*^9, 
   3.8631842473541946`*^9, 3.8631872404372997`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"0160ff5a-581c-4add-93fc-bd4bf334b8db"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, 3.854477597242933*^9, 3.854480958851514*^9, 
   3.85448983354533*^9, 3.855750161731307*^9, 3.8568697062820406`*^9, {
   3.856892048171756*^9, 3.85689206818734*^9}, 3.856892099991905*^9, 
   3.85689218168478*^9, 3.8568922207022395`*^9, 3.8568923221608615`*^9, 
   3.8568925106937685`*^9, 3.8568926021074305`*^9, 3.8568930813751483`*^9, {
   3.856893124185241*^9, 3.8568931390310035`*^9}, 3.856899883971177*^9, 
   3.8569121395163636`*^9, 3.8569649859701166`*^9, 3.8570667758826413`*^9, 
   3.85808609615504*^9, 3.858093437942514*^9, 3.8586895537580376`*^9, 
   3.858774603841378*^9, 3.8588679461955595`*^9, 3.8588902743702183`*^9, 
   3.858947843052919*^9, 3.858966847587043*^9, 3.8589792333938985`*^9, 
   3.85902714621766*^9, 3.859040777621257*^9, 3.8590478846389985`*^9, {
   3.859389353284477*^9, 3.8593893645714684`*^9}, 3.860107279697117*^9, 
   3.8601075035048466`*^9, 3.8607828288936253`*^9, 3.8608700571254053`*^9, 
   3.860954276189712*^9, 3.861029277573394*^9, 3.8611352351615944`*^9, 
   3.8631842473541946`*^9, 3.8631872405154057`*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"1b46abd6-89e0-4970-a357-bcd5ab5fa329"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, 3.854477597242933*^9, 3.854480958851514*^9, 
   3.85448983354533*^9, 3.855750161731307*^9, 3.8568697062820406`*^9, {
   3.856892048171756*^9, 3.85689206818734*^9}, 3.856892099991905*^9, 
   3.85689218168478*^9, 3.8568922207022395`*^9, 3.8568923221608615`*^9, 
   3.8568925106937685`*^9, 3.8568926021074305`*^9, 3.8568930813751483`*^9, {
   3.856893124185241*^9, 3.8568931390310035`*^9}, 3.856899883971177*^9, 
   3.8569121395163636`*^9, 3.8569649859701166`*^9, 3.8570667758826413`*^9, 
   3.85808609615504*^9, 3.858093437942514*^9, 3.8586895537580376`*^9, 
   3.858774603841378*^9, 3.8588679461955595`*^9, 3.8588902743702183`*^9, 
   3.858947843052919*^9, 3.858966847587043*^9, 3.8589792333938985`*^9, 
   3.85902714621766*^9, 3.859040777621257*^9, 3.8590478846389985`*^9, {
   3.859389353284477*^9, 3.8593893645714684`*^9}, 3.860107279697117*^9, 
   3.8601075035048466`*^9, 3.8607828288936253`*^9, 3.8608700571254053`*^9, 
   3.860954276189712*^9, 3.861029277573394*^9, 3.8611352351615944`*^9, 
   3.8631842473541946`*^9, 3.863187240546639*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"cc53d8ff-ce3d-411d-bb78-a83d89cf97b7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, 3.854477597242933*^9, 3.854480958851514*^9, 
   3.85448983354533*^9, 3.855750161731307*^9, 3.8568697062820406`*^9, {
   3.856892048171756*^9, 3.85689206818734*^9}, 3.856892099991905*^9, 
   3.85689218168478*^9, 3.8568922207022395`*^9, 3.8568923221608615`*^9, 
   3.8568925106937685`*^9, 3.8568926021074305`*^9, 3.8568930813751483`*^9, {
   3.856893124185241*^9, 3.8568931390310035`*^9}, 3.856899883971177*^9, 
   3.8569121395163636`*^9, 3.8569649859701166`*^9, 3.8570667758826413`*^9, 
   3.85808609615504*^9, 3.858093437942514*^9, 3.8586895537580376`*^9, 
   3.858774603841378*^9, 3.8588679461955595`*^9, 3.8588902743702183`*^9, 
   3.858947843052919*^9, 3.858966847587043*^9, 3.8589792333938985`*^9, 
   3.85902714621766*^9, 3.859040777621257*^9, 3.8590478846389985`*^9, {
   3.859389353284477*^9, 3.8593893645714684`*^9}, 3.860107279697117*^9, 
   3.8601075035048466`*^9, 3.8607828288936253`*^9, 3.8608700571254053`*^9, 
   3.860954276189712*^9, 3.861029277573394*^9, 3.8611352351615944`*^9, 
   3.8631842473541946`*^9, 3.863187240546639*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"fb1fa19b-1420-4d90-b0bd-9871ea310e06"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, 3.854477597242933*^9, 3.854480958851514*^9, 
   3.85448983354533*^9, 3.855750161731307*^9, 3.8568697062820406`*^9, {
   3.856892048171756*^9, 3.85689206818734*^9}, 3.856892099991905*^9, 
   3.85689218168478*^9, 3.8568922207022395`*^9, 3.8568923221608615`*^9, 
   3.8568925106937685`*^9, 3.8568926021074305`*^9, 3.8568930813751483`*^9, {
   3.856893124185241*^9, 3.8568931390310035`*^9}, 3.856899883971177*^9, 
   3.8569121395163636`*^9, 3.8569649859701166`*^9, 3.8570667758826413`*^9, 
   3.85808609615504*^9, 3.858093437942514*^9, 3.8586895537580376`*^9, 
   3.858774603841378*^9, 3.8588679461955595`*^9, 3.8588902743702183`*^9, 
   3.858947843052919*^9, 3.858966847587043*^9, 3.8589792333938985`*^9, 
   3.85902714621766*^9, 3.859040777621257*^9, 3.8590478846389985`*^9, {
   3.859389353284477*^9, 3.8593893645714684`*^9}, 3.860107279697117*^9, 
   3.8601075035048466`*^9, 3.8607828288936253`*^9, 3.8608700571254053`*^9, 
   3.860954276189712*^9, 3.861029277573394*^9, 3.8611352351615944`*^9, 
   3.8631842473541946`*^9, 3.8631872405622616`*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"75975843-f738-473a-8a79-fa0464a7f46c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Final", " ", "solution", " ", "for", " ", "the", " ", "O", 
     RowBox[{"(", "\[Epsilon]", ")"}], " ", 
     RowBox[{"problem", ".", " ", "There"}], " ", "is", " ", "no", " ", 
     "particular", " ", "solution", " ", "proportional", " ", "to", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "n", "*", "x"}], "]"}], " ", "at", " ", 
     "this", " ", "order", " ", "because", " ", "of", " ", "the", " ", 
     "choice", " ", "of", " ", "normalization", " ", "on", " ", 
     RowBox[{"w", ".", " ", "At"}], " ", "this", " ", "order"}], ",", " ", 
    RowBox[{
     SubscriptBox["\[Gamma]", "1"], " ", "is", " ", "an", " ", "arbitrary", 
     " ", 
     RowBox[{"constant", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["w", "1"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h", 
          RowBox[{"1", ",", "j"}]], ",", 
         SubscriptBox["\[Phi]", 
          RowBox[{"1", ",", "j"}]]}], "}"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", "*", "j", "*", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox["\[ImaginaryI]", 
        SubscriptBox["c", "0"]]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox[
        RowBox[{"-", "\[ImaginaryI]"}], 
        SubscriptBox["c", "0"]]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]], "*", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.8242370255451097`*^9, 3.824237069106557*^9}, {
  3.824244096930807*^9, 3.8242441318920865`*^9}, {3.8242443855204077`*^9, 
  3.824244409672367*^9}, {3.824245637378871*^9, 3.8242456377474823`*^9}, {
  3.824245684140806*^9, 3.8242457046099596`*^9}, {3.8242457447945557`*^9, 
  3.8242457716378627`*^9}, {3.8243097626122437`*^9, 3.8243098057179384`*^9}, {
  3.8359742915208893`*^9, 3.8359742921143503`*^9}, {3.8366869166108985`*^9, 
  3.83668692736432*^9}, {3.8366869592078342`*^9, 3.8366870529558973`*^9}, {
  3.8568998907374425`*^9, 3.8568999046163263`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"f4ed5d58-2348-4d3c-bcef-df755322c494"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["h", 
     RowBox[{"1", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]}], 
     SubscriptBox["c", "0"]], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"1", ",", "0"}]], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "1"}]]}], 
     SubscriptBox["c", "0"]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "2"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.824237040424094*^9, 3.824237069511461*^9}, {
   3.8242441005830393`*^9, 3.824244132499463*^9}, {3.824244397942233*^9, 
   3.8242444099905148`*^9}, 3.824245712432865*^9, 3.8245087856159244`*^9, 
   3.8248282439700565`*^9, 3.829303745204534*^9, 3.8294738911545205`*^9, 
   3.829825829975224*^9, 3.829830845373143*^9, 3.8298503321597524`*^9, {
   3.8315178838436003`*^9, 3.8315178998287067`*^9}, 3.832502948440692*^9, 
   3.832767497235362*^9, 3.83432230463995*^9, 3.8346727516105413`*^9, 
   3.835974312748376*^9, 3.8360642477506657`*^9, 3.8360650887373533`*^9, 
   3.836065541158641*^9, 3.8366869287179728`*^9, 3.8366869604506316`*^9, {
   3.8366870459034643`*^9, 3.836687053828573*^9}, 3.854477681124576*^9, 
   3.8544809624002037`*^9, 3.85448983716916*^9, 3.8557501670863223`*^9, 
   3.85686970928364*^9, 3.856899946531623*^9, 3.856912149785102*^9, 
   3.8569649892798433`*^9, 3.857066779945672*^9, 3.858086100185731*^9, 
   3.858093439629493*^9, 3.8586895559131403`*^9, 3.858774607669997*^9, 
   3.858867948757272*^9, 3.8588902779464426`*^9, 3.8589478457082987`*^9, 
   3.858966850188771*^9, 3.8589792356900167`*^9, 3.8590271486771812`*^9, 
   3.859040779951392*^9, 3.8590478873597097`*^9, 3.859389370345696*^9, 
   3.8601075064912305`*^9, 3.8607828317985096`*^9, 3.8608700598351636`*^9, 
   3.8609542785738883`*^9, 3.8610292799655824`*^9, {3.8611352380491037`*^9, 
   3.8611352420473356`*^9}, 3.8631842532528005`*^9, 3.86318724427982*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"e15a29be-a4d4-4c0d-9d96-475dc5f240e6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"IV", ".", " ", "Second"}], "-", 
    RowBox[{"Order", " ", "Problem"}]}], "Section"]}]], "Input",
 CellChangeTimes->{{3.8242489864841957`*^9, 3.8242489983538294`*^9}, {
  3.8359743185437613`*^9, 
  3.8359743196043673`*^9}},ExpressionUUID->"963de281-4453-4fe8-b797-\
d86e3aace76f"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Define", " ", "operator", " ", 
    SubscriptBox["L", "2"], " ", "for", " ", "numerical", " ", 
    RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumL", "2"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["c", "0"], "*", 
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], "*", 
                 SubscriptBox["C", "\[Kappa]"]}], "+", 
                RowBox[{
                 SubscriptBox["c", "0"], "*", 
                 SubscriptBox["\[Mu]", "1"], "*", 
                 SubscriptBox["s", "\[Kappa]"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}]}]}], ")"}], 
              "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["c", "2"], "*", 
                 SubscriptBox["C", "\[Kappa]"]}], " ", "+", " ", 
                RowBox[{
                 SubscriptBox["c", "0"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"1", "/", "2"}], "*", 
                    SubscriptBox["C", "\[Kappa]"], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "^", 
                    "2"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "*", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", "*", "\[Eta]2"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], " ", 
             "+", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    SubscriptBox["C", "\[Kappa]"], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["c", "0"], "*", 
                    SubscriptBox["s", "\[Kappa]"], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}]}], ")"}]}], " ", 
                "+", " ", 
                RowBox[{"\[Kappa]", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["c", "0"], "*", 
                    SubscriptBox["C", "\[Kappa]"], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["c", "0"], "*", 
                    SubscriptBox["s", "\[Kappa]"], "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}]}]}], 
               ")"}], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], "*", 
                 SubscriptBox["s", "\[Kappa]"]}], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], "*", 
                 SubscriptBox["C", "\[Kappa]"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}]}]}], ")"}], 
              "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "-", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"1", "/", "2"}], "*", 
                 SubscriptBox["s", "\[Kappa]"], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "^", 
                  "2"}]}], "+", 
                RowBox[{
                 SubscriptBox["C", "\[Kappa]"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], " ", "+", " ", 
                   RowBox[{
                    SubscriptBox["\[Mu]", "1"], "*", "\[Eta]1"}], "+", 
                   RowBox[{"\[Kappa]", "*", "\[Eta]2"}]}], ")"}]}]}], ")"}], 
              "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}],
            ",", "kmod"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "/", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], "*", 
              SubscriptBox["c", "0"], "*", 
              RowBox[{"1", "^", "3"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], " ", "+", " ", 
             RowBox[{"2", "*", 
              RowBox[{
               SubscriptBox["c", "0"], "^", "2"}], "*", 
              RowBox[{"1", "^", "2"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}], "*", 
           "\[ImaginaryI]", "*", 
           RowBox[{"Fdiff", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], " ", "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           RowBox[{
            SubscriptBox["c", "0"], "^", "2"}], "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"D", "[", 
            RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", " ", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["c", "0"]}], "*", "1"}], ")"}], "*", "2", "*", 
              "\[ImaginaryI]", "*", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"2", "*", "1", "*", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
                RowBox[{"2", "*", 
                 SubscriptBox["c", "0"], "*", 
                 RowBox[{"1", "^", "3"}], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], ")"}], "^", 
                  "2"}]}]}], ")"}], "*", "\[ImaginaryI]", "*", 
              RowBox[{"Fdiff", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}], 
            ")"}]}], "-", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"D", "[", 
            RowBox[{"q1", ",", "x"}], "]"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Define", " ", "operator", " ", 
     SubscriptBox["R", "2"], " ", "for", " ", "numerical", " ", 
     RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumR", "2"], "[", 
      RowBox[{"w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_"}],
       "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"1", "/", "2"}], "*", 
                SubscriptBox["C", "\[Kappa]"], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", "*", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", "*", "\[Eta]1"}]}], ")"}], "^", 
                 "2"}]}], " ", "+", " ", 
               RowBox[{
                SubscriptBox["s", "\[Kappa]"], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Alpha]", "*", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], "*", "\[Eta]1"}], "+", 
                  RowBox[{"\[Kappa]", "*", "\[Eta]2"}]}], ")"}]}]}], ")"}], 
             "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", 
             RowBox[{"1", "^", "2"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["c", "0"], "*", "1", "*", 
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8242504557490396`*^9, 3.824250510536577*^9}, {
   3.824250558045709*^9, 3.8242505770060053`*^9}, {3.8242506208185444`*^9, 
   3.8242509143633776`*^9}, {3.8242509461004276`*^9, 3.824251186394908*^9}, {
   3.824251245255171*^9, 3.824251246704295*^9}, {3.8242512881226172`*^9, 
   3.824251354633906*^9}, {3.824251413331665*^9, 3.824251413436166*^9}, {
   3.824251447819129*^9, 3.8242514479068565`*^9}, {3.8242515512470913`*^9, 
   3.824251552366618*^9}, {3.8242516279130087`*^9, 3.824251844962574*^9}, {
   3.8242519215605373`*^9, 3.8242519257254066`*^9}, {3.8242519620688934`*^9, 
   3.824252177973816*^9}, 3.8242522349778757`*^9, {3.8242523864856215`*^9, 
   3.8242523932164073`*^9}, {3.8242525148599844`*^9, 
   3.8242525154334764`*^9}, {3.8242525772071695`*^9, 
   3.8242526166905947`*^9}, {3.824252664588333*^9, 3.8242526646960425`*^9}, {
   3.824252696488741*^9, 3.8242528189231086`*^9}, {3.824252869617689*^9, 
   3.8242528704564857`*^9}, {3.8242529034823456`*^9, 3.824253050813654*^9}, {
   3.8243139890760703`*^9, 3.824313990143183*^9}, {3.824508942792533*^9, 
   3.8245090478439474`*^9}, {3.824509081303008*^9, 3.824509097028672*^9}, {
   3.824509147623588*^9, 3.8245091478039427`*^9}, {3.824509257611655*^9, 
   3.824509257690446*^9}, {3.824509292058135*^9, 3.824509345529363*^9}, {
   3.824509392853689*^9, 3.8245094417614098`*^9}, {3.824828337998954*^9, 
   3.824828460106573*^9}, {3.8248284978842793`*^9, 3.8248286353461246`*^9}, {
   3.8248286782416215`*^9, 3.8248286834667177`*^9}, {3.8248287219651794`*^9, 
   3.82482884120378*^9}, {3.8248291009035482`*^9, 3.8248291161234136`*^9}, {
   3.8248292945286865`*^9, 3.8248293164614553`*^9}, {3.8359743401646805`*^9, 
   3.8359743533637943`*^9}, {3.836687158023981*^9, 3.8366872023822885`*^9}, {
   3.8544777206098375`*^9, 3.8544777234043283`*^9}, {3.8544777565186377`*^9, 
   3.8544778150854626`*^9}, {3.854477852273415*^9, 3.854477869968871*^9}, {
   3.854477996083251*^9, 3.8544781490210733`*^9}, {3.85447825406721*^9, 
   3.8544782595915723`*^9}, {3.854478340896527*^9, 3.854478539344915*^9}, {
   3.8544786307676997`*^9, 3.854478642567393*^9}, {3.854478705614562*^9, 
   3.854478754696082*^9}, {3.8544788071795454`*^9, 3.8544789215927677`*^9}, {
   3.8544789978563848`*^9, 3.854479074624194*^9}, {3.8544791056510687`*^9, 
   3.8544791262558002`*^9}, {3.854479943204853*^9, 3.8544799820644264`*^9}, {
   3.8544807071869135`*^9, 3.8544807506388083`*^9}, {3.8557547085398517`*^9, 
   3.855754709492833*^9}, 3.856868747999812*^9, {3.8593894104270277`*^9, 
   3.8593894178324103`*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"c5bbb4b4-efba-48df-95e5-9cc1cf8111a8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", "of", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["A", "0"], "-", 
        SubscriptBox["\[Lambda]", "0"]}], ")"}], 
      SubscriptBox["w", "1"]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], "*", 
       SubscriptBox["w", "0"]}], " ", "+", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["R", "0"], 
        RowBox[{"-", "1"}]], 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Lambda]", "0"], 
             SubscriptBox["R", "1"]}], " ", "-", " ", 
            SubscriptBox["L", "1"]}], ")"}], 
          SubscriptBox["w", 
           RowBox[{"1", " "}]]}], "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Lambda]", "0"], 
             SubscriptBox["R", "2"]}], " ", "-", " ", 
            SubscriptBox["L", "2"]}], ")"}], 
          SubscriptBox["w", 
           RowBox[{"0", " "}]]}]}], ")"}]}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"where", " ", 
      SubscriptBox["A", "0"]}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["R", "0"], 
       RowBox[{"-", "1"}]], 
      RowBox[{
       SubscriptBox["L", "0"], "."}]}]}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["IHT", "2"], "=", 
    RowBox[{"NCoefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "*", 
        SubscriptBox["w", "0"]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["NumInvR", "0"], "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["\[Lambda]", "0"], "*", 
           RowBox[{
            SubscriptBox["NumR", "1"], "[", 
            RowBox[{
             SubscriptBox["w", "1"], ",", 
             RowBox[{"GenModulate", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
              "]"}], ",", " ", 
             RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], " ", "-", " ", 
          RowBox[{
           SubscriptBox["NumL", "1"], "[", 
           RowBox[{
            SubscriptBox["w", "1"], ",", 
            RowBox[{"GenModulate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
             "]"}], ",", 
            RowBox[{"Cos", "[", "x", "]"}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}], " ", "+", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "0"], "*", 
           RowBox[{
            SubscriptBox["NumR", "2"], "[", 
            RowBox[{
             SubscriptBox["w", "0"], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", " ", 
             RowBox[{"Cos", "[", "x", "]"}], ",", 
             RowBox[{"2", "*", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], "*", 
              RowBox[{"Sin", "[", "x", "]"}]}], ",", 
             RowBox[{"2", "*", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", "*", "x"}], "]"}]}]}], "]"}]}], " ", "-", " ", 
          RowBox[{
           SubscriptBox["NumL", "2"], "[", 
           RowBox[{
            SubscriptBox["w", "0"], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"Cos", "[", "x", "]"}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], "*", "x"}], " ", "+", " ", 
             RowBox[{"2", "*", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]], "*", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", "*", "x"}], "]"}]}]}]}], "]"}], "+", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], "*", 
           RowBox[{
            SubscriptBox["NumR", "1"], "[", 
            RowBox[{
             SubscriptBox["w", "0"], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
             RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], " ", "+", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], "*", 
           RowBox[{
            SubscriptBox["NumR", "0"], "[", 
            RowBox[{
             SubscriptBox["w", "1"], ",", 
             RowBox[{"GenModulate", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
              "]"}]}], "]"}]}]}], ",", 
         RowBox[{"GenModulate", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
          "]"}]}], "]"}]}], " ", ",", 
      RowBox[{"GenModulate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
       "]"}]}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8243035049000626`*^9, {3.8243035962054367`*^9, 3.8243039572277718`*^9}, {
   3.8243039903475065`*^9, 3.8243040201896243`*^9}, 3.8243081837573605`*^9, {
   3.8248293440619564`*^9, 3.824829348247904*^9}, {3.8359744383435135`*^9, 
   3.835974449753024*^9}, {3.8366872591008167`*^9, 3.836687305549447*^9}, {
   3.836688323230062*^9, 3.8366884135150394`*^9}, 3.863184266811611*^9},
 CellLabel->"In[48]:=",ExpressionUUID->"85f3239a-80fe-48e1-b24b-ec66ea729324"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"9", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", 
          RowBox[{"-", "3"}]], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "3"}]]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", 
          RowBox[{"-", "1"}]], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "1"}]]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "1"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["C", "1"]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", "2"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "2"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", "1"}]]}], 
        SubscriptBox["C", "2"]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", "1"}]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"9", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "3"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", "2"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["C", "3"]}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["c", "0", "2"]}], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["c", "0", "2"]}], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "2"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8631842677762213`*^9, 3.8631872499967337`*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"40ed4890-fe17-4e7c-a36e-81265d2f1a57"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"2", ",", "0"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"2", ",", "1"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.854489882085451*^9, 3.854489911922989*^9}, {
   3.854489948765246*^9, 3.854489978577795*^9}, {3.8568882868746214`*^9, 
   3.856888288822133*^9}, {3.8569122013741302`*^9, 3.8569122020850277`*^9}, 
   3.8569127978264484`*^9, 3.8569592652859087`*^9, 3.8569609271639605`*^9, 
   3.8569631197748013`*^9, 3.856965042387083*^9, {3.8631842727618413`*^9, 
   3.863184281368297*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"eee5d6f5-6526-4088-a224-e9cee611d92b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                SubscriptBox["IHT", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], "//.", " ", 
                RowBox[{
                 SubscriptBox["s", 
                  RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["C", 
                    RowBox[{"-", "1"}]]}], "*", 
                  SuperscriptBox[
                   SubscriptBox["c", "0"], "2"]}]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", 
           RowBox[{"-", "1"}]], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["IHT", 
                RowBox[{"2", ",", "0"}]], "//.", 
               RowBox[{
                SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
               " ", 
              RowBox[{
               SubscriptBox["C", "0"], " ", "\[Rule]", " ", "1"}]}], "//.", 
             " ", 
             RowBox[{
              SubscriptBox["partsoln", "1"], "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", "  ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], "->", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", "0"], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                SubscriptBox["IHT", 
                 RowBox[{"2", ",", "1"}]], "//.", " ", 
                RowBox[{
                 SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
                 RowBox[{
                  SubscriptBox["C", "1"], "*", 
                  SuperscriptBox[
                   SubscriptBox["c", "0"], "2"]}]}]}], "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", "1"], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.836687526280409*^9, 3.836687534067562*^9}, {
  3.8366879450177517`*^9, 3.836687946585737*^9}, {3.836688555634179*^9, 
  3.836688560114268*^9}, {3.8366887284725075`*^9, 3.8366888292217293`*^9}, {
  3.8366888618015327`*^9, 3.836688876034752*^9}, {3.8366889583004704`*^9, 
  3.8366889947306986`*^9}, {3.8366890502668552`*^9, 3.836689130314056*^9}, {
  3.8366906344160604`*^9, 3.8366906598681264`*^9}, {3.836691285535729*^9, 
  3.836691412761921*^9}, {3.836691469125493*^9, 3.836691472588806*^9}, {
  3.8366915180731297`*^9, 3.836691539628474*^9}, {3.836692271589815*^9, 
  3.8366923286144047`*^9}, {3.8366923943968935`*^9, 3.8366924190564594`*^9}, {
  3.8366924975375223`*^9, 3.836692500029627*^9}, {3.856914438860536*^9, 
  3.8569144560947027`*^9}, {3.856914505488617*^9, 3.8569145803454976`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"7b100f7e-5a7d-4a29-9e28-971fe38dd069"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "5"]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"]}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "-", 
    RowBox[{"\[Alpha]", " ", 
     SubscriptBox["c", "0"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "7"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "9"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "-", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"10", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"3", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{"48", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "14"}], "-", 
          RowBox[{"2", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "-", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"10", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"32", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"5", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]"}], "+", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Alpha]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.859389759283837*^9, 3.8601075184454927`*^9, 
  3.8607828917048016`*^9, 3.8608700709749746`*^9, 3.860954292044205*^9, 
  3.8610292942763577`*^9, 3.861135294603388*^9, 3.863184311777108*^9, 
  3.863187256747357*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"a77b8aad-d1a4-419b-a6d4-482b0c53d39d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["c", "0", "3"]}]], 
  RowBox[{
   SubscriptBox["\[Mu]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"5", " ", 
         SubsuperscriptBox["c", "0", "2"]}], "-", 
        RowBox[{"2", " ", "\[Alpha]", " ", 
         SubsuperscriptBox["c", "0", "4"]}], "-", 
        SubsuperscriptBox["c", "0", "6"], "+", 
        RowBox[{"\[Alpha]", " ", 
         SubsuperscriptBox["c", "0", "8"]}]}], ")"}], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubscriptBox["c", "0"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], "-", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "3"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
      SubsuperscriptBox["c", "0", "5"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], "-", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "7"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubsuperscriptBox["c", "0", "9"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"5", " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["c", "0", "2"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "-", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "4"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubsuperscriptBox["c", "0", "6"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "8"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.859389759283837*^9, 3.8601075184454927`*^9, 
  3.8607828917048016`*^9, 3.8608700709749746`*^9, 3.860954292044205*^9, 
  3.8610292942763577`*^9, 3.861135294603388*^9, 3.863184311777108*^9, 
  3.8631872567785974`*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"c0128ff3-f913-43d6-93e6-3d8e6ff1d53b"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "5"]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"]}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{"\[Alpha]", " ", 
     SubscriptBox["c", "0"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "7"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", "\[Alpha]"}], "-", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "9"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "-", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "14"}], "+", 
          RowBox[{"2", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}]}], ")"}], 
        " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"10", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["c", "2"]}], "+", 
          SubscriptBox["\[Lambda]", "2"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["r", "1"]}], "+", 
             SubscriptBox["\[Mu]", "1"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"10", "-", 
             RowBox[{"3", " ", 
              SuperscriptBox["\[Alpha]", "2"], " ", 
              SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["r", "1"]}], "+", 
             SubscriptBox["\[Mu]", "1"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "20"}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["r", "1"], " ", 
              SubscriptBox["\[Mu]", "1"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"5", " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "+", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["c", "2"], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[Lambda]", "2"]}], "-", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.859389759283837*^9, 3.8601075184454927`*^9, 
  3.8607828917048016`*^9, 3.8608700709749746`*^9, 3.860954292044205*^9, 
  3.8610292942763577`*^9, 3.861135294603388*^9, 3.863184311777108*^9, 
  3.863187257309677*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"381eae08-96a6-461c-baa7-0c58db5eafd3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["S", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], "/", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["r", "1"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "^", "2"}]}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], ")"}]}], "]"}]}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"*", " ", 
      SubscriptBox["T", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", "is", " ", "negative", " ", "the", " ", 
      "second", " ", "derivative", " ", "of", " ", "the", " ", "dispersion", 
      " ", "relation", " ", "evaluated", " ", "at", " ", "k"}], "=", "1."}], 
    " ", "**)"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["U", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "/", "\[ImaginaryI]"}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", 
         "//.", " ", 
         RowBox[{
          SubscriptBox["r", "1"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
        " ", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["V", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "/", "\[ImaginaryI]"}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", 
         "//.", " ", 
         RowBox[{
          SubscriptBox["r", "1"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
        " ", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.836689133211673*^9, 3.8366892811053886`*^9}, {
  3.8366893156214914`*^9, 3.8366893215657945`*^9}, {3.836689390979411*^9, 
  3.836689422438686*^9}, {3.836689517623274*^9, 3.836689609515186*^9}, {
  3.8366899127684164`*^9, 3.8366899487457733`*^9}, {3.83668998998062*^9, 
  3.8366900043919163`*^9}, {3.836690203588502*^9, 3.8366904125567074`*^9}, {
  3.8366918976890163`*^9, 3.836691901236161*^9}, {3.8366920900986896`*^9, 
  3.8366920905286784`*^9}, {3.8366922089862857`*^9, 3.8366922124055276`*^9}, {
  3.8366924267192883`*^9, 3.836692430858803*^9}, {3.854481271275882*^9, 
  3.8544813042474856`*^9}, {3.8569002078497915`*^9, 3.8569002127469797`*^9}, {
  3.8587961087853546`*^9, 3.8587961544741936`*^9}, {3.8588679683728533`*^9, 
  3.8588679687164917`*^9}, {3.859389410616905*^9, 3.859389410616905*^9}, {
  3.859389805508938*^9, 3.859389815028309*^9}, {3.863184334040728*^9, 
  3.863184346914181*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"f7fffafa-2c1e-48cd-8029-01001fa8e0b0"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Alpha]", "+", 
   RowBox[{"5", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   SubsuperscriptBox["c", "0", "6"], "+", 
   RowBox[{"\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "8"]}]}], 
  RowBox[{"4", " ", 
   SubsuperscriptBox["c", "0", "2"]}]]], "Output",
 CellChangeTimes->{
  3.8569625083832564`*^9, 3.856965233998922*^9, 3.8570668212480364`*^9, 
   3.8580861208681564`*^9, 3.858093502945444*^9, 3.858689580517527*^9, 
   3.8587747029300566`*^9, 3.85886868342387*^9, 3.858890303230031*^9, 
   3.8589478687216773`*^9, 3.858966906396519*^9, 3.8589792898034954`*^9, 
   3.8590271683624535`*^9, 3.859040798077197*^9, 3.859047903631881*^9, 
   3.8593898161395645`*^9, 3.860107522666175*^9, {3.8607828924077377`*^9, 
   3.8607828930324974`*^9}, 3.860870074429205*^9, 3.8609542955399537`*^9, 
   3.8610292966866927`*^9, 3.8611352952503414`*^9, 3.863184347970649*^9, 
   3.8631872597776575`*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"a70583d1-c749-4d2f-8452-733dd22a2ed6"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], "-", 
   RowBox[{
    SubsuperscriptBox["c", "0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
      SubsuperscriptBox["c", "0", "2"], "+", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "4"]}]}], ")"}]}]}], 
  RowBox[{"4", " ", 
   SubsuperscriptBox["c", "0", "3"]}]]], "Output",
 CellChangeTimes->{
  3.8569625083832564`*^9, 3.856965233998922*^9, 3.8570668212480364`*^9, 
   3.8580861208681564`*^9, 3.858093502945444*^9, 3.858689580517527*^9, 
   3.8587747029300566`*^9, 3.85886868342387*^9, 3.858890303230031*^9, 
   3.8589478687216773`*^9, 3.858966906396519*^9, 3.8589792898034954`*^9, 
   3.8590271683624535`*^9, 3.859040798077197*^9, 3.859047903631881*^9, 
   3.8593898161395645`*^9, 3.860107522666175*^9, {3.8607828924077377`*^9, 
   3.8607828930324974`*^9}, 3.860870074429205*^9, 3.8609542955399537`*^9, 
   3.8610292966866927`*^9, 3.8611352952503414`*^9, 3.863184347970649*^9, 
   3.8631872598401384`*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"3538c0bf-8577-4cf5-b108-235d0e2b1f2f"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["1", 
     SubsuperscriptBox["c", "0", "3"]], "-", 
    RowBox[{"4", " ", 
     SubscriptBox["c", "0"]}], "+", 
    SubsuperscriptBox["c", "0", "5"], "-", 
    FractionBox[
     RowBox[{"4", " ", 
      SubscriptBox["N", 
       RowBox[{"2", ",", "2"}]]}], 
     SubscriptBox["c", "0"]], "+", 
    RowBox[{"12", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubscriptBox["N", 
      RowBox[{"2", ",", "2"}]]}], "-", 
    RowBox[{"16", " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8569625083832564`*^9, 3.856965233998922*^9, 3.8570668212480364`*^9, 
   3.8580861208681564`*^9, 3.858093502945444*^9, 3.858689580517527*^9, 
   3.8587747029300566`*^9, 3.85886868342387*^9, 3.858890303230031*^9, 
   3.8589478687216773`*^9, 3.858966906396519*^9, 3.8589792898034954`*^9, 
   3.8590271683624535`*^9, 3.859040798077197*^9, 3.859047903631881*^9, 
   3.8593898161395645`*^9, 3.860107522666175*^9, {3.8607828924077377`*^9, 
   3.8607828930324974`*^9}, 3.860870074429205*^9, 3.8609542955399537`*^9, 
   3.8610292966866927`*^9, 3.8611352952503414`*^9, 3.863184347970649*^9, 
   3.8631872599650784`*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"e4e97453-e0ef-46a0-828f-cc266a6bc9e9"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["c", "0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "14"}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "4"]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "8"]}], "+", 
      RowBox[{"10", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], "-", 
      RowBox[{"5", " ", 
       SubsuperscriptBox["c", "0", "6"], " ", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], "+", 
      RowBox[{"16", " ", 
       SubsuperscriptBox["c", "0", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "2"], "-", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["c", "2"]}], "+", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}], ")"}]}]}], ")"}]}]}], 
  RowBox[{
   RowBox[{"8", " ", 
    SubsuperscriptBox["c", "0", "5"]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["c", "0", "3"], " ", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "2"]}]}]]], "Output",
 CellChangeTimes->{
  3.8569625083832564`*^9, 3.856965233998922*^9, 3.8570668212480364`*^9, 
   3.8580861208681564`*^9, 3.858093502945444*^9, 3.858689580517527*^9, 
   3.8587747029300566`*^9, 3.85886868342387*^9, 3.858890303230031*^9, 
   3.8589478687216773`*^9, 3.858966906396519*^9, 3.8589792898034954`*^9, 
   3.8590271683624535`*^9, 3.859040798077197*^9, 3.859047903631881*^9, 
   3.8593898161395645`*^9, 3.860107522666175*^9, {3.8607828924077377`*^9, 
   3.8607828930324974`*^9}, 3.860870074429205*^9, 3.8609542955399537`*^9, 
   3.8610292966866927`*^9, 3.8611352952503414`*^9, 3.863184347970649*^9, 
   3.8631872602618585`*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"722f715a-652e-4951-9559-328484b1597f"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.860782867251386*^9, 
  3.8607828691413813`*^9}},ExpressionUUID->"1a572e5b-1723-457e-b975-\
9e266b74a347"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Limits", " ", "of", " ", "these", " ", "quantities", " ", "as",
      " ", "\[Alpha]"}], " ", "->", " ", "Infinity"}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], "->", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", "->", "Infinity"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["T", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", " ", "->", " ", "Infinity"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["U", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], " ", "->", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
           RowBox[{"(", 
            RowBox[{"4", 
             SuperscriptBox[
              SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], " ", "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", ",", 
     RowBox[{"\[Alpha]", "->", "Infinity"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["V", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
              ")"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", "->", " ", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"4", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "0"], " ", "->", " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "j_"], ":>", " ", 
       RowBox[{"\[Omega]", "[", 
        RowBox[{"j", "+", 
         SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", "->", "Infinity"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.856914623171461*^9, {3.8569146547216835`*^9, 3.856914755135185*^9}, {
   3.856914793940728*^9, 3.8569148016746545`*^9}, {3.8569148321436033`*^9, 
   3.8569148346712284`*^9}, {3.856914865076108*^9, 3.8569149029491615`*^9}, 
   3.856914986784205*^9, {3.8569152729309125`*^9, 3.8569153160142965`*^9}, {
   3.856965367695408*^9, 3.8569653722403364`*^9}, 3.858868691233864*^9, {
   3.863184378712474*^9, 3.8631844228076596`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"32554275-2b8d-4252-9834-57f0bb28b1b1"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.856914694854742*^9, 3.856914713562293*^9}, 
   3.8569147559837575`*^9, {3.856914873163534*^9, 3.8569149035297136`*^9}, 
   3.85691498830657*^9, 3.856915320282386*^9, 3.8569653752805243`*^9, 
   3.858086122914394*^9, 3.858093503882643*^9, 3.85868958247252*^9, 
   3.8587747038706017`*^9, 3.858868694395377*^9, 3.8589478745568914`*^9, 
   3.8593898426483145`*^9, 3.860107525368434*^9, {3.863184410905357*^9, 
   3.8631844231993537`*^9}, 3.863187262433038*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"9f2aae48-e7c5-4c5e-a1cf-55bb08c69100"],

Cell[BoxData[
 FractionBox["1", "4"]], "Output",
 CellChangeTimes->{{3.856914694854742*^9, 3.856914713562293*^9}, 
   3.8569147559837575`*^9, {3.856914873163534*^9, 3.8569149035297136`*^9}, 
   3.85691498830657*^9, 3.856915320282386*^9, 3.8569653752805243`*^9, 
   3.858086122914394*^9, 3.858093503882643*^9, 3.85868958247252*^9, 
   3.8587747038706017`*^9, 3.858868694395377*^9, 3.8589478745568914`*^9, 
   3.8593898426483145`*^9, 3.860107525368434*^9, {3.863184410905357*^9, 
   3.8631844231993537`*^9}, 3.863187262495536*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"aa515faa-d15e-421e-beb7-d9584b2b7fc0"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.856914694854742*^9, 3.856914713562293*^9}, 
   3.8569147559837575`*^9, {3.856914873163534*^9, 3.8569149035297136`*^9}, 
   3.85691498830657*^9, 3.856915320282386*^9, 3.8569653752805243`*^9, 
   3.858086122914394*^9, 3.858093503882643*^9, 3.85868958247252*^9, 
   3.8587747038706017`*^9, 3.858868694395377*^9, 3.8589478745568914`*^9, 
   3.8593898426483145`*^9, 3.860107525368434*^9, {3.863184410905357*^9, 
   3.8631844231993537`*^9}, 3.8631872625892363`*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"89671364-2902-47df-a7ac-da4c50860427"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.856914694854742*^9, 3.856914713562293*^9}, 
   3.8569147559837575`*^9, {3.856914873163534*^9, 3.8569149035297136`*^9}, 
   3.85691498830657*^9, 3.856915320282386*^9, 3.8569653752805243`*^9, 
   3.858086122914394*^9, 3.858093503882643*^9, 3.85868958247252*^9, 
   3.8587747038706017`*^9, 3.858868694395377*^9, 3.8589478745568914`*^9, 
   3.8593898426483145`*^9, 3.860107525368434*^9, {3.863184410905357*^9, 
   3.8631844231993537`*^9}, 3.863187262776675*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"183228af-3d31-4dad-a8d0-31210386c0c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}], ",", "v2"}]], "=", 
     RowBox[{
      RowBox[{"2", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["c", "g"], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], " ", "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["U", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["T", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
            SubscriptBox["V", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "-", 
      SubscriptBox["cond", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}], ",", "v2"}]]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8366904527260375`*^9, 3.836690596902311*^9}, {
   3.836692122310469*^9, 3.8366921281367273`*^9}, 3.8366924430892496`*^9, {
   3.8366924777417955`*^9, 3.8366924823336554`*^9}, {3.854481255396475*^9, 
   3.854481258789068*^9}, {3.856870077899519*^9, 3.8568700801550455`*^9}, {
   3.856900221656106*^9, 3.8569002263264856`*^9}, {3.8569152344969597`*^9, 
   3.8569152449213505`*^9}, 3.859389410632526*^9, {3.8631844340897455`*^9, 
   3.8631844353254843`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"1bf015e2-4f49-412d-be92-4a2408f4a10d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8569653855810995`*^9, 3.8570668313558865`*^9, {3.858086126230982*^9, 
   3.858086129610923*^9}, 3.858093504819841*^9, 3.858689586393116*^9, 
   3.858774704466907*^9, 3.858868701471674*^9, 3.8588903209410954`*^9, 
   3.8589478783723884`*^9, 3.858966907044695*^9, 3.8589792904282875`*^9, 
   3.859027176016411*^9, 3.8590408081438665`*^9, 3.8590479086974554`*^9, 
   3.859389865503521*^9, 3.8601075283387804`*^9, 3.8607828936416755`*^9, 
   3.860870082421461*^9, 3.860954300470553*^9, 3.86102930265355*^9, 
   3.861135295969241*^9, 3.863184436395893*^9, 3.8631872652602816`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"88bbd527-1d56-4935-ae88-f88140de4122"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"2", ",", "0"}]], "=", 
    RowBox[{"Factor", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", 
          SubscriptBox["cond", 
           RowBox[{"2", ",", "0"}]], "]"}], ",", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "^", "2"}]}], "]"}], "/", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["S", 
     RowBox[{"2", ",", "0"}]], " ", "=", " ", 
    RowBox[{"Factor", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", 
          SubscriptBox["cond", 
           RowBox[{"2", ",", "0"}]], "]"}], ",", 
         SubscriptBox["\[Mu]", "1"]}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], ")"}]}], "]"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8569157129984894`*^9, 3.8569157530505443`*^9}, {
  3.856915799532321*^9, 3.8569158394651814`*^9}, {3.856915891467896*^9, 
  3.8569159734390345`*^9}, {3.8569625985940943`*^9, 3.8569626183367443`*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"6184f214-e240-40f4-b62a-2c4b58a65333"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "-", 
     SubsuperscriptBox["c", "0", "2"], "-", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "2"]}], "+", 
     RowBox[{"\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "4"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "-", 
     SubsuperscriptBox["c", "0", "2"], "+", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "2"]}], "+", 
     RowBox[{"\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "4"]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   SubsuperscriptBox["c", "0", "2"]}]]], "Output",
 CellChangeTimes->{{3.8569157162804775`*^9, 3.8569157533480296`*^9}, {
   3.8569158098880796`*^9, 3.8569158262465982`*^9}, {3.856915908587205*^9, 
   3.856915921604207*^9}, {3.856915955264983*^9, 3.856915974208338*^9}, {
   3.856962602872752*^9, 3.8569626187604265`*^9}, 3.856965427007052*^9, 
   3.8570668359833364`*^9, 3.8580861340155115`*^9, 3.8580935049448004`*^9, 
   3.8586895950837855`*^9, 3.858774704529814*^9, 3.858868706860571*^9, 
   3.8588903250919247`*^9, 3.858947883089625*^9, 3.858966907144814*^9, 
   3.8589792905376277`*^9, 3.859027183053843*^9, 3.859040810721653*^9, 
   3.859047911873412*^9, 3.8593898865648985`*^9, 3.8601075323868923`*^9, 
   3.860782893719758*^9, 3.860870085470064*^9, 3.8609543044455676`*^9, 
   3.8610293056643443`*^9, 3.8611352961437607`*^9, 3.863184449027405*^9, 
   3.8631872674281797`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"abe2072e-4091-417f-85eb-0fe2122c628c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Alpha]", "+", 
   RowBox[{"5", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   SubsuperscriptBox["c", "0", "6"], "+", 
   RowBox[{"\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "8"]}]}], 
  RowBox[{"4", " ", 
   SubsuperscriptBox["c", "0", "3"]}]]], "Output",
 CellChangeTimes->{{3.8569157162804775`*^9, 3.8569157533480296`*^9}, {
   3.8569158098880796`*^9, 3.8569158262465982`*^9}, {3.856915908587205*^9, 
   3.856915921604207*^9}, {3.856915955264983*^9, 3.856915974208338*^9}, {
   3.856962602872752*^9, 3.8569626187604265`*^9}, 3.856965427007052*^9, 
   3.8570668359833364`*^9, 3.8580861340155115`*^9, 3.8580935049448004`*^9, 
   3.8586895950837855`*^9, 3.858774704529814*^9, 3.858868706860571*^9, 
   3.8588903250919247`*^9, 3.858947883089625*^9, 3.858966907144814*^9, 
   3.8589792905376277`*^9, 3.859027183053843*^9, 3.859040810721653*^9, 
   3.859047911873412*^9, 3.8593898865648985`*^9, 3.8601075323868923`*^9, 
   3.860782893719758*^9, 3.860870085470064*^9, 3.8609543044455676`*^9, 
   3.8610293056643443`*^9, 3.8611352961437607`*^9, 3.863184449027405*^9, 
   3.863187267443765*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"16e1be86-7304-4e83-865c-6c8f0d24d357"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Limit", " ", "of", " ", "these", " ", 
    RowBox[{"quantities", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"2", ",", "0"}]], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["c", "0"], "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", " ", "->", " ", "Infinity"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["T", 
       RowBox[{"2", ",", "0"}]], "//.", " ", 
      RowBox[{
       SubscriptBox["c", "0"], "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", "->", " ", "Infinity"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8569159914552064`*^9, 3.8569160332149315`*^9}, {
  3.863184456560405*^9, 3.8631844674287877`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"5fd798eb-1989-4fe0-b6cf-1e53efe40699"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.856916033622877*^9, 3.856965427168224*^9, 3.8580861356436*^9, 
   3.858774704624605*^9, 3.859389893170122*^9, 3.860782893860355*^9, {
   3.863184451938575*^9, 3.863184469273577*^9}, 3.8631872690994525`*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"46acb370-a2e3-4567-813f-9e0ac30d2d96"],

Cell[BoxData[
 RowBox[{"-", "\[Infinity]"}]], "Output",
 CellChangeTimes->{
  3.856916033622877*^9, 3.856965427168224*^9, 3.8580861356436*^9, 
   3.858774704624605*^9, 3.859389893170122*^9, 3.860782893860355*^9, {
   3.863184451938575*^9, 3.863184469273577*^9}, 3.8631872691463337`*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"d9685f17-e475-4be7-9594-3720fadccaa7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"2", ",", "0", ",", "v2"}]], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       SubscriptBox["T", 
        RowBox[{"2", ",", "0"}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "+", " ", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]], "+", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"2", ",", "0", ",", "v2"}]], "-", 
      SubscriptBox["cond", 
       RowBox[{"2", ",", "0"}]]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8366919721118717`*^9, 3.836691987777651*^9}, {
  3.836692019277685*^9, 3.836692020278702*^9}, {3.8569002862763805`*^9, 
  3.856900290575028*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"9171d768-66a4-4e48-8e08-47cfc17ff4be"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836691973301375*^9, 3.836691988254792*^9}, 
   3.8366920341697826`*^9, 3.8366922324628744`*^9, 3.8544813647900286`*^9, 
   3.8544900016532845`*^9, 3.856870224602458*^9, 3.856900291043652*^9, 
   3.856916544088852*^9, 3.8569654273998203`*^9, 3.8570668419482875`*^9, 
   3.858086138976636*^9, 3.858093505054141*^9, 3.858689602335986*^9, 
   3.858774704749454*^9, {3.8588687132179403`*^9, 3.858868728643682*^9}, 
   3.8588903315533876`*^9, 3.858947891467131*^9, 3.8589669072281475`*^9, 
   3.8589792906469755`*^9, 3.859027201532323*^9, 3.859040825726391*^9, 
   3.8590479153970375`*^9, 3.859389908354746*^9, 3.8601075377938433`*^9, 
   3.860782893969694*^9, 3.860870089265707*^9, 3.8609543079763002`*^9, 
   3.86102930842097*^9, 3.8631844885422063`*^9, 3.8631872717788444`*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"57f2caf8-9570-4192-8958-ce801192fa68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["S", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"2", ",", "1"}]], "/", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["r", "1"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"2", ",", "1"}]], "/", 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], ")"}]}], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["U", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", "1"}]], "/", "\[ImaginaryI]"}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "]"}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
        " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
      " ", 
      RowBox[{
       SubscriptBox["r", "1"], " ", "\[Rule]", " ", "0"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["V", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", "1"}]], "/", "\[ImaginaryI]"}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "]"}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
        " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
      " ", 
      RowBox[{
       SubscriptBox["r", "1"], " ", "\[Rule]", " ", "0"}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.8366922635526843`*^9, {3.836692514841197*^9, 3.836692743797945*^9}, {
   3.8366929391480827`*^9, 3.836692991955048*^9}, {3.8366930283859544`*^9, 
   3.8366930939630375`*^9}, {3.8544813998425455`*^9, 
   3.8544814209568043`*^9}, {3.8569003429131384`*^9, 3.8569003531209326`*^9}, 
   3.858868723915515*^9, {3.8593894106509404`*^9, 3.8593894106600094`*^9}, {
   3.8593899169698052`*^9, 3.8593899245688868`*^9}, 3.863184521590878*^9},
 CellLabel->"In[71]:=",ExpressionUUID->"3462fb37-b006-4fb4-8de1-6400ef60c223"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"\[Alpha]", "+", 
    RowBox[{"5", " ", 
     SubsuperscriptBox["c", "0", "2"]}], "-", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "4"]}], "-", 
    SubsuperscriptBox["c", "0", "6"], "+", 
    RowBox[{"\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "8"]}]}], 
   RowBox[{"4", " ", 
    SubsuperscriptBox["c", "0", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, {3.8544814083737497`*^9, 3.8544814217690134`*^9}, 
   3.8544900089410076`*^9, 3.8568702320088615`*^9, {3.8569003292947054`*^9, 
   3.8569003541674705`*^9}, 3.856916554201477*^9, 3.8569654315706167`*^9, 
   3.857066845041023*^9, 3.8580861403944783`*^9, 3.8580935051634827`*^9, 
   3.858689604241585*^9, 3.858774704811937*^9, 3.8588687243912387`*^9, 
   3.8588903341227117`*^9, 3.8589478942246933`*^9, 3.858966907325246*^9, 
   3.85897929074072*^9, 3.85902720587053*^9, 3.8590408282590623`*^9, 
   3.8590479174700513`*^9, 3.8593899259840097`*^9, 3.86010754001188*^9, 
   3.8607828940634146`*^9, 3.860870091096925*^9, 3.8609543100149918`*^9, 
   3.8610293104828496`*^9, 3.861135296237996*^9, 3.8631844932030716`*^9, 
   3.8631872755432863`*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"ddd10b2d-2a00-4308-b356-1fd5fae99188"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["\[Alpha]", "2"]}], "+", 
   RowBox[{
    SubsuperscriptBox["c", "0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
      SubsuperscriptBox["c", "0", "2"], "+", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["c", "0", "4"]}]}], ")"}]}]}], 
  RowBox[{"4", " ", 
   SubsuperscriptBox["c", "0", "3"]}]]], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, {3.8544814083737497`*^9, 3.8544814217690134`*^9}, 
   3.8544900089410076`*^9, 3.8568702320088615`*^9, {3.8569003292947054`*^9, 
   3.8569003541674705`*^9}, 3.856916554201477*^9, 3.8569654315706167`*^9, 
   3.857066845041023*^9, 3.8580861403944783`*^9, 3.8580935051634827`*^9, 
   3.858689604241585*^9, 3.858774704811937*^9, 3.8588687243912387`*^9, 
   3.8588903341227117`*^9, 3.8589478942246933`*^9, 3.858966907325246*^9, 
   3.85897929074072*^9, 3.85902720587053*^9, 3.8590408282590623`*^9, 
   3.8590479174700513`*^9, 3.8593899259840097`*^9, 3.86010754001188*^9, 
   3.8607828940634146`*^9, 3.860870091096925*^9, 3.8609543100149918`*^9, 
   3.8610293104828496`*^9, 3.861135296237996*^9, 3.8631844932030716`*^9, 
   3.863187275590264*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"6164eee9-f4db-4791-a7f3-7ad1d8e1de07"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "3"]}]]}], "+", 
  SubscriptBox["c", "0"], "-", 
  FractionBox[
   SubsuperscriptBox["c", "0", "5"], "4"], "+", 
  FractionBox[
   SubscriptBox["N", 
    RowBox[{"2", ",", "2"}]], 
   SubscriptBox["c", "0"]], "-", 
  RowBox[{"3", " ", 
   SubsuperscriptBox["c", "0", "3"], " ", 
   SubscriptBox["N", 
    RowBox[{"2", ",", "2"}]]}], "+", 
  RowBox[{"4", " ", 
   SubscriptBox["Q", 
    RowBox[{"2", ",", "2"}]]}]}]], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, {3.8544814083737497`*^9, 3.8544814217690134`*^9}, 
   3.8544900089410076`*^9, 3.8568702320088615`*^9, {3.8569003292947054`*^9, 
   3.8569003541674705`*^9}, 3.856916554201477*^9, 3.8569654315706167`*^9, 
   3.857066845041023*^9, 3.8580861403944783`*^9, 3.8580935051634827`*^9, 
   3.858689604241585*^9, 3.858774704811937*^9, 3.8588687243912387`*^9, 
   3.8588903341227117`*^9, 3.8589478942246933`*^9, 3.858966907325246*^9, 
   3.85897929074072*^9, 3.85902720587053*^9, 3.8590408282590623`*^9, 
   3.8590479174700513`*^9, 3.8593899259840097`*^9, 3.86010754001188*^9, 
   3.8607828940634146`*^9, 3.860870091096925*^9, 3.8609543100149918`*^9, 
   3.8610293104828496`*^9, 3.861135296237996*^9, 3.8631844932030716`*^9, 
   3.8631872757151294`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"98837ce3-c707-4de0-9b92-3e76219cd653"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SubsuperscriptBox["\[Omega]", "2", "2"], "+", 
   RowBox[{
    SubsuperscriptBox["c", "0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"14", "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "4"]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "8"]}], "-", 
      RowBox[{"10", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
      RowBox[{"5", " ", 
       SubsuperscriptBox["c", "0", "6"], " ", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["c", "2"], "-", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
      RowBox[{"16", " ", 
       SubsuperscriptBox["c", "0", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["c", "2"]}], "+", 
         SubscriptBox["Q", 
          RowBox[{"2", ",", "0"}]]}], ")"}]}]}], ")"}]}]}], 
  RowBox[{
   RowBox[{"8", " ", 
    SubsuperscriptBox["c", "0", "5"]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["c", "0", "3"], " ", 
    SubsuperscriptBox["\[Omega]", "2", "2"]}]}]]], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, {3.8544814083737497`*^9, 3.8544814217690134`*^9}, 
   3.8544900089410076`*^9, 3.8568702320088615`*^9, {3.8569003292947054`*^9, 
   3.8569003541674705`*^9}, 3.856916554201477*^9, 3.8569654315706167`*^9, 
   3.857066845041023*^9, 3.8580861403944783`*^9, 3.8580935051634827`*^9, 
   3.858689604241585*^9, 3.858774704811937*^9, 3.8588687243912387`*^9, 
   3.8588903341227117`*^9, 3.8589478942246933`*^9, 3.858966907325246*^9, 
   3.85897929074072*^9, 3.85902720587053*^9, 3.8590408282590623`*^9, 
   3.8590479174700513`*^9, 3.8593899259840097`*^9, 3.86010754001188*^9, 
   3.8607828940634146`*^9, 3.860870091096925*^9, 3.8609543100149918`*^9, 
   3.8610293104828496`*^9, 3.861135296237996*^9, 3.8631844932030716`*^9, 
   3.8631872760431027`*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"76fc6366-1bbe-4d4b-9497-2430dd4ee00e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Limit", " ", "of", " ", "these", " ", "quantities", " ", "as", 
     " ", "\[Alpha]"}], " ", "->", " ", 
    RowBox[{"Infinity", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"2", ",", "1"}]], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], "->", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", "->", "Infinity"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["T", 
       RowBox[{"2", ",", "1"}]], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", " ", "->", " ", "Infinity"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["U", 
           RowBox[{"2", ",", "1"}]], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "->", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
           RowBox[{"(", 
            RowBox[{"4", 
             SuperscriptBox[
              SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], " ", "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", ",", 
     RowBox[{"\[Alpha]", "->", "Infinity"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["V", 
            RowBox[{"2", ",", "1"}]], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
              ")"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", "->", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"4", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "0"], " ", "->", " ", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
      RowBox[{
       SubscriptBox["\[Omega]", "j_"], ":>", " ", 
       RowBox[{"\[Omega]", "[", 
        RowBox[{"j", "+", 
         SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], ",", 
     RowBox[{"\[Alpha]", "->", "Infinity"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8569165810588517`*^9, 3.856916593951333*^9}, {
  3.8569648664422135`*^9, 3.8569648786337667`*^9}, {3.858868737812642*^9, 
  3.8588687389841137`*^9}, {3.863184498373721*^9, 3.8631845149482975`*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"d9d3fc3c-17a3-4848-ba46-85f685b6c5ed"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{3.8569165949708414`*^9, 3.856953203936818*^9, 
  3.8569648846095448`*^9, 3.8569654443711147`*^9, 3.858086142674898*^9, 
  3.8580935060225835`*^9, 3.858868739452716*^9, 3.8608700933617973`*^9, 
  3.8631845168331842`*^9, 3.8631872779667196`*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"04d4d453-0369-4ef5-b465-3c12798a8671"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", "4"]}]], "Output",
 CellChangeTimes->{3.8569165949708414`*^9, 3.856953203936818*^9, 
  3.8569648846095448`*^9, 3.8569654443711147`*^9, 3.858086142674898*^9, 
  3.8580935060225835`*^9, 3.858868739452716*^9, 3.8608700933617973`*^9, 
  3.8631845168331842`*^9, 3.863187278029219*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"86b368b4-f3f5-410b-92b2-385a1d96f8cd"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.8569165949708414`*^9, 3.856953203936818*^9, 
  3.8569648846095448`*^9, 3.8569654443711147`*^9, 3.858086142674898*^9, 
  3.8580935060225835`*^9, 3.858868739452716*^9, 3.8608700933617973`*^9, 
  3.8631845168331842`*^9, 3.863187278107317*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"ff6e8ffb-b090-47ab-b2a1-81c530b08ae1"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.8569165949708414`*^9, 3.856953203936818*^9, 
  3.8569648846095448`*^9, 3.8569654443711147`*^9, 3.858086142674898*^9, 
  3.8580935060225835`*^9, 3.858868739452716*^9, 3.8608700933617973`*^9, 
  3.8631845168331842`*^9, 3.863187278263543*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"01c031de-f7ac-4862-8b1d-71f64a3efa17"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"2", ",", "1", ",", "v2"}]], "=", 
     RowBox[{
      RowBox[{"2", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["c", "g"], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "1"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["U", 
           RowBox[{"2", ",", "1"}]], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["T", 
              RowBox[{"2", ",", "1"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
            SubscriptBox["V", 
             RowBox[{"2", ",", "1"}]]}], ")"}], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"2", ",", "1", ",", "v2"}]], "-", 
      SubscriptBox["cond", 
       RowBox[{"2", ",", "1"}]]}], "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8366928289670663`*^9, 3.8366929247157607`*^9}, {
   3.836693100976225*^9, 3.836693125132848*^9}, {3.854481434449382*^9, 
   3.8544814377285166`*^9}, {3.8568702577323503`*^9, 
   3.8568702584196625`*^9}, {3.85690036087121*^9, 3.8569003647160473`*^9}, 
   3.8593894106756535`*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"641bbf34-dd3f-4b53-914d-a6e593739839"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8366931255086718`*^9, 3.854481440450291*^9, 
  3.8544900133983784`*^9, 3.8568702594661655`*^9, 3.8569003696215525`*^9, 
  3.856916633342101*^9, 3.8569654508027315`*^9, 3.857066850418586*^9, 
  3.8580861462542734`*^9, 3.8580935066786184`*^9, 3.858689613799885*^9, 
  3.8587747054077024`*^9, 3.8588687467665887`*^9, 3.8588903422532835`*^9, 
  3.8589479068487854`*^9, 3.8589669079002495`*^9, 3.8589792913186054`*^9, 
  3.8590272104098372`*^9, 3.8590408335542307`*^9, 3.8590479216266794`*^9, 
  3.859389944414926*^9, 3.8601075445124545`*^9, 3.8607828987831593`*^9, 
  3.8608700956775246`*^9, 3.8609543142181063`*^9, 3.8610293146868143`*^9, 
  3.861135296820408*^9, 3.8631845386008053`*^9, 3.863187280544038*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"060f80a3-61ff-419f-9f35-24df07fd818a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Proofs", " ", "of", " ", "identities", " ", "of", " ", 
    "capitalized", " ", 
    RowBox[{"coefficients", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["S", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["T", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["T", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["U", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["U", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["V", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "+", 
      SubscriptBox["V", 
       RowBox[{"2", ",", "1"}]]}], "//.", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"-", "2"}]], " ", "\[Rule]", " ", 
      RowBox[{"-", 
       SubscriptBox["\[Omega]", "2"]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8366931420804*^9, 3.8366932267566977`*^9}, {
  3.8544814627170315`*^9, 3.8544814720804152`*^9}, {3.854481967736924*^9, 
  3.854481977161289*^9}, {3.8568702690037594`*^9, 3.8568702694411235`*^9}, {
  3.8631845415028057`*^9, 3.8631845650398874`*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"b0a506d9-e525-4026-a825-f3251f278f77"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.8544814457010565`*^9, 3.854481473064479*^9}, 3.85448197772358*^9, 
   3.854490015507075*^9, 3.8568702708472347`*^9, 3.8569003767800837`*^9, 
   3.8569166419250174`*^9, 3.8569654527010183`*^9, 3.8570668527147408`*^9, 
   3.8580861477225647`*^9, 3.858093506772341*^9, 3.858689616081333*^9, 
   3.8587747054706545`*^9, 3.8588687494064045`*^9, 3.858890344735115*^9, 
   3.858947908776019*^9, 3.858966907962738*^9, 3.8589792914123745`*^9, 
   3.8590272126833305`*^9, 3.8590408357098103`*^9, 3.85904792309124*^9, 
   3.859389947143156*^9, 3.8607828999858694`*^9, 3.860870097395692*^9, 
   3.8609543161726227`*^9, 3.8610293160301323`*^9, 3.8611352968919363`*^9, 
   3.863184569799133*^9, 3.863187284247504*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"cd74cce5-f0f3-49aa-8459-e4423a14db04"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.8544814457010565`*^9, 3.854481473064479*^9}, 3.85448197772358*^9, 
   3.854490015507075*^9, 3.8568702708472347`*^9, 3.8569003767800837`*^9, 
   3.8569166419250174`*^9, 3.8569654527010183`*^9, 3.8570668527147408`*^9, 
   3.8580861477225647`*^9, 3.858093506772341*^9, 3.858689616081333*^9, 
   3.8587747054706545`*^9, 3.8588687494064045`*^9, 3.858890344735115*^9, 
   3.858947908776019*^9, 3.858966907962738*^9, 3.8589792914123745`*^9, 
   3.8590272126833305`*^9, 3.8590408357098103`*^9, 3.85904792309124*^9, 
   3.859389947143156*^9, 3.8607828999858694`*^9, 3.860870097395692*^9, 
   3.8609543161726227`*^9, 3.8610293160301323`*^9, 3.8611352968919363`*^9, 
   3.863184569799133*^9, 3.8631872842631245`*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"62530f0c-3c9c-4b69-99f0-51f36f6f4fb8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.8544814457010565`*^9, 3.854481473064479*^9}, 3.85448197772358*^9, 
   3.854490015507075*^9, 3.8568702708472347`*^9, 3.8569003767800837`*^9, 
   3.8569166419250174`*^9, 3.8569654527010183`*^9, 3.8570668527147408`*^9, 
   3.8580861477225647`*^9, 3.858093506772341*^9, 3.858689616081333*^9, 
   3.8587747054706545`*^9, 3.8588687494064045`*^9, 3.858890344735115*^9, 
   3.858947908776019*^9, 3.858966907962738*^9, 3.8589792914123745`*^9, 
   3.8590272126833305`*^9, 3.8590408357098103`*^9, 3.85904792309124*^9, 
   3.859389947143156*^9, 3.8607828999858694`*^9, 3.860870097395692*^9, 
   3.8609543161726227`*^9, 3.8610293160301323`*^9, 3.8611352968919363`*^9, 
   3.863184569799133*^9, 3.8631872842787685`*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"f3b9b09e-e29f-49f4-a0c5-5081d13da59b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.8544814457010565`*^9, 3.854481473064479*^9}, 3.85448197772358*^9, 
   3.854490015507075*^9, 3.8568702708472347`*^9, 3.8569003767800837`*^9, 
   3.8569166419250174`*^9, 3.8569654527010183`*^9, 3.8570668527147408`*^9, 
   3.8580861477225647`*^9, 3.858093506772341*^9, 3.858689616081333*^9, 
   3.8587747054706545`*^9, 3.8588687494064045`*^9, 3.858890344735115*^9, 
   3.858947908776019*^9, 3.858966907962738*^9, 3.8589792914123745`*^9, 
   3.8590272126833305`*^9, 3.8590408357098103`*^9, 3.85904792309124*^9, 
   3.859389947143156*^9, 3.8607828999858694`*^9, 3.860870097395692*^9, 
   3.8609543161726227`*^9, 3.8610293160301323`*^9, 3.8611352968919363`*^9, 
   3.863184569799133*^9, 3.8631872842787685`*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"45a41919-d541-4d67-98dd-3753a094d517"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"*", " ", 
      SubscriptBox["symV", "2"]}], "-", 
     SubscriptBox["symU", "2"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"0", " ", "when", " ", "\[Alpha]"}], " ", ">", " ", "0."}]}], 
   " ", "**)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["U", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "-", 
           RowBox[{"(", 
            SubscriptBox["V", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], ")"}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], " ", "->", " ", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
           RowBox[{"(", 
            RowBox[{"4", 
             SuperscriptBox[
              SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], " ", "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "j_"], ":>", " ", 
      RowBox[{"\[Omega]", "[", 
       RowBox[{"j", "+", 
        SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.859041792708336*^9, 3.8590418141299577`*^9}, 
   3.863184639443183*^9},
 CellLabel->"In[85]:=",ExpressionUUID->"b9ef80e0-8b16-44dd-8a84-228a70cad8ba"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8590418148986793`*^9, 3.8590479773687334`*^9, 
  3.8607829050243263`*^9, 3.863184640168337*^9, 3.863187286843899*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"ad672b53-bf9f-4778-b573-d161ccf44bd6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Express", " ", "the", " ", "solvability", " ", "conditions", 
     " ", "using", " ", "symbolic", " ", 
     RowBox[{"variables", ".", " ", "Here"}]}], ",", " ", 
    RowBox[{
    "the", " ", "prefix", " ", "sym", " ", "is", " ", "used", " ", "so", " ", 
     "that", " ", "the", " ", "full", " ", "expressions", " ", "of", " ", 
     "the", " ", "variables", " ", "below", " ", "are", " ", "supressed"}], 
    ",", " ", 
    RowBox[{"for", " ", "ease", " ", "of", " ", 
     RowBox[{"readability", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
  " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}], ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{"2", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["c", "g"], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], " ", "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["symU", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symT", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
            SubscriptBox["symV", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"2", ",", "0", ",", "v2"}]], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "+", " ", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]], "+", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"2", ",", "1", ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{"2", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["c", "g"], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], " ", "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{"-", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}], ")"}], "*", 
       SubscriptBox["\[Mu]", "1"]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symU", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], ")"}], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
            RowBox[{"(", 
             RowBox[{"-", 
              SubscriptBox["symV", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}], ")"}], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8569532344696755`*^9, 3.8569532430625334`*^9}, {
  3.856953406323129*^9, 3.8569534397679105`*^9}, {3.856953823408745*^9, 
  3.856953834709542*^9}, {3.8569538860649204`*^9, 3.8569538958641276`*^9}, {
  3.858774667804522*^9, 3.8587747139523115`*^9}, {3.858775117912142*^9, 
  3.8587751408556976`*^9}, {3.8593894106756535`*^9, 3.859389410691269*^9}, {
  3.863184646727775*^9, 3.863184693907626*^9}, {3.8631847328939047`*^9, 
  3.8631847610709333`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"a27ffe86-bcea-4e87-a069-51ecc8e9b69f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Solve", " ", "the", " ", "solvability", " ", "conditions", " ", 
    "for", " ", 
    SubscriptBox["\[Lambda]", "2"], " ", "and", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"+", 
        RowBox[{"/", 
         RowBox[{"-", "1"}]}]}]}]], "."}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"Expand", "[", 
   RowBox[{"PowerExpand", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Refine", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Refine", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"Refine", "[", 
            RowBox[{
             RowBox[{"Simplify", "[", 
              RowBox[{
               RowBox[{"Solve", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symcond", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}], ",", "v2"}]], "==", "0"}], " ", "&&", 
                  "\[IndentingNewLine]", " ", 
                  RowBox[{
                   SubscriptBox["symcond", 
                    RowBox[{"2", ",", "0", ",", "v2"}]], "==", "0"}], " ", "&&",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   SubscriptBox["symcond", 
                    RowBox[{"2", ",", "1", ",", "v2"}]], "==", "0"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   SubscriptBox["\[Lambda]", "2"], ",", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "}"}]}], "]"}], "//.", " ", 
               RowBox[{
                SubscriptBox["symV", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], "->", " ", 
                SubscriptBox["symU", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]], ">", "0"}], ",", 
               RowBox[{
                SubscriptBox["symT", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], ">", "0"}], ",", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "}"}]}], "]"}], " ",
            "]"}], ",", 
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], ">", "0"}]}], "]"}], "]"}], ",", 
       RowBox[{
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], "<", "0"}]}], "]"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.860107599048443*^9, 3.860107636528846*^9}, {
  3.860107684049719*^9, 3.860107684237155*^9}, {3.8601078835917864`*^9, 
  3.8601079033785996`*^9}, {3.8601079556010303`*^9, 3.8601079682321386`*^9}, {
  3.8631847020996065`*^9, 3.863184722950469*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"76892369-c2e0-4d71-b904-cfae233ed5f5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["c", "g"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"]}], "+", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symU", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]], "-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symU", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]], "+", 
       FractionBox[
        RowBox[{
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symU", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["c", "g"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"]}], "-", 
       FractionBox[
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symU", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]], "+", 
       FractionBox[
        RowBox[{
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symU", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]], "-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symU", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SqrtBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]]}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8601076008447385`*^9, 3.8601076393249383`*^9}, 
   3.8601076861740336`*^9, {3.860107888285323*^9, 3.860107904409539*^9}, {
   3.860107960147253*^9, 3.8601079693783827`*^9}, 3.8607829173240786`*^9, 
   3.8608701096720953`*^9, 3.860954328468764*^9, 3.8610293244240527`*^9, 
   3.861135298198074*^9, 3.8631847249092317`*^9, 3.8631872915923967`*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"d5b2be79-1a5f-4300-83b6-bd025dfbaa50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Redefining", " ", "the", " ", "solutions", " ", "above", " ", 
     "in", " ", "terms", " ", "of", " ", "the", " ", "variables", " ", 
     SubscriptBox["e", "BW"]}], ",", " ", 
    SubscriptBox["e", "\[Placeholder]"]}], " ", "**)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["symLambdaBeta", "2"], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Refine", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"Refine", "[", 
             RowBox[{
              RowBox[{"Simplify", "[", 
               RowBox[{"Refine", "[", 
                RowBox[{
                 RowBox[{"Simplify", "[", 
                  RowBox[{
                   RowBox[{"Refine", "[", 
                    RowBox[{
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{"Solve", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}], ",", "v2"}]], "==", "0"}], " ", "&&", 
                    "\[IndentingNewLine]", " ", 
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"2", ",", "0", ",", "v2"}]], "==", "0"}], " ", "&&",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"2", ",", "1", ",", "v2"}]], "==", "0"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "2"], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "}"}]}], "]"}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symV", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]], ">", "0"}], ",", 
                    RowBox[{
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], ">", "0"}], ",", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "}"}]}], "]"}], 
                   " ", "//.", 
                   RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], "]"}], ",", 
                 RowBox[{
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], ">", "0"}]}], "]"}], "]"}], ",", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], "<", "0"}]}], "]"}], "//.", " ", 
            RowBox[{
             SubscriptBox["symT", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", 
             RowBox[{
              SubscriptBox["e", "2"], "/", "4"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SubscriptBox["e", "BW"]}], "+", 
              RowBox[{
               SubscriptBox["e", "2"], " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"]}]}], "<", "0"}], ",", 
            RowBox[{
             SubscriptBox["e", "2"], ">", "0"}]}], "}"}]}], "]"}], "//.", 
        RowBox[{
         SubscriptBox["e", "BW"], "->", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox["\[CapitalDelta]", "BW"], "2"], "/", 
           RowBox[{"(", 
            RowBox[{"8", "*", 
             SubscriptBox["e", "2"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["e", "2"], "*", 
           RowBox[{
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "2"], "/", "8"}]}]}]}]}], "]"}], ",", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "BW"], ">", "0"}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.854481566223502*^9, 3.854481706868623*^9}, {
   3.854481761106604*^9, 3.8544817707503366`*^9}, {3.8544818070398436`*^9, 
   3.8544818705563564`*^9}, 3.854481983273589*^9, {3.8568702902436457`*^9, 
   3.856870314101421*^9}, {3.856870379635931*^9, 3.8568704100459056`*^9}, {
   3.8568705142313375`*^9, 3.8568705150748167`*^9}, {3.8568709350927052`*^9, 
   3.8568709354988422`*^9}, {3.856890888070757*^9, 3.8568909707539444`*^9}, {
   3.856891001886469*^9, 3.856891002839469*^9}, {3.8569003918366346`*^9, 
   3.8569004913245544`*^9}, {3.8569006916543646`*^9, 3.856900704794465*^9}, {
   3.856902903994342*^9, 3.8569029097897167`*^9}, {3.856910047317732*^9, 
   3.8569100863073997`*^9}, {3.8569171463707314`*^9, 
   3.8569171578312054`*^9}, {3.856953247359748*^9, 3.8569532847869515`*^9}, {
   3.8569534465948277`*^9, 3.8569534604285226`*^9}, {3.856953841122733*^9, 
   3.856953842187441*^9}, {3.8569539060456686`*^9, 3.8569539063031235`*^9}, {
   3.858775145520919*^9, 3.8587751627885838`*^9}, {3.8590408543251314`*^9, 
   3.859041003806202*^9}, {3.8590410785228996`*^9, 3.859041207022044*^9}, {
   3.859041248137578*^9, 3.8590412670923376`*^9}, {3.859041297475477*^9, 
   3.8590413059452324`*^9}, {3.859041410812623*^9, 3.8590414478510222`*^9}, {
   3.859041482354006*^9, 3.859041624061242*^9}, {3.8590416556496305`*^9, 
   3.859041657508405*^9}, {3.859041873274624*^9, 3.859041881306135*^9}, {
   3.8590460524771457`*^9, 3.8590460830568247`*^9}, {3.8631847710141907`*^9, 
   3.8631848104087353`*^9}, {3.863184861101454*^9, 3.863184888197132*^9}, {
   3.8631873065979443`*^9, 3.8631873174142265`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"cbd8618b-3200-4b26-a559-2f5db49030b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "8"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["c", "g"], " ", 
          SubscriptBox["r", "1"]}], "+", 
         SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", "BW"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["e", "2"], " ", 
           SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", "BW"], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["e", "2"], " ", 
            SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["e", "2"], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["c", "g"], " ", 
          SubscriptBox["r", "1"]}], "+", 
         SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", "BW"], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["e", "2"], " ", 
            SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["e", "2"], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", "BW"], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["e", "2"], " ", 
           SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8631873322503133`*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"ccb98c45-66ba-47f4-a884-6a98162d4c89"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Obtain", " ", "an", " ", "explicit", " ", "expression", " ", 
    "of", " ", 
    RowBox[{
     SubscriptBox["e", "BW"], "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["Exple", "BW"], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                   RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                  RowBox[{
                   SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["C", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", 
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["D", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symE", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["E", 
                  RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], "->", " ", 
                SubscriptBox["S", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["T", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symU", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["U", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], "->", " ", 
             SubscriptBox["S", 
              RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["T", 
             RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "g"], "->", 
       SubscriptBox["c", 
        SubscriptBox["g", 
         RowBox[{"1", ",", "1"}]]]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "0"], "->", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.860870223467455*^9, 3.8608702302181883`*^9}, {
   3.860870260527258*^9, 3.860870289896441*^9}, {3.860870784612509*^9, 
   3.860870790659871*^9}, 3.8631848612019486`*^9, {3.863184902588721*^9, 
   3.863184942636052*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"d72fc652-400e-4699-8372-7dbd1267a2c6"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "4"}], "+", 
   RowBox[{"8", " ", 
    SuperscriptBox["\[Alpha]", "2"]}], "+", 
   RowBox[{"8", " ", 
    RowBox[{"Cosh", "[", 
     RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
   RowBox[{"5", " ", 
    RowBox[{"Cosh", "[", 
     RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "+", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], " ", 
       RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "+", 
      RowBox[{"18", " ", "\[Alpha]", " ", 
       SuperscriptBox[
        RowBox[{"Csch", "[", 
         RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}]}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{"Cosh", "[", 
      RowBox[{"4", " ", "\[Alpha]"}], "]"}], "-", 
     RowBox[{"4", " ", "\[Alpha]", " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"4", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.8608702340173273`*^9, {3.8608702660079775`*^9, 3.8608702919583144`*^9}, 
   3.860870797664367*^9, 3.861029336336273*^9, 3.8611353037382307`*^9, 
   3.8631849351889343`*^9, 3.863187346159647*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"e4bcaa45-0c38-4294-8c65-cbc5aa6eaa57"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", "Plot", " ", 
    RowBox[{
     SubscriptBox["e", "BW"], "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    SubscriptBox["Exple", "BW"], ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "0", ",", "3.15"}], "}"}], ",", 
    RowBox[{"Ticks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0.5", ",", "1", ",", "1.5", ",", "2", ",", "2.5", ",", 
         "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "3.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Thickness", "[", "0.01", "]"}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "->", 
     RowBox[{"Directive", "[", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Arrowheads", "[", "0.035", "]"}], ",", 
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8608702988806896`*^9, 3.8608703183585176`*^9}, {
  3.8608718667733545`*^9, 3.860872003644705*^9}, {3.860872035858899*^9, 
  3.8608720374461637`*^9}, {3.8631849464388547`*^9, 3.863184965841422*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"39be5729-e3ef-47be-aeb5-94c997f358a0"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.01], Opacity[1.], 
      LineBox[CompressedData["
1:eJwlTwk01PsfHYMxkxZrxGss/QkPT9GKPr9XimghZaskRRFpEbJFIU8iWyEp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       "]], 
      LineBox[{{0.000965963105829909, 1.5}, {0.0009659631058299263, -2.}}]},
     Annotation[#, "Charting`Private`Tag$16114#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[{
     GrayLevel[0], 
     Arrowheads[0.035], FontSize -> 18, 
     Thickness[0.004]}],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 3.25}, {-2., 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{{{0, 
      FormBox["0", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}, {2.5, 
      FormBox["2.5`", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}}, {{-2, 
      FormBox[
       RowBox[{"-", "2"}], TraditionalForm]}, {-1, 
      FormBox[
       RowBox[{"-", "1"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{{3.860870311139095*^9, 3.8608703190143642`*^9}, 
   3.860870808976497*^9, {3.8608718926793647`*^9, 3.8608720121678195`*^9}, 
   3.8610293605129642`*^9, 3.8611353047433863`*^9, 3.8631849547978086`*^9, 
   3.863187347303906*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"507bc525-add3-482d-94f1-b04f2704a02c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Extract", " ", "symbolic", " ", "expressions", " ", "of", " ", 
     SubscriptBox["\[Lambda]", "2"], " ", "and", " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"+", 
        RowBox[{"/", 
         RowBox[{"-", "1"}]}]}]}]], " ", "on", " ", "the", " ", "half"}], "-", 
    RowBox[{"loop", " ", "of", " ", "the", " ", "figure"}], "-", 
    RowBox[{"eight", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"symLambda2", " ", "=", " ", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["symLambdaBeta", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"symBeta0neg1", " ", "=", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]], "//.", 
     RowBox[{
      SubscriptBox["symLambdaBeta", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"symBeta0pos1", " ", "=", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]], "//.", 
     RowBox[{
      SubscriptBox["symLambdaBeta", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "3"}], "]"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.859041829680615*^9, 3.859041895732995*^9}, {
  3.859041957267702*^9, 3.859042050446823*^9}, {3.859391486137636*^9, 
  3.859391490810754*^9}, {3.863184982818323*^9, 3.863185013925522*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"907f1e4e-cdae-4878-aa06-12197b8b277e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["c", "g"], " ", 
     SubscriptBox["r", "1"]}], "+", 
    SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}], " ", 
  SubscriptBox["\[Mu]", "1"]}]], "Output",
 CellChangeTimes->{3.8631873475849295`*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"ddf55cc3-5214-4317-ad14-bf537bdf2ee4"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "BW"], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}]]}]], "Output",
 CellChangeTimes->{3.8631873475849295`*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"bc9ff33a-dff5-4105-a404-cdd1f2666f78"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[CapitalDelta]", "BW"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["e", "2"], " ", 
      SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubscriptBox["\[Beta]", 
    RowBox[{"0", ",", "0"}]]}], 
  RowBox[{"2", " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]]}]]], "Output",
 CellChangeTimes->{3.8631873476005487`*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"d180481f-15d8-43d5-b740-b0ec13548b00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["partIHT", "2"], "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["IHT", "2"], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "6", ",", "7"}], "}"}]}], "]"}], "]"}], 
      "/.", " ", 
      RowBox[{
       SubscriptBox["s", "j_"], "\[RuleDelayed]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Omega]", "j"], "2"], "*", 
        RowBox[{
         SubscriptBox["C", "j"], "/", "j"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ", 
     "at", " ", "this", " ", 
     RowBox[{"order", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", "2"], " ", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"partsoln", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["IHT", "2"], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "6", ",", "7"}], "}"}]}], "]"}], 
         "]"}], "/.", " ", 
        RowBox[{
         SubscriptBox["s", "j_"], "\[RuleDelayed]", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Omega]", "j"], "^", "2"}], "*", 
          RowBox[{
           SubscriptBox["C", "j"], "/", 
           RowBox[{"(", "j", ")"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "6", ",", "7"}], "}"}], "]"}], "]"}], 
       ",", "2"}], "]"}], "]"}]}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8570527323520994`*^9, 3.8570528335061517`*^9}, {
  3.858870025921588*^9, 3.858870026765073*^9}, {3.8588903725612235`*^9, 
  3.8588903742233324`*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"f833616a-ca60-4bc3-880a-2929d876ea16"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"72", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"8", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "3"}], "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "3"}], "2"], " ", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"81", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"28", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"18", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"7", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"36", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"18", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"72", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{"16", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"72", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"8", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "3"}], "2"]}]}]], 
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], "+", 
             RowBox[{"8", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["c", "0", "3"], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["c", "0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["c", "0"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]]}], "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "3"}], "2"], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"8", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}]}], ")"}]}], "-", 
          RowBox[{
           SubsuperscriptBox["c", "0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"11", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "3"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]], "+", 
                RowBox[{"2", " ", 
                 SubscriptBox["N", 
                  RowBox[{"2", ",", "2"}]], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
             RowBox[{"16", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}]}], ")"}]}]}], ")"}]}]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"8", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"], " ", 
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["\[Mu]", "1"]}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]"}], "+", 
                  RowBox[{"3", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
            RowBox[{"3", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]], "+", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"4", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"\[Alpha]", " ", 
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["\[Lambda]", "1"]}], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{"\[ImaginaryI]", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"8", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}]}]], 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Mu]", "1"]}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["c", "0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], "-", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubsuperscriptBox["c", "0", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Lambda]", "1"], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["c", "0"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]]}], "-", 
             RowBox[{"6", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[Lambda]", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]]}], "+", 
                RowBox[{
                 SubsuperscriptBox["\[Omega]", 
                  RowBox[{"-", "2"}], "2"], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
             RowBox[{"8", " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["c", "0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "\[Alpha]"}], "+", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]], "+", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Lambda]", "1"], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"8", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], "+", 
               RowBox[{"2", " ", "\[Alpha]", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", "\[Alpha]", " ", 
                   SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                  RowBox[{"3", " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
               RowBox[{"3", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"\[Alpha]", " ", 
                SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{
                SubscriptBox["\[Lambda]", "1"], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"8", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}]}]], 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Mu]", "1"]}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["c", "0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"1", ",", "1"}]], "+", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]]}], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["c", "0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", "2"}]]}], "+", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]]}], "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["h", 
                 RowBox[{"1", ",", "1"}]], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Lambda]", "1"], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubsuperscriptBox["c", "0", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Lambda]", "1"], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["c", "0"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Lambda]", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "2"}]]}], "+", 
                RowBox[{
                 SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "1"}]], " ", 
                 SubscriptBox["Q", 
                  RowBox[{"1", ",", "1"}]]}], "+", 
                RowBox[{"8", " ", 
                 SubscriptBox["Q", 
                  RowBox[{"1", ",", "1"}]], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", "1"}]]}], "+", 
                RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"1", ",", "1"}]]}], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", "\[Alpha]"}], "+", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"72", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"8", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "3", "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"81", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"28", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"18", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"7", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"36", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"18", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"72", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"16", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"72", " ", 
           SubsuperscriptBox["c", "0", "3"]}], "-", 
          RowBox[{"8", " ", 
           SubscriptBox["c", "0"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}]], 
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "3", "2"], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "-", 
           RowBox[{"8", " ", 
            SubsuperscriptBox["c", "0", "3"], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"8", " ", 
            SubsuperscriptBox["c", "0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "2"}]], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "-", 
           RowBox[{
            SubsuperscriptBox["c", "0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"11", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "2"}]], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "-", 
              RowBox[{"16", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}]}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570528436661887`*^9, 3.8570668917199593`*^9, 3.858086183886506*^9, 
   3.858093515829382*^9, 3.8586899742454915`*^9, 3.8587752099988947`*^9, 
   3.85887002947018*^9, {3.858890368081617*^9, 3.8588903778619394`*^9}, 
   3.858947976786993*^9, {3.858966920447472*^9, 3.858966930667607*^9}, 
   3.8589795147883387`*^9, 3.8590422607862406`*^9, 3.85904799575315*^9, 
   3.85939172794771*^9, 3.860783038806322*^9, 3.8609543471134014`*^9, 
   3.8610293724993563`*^9, 3.8611353109450936`*^9, 3.863185041065523*^9, 
   3.863187357415213*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"690c8dd7-6c1e-4380-aa3e-cb4465307fda"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            SuperscriptBox[
             SubscriptBox["c", "0"], "2"]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["s", 
           RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["C", 
             RowBox[{"-", "1"}]]}], "*", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"2", ",", "0"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], "\[Rule]", " ", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["IHT", 
               RowBox[{"2", ",", "0"}]], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], "*", 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
            SubscriptBox["c", 
             SubscriptBox["g", 
              RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
         " ", 
         RowBox[{
          SubscriptBox["C", "0"], "\[Rule]", " ", "1"}]}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]], " ", "\[Rule]", " ", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", " ", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]], "\[Rule]", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"2", ",", "1"}]], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            SuperscriptBox[
             SubscriptBox["c", "0"], "2"]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
          RowBox[{
           SubscriptBox["C", "1"], "*", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}], 
     "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8570527452780967`*^9, 3.8570527519479876`*^9}, {
  3.8570528719346123`*^9, 3.8570528819044013`*^9}, {3.857053065545776*^9, 
  3.857053095847333*^9}, {3.8570545165115647`*^9, 3.857054530811715*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"00df7e46-cbf2-4035-9128-b9a0a3970f18"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["c", "0", "3"]}]], 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Alpha]", " ", 
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          SuperscriptBox["\[Alpha]", "2"], " ", 
          SubsuperscriptBox["c", "0", "6"], " ", 
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "+", 
         RowBox[{"\[Alpha]", " ", 
          SubscriptBox["\[Mu]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["r", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "2"], " ", 
          SubscriptBox["\[Mu]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             SuperscriptBox["\[Alpha]", "2"], " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}]], "+", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "0"}]], "+", 
            RowBox[{"\[Alpha]", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "-", 
            RowBox[{"\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["r", "1"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["c", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.859391756152895*^9, 3.860783040955353*^9, 
  3.8609543492619457`*^9, 3.8610293751100984`*^9, 3.8611353131983695`*^9, 
  3.8631850553018246`*^9, 3.8631873601955743`*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"97755b08-665a-4bbe-9dc8-b59d38eeea08"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"2", ",", "0"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["c", "0", "5"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]], "-", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["c", "0", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["h", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["h", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["c", "0", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "0"}]], "+", 
          SubscriptBox["\[Phi]", 
           RowBox[{"1", ",", "0"}]]}], ")"}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["c", "0", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "0"}]], "+", 
          SubscriptBox["\[Phi]", 
           RowBox[{"1", ",", "0"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]], "-", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "0"}]], "+", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "0"}]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], "-", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.859391756152895*^9, 3.860783040955353*^9, 
  3.8609543492619457`*^9, 3.8610293751100984`*^9, 3.8611353131983695`*^9, 
  3.8631850553018246`*^9, 3.863187360757922*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"30aa60d3-ad13-4d51-8f00-c23ecf2022ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"2", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "3"]}]], 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["N", 
          RowBox[{"2", ",", "2"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"2", " ", "\[Alpha]", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], "+", 
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", 
         SubsuperscriptBox["c", "0", "6"], " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], "-", 
        RowBox[{
         SubsuperscriptBox["c", "0", "2"], " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["h", 
            RowBox[{"1", ",", "1"}]], "+", 
           RowBox[{
            SuperscriptBox["\[Alpha]", "2"], " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "-", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
        RowBox[{"\[Alpha]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["r", "1"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
        RowBox[{
         SubsuperscriptBox["c", "0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["h", 
            RowBox[{"1", ",", "0"}]], "+", 
           SubscriptBox["h", 
            RowBox[{"1", ",", "2"}]], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"\[Alpha]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["r", "1"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SubsuperscriptBox["c", "0", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["c", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "0"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "2"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["c", "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Lambda]", "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.859391756152895*^9, 3.860783040955353*^9, 
  3.8609543492619457`*^9, 3.8610293751100984`*^9, 3.8611353131983695`*^9, 
  3.8631850553018246`*^9, 3.863187360929713*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"3727d6d2-2cbe-463d-92f4-405c2aa15874"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Check", " ", "that", " ", "the", " ", "particular", " ", 
    "solutions", " ", "are", " ", 
    RowBox[{"correct", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   SubscriptBox["NumInvR", "0"], "[", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "3"}], "*", "\[ImaginaryI]", "*", "x"}], 
                    "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "]"}], ")"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "3"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "3"}], "}"}]}], "]"}], "-", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["IHT", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], "*", 
                   RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "3"}], "*", "\[ImaginaryI]", "*", "x"}], 
                    "]"}]}]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "/.", " ", 
               RowBox[{
                SubscriptBox["s", "j_"], "\[RuleDelayed]", 
                RowBox[{
                 SuperscriptBox[
                  SubscriptBox["\[Omega]", "j"], "2"], "*", 
                 RowBox[{
                  SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", "*", 
                   RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"16", "*", 
                  RowBox[{
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                 ")"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], " ", "->", " ", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.",
             " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "->", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", "*", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["c", "2"], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "0"], " ", "->", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "j_"], ":>", " ", 
         RowBox[{"\[Omega]", "[", 
          RowBox[{"j", "+", 
           SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
       RowBox[{
        SubscriptBox["C", "j_"], ":>", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Alpha]", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
       " ", 
      RowBox[{
       SubscriptBox["s", "j_"], ":>", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    SubscriptBox["NumInvR", "0"], "[", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "x"}], 
                    "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "]"}], ")"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "2"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "2"}], "}"}]}], "]"}], "-", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["IHT", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "2"}], "]"}], "]"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "2"}], "*", "\[ImaginaryI]", "*", "x"}], 
                    "]"}]}]}], "//.", " ", 
                   RowBox[{"Flatten", "[", 
                    SubscriptBox["partsoln", "1"], "]"}]}], "//.", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], " ", "//.", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "/.", " ", 
               RowBox[{
                SubscriptBox["s", "j_"], "\[RuleDelayed]", 
                RowBox[{
                 SuperscriptBox[
                  SubscriptBox["\[Omega]", "j"], "2"], "*", 
                 RowBox[{
                  SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", "*", 
                   RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"16", "*", 
                  RowBox[{
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                 ")"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], " ", "->", " ", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.",
             " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "->", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", "*", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["c", "2"], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "0"], " ", "->", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "j_"], ":>", " ", 
         RowBox[{"\[Omega]", "[", 
          RowBox[{"j", "+", 
           SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
       RowBox[{
        SubscriptBox["C", "j_"], ":>", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Alpha]", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
       " ", 
      RowBox[{
       SubscriptBox["s", "j_"], ":>", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumInvR", "0"], "[", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "1"}], "}"}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"-", "1"}], "}"}]}], "]"}], "-", 
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], " ", 
                    "-", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{
                    SubscriptBox["cond", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "/", 
                    RowBox[{"(", 
                    RowBox[{"\[ImaginaryI]", "*", 
                    SubscriptBox["c", "0"]}], ")"}]}]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}]}], "//.",
                     " ", 
                    RowBox[{"Flatten", "[", 
                    SubscriptBox["partsoln", "1"], "]"}]}], " ", "//.", " ", 
                   SubscriptBox["partsoln", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", "0"}]]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["s", 
                 RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
                RowBox[{
                 RowBox[{"-", 
                  SubscriptBox["C", 
                   RowBox[{"-", "1"}]]}], "*", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "2"]}]}]}], "/.", " ", 
              RowBox[{
               SubscriptBox["s", "j_"], "\[RuleDelayed]", 
               RowBox[{
                SuperscriptBox[
                 SubscriptBox["\[Omega]", "j"], "2"], "*", 
                RowBox[{
                 SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], "->", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"16", "*", 
                 RowBox[{
                  RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                ")"}]}]}]}], "//.", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", "->", " ", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", 
                SuperscriptBox[
                 SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.",
            " ", 
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"2", ",", "2"}]], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"32", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["c", "2"], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"6", "+", 
              RowBox[{"2", "*", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              SubscriptBox["c", "0"], "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
              RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
         " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "0"], " ", "->", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "j_"], ":>", " ", 
        RowBox[{"\[Omega]", "[", 
         RowBox[{"j", "+", 
          SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
      RowBox[{
       SubscriptBox["C", "j_"], ":>", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
      " ", 
     RowBox[{
      SubscriptBox["s", "j_"], ":>", " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"\[Alpha]", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["NumInvR", "0"], "[", 
            RowBox[{
             RowBox[{
              SubscriptBox["NumL", "0"], "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   SubscriptBox["h", 
                    RowBox[{"2", ",", "0"}]], ",", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "0"}]]}], "}"}], "//.", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", "0"}]]}], ")"}], ",", 
               RowBox[{"{", "0", "}"}]}], "]"}], ",", 
             RowBox[{"{", "0", "}"}]}], "]"}], "-", 
           SubscriptBox["IHT", 
            RowBox[{"2", ",", "0"}]], " ", "+", 
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["cond", 
              RowBox[{"2", ",", "0"}]], ",", "0"}], "}"}]}], " ", "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
         SubscriptBox["c", 
          SubscriptBox["g", 
           RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["C", "0"], " ", "\[Rule]", " ", "1"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]], "->", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         SubscriptBox["c", "0"]}], ")"}]}]}]}], " ", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumInvR", "0"], "[", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "1"}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "1"}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "1"}]]}], ")"}], ",", 
                    RowBox[{"{", "1", "}"}]}], "]"}], ",", 
                    RowBox[{"{", "1", "}"}]}], "]"}], "-", 
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"2", ",", "1"}]], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{
                    SubscriptBox["cond", 
                    RowBox[{"2", ",", "1"}]], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    SubscriptBox["c", "0"]}], ")"}]}]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}]}], " ", "//.",
                     " ", 
                    RowBox[{"Flatten", "[", 
                    SubscriptBox["partsoln", "1"], "]"}]}], " ", "//.", 
                   SubscriptBox["partsoln", 
                    RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", "1"}]]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
                RowBox[{
                 SubscriptBox["C", "1"], "*", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "2"]}]}]}], "/.", " ", 
              RowBox[{
               SubscriptBox["s", "j_"], "\[RuleDelayed]", 
               RowBox[{
                SuperscriptBox[
                 SubscriptBox["\[Omega]", "j"], "2"], "*", 
                RowBox[{
                 SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], "->", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", "*", 
                  RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"16", "*", 
                 RowBox[{
                  RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                ")"}]}]}]}], "//.", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", "->", " ", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", 
                SuperscriptBox[
                 SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.",
            " ", 
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"2", ",", "2"}]], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"32", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["c", "2"], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"6", "+", 
              RowBox[{"2", "*", 
               RowBox[{"Cosh", "[", 
                RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              SubscriptBox["c", "0"], "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
              RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
         " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "0"], " ", "->", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
       RowBox[{
        SubscriptBox["\[Omega]", "j_"], ":>", " ", 
        RowBox[{"\[Omega]", "[", 
         RowBox[{"j", "+", 
          SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
      RowBox[{
       SubscriptBox["C", "j_"], ":>", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
      " ", 
     RowBox[{
      SubscriptBox["s", "j_"], ":>", " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"\[Alpha]", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    SubscriptBox["NumInvR", "0"], "[", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "2"}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "2"}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"2", "*", "\[ImaginaryI]", "*", "x"}], "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "All"}], "]"}], "]"}]}], "]"}], ")"}], 
                    ",", 
                    RowBox[{"{", "2", "}"}]}], "]"}], ",", 
                    RowBox[{"{", "2", "}"}]}], "]"}], "-", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["IHT", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "6"}], "]"}], "]"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"2", "*", "\[ImaginaryI]", "*", "x"}], "]"}]}]}], 
                   "//.", " ", 
                   RowBox[{"Flatten", "[", 
                    SubscriptBox["partsoln", "1"], "]"}]}], "//.", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", "1"}]]}], " ", "//.", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "/.", " ", 
               RowBox[{
                SubscriptBox["s", "j_"], "\[RuleDelayed]", 
                RowBox[{
                 SuperscriptBox[
                  SubscriptBox["\[Omega]", "j"], "2"], "*", 
                 RowBox[{
                  SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", "*", 
                   RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"16", "*", 
                  RowBox[{
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                 ")"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], " ", "->", " ", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.",
             " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "->", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", "*", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["c", "2"], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "0"], " ", "->", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "j_"], ":>", " ", 
         RowBox[{"\[Omega]", "[", 
          RowBox[{"j", "+", 
           SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
       RowBox[{
        SubscriptBox["C", "j_"], ":>", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Alpha]", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
       " ", 
      RowBox[{
       SubscriptBox["s", "j_"], ":>", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    SubscriptBox["NumInvR", "0"], "[", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["NumL", "0"], "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "3"}]], ",", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "3"}]]}], "}"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"3", "*", "\[ImaginaryI]", "*", "x"}], "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"4", ",", "All"}], "]"}], "]"}]}], "]"}], ")"}], 
                    ",", 
                    RowBox[{"{", "3", "}"}]}], "]"}], ",", 
                    RowBox[{"{", "3", "}"}]}], "]"}], "-", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["IHT", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "7"}], "]"}], "]"}], "*", 
                    RowBox[{"Exp", "[", 
                    RowBox[{"3", "*", "\[ImaginaryI]", "*", "x"}], "]"}]}]}], 
                   "//.", " ", 
                   RowBox[{"Flatten", "[", 
                    SubscriptBox["partsoln", "1"], "]"}]}], "//.", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", "1"}]]}], " ", "//.", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], "*", 
                   SubscriptBox["\[Mu]", "1"], "*", 
                   SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                 SubscriptBox["c", 
                  SubscriptBox["g", 
                   RowBox[{"1", ",", "1"}]]]}]}], " ", "/.", " ", 
               RowBox[{
                SubscriptBox["s", "j_"], "\[RuleDelayed]", 
                RowBox[{
                 SuperscriptBox[
                  SubscriptBox["\[Omega]", "j"], "2"], "*", 
                 RowBox[{
                  SubscriptBox["C", "j"], "/", "j"}]}]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", "*", 
                   RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"16", "*", 
                  RowBox[{
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
                 ")"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], " ", "->", " ", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
               RowBox[{"(", 
                RowBox[{"4", 
                 SuperscriptBox[
                  SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.",
             " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "->", " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", 
                RowBox[{"2", "*", 
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["c", "2"], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "+", 
               RowBox[{"2", "*", 
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
          " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "0"], " ", "->", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
        RowBox[{
         SubscriptBox["\[Omega]", "j_"], ":>", " ", 
         RowBox[{"\[Omega]", "[", 
          RowBox[{"j", "+", 
           SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "/.", " ", 
       RowBox[{
        SubscriptBox["C", "j_"], ":>", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"\[Alpha]", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], " ", "/.",
       " ", 
      RowBox[{
       SubscriptBox["s", "j_"], ":>", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"\[Alpha]", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Mu]", "0"], "+", "j"}], ")"}]}], "]"}]}]}], "]"}], 
    "]"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8570535463697724`*^9, 3.8570537252588577`*^9}, {
  3.857053818529663*^9, 3.85705381856091*^9}, {3.857053868792837*^9, 
  3.8570538985436373`*^9}, {3.857053958525278*^9, 3.857053967189041*^9}, {
  3.857054099817952*^9, 3.8570540999116416`*^9}, {3.8570541326152945`*^9, 
  3.8570541577468853`*^9}, {3.857054203308571*^9, 3.8570542322612963`*^9}, {
  3.857068372270253*^9, 3.857068422013399*^9}, {3.857068827714834*^9, 
  3.8570688367238817`*^9}, {3.85706886737096*^9, 3.8570689374633794`*^9}, {
  3.8570693104421005`*^9, 3.8570694607333784`*^9}, {3.8570695294164*^9, 
  3.8570696119881115`*^9}, {3.85706966332969*^9, 3.8570696641183043`*^9}, {
  3.857069726095603*^9, 3.8570697841371217`*^9}, {3.8572370456743097`*^9, 
  3.857237097998854*^9}, {3.8572371344906516`*^9, 3.8572371391809373`*^9}, {
  3.8572371781889725`*^9, 3.8572372032789297`*^9}, {3.857237239687006*^9, 
  3.8572372805231915`*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"207808fb-7a86-4b39-8a98-de03a0a57ecb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.863187363600752*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"e143be7d-a681-44a6-82bc-b202f1ff15c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.8631873637569313`*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"07318698-110a-44a4-9085-d63d581f90ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.8631873639131327`*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"ee8c9542-8bad-4c40-90af-56caf6ea456c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.863187363975611*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"9c057f02-2225-4f94-b811-1c9183ddb618"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.8631873640849504`*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"53a468b9-0b06-4543-a202-317856fba9e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.8631873642567916`*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"0b05a685-5e46-4ccd-84b4-cd0adb039cd8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8570545421622305`*^9, 3.8570547416148252`*^9, 3.8570684238576603`*^9, 
   3.857068838168023*^9, 3.8570688798995533`*^9, {3.857068913166854*^9, 
   3.8570689380622215`*^9}, {3.857069442923468*^9, 3.857069456517742*^9}, {
   3.857069530105791*^9, 3.857069612925358*^9}, 3.857069664509445*^9, {
   3.857069740411747*^9, 3.8570697846495805`*^9}, 3.8572371915544043`*^9, 
   3.8572372861231904`*^9, 3.858086197831048*^9, 3.858093517578829*^9, 
   3.858689984571344*^9, 3.858775244778966*^9, 3.858870036408082*^9, 
   3.8588903956293907`*^9, 3.8589479834441037`*^9, 3.8589669379551363`*^9, 
   3.8589795258551054`*^9, 3.8590423400439014`*^9, 3.8590480018792777`*^9, 
   3.859391779783046*^9, 3.860783044534403*^9, 3.860954351898382*^9, 
   3.8610293778823977`*^9, 3.861135316480203*^9, 3.863185063614413*^9, 
   3.863187364381796*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"af417c2f-a646-4662-8a83-5ee5d1492997"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Final", " ", "solution", " ", "for", " ", "the", " ", "O", 
     RowBox[{"(", 
      SuperscriptBox["\[Epsilon]", "2"], ")"}], " ", 
     RowBox[{"problem", ".", " ", "There"}], " ", "is", " ", "no", " ", 
     "particular", " ", "solution", " ", "proportional", " ", "to", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "n", "*", "x"}], "]"}], " ", "at", " ", 
     "this", " ", "order", " ", "because", " ", "of", " ", "the", " ", 
     "choice", " ", "of", " ", "normalization", " ", "on", " ", 
     RowBox[{"w", ".", " ", "At"}], " ", "this", " ", "order"}], ",", " ", 
    RowBox[{
     SubscriptBox["\[Gamma]", "2"], " ", "is", " ", "an", " ", "arbitrary", 
     " ", 
     RowBox[{"constant", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["w", "2"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h", 
          RowBox[{"2", ",", "j"}]], ",", 
         SubscriptBox["\[Phi]", 
          RowBox[{"2", ",", "j"}]]}], "}"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", "*", "j", "*", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
         "]"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox["\[ImaginaryI]", 
        SubscriptBox["c", "0"]]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox[
        RowBox[{"-", "\[ImaginaryI]"}], 
        SubscriptBox["c", "0"]]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]], "*", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.857237353263386*^9, 3.8572373870931845`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"bdcd2f26-0684-4c49-b1cc-6a84eeb902e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["h", 
     RowBox[{"2", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], 
     SubscriptBox["c", "0"]], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"2", ",", "0"}]], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "1"}]]}], 
     SubscriptBox["c", "0"]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "3"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8572373880926743`*^9, 3.858086202285025*^9, 
  3.858093521606798*^9, 3.8586899882136087`*^9, 3.8587752479210153`*^9, 
  3.8588700399694796`*^9, 3.858890399464156*^9, 3.8589479861520233`*^9, 
  3.858966941762319*^9, 3.858979528788865*^9, 3.859042350077795*^9, 
  3.8590480044698696`*^9, 3.8593917835039234`*^9, 3.860783047627782*^9, 
  3.860954354827411*^9, 3.8610293807408504`*^9, 3.8611353189410343`*^9, 
  3.863185067455076*^9, 3.863187366396734*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"bc2a8175-713e-4107-9cbe-137c77b22727"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"V", ".", " ", "Third"}], "-", 
    RowBox[{"Order", " ", "Problem"}]}], "Section"]}]], "Input",
 CellChangeTimes->{{3.857239577786849*^9, 
  3.857239594267783*^9}},ExpressionUUID->"bb10e97d-b9cf-4a03-9bb3-\
100a3f609613"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Define", " ", "operator", " ", 
    SubscriptBox["L", "3"], " ", "for", " ", "numerical", " ", 
    RowBox[{"computations", "."}]}], " ", "**)"}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumL", "3"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_", ",", "q3_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
                "+", 
                RowBox[{"\[Kappa]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], ")"}], 
                    " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
                ")"}], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["s", "\[Kappa]"], " ", 
                 SubscriptBox["c", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["c", "0"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "6"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["s", "\[Kappa]"], " ", 
                 SubscriptBox["r", "2"], 
                 SubscriptBox["\[Mu]", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["C", "\[Kappa]"], " ", 
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", "6"], " ", 
                 SubscriptBox["C", "\[Kappa]"], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], 
                "+", 
                RowBox[{
                 SubscriptBox["s", "\[Kappa]"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["C", "\[Kappa]"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                   RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], ")"}], 
              "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}],
            ",", "kmod"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["c", "0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["c", "0"], " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["c", "0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["c", "0"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"q1", ",", "x"}], "]"}], "2"], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["c", "0"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
            ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["c", "0"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["r", "2"], 
                 SubscriptBox["\[Mu]", "1"]}], "-", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}]}], ")"}]}], 
             "+", 
             RowBox[{
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SubscriptBox["c", "0"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "-", 
             RowBox[{"D", "[", 
              RowBox[{"q3", ",", "x"}], "]"}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}]}], 
        "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Define", " ", "operator", " ", 
     SubscriptBox["R", "3"], " ", "for", " ", "numerical", " ", 
     RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumR", "3"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "6"], " ", 
                SubscriptBox["s", "\[Kappa]"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], "+", 
               RowBox[{
                SubscriptBox["C", "\[Kappa]"], 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Alpha]", " ", 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Alpha]", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["s", "\[Kappa]"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Alpha]", " ", 
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], ")"}], 
             "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["c", "0"]}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"], "-", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]2", ",", "x"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{"D", "[", 
                RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.857237401918007*^9, {3.857239568987095*^9, 3.85723957467509*^9}, {
   3.8572396229427004`*^9, 3.8572396298871717`*^9}, {3.8573127727029824`*^9, 
   3.857312831169829*^9}, {3.857312953623693*^9, 3.8573129588406625`*^9}, {
   3.858083538786378*^9, 3.8580835412287807`*^9}, {3.8580835723023787`*^9, 
   3.8580835729271746`*^9}, {3.858083663638891*^9, 3.858083887908461*^9}, {
   3.8580839258324833`*^9, 3.8580839978848376`*^9}, 3.8580853141013546`*^9, 
   3.858085440072712*^9, {3.858085509065872*^9, 3.8580855468019953`*^9}, {
   3.858085577822402*^9, 3.858085651067671*^9}, {3.858085895207419*^9, 
   3.8580859125873475`*^9}, {3.8593894108676586`*^9, 3.859389411136031*^9}, {
   3.8593918008960333`*^9, 3.8593918171824694`*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"ebaa48e5-186a-4abd-bd95-9273e755eea3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["IHT", "3"], " ", "=", " ", "\[IndentingNewLine]", 
   RowBox[{"NCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], "*", 
       SubscriptBox["w", "2"]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], "*", 
       SubscriptBox["w", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], "*", 
       SubscriptBox["w", "0"]}], "+", 
      RowBox[{
       SubscriptBox["NumInvR", "0"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SubscriptBox["NumL", "1"], "[", 
           RowBox[{
            SubscriptBox["w", "2"], ",", 
            RowBox[{"GenModulate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
             "]"}], ",", 
            RowBox[{"Cos", "[", "x", "]"}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}]}], "-", 
         RowBox[{
          SubscriptBox["NumL", "2"], "[", 
          RowBox[{
           SubscriptBox["w", "1"], ",", 
           RowBox[{"GenModulate", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
            "]"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], "*", "x"}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}]}]}], "]"}], "-", 
         RowBox[{
          SubscriptBox["NumL", "3"], "[", 
          RowBox[{
           SubscriptBox["w", "0"], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], "*", "x"}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"3", ",", "3"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"3", "*", "x"}], "]"}]}]}]}], "]"}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["NumR", "1"], "[", 
             RowBox[{
              SubscriptBox["w", "1"], ",", 
              RowBox[{"GenModulate", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}],
                "]"}], ",", 
              RowBox[{"Cos", "[", "x", "]"}]}], "]"}], "+", 
            RowBox[{
             SubscriptBox["NumR", "2"], "[", 
             RowBox[{
              SubscriptBox["w", "0"], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
              RowBox[{"Cos", "[", "x", "]"}], ",", 
              RowBox[{"2", "*", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], "*", 
               RowBox[{"Sin", "[", "x", "]"}]}], ",", 
              RowBox[{"2", "*", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", "*", "x"}], "]"}]}]}], "]"}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          RowBox[{
           SubscriptBox["NumR", "1"], "[", 
           RowBox[{
            SubscriptBox["w", "0"], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"GenModulate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], "]"}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.858084031882476*^9, {3.8580842618091197`*^9, 3.8580842790047035`*^9}, {
   3.8580845040431805`*^9, 3.858084845877962*^9}, {3.858084884607833*^9, 
   3.858085086066019*^9}, {3.8580851741638317`*^9, 3.858085244690663*^9}, 
   3.858086224321624*^9, 3.863185077007817*^9},
 CellLabel->
  "In[111]:=",ExpressionUUID->"82bd5689-2603-4e99-af0a-d94a05f7a2c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      RowBox[{"32", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"3", " ", 
         SubscriptBox["s", 
          RowBox[{"-", "3"}]], " ", 
         SubscriptBox["\[Lambda]", "1"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "3"}]]}]]}], "-", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"15", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SubscriptBox["s", 
          RowBox[{"-", "1"}]], " ", 
         SubscriptBox["\[Lambda]", "1"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"2", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "1"}]]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "0"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "8"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "1"}]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["27", "8"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"15", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "3"]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "4"]}]], "-", 
      RowBox[{"32", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "4"]}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "2"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8631850782610264`*^9, 3.863187374277652*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"f6705da9-6664-4949-bb0c-3611e19d5181"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "=", 
     RowBox[{
      SubscriptBox["IHT", "3"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"3", ",", "0"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "3"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"3", ",", "1"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "3"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "6"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8580862264083166`*^9, 3.8580863258055277`*^9}, {
  3.858087072958722*^9, 3.8580870850600863`*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"97aa6e72-ae2b-4c16-8add-0563c8067b0d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "First", " ", "solvability", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  SubscriptBox["IHT", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "//.", " ", 
                  RowBox[{
                   SubscriptBox["s", 
                    RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
                   RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["C", 
                    RowBox[{"-", "1"}]]}], "*", 
                    SuperscriptBox[
                    SubscriptBox["c", "0"], "2"]}]}]}], " ", "//.", " ", 
                 RowBox[{
                  SubscriptBox["partsoln", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", "0"}]]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "1"}]]}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
         SubscriptBox["c", 
          SubscriptBox["g", 
           RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{"Conjugate", "[", 
         SubscriptBox["FA", 
          RowBox[{"-", "1"}]], "]"}], ",", 
        RowBox[{
         SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
     "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.858086327523755*^9, {3.8580863659616947`*^9, 3.8580863715269823`*^9}, {
   3.8580865161901035`*^9, 3.8580865241750655`*^9}, {3.8580865607819185`*^9, 
   3.8580866036343613`*^9}, {3.8580870105663643`*^9, 3.8580870212713375`*^9}, 
   3.8580871222491207`*^9, {3.858597287355615*^9, 3.858597296645313*^9}, 
   3.8631851045672684`*^9},
 CellLabel->
  "In[115]:=",ExpressionUUID->"901f460e-a37b-4c1b-972e-195c7f4faf99"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"24", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubsuperscriptBox["c", "0", "2"]}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "96"}], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "16"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"48", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "17"], " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubscriptBox["c", "0"], " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "-", 
    RowBox[{"24", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"6", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"6", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "64"}], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"64", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", 
        SubscriptBox["r", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"32", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "64"}], " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"16", "-", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"16", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"16", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"256", " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"128", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"64", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"128", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"192", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"48", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"256", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"256", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"160", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "-", 
       RowBox[{"512", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"12", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "32"}], " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"24", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"6", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "\[Alpha]"}], "+", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "-", 
       RowBox[{"20", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "-", 
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"16", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Mu]", "1"]}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "8"}], " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"16", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "-", 
       RowBox[{"10", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"12", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"13", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"6", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Alpha]"}], "+", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Alpha]"}], "+", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"16", "-", 
             RowBox[{"5", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "-", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}], "+", 
             RowBox[{"16", " ", 
              SubscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SubsuperscriptBox["\[Omega]", 
                  RowBox[{"-", "2"}], "2"]}]}], ")"}]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"16", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"8", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "-", 
             RowBox[{"32", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "+", 
             RowBox[{"16", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["\[Alpha]", "2"], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"16", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "64"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "4"], "-", 
             RowBox[{"96", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"8", " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "56"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "17"}], "+", 
                RowBox[{"16", " ", 
                 SubscriptBox["r", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", 
                SubscriptBox["r", "2"]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"32", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "+", 
             RowBox[{"16", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"28", "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "4"], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "-", 
          RowBox[{"24", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "10"}], " ", "\[Alpha]"}], "-", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", 
                SubscriptBox["r", "2"]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{"6", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "+", 
          RowBox[{"10", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}]}], "-", 
          RowBox[{"24", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"12", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "14"}], " ", "\[Alpha]"}], "+", 
             RowBox[{"16", " ", "\[Alpha]", " ", 
              SubscriptBox["r", "2"]}], "-", 
             RowBox[{"11", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"16", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{"24", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", 
             RowBox[{"3", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "-", 
          RowBox[{"48", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"11", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}]}], "-", 
          RowBox[{"24", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"6", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "4"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", "\[Alpha]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", 
                RowBox[{"8", " ", 
                 SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "-", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", "\[Alpha]"}], "+", 
             RowBox[{"44", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "-", 
             RowBox[{"13", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["\[Omega]", 
                  RowBox[{"-", "2"}], "2"]}], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SubsuperscriptBox["\[Omega]", 
                  RowBox[{"-", "2"}], "4"]}]}], ")"}]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Lambda]", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "+", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "4"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"11", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.8631851076337304`*^9, 3.863187387014824*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"abf50dc4-1b39-466b-a014-60bb358abdd3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond3neg1\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["T", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["V", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1\[Beta]", 
      RowBox[{"1", ",", "0"}]], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond3neg1\[Beta]", 
      RowBox[{"1", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], "*", 
      SubscriptBox["S", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1\[Beta]", 
      RowBox[{"1", ",", "1"}]], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond3neg1\[Beta]", 
      RowBox[{"1", ",", "1"}]], "-", 
     RowBox[{"\[ImaginaryI]", "*", 
      SubscriptBox["U", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1No\[Beta]", 
      RowBox[{"1", ",", "dot"}]], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "/.", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "j_"}]], ":>", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8580871265182877`*^9, 3.858087168501532*^9}, {
  3.8580872152118816`*^9, 3.8580872520675497`*^9}, {3.8631851155583563`*^9, 
  3.863185186892618*^9}, {3.863185354118086*^9, 3.8631853838560214`*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"872db611-d60d-4871-9ddc-8becd901ecf8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.85808716900119*^9, 3.858087252457873*^9, 3.858093537306915*^9, 
   3.8586900331644125`*^9, 3.8587752768622465`*^9, 3.8588700543270626`*^9, 
   3.858890413826852*^9, 3.8589479974166107`*^9, 3.858966953658313*^9, 
   3.8589795518709345`*^9, 3.8590424592643075`*^9, 3.8590480149975996`*^9, 
   3.8593918776517115`*^9, 3.860783064551243*^9, 3.8609543689599943`*^9, 
   3.8610293920126767`*^9, 3.8611353318132896`*^9, 3.863185309647373*^9, {
   3.8631853618708115`*^9, 3.8631853847109704`*^9}, 3.8631873897795434`*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"cf22651b-fe81-4ffd-b2e9-8e41eba2a1cf"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.85808716900119*^9, 3.858087252457873*^9, 3.858093537306915*^9, 
   3.8586900331644125`*^9, 3.8587752768622465`*^9, 3.8588700543270626`*^9, 
   3.858890413826852*^9, 3.8589479974166107`*^9, 3.858966953658313*^9, 
   3.8589795518709345`*^9, 3.8590424592643075`*^9, 3.8590480149975996`*^9, 
   3.8593918776517115`*^9, 3.860783064551243*^9, 3.8609543689599943`*^9, 
   3.8610293920126767`*^9, 3.8611353318132896`*^9, 3.863185309647373*^9, {
   3.8631853618708115`*^9, 3.8631853847109704`*^9}, 3.8631873897951655`*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"2f8aa292-9519-4ffe-b672-9848cfec46ee"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.85808716900119*^9, 3.858087252457873*^9, 3.858093537306915*^9, 
   3.8586900331644125`*^9, 3.8587752768622465`*^9, 3.8588700543270626`*^9, 
   3.858890413826852*^9, 3.8589479974166107`*^9, 3.858966953658313*^9, 
   3.8589795518709345`*^9, 3.8590424592643075`*^9, 3.8590480149975996`*^9, 
   3.8593918776517115`*^9, 3.860783064551243*^9, 3.8609543689599943`*^9, 
   3.8610293920126767`*^9, 3.8611353318132896`*^9, 3.863185309647373*^9, {
   3.8631853618708115`*^9, 3.8631853847109704`*^9}, 3.8631873898107853`*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"75232459-da73-46d0-ba06-d5b3ee9c6542"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.85808716900119*^9, 3.858087252457873*^9, 3.858093537306915*^9, 
   3.8586900331644125`*^9, 3.8587752768622465`*^9, 3.8588700543270626`*^9, 
   3.858890413826852*^9, 3.8589479974166107`*^9, 3.858966953658313*^9, 
   3.8589795518709345`*^9, 3.8590424592643075`*^9, 3.8590480149975996`*^9, 
   3.8593918776517115`*^9, 3.860783064551243*^9, 3.8609543689599943`*^9, 
   3.8610293920126767`*^9, 3.8611353318132896`*^9, 3.863185309647373*^9, {
   3.8631853618708115`*^9, 3.8631853847109704`*^9}, 3.8631873898107853`*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"5f6afde8-674a-4df7-84b4-5a36ef0567e7"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.85808716900119*^9, 3.858087252457873*^9, 3.858093537306915*^9, 
   3.8586900331644125`*^9, 3.8587752768622465`*^9, 3.8588700543270626`*^9, 
   3.858890413826852*^9, 3.8589479974166107`*^9, 3.858966953658313*^9, 
   3.8589795518709345`*^9, 3.8590424592643075`*^9, 3.8590480149975996`*^9, 
   3.8593918776517115`*^9, 3.860783064551243*^9, 3.8609543689599943`*^9, 
   3.8610293920126767`*^9, 3.8611353318132896`*^9, 3.863185309647373*^9, {
   3.8631853618708115`*^9, 3.8631853847109704`*^9}, 3.863187389826422*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"244c35ce-f1a0-4649-ae1a-111619b841f8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.85808716900119*^9, 3.858087252457873*^9, 3.858093537306915*^9, 
   3.8586900331644125`*^9, 3.8587752768622465`*^9, 3.8588700543270626`*^9, 
   3.858890413826852*^9, 3.8589479974166107`*^9, 3.858966953658313*^9, 
   3.8589795518709345`*^9, 3.8590424592643075`*^9, 3.8590480149975996`*^9, 
   3.8593918776517115`*^9, 3.860783064551243*^9, 3.8609543689599943`*^9, 
   3.8610293920126767`*^9, 3.8611353318132896`*^9, 3.863185309647373*^9, {
   3.8631853618708115`*^9, 3.8631853847109704`*^9}, 3.863187389842023*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"c2830b6b-cc72-41fb-bcac-15393abdc55f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1No\[Beta]", 
      RowBox[{"1", ",", "dot"}]], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "/.", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "j_"}]], ":>", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]]}]], "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond3neg1No\[Beta]", 
         RowBox[{"1", ",", "dot"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]]}]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond3neg1No\[Beta]", 
         RowBox[{"1", ",", "dot"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]]}]], "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond3neg1No\[Beta]", 
         RowBox[{"1", ",", "dot"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond3neg1No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", 
           SubscriptBox["1", 
            SubscriptBox["\[Mu]", "1"]]}]}]]]}]], " ", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond3neg1No\[Beta]", 
            RowBox[{"1", ",", 
             SubscriptBox["dot", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]]}]], "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
          " ", 
          RowBox[{
           RowBox[{
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], "]"}], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["A", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond3neg1No\[Beta]", 
        RowBox[{"1", ",", 
         SubscriptBox["dot", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             SubscriptBox["1", 
              SubscriptBox["\[Mu]", "1"]]}]}]]]}]], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["B", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond3neg1No\[Beta]", 
         RowBox[{"1", ",", 
          SubscriptBox["dot", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]]}]], ",", 
        RowBox[{
         SubscriptBox["r", "1"], 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}]}], "]"}], "/", "\[ImaginaryI]"}],
      "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["cond3neg1No\[Beta]", 
          RowBox[{"1", ",", 
           SubscriptBox["dot", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", 
               SubscriptBox["1", 
                SubscriptBox["\[Mu]", "1"]]}]}]]]}]], "/", "\[ImaginaryI]"}], 
        "//.", 
        RowBox[{
         RowBox[{
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], " ", "//.", 
      RowBox[{
       SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["D", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond3neg1No\[Beta]", 
            RowBox[{"1", ",", 
             SubscriptBox["dot", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]]}]], "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
          " ", 
          RowBox[{
           RowBox[{
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], "]"}], ",", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "^", "3"}]}], "]"}], "/", 
      "\[ImaginaryI]"}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.858088846447407*^9, 3.8580888826359177`*^9}, {
   3.858088913171025*^9, 3.858088916691057*^9}, {3.8580889685720816`*^9, 
   3.8580889689157104`*^9}, {3.8580890204109097`*^9, 3.858089038800662*^9}, {
   3.858089084295512*^9, 3.858089104207883*^9}, {3.858090795441557*^9, 
   3.8580908133879423`*^9}, {3.858596965617902*^9, 3.8585969663988705`*^9}, {
   3.8631851986465855`*^9, 3.863185207024753*^9}, {3.8631852381132145`*^9, 
   3.8631852573318872`*^9}, {3.863185444772727*^9, 3.863185454742403*^9}, 
   3.8631854850450153`*^9},
 CellLabel->
  "In[126]:=",ExpressionUUID->"1c911b43-ef82-4fe8-b47d-9e314573de13"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox["\[Alpha]", 
   SubsuperscriptBox["c", "0", "2"]], "-", 
  RowBox[{"\[Alpha]", " ", 
   SubsuperscriptBox["c", "0", "2"]}]}]], "Output",
 CellChangeTimes->{3.859391941100464*^9, 3.860783093714411*^9, 
  3.860954393622187*^9, 3.8610294238714323`*^9, 3.8611353636263027`*^9, 
  3.8631852807033205`*^9, 3.8631854140315075`*^9, 3.8631854766908917`*^9, 
  3.8631874173135056`*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"36fffa73-6122-4dc7-955b-e5b0263ffb15"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", "-", 
     SubsuperscriptBox["c", "0", "2"], "+", 
     SubsuperscriptBox["c", "0", "6"], "-", 
     RowBox[{"\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "8"]}]}], ")"}]}], 
  SubsuperscriptBox["c", "0", "3"]]], "Output",
 CellChangeTimes->{3.859391941100464*^9, 3.860783093714411*^9, 
  3.860954393622187*^9, 3.8610294238714323`*^9, 3.8611353636263027`*^9, 
  3.8631852807033205`*^9, 3.8631854140315075`*^9, 3.8631854766908917`*^9, 
  3.863187417360367*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"008d82bd-12ce-4494-93dd-9deaffb09c69"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubsuperscriptBox["c", "0", "2"]}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "16"]}], "+", 
    RowBox[{"\[Alpha]", " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"13", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"56", "+", 
       RowBox[{"17", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"10", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"28", " ", "\[Alpha]"}], "+", 
       RowBox[{"22", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "-", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "-", 
    RowBox[{"10", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
       RowBox[{"44", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"13", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{"16", "-", 
       RowBox[{"5", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "2"]}], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.859391941100464*^9, 3.860783093714411*^9, 
  3.860954393622187*^9, 3.8610294238714323`*^9, 3.8611353636263027`*^9, 
  3.8631852807033205`*^9, 3.8631854140315075`*^9, 3.8631854766908917`*^9, 
  3.8631874180476255`*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"5f29e5c2-f188-4fc9-9caf-f524a6e5d0cd"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "6"]}], "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "10"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "12"]}]}], 
  RowBox[{"12", " ", 
   SubsuperscriptBox["c", "0", "5"]}]]], "Output",
 CellChangeTimes->{3.859391941100464*^9, 3.860783093714411*^9, 
  3.860954393622187*^9, 3.8610294238714323`*^9, 3.8611353636263027`*^9, 
  3.8631852807033205`*^9, 3.8631854140315075`*^9, 3.8631854766908917`*^9, 
  3.863187418734907*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"571b559b-cc73-415f-91b6-d6fac905b31b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox["cond3neg1No\[Beta]", 
     RowBox[{"1", ",", 
      SubscriptBox["dot", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]]}]], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "3"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           SubscriptBox["C", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["D", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.858093620329239*^9, 3.8580936889710436`*^9}, {
   3.858093719976845*^9, 3.8580937233852034`*^9}, {3.858093833508129*^9, 
   3.8580938812716274`*^9}, {3.8580939654940333`*^9, 
   3.8580940001866293`*^9}, {3.858094417757406*^9, 3.858094460530064*^9}, {
   3.858094746064164*^9, 3.8580948176670523`*^9}, {3.858094937819569*^9, 
   3.8580949462578106`*^9}, {3.8585970709365416`*^9, 
   3.8585970713804197`*^9}, {3.858870649637761*^9, 3.8588706585917253`*^9}, 
   3.859389411682833*^9, 3.859391801178869*^9, {3.859392363198965*^9, 
   3.859392371821039*^9}, 3.8593924172145257`*^9},
 CellLabel->
  "In[135]:=",ExpressionUUID->"2bc25b57-7db5-476e-a367-5b4eec0fd7e5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8580936682587705`*^9, 3.8580936898145533`*^9}, 
   3.8580937264960938`*^9, {3.8580938756607895`*^9, 3.8580938858335056`*^9}, 
   3.8580940016094475`*^9, {3.85809444656021*^9, 3.8580944617952957`*^9}, 
   3.8580947515525994`*^9, {3.858094810695654*^9, 3.858094818979126*^9}, 
   3.8580949471034155`*^9, 3.858597074941491*^9, 3.858690065503536*^9, 
   3.8587753231440315`*^9, {3.858870308673504*^9, 3.858870321958479*^9}, {
   3.8588706460287395`*^9, 3.85887065924761*^9}, 3.858890449341131*^9, 
   3.8589480246612244`*^9, 3.858966977002062*^9, {3.8589796352015977`*^9, 
   3.8589796701814547`*^9}, 3.8590426264229813`*^9, 3.8590480443911095`*^9, 
   3.85939237649141*^9, 3.859392418026762*^9, 3.8593930189318266`*^9, 
   3.860783101391621*^9, 3.860954397213166*^9, 3.86102942915853*^9, 
   3.86113536697637*^9, 3.863185495138379*^9, 3.8631874188130236`*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"94b5e6b8-94ae-45e3-8695-f508f1a5ce47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond3neg1No\[Beta]", 
         RowBox[{"1", ",", 
          SubscriptBox["dot", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]]}]], ",", 
        SubscriptBox["\[Lambda]", "2"]}], "]"}], "/", "\[ImaginaryI]"}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["F", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond3neg1No\[Beta]", 
        RowBox[{"1", ",", 
         SubscriptBox["dot", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]]}]], ",", 
       RowBox[{
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["cond3neg1No\[Beta]", 
          RowBox[{"1", ",", 
           SubscriptBox["dot", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]]}]], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], " ", "->", " ", "0"}]}], " ", "//.",
         " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], " ", "->", " ", "0"}]}], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.858092423801543*^9, {3.858094993722805*^9, 3.858095109700781*^9}, {
   3.8585970789930677`*^9, 3.858597087338323*^9}, {3.8588707169382906`*^9, 
   3.858870720312235*^9}, {3.8589796759461427`*^9, 3.8589796821971965`*^9}, {
   3.859042649645958*^9, 3.859042654878461*^9}, {3.859389411691244*^9, 
   3.8593894117068653`*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"8f861610-a602-4d27-b96e-da55f765ffeb"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SubsuperscriptBox["c", "0", "4"]}], 
   RowBox[{"2", " ", 
    SubscriptBox["c", "0"]}]]}]], "Output",
 CellChangeTimes->{{3.8580949941912427`*^9, 3.858095110387862*^9}, 
   3.8585970884473057`*^9, 3.858690070036482*^9, 3.858775324586728*^9, 
   3.858870724888895*^9, 3.8588904514936996`*^9, 3.8589480251454477`*^9, 
   3.8589669770884933`*^9, 3.8589796831341887`*^9, 3.8590426553669214`*^9, 
   3.859048045203069*^9, 3.859393064620911*^9, 3.8607831031946836`*^9, 
   3.860954397303399*^9, 3.8610294292834873`*^9, 3.861135367055009*^9, 
   3.863185498674759*^9, 3.8631874188755035`*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"1290adc6-3c08-4165-ae87-cbe264ac39ef"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"3", "-", 
    SubsuperscriptBox["c", "0", "4"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8580949941912427`*^9, 3.858095110387862*^9}, 
   3.8585970884473057`*^9, 3.858690070036482*^9, 3.858775324586728*^9, 
   3.858870724888895*^9, 3.8588904514936996`*^9, 3.8589480251454477`*^9, 
   3.8589669770884933`*^9, 3.8589796831341887`*^9, 3.8590426553669214`*^9, 
   3.859048045203069*^9, 3.859393064620911*^9, 3.8607831031946836`*^9, 
   3.860954397303399*^9, 3.8610294292834873`*^9, 3.861135367055009*^9, 
   3.863185498674759*^9, 3.8631874188911047`*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"0237d244-187a-4e08-8cae-609275ec87b3"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], "+", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "10"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "12"]}]}], 
  RowBox[{"8", " ", 
   SubsuperscriptBox["c", "0", "4"]}]]], "Output",
 CellChangeTimes->{{3.8580949941912427`*^9, 3.858095110387862*^9}, 
   3.8585970884473057`*^9, 3.858690070036482*^9, 3.858775324586728*^9, 
   3.858870724888895*^9, 3.8588904514936996`*^9, 3.8589480251454477`*^9, 
   3.8589669770884933`*^9, 3.8589796831341887`*^9, 3.8590426553669214`*^9, 
   3.859048045203069*^9, 3.859393064620911*^9, 3.8607831031946836`*^9, 
   3.860954397303399*^9, 3.8610294292834873`*^9, 3.861135367055009*^9, 
   3.863185498674759*^9, 3.8631874189067235`*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"4d7abd93-f8c0-44e7-8c48-205363940614"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox["cond3neg1No\[Beta]", 
     RowBox[{"1", ",", 
      SubscriptBox["dot", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]]}]], " ", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["E", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Lambda]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["F", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["r", "1"], 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["G", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.85809514309813*^9, {3.858095174037512*^9, 3.8580952198134594`*^9}, {
   3.8585970929167624`*^9, 3.8585970947288337`*^9}, {3.8588707289504867`*^9, 
   3.8588707353445816`*^9}, 3.8593894117068653`*^9},
 CellLabel->
  "In[139]:=",ExpressionUUID->"46771052-6587-48b0-a0e7-b2321fc6aa25"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858095220081541*^9, 3.8585970959054966`*^9, 
  3.8586900746472063`*^9, 3.858775327034501*^9, 3.8588707362973747`*^9, 
  3.8588904548079395`*^9, 3.8589480278974495`*^9, 3.858966977187234*^9, 
  3.858979686259671*^9, 3.8590426589595394`*^9, 3.859048048379506*^9, 
  3.8593930687606497`*^9, 3.8607831058323097`*^9, 3.8609543975166125`*^9, 
  3.8610294294240704`*^9, 3.86113536712605*^9, 3.863185500944199*^9, 
  3.8631874189692273`*^9},
 CellLabel->
  "Out[139]=",ExpressionUUID->"c5608dfb-e39b-4409-a15b-405a79edd16f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "2"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "1"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", 
              SubscriptBox["g", 
               RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["T", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["V", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]], "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "*", 
       SubscriptBox["U", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "3"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "2"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["A", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "*", 
              SubscriptBox["\[Lambda]", "2"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["B", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "*", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["C", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["D", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "*", 
              SuperscriptBox[
               SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], 
        ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["E", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["F", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["G", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "-", 
     SubscriptBox["cond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "v2"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8580951478343916`*^9, 3.8580951659547224`*^9}, {
   3.8580952265977993`*^9, 3.858095366443632*^9}, {3.858870799581475*^9, 
   3.858870815348708*^9}, 3.8588904598509703`*^9, {3.8593894117225113`*^9, 
   3.8593894117381268`*^9}, 3.859391801194483*^9, {3.863185509352002*^9, 
   3.8631855096231804`*^9}},
 CellLabel->
  "In[140]:=",ExpressionUUID->"9368f784-3a8f-4ab8-875e-5e882b8eb415"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.863185510844035*^9, 3.863187419172264*^9},
 CellLabel->
  "Out[141]=",ExpressionUUID->"947be519-9bc7-4213-b715-be2e0996b2a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Second", " ", "solvability", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"3", ",", "0"}]], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"3", ",", "0"}]], "//.", " ", 
                    RowBox[{
                    SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ",
                    "//.", " ", 
                   RowBox[{
                    SubscriptBox["C", "0"], "->", " ", "1"}]}], " ", "//.", 
                  " ", 
                  SubscriptBox["partsoln", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", "0"}]]}], "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", "1"}]]}], "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
              SubscriptBox["partsoln", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "1"}]]}], "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
         SubscriptBox["c", 
          SubscriptBox["g", 
           RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{"Conjugate", "[", 
         SubscriptBox["FA", "0"], "]"}], ",", 
        RowBox[{
         SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
     "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8583559213824577`*^9, 3.8583559553507037`*^9}, {
   3.8583562049479365`*^9, 3.858356234554598*^9}, {3.858356269723999*^9, 
   3.858356291245979*^9}, {3.8583564209340563`*^9, 3.8583564210433936`*^9}, 
   3.858356453493947*^9, {3.8583567462414455`*^9, 3.858356747147213*^9}, {
   3.8585973083100653`*^9, 3.8585973177590027`*^9}, 3.863185720329941*^9},
 CellLabel->
  "In[142]:=",ExpressionUUID->"fafb2a1a-e1c8-463a-aee6-a872a8bf4ce3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["c", "0", "5"]}]], 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]], "-", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubsuperscriptBox["c", "0", "12"], " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]], "-", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubsuperscriptBox["c", "0", "11"], " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "5"], " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["r", "1"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], ")"}]}], "+", 
     RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "9"], " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["r", "1"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], ")"}]}], "+", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["c", "0", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["\[Lambda]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["\[Alpha]", "2"], " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["c", "0", "7"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["\[Lambda]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["r", "1"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "2"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "-", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "10"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
     RowBox[{
      SubsuperscriptBox["c", "0", "4"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", "\[Alpha]", " ", 
         SubscriptBox["\[Lambda]", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "-", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        RowBox[{"12", " ", 
         SubscriptBox["r", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        RowBox[{"10", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["c", "0", "6"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["\[Lambda]", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "-", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["c", "0", "8"], " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "-", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["r", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "\[Alpha]", " ", 
            SubscriptBox["\[Lambda]", "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.8631857209042044`*^9, 3.863187419562784*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"ede57edc-7e59-40d1-967c-8a48e0505f8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"3", ",", "0"}]], ",", 
      SubscriptBox["\[Lambda]", "3"]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"3", ",", "0"}]], ",", 
      RowBox[{
       SubscriptBox["r", "2"], 
       SubscriptBox["\[Mu]", "1"]}]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"3", ",", "0"}]], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"3", ",", "0"}]], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "0"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"3", ",", "0"}]], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "1"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"3", ",", "0"}]], "-", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["S", 
         RowBox[{"2", ",", "0"}]], "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Factor", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"3", ",", "0"}]], "-", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "^", "2"}], "*", 
         SubscriptBox["T", 
          RowBox[{"2", ",", "0"}]], "*", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "0"}]]}]}], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "]"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Factor", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"3", ",", "0"}]], "-", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["S", 
          RowBox[{"2", ",", "0"}]], "*", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "1"}]]}]}], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "]"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cond30Remain", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["cond", 
           RowBox[{"3", ",", "0"}]], "//.", 
          RowBox[{
           SubscriptBox["\[Lambda]", "3"], " ", "->", "0"}]}], " ", "//.", 
         " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"]}], " ", "->", " ", "0"}]}], " ", "/.", 
        " ", 
        RowBox[{
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", "j_"}]], ":>", " ", "0"}]}], " ", "/.", " ", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "j_"}]], ":>", " ", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"cond30Remain", ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["A", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"cond30Remain", ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "]"}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["B", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"cond30Remain", "/", "\[ImaginaryI]"}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "]"}], "]"}], ",", 
       RowBox[{
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"cond30Remain", "/", "\[ImaginaryI]"}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "]"}], "]"}], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"cond30Remain", " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["A", 
            RowBox[{"3", ",", "0"}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{
           SubscriptBox["B", 
            RowBox[{"3", ",", "0"}]], "*", "\[ImaginaryI]", "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"], "*", 
           SubscriptBox["C", 
            RowBox[{"3", ",", "0"}]]}]}], ")"}], "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"cond30Remain", ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "]"}], "]"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "*", 
        SubscriptBox["A", 
         RowBox[{"3", ",", "0"}]]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["B", 
         RowBox[{"3", ",", "0"}]]}], "-", 
       RowBox[{"\[ImaginaryI]", "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"], "*", 
        SubscriptBox["C", 
         RowBox[{"3", ",", "0"}]]}]}], ")"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["D", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"cond30Remain", "/", 
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"]}], ")"}]}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]}], "]"}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"cond30Remain", "/", 
           SubscriptBox["\[Mu]", "1"]}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]}], "]"}], "]"}], ",", 
       RowBox[{
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"cond30Remain", "-", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["D", 
            RowBox[{"3", ",", "0"}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{
           SubscriptBox["E", 
            RowBox[{"3", ",", "0"}]], "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}]}], ")"}]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.858356462906521*^9, 3.8583564869600163`*^9}, {
   3.858356530007409*^9, 3.858356574210148*^9}, {3.8583566221035795`*^9, 
   3.858356629144659*^9}, {3.8583566791716833`*^9, 3.858356679936903*^9}, {
   3.858356722444707*^9, 3.8583567233194313`*^9}, {3.858356777180673*^9, 
   3.858356831735962*^9}, {3.8583570025818553`*^9, 3.8583571142190857`*^9}, {
   3.858357150186921*^9, 3.858357192115646*^9}, {3.8583572229151115`*^9, 
   3.8583572297787485`*^9}, {3.8583572977188125`*^9, 
   3.8583573942451067`*^9}, {3.8583574251854553`*^9, 3.8583574420234385`*^9}, 
   3.8588904759030323`*^9, {3.85939180121007*^9, 3.85939180121007*^9}, {
   3.863185530764946*^9, 3.863185552140352*^9}, {3.8631856047394285`*^9, 
   3.8631856162806587`*^9}, {3.863185653472848*^9, 3.863185674029034*^9}},
 CellLabel->
  "In[143]:=",ExpressionUUID->"3ac6b69c-38ce-4991-904c-50092c1c4eb3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187419718963*^9},
 CellLabel->
  "Out[143]=",ExpressionUUID->"aa04eef7-fa0d-4c9d-be45-3ba249458a95"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.8631874197345843`*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"a2fd9a5c-71c6-4180-bff9-00e0c879141b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.8631874197345843`*^9},
 CellLabel->
  "Out[145]=",ExpressionUUID->"962c5c37-c24a-49cd-8866-f232fa36b2e3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187419750207*^9},
 CellLabel->
  "Out[146]=",ExpressionUUID->"8cc94914-138c-46c4-b127-0522913798a8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187419765826*^9},
 CellLabel->
  "Out[147]=",ExpressionUUID->"a0ecb679-44fc-45a2-adfe-8b373fb17df8"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187419765826*^9},
 CellLabel->
  "Out[148]=",ExpressionUUID->"ce6b94b2-0dc7-493e-9d5d-566c3d742592"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187419781446*^9},
 CellLabel->
  "Out[149]=",ExpressionUUID->"c7c6d672-c811-44f3-afc8-88038cf29284"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.8631874197970643`*^9},
 CellLabel->
  "Out[150]=",ExpressionUUID->"3000cc97-995a-4e25-b405-6b3bee507bd3"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   SubsuperscriptBox["c", "0", "4"]}], 
  RowBox[{"2", " ", 
   SubsuperscriptBox["c", "0", "2"]}]]], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187420187563*^9},
 CellLabel->
  "Out[153]=",ExpressionUUID->"db5c4b1e-76ca-46ea-baac-38563406ad87"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "3"}], "+", 
    SubsuperscriptBox["c", "0", "4"]}], 
   RowBox[{"2", " ", 
    SubscriptBox["c", "0"]}]]}]], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.8631874204843445`*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"bf0af573-1315-47c2-a276-8f058c56e7eb"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], "+", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "10"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "12"]}]}], 
  RowBox[{"8", " ", 
   SubsuperscriptBox["c", "0", "5"]}]]], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.8631874207498865`*^9},
 CellLabel->
  "Out[155]=",ExpressionUUID->"62da9088-ed27-430b-8542-3cc6e881d13f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187420781124*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"0dd55d09-bfaa-45a8-b060-f2b95649d730"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187420781124*^9},
 CellLabel->
  "Out[157]=",ExpressionUUID->"7315c153-df0e-452c-b6ab-8d6691a0a86b"],

Cell[BoxData[
 RowBox[{
  FractionBox["\[Alpha]", 
   SubscriptBox["c", "0"]], "+", 
  SubscriptBox["c", "0"], "-", 
  RowBox[{"\[Alpha]", " ", 
   SubsuperscriptBox["c", "0", "3"]}]}]], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187420843605*^9},
 CellLabel->
  "Out[158]=",ExpressionUUID->"a8949d6f-a6b7-47bd-8e0d-310f02125ad4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[Alpha]"}], "+", 
  SubsuperscriptBox["c", "0", "2"], "-", 
  RowBox[{"\[Alpha]", " ", 
   SubsuperscriptBox["c", "0", "4"]}]}]], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187420859223*^9},
 CellLabel->
  "Out[159]=",ExpressionUUID->"b6828fcb-5cc9-4c1f-a98f-92ed8b80dfbc"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8583564773033085`*^9, 3.8583564872412004`*^9}, 
   3.8583565339592886`*^9, 3.85835657489724*^9, 3.8583566296132526`*^9, 
   3.8583566807647595`*^9, 3.858356726900914*^9, {3.858356757750106*^9, 
   3.8583567815443087`*^9}, {3.858356812860923*^9, 3.858356832704208*^9}, {
   3.8583570215407124`*^9, 3.8583571146094337`*^9}, {3.8583571669923787`*^9, 
   3.8583571930839243`*^9}, 3.8583572302785764`*^9, 3.8583573020776453`*^9, 
   3.85835736093618*^9, 3.8583574470430446`*^9, 3.858690224386379*^9, 
   3.858775338324291*^9, 3.8588708310422635`*^9, 3.8588904774434958`*^9, 
   3.8589480383085127`*^9, 3.858966979894706*^9, 3.858979697500103*^9, 
   3.859042675591534*^9, 3.8590480580275354`*^9, 3.8593933305004063`*^9, 
   3.860783112850992*^9, 3.860954405861691*^9, 3.861029430512788*^9, 
   3.861135376339946*^9, {3.8631855396562557`*^9, 3.8631855691392064`*^9}, 
   3.8631856180844793`*^9, 3.8631856842259016`*^9, 3.863187420859223*^9},
 CellLabel->
  "Out[160]=",ExpressionUUID->"cac595f9-3d16-42bf-b6c9-f228ecc9937a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Proof", " ", "of", " ", "identities", " ", "for", " ", 
    "capitalized", " ", 
    RowBox[{"coefficients", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["C", 
      RowBox[{"3", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["G", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], "/", 
      SubscriptBox["c", "0"]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["A", 
      RowBox[{"3", ",", "0"}]], "+", 
     RowBox[{
      SubscriptBox["E", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], "/", 
      SubscriptBox["c", "0"]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["B", 
      RowBox[{"3", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["F", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], "/", 
      SubscriptBox["c", "0"]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["D", 
      RowBox[{"3", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["c", "0"], "*", 
      SubscriptBox["A", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        SubscriptBox["c", "0"], "2"]}], "*", 
      SubscriptBox["A", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{"2", "*", "\[Alpha]"}], "+", 
     SubscriptBox["E", 
      RowBox[{"3", ",", "0"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858864547090295*^9, 3.8588645474377837`*^9}, {
  3.8588708858423824`*^9, 3.8588709032215223`*^9}, {3.863185582153494*^9, 
  3.863185593923321*^9}, {3.8631856278123784`*^9, 3.8631856308930497`*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"5fc70bac-a8f0-4c65-9c2d-5590ceed9eb2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858864548968514*^9, 3.858870903674306*^9, 
  3.858890486767332*^9, 3.85894804443449*^9, 3.858966984475359*^9, 
  3.8589797163177767`*^9, 3.859042698251102*^9, 3.859048063795581*^9, 
  3.8593934643067675`*^9, 3.8607831176970415`*^9, 3.8609544113303328`*^9, 
  3.8610294364564123`*^9, 3.861135382183753*^9, 3.8631855786428237`*^9, 
  3.863185631260547*^9, 3.8631874209373255`*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"049e9c77-fd56-41c6-abce-09a933182f8c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858864548968514*^9, 3.858870903674306*^9, 
  3.858890486767332*^9, 3.85894804443449*^9, 3.858966984475359*^9, 
  3.8589797163177767`*^9, 3.859042698251102*^9, 3.859048063795581*^9, 
  3.8593934643067675`*^9, 3.8607831176970415`*^9, 3.8609544113303328`*^9, 
  3.8610294364564123`*^9, 3.861135382183753*^9, 3.8631855786428237`*^9, 
  3.863185631260547*^9, 3.863187420952944*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"bd300d95-465f-4f94-b48c-cc8f203bb326"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858864548968514*^9, 3.858870903674306*^9, 
  3.858890486767332*^9, 3.85894804443449*^9, 3.858966984475359*^9, 
  3.8589797163177767`*^9, 3.859042698251102*^9, 3.859048063795581*^9, 
  3.8593934643067675`*^9, 3.8607831176970415`*^9, 3.8609544113303328`*^9, 
  3.8610294364564123`*^9, 3.861135382183753*^9, 3.8631855786428237`*^9, 
  3.863185631260547*^9, 3.863187420952944*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"d9f141f6-35ea-43c9-9593-57a296fa6978"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858864548968514*^9, 3.858870903674306*^9, 
  3.858890486767332*^9, 3.85894804443449*^9, 3.858966984475359*^9, 
  3.8589797163177767`*^9, 3.859042698251102*^9, 3.859048063795581*^9, 
  3.8593934643067675`*^9, 3.8607831176970415`*^9, 3.8609544113303328`*^9, 
  3.8610294364564123`*^9, 3.861135382183753*^9, 3.8631855786428237`*^9, 
  3.863185631260547*^9, 3.8631874209685955`*^9},
 CellLabel->
  "Out[164]=",ExpressionUUID->"b99bfe87-6073-4a29-a46d-68a7097c351b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858864548968514*^9, 3.858870903674306*^9, 
  3.858890486767332*^9, 3.85894804443449*^9, 3.858966984475359*^9, 
  3.8589797163177767`*^9, 3.859042698251102*^9, 3.859048063795581*^9, 
  3.8593934643067675`*^9, 3.8607831176970415`*^9, 3.8609544113303328`*^9, 
  3.8610294364564123`*^9, 3.861135382183753*^9, 3.8631855786428237`*^9, 
  3.863185631260547*^9, 3.8631874209841833`*^9},
 CellLabel->
  "Out[165]=",ExpressionUUID->"dd4e3826-4ff8-4101-8110-d68c642f15bd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["0"], "Input",
 CellChangeTimes->{3.8631856802878156`*^9},
 CellLabel->
  "In[452]:=",ExpressionUUID->"b84ff19d-0710-4a76-b668-a11d1d5f89d0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858864548968514*^9, 3.858870903674306*^9, 
  3.858890486767332*^9, 3.85894804443449*^9, 3.858966984475359*^9, 
  3.8589797163177767`*^9, 3.859042698251102*^9, 3.859048063795581*^9, 
  3.8593934643067675`*^9, 3.8607831176970415`*^9, 3.8609544113303328`*^9, 
  3.8610294364564123`*^9, 3.861135382183753*^9, 3.8631855786428237`*^9, 
  3.863185631297325*^9, 3.8631856803553944`*^9},
 CellLabel->
  "Out[452]=",ExpressionUUID->"f92eba5e-c7ca-4f78-a405-23e1f6cca3c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "0", ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["T", 
        RowBox[{"2", ",", "0"}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", "0"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"], "*", 
          SubscriptBox["C", 
           RowBox[{"3", ",", "0"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["D", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["E", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", "0"}]]}], "-", 
         RowBox[{"\[ImaginaryI]", "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"], "*", 
          SubscriptBox["C", 
           RowBox[{"3", ",", "0"}]]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "0"}]], "-", 
     SubscriptBox["cond", 
      RowBox[{"3", ",", "0", ",", "v2"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858360558842258*^9, 3.8583607552006583`*^9}, {
  3.8588709763593025`*^9, 3.8588709977194967`*^9}, {3.8593894118563476`*^9, 
  3.8593894118719826`*^9}, {3.863185703600459*^9, 3.8631857038613625`*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"e5e53fe4-dd9f-496d-8929-bcc609489ff3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8631857043864326`*^9, 3.863187421093546*^9},
 CellLabel->
  "Out[167]=",ExpressionUUID->"673adc19-b757-4277-a786-8d395ae86249"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Third", " ", "solvability", " ", "condition"}], " ", 
   "**)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"3", ",", "1"}]], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  SubscriptBox["IHT", 
                   RowBox[{"3", ",", "1"}]], "//.", " ", 
                  RowBox[{
                   SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
                   RowBox[{
                    SubscriptBox["C", "1"], "*", 
                    SuperscriptBox[
                    SubscriptBox["c", "0"], "2"]}]}]}], " ", "//.", " ", 
                 RowBox[{
                  SubscriptBox["partsoln", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", "1"}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", "0"}]]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "1"}]]}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
         SubscriptBox["c", 
          SubscriptBox["g", 
           RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{"Conjugate", "[", 
         SubscriptBox["FA", "1"], "]"}], ",", 
        RowBox[{
         SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
     "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858597329056805*^9, 3.8585973721038647`*^9}, {
   3.8585974117424827`*^9, 3.8585974179676685`*^9}, {3.85859746004558*^9, 
   3.8585974601549172`*^9}, 3.8631857158161716`*^9},
 CellLabel->
  "In[168]:=",ExpressionUUID->"2f17ea41-0df3-4503-b12e-43cb74430512"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"24", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubsuperscriptBox["c", "0", "2"]}], "+", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"48", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "17"], " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubscriptBox["c", "0"], " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "-", 
    RowBox[{"96", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "16"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{"24", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"6", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"16", " ", 
        SubscriptBox["r", "1"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"64", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"32", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"16", "-", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"16", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"16", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"6", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]"}], "-", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["c", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "0"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"6", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Alpha]"}], "+", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Alpha]"}], "+", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"12", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"13", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "-", 
          RowBox[{"24", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{"5", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "10"}], " ", "\[Alpha]"}], "-", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", 
                SubscriptBox["r", "2"]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"48", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "64"}], "+", 
          SubsuperscriptBox["\[Omega]", "2", "4"], "-", 
          RowBox[{"96", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "16"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"16", "-", 
             RowBox[{"5", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}], "+", 
             RowBox[{"16", " ", 
              SubscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}]}], 
            ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"16", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"8", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "-", 
             RowBox[{"32", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "+", 
             RowBox[{"16", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["\[Alpha]", "2"], " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"48", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"8", " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "56"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "17"}], "+", 
                RowBox[{"16", " ", 
                 SubscriptBox["r", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", 
                SubscriptBox["r", "2"]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "4"], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"28", "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"32", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "+", 
             RowBox[{"16", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "48"}], "+", 
          SubsuperscriptBox["\[Omega]", "2", "4"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"16", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"32", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"64", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"80", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}], "-", 
          RowBox[{"16", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
       RowBox[{"256", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Lambda]", "3"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              SubscriptBox["c", "2"]}], "+", 
             SubscriptBox["\[Lambda]", "2"], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"12", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "-", 
          RowBox[{"32", " ", "\[Alpha]", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"16", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", "\[Alpha]", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"16", " ", "\[ImaginaryI]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"8", " ", "\[Alpha]", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}], "+", 
          RowBox[{"20", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Lambda]", "3"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              SubscriptBox["c", "2"]}], "+", 
             SubscriptBox["\[Lambda]", "2"], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"3", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"16", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SubscriptBox["r", "1"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "-", 
          RowBox[{"32", " ", "\[Alpha]", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Lambda]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", "\[Alpha]"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"8", " ", "\[Alpha]", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Lambda]", "3"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              SubscriptBox["c", "2"]}], "+", 
             SubscriptBox["\[Lambda]", "2"], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"96", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"16", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}]}], "+", 
          RowBox[{"24", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "14"}], " ", "\[Alpha]"}], "+", 
             RowBox[{"16", " ", "\[Alpha]", " ", 
              SubscriptBox["r", "2"]}], "-", 
             RowBox[{"11", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"16", " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"24", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "+", 
             RowBox[{"3", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"11", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "16"}], "+", 
          SubsuperscriptBox["\[Omega]", "2", "4"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", "\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}]}], "-", 
          RowBox[{"24", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{"6", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "\[Alpha]", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "+", 
             SubsuperscriptBox["\[Omega]", "2", "4"]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", "\[Alpha]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", 
                RowBox[{"8", " ", 
                 SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"16", " ", "\[Alpha]"}], "+", 
             RowBox[{"44", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
             RowBox[{"13", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["r", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}]}], 
            ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["r", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"22", " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.863185729549775*^9, 3.86318742436093*^9},
 CellLabel->
  "Out[168]=",ExpressionUUID->"58a2eb8c-2f56-4482-bb29-6e9c3a66d26b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "1"}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "1"}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "1"}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"3", ",", "1"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31\[Beta]", 
      RowBox[{"1", ",", "0"}]], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"3", ",", "1"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31\[Beta]", 
      RowBox[{"1", ",", "1"}]], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"3", ",", "1"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond31\[Beta]", 
      RowBox[{"1", ",", "1"}]], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["T", 
         RowBox[{"2", ",", "1"}]], "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["V", 
         RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond31\[Beta]", 
      RowBox[{"1", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], "*", 
      SubscriptBox["S", 
       RowBox[{"2", ",", "1"}]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond31\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "-", 
     RowBox[{"\[ImaginaryI]", "*", 
      SubscriptBox["U", 
       RowBox[{"2", ",", "1"}]]}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31No\[Beta]", 
      RowBox[{"1", ",", "dot"}]], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"3", ",", "1"}]], "/.", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "j_"}]], ":>", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]]}]], "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond31No\[Beta]", 
         RowBox[{"1", ",", "dot"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]]}]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond31No\[Beta]", 
         RowBox[{"1", ",", "dot"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]]}]], "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond31No\[Beta]", 
         RowBox[{"1", ",", "dot"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond31No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          SubscriptBox["1", 
           SubscriptBox["\[Mu]", "1"]]}]]]}]], " ", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond31No\[Beta]", 
            RowBox[{"1", ",", 
             SubscriptBox["dot", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]]]}]], "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
          " ", 
          RowBox[{
           RowBox[{
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], "]"}], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["A", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond31No\[Beta]", 
        RowBox[{"1", ",", 
         SubscriptBox["dot", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            SubscriptBox["1", 
             SubscriptBox["\[Mu]", "1"]]}]]]}]], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["B", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond31No\[Beta]", 
         RowBox[{"1", ",", 
          SubscriptBox["dot", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]]}]], ",", 
        RowBox[{
         SubscriptBox["r", "1"], 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}]}], "]"}], "/", "\[ImaginaryI]"}],
      "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["cond31No\[Beta]", 
          RowBox[{"1", ",", 
           SubscriptBox["dot", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              SubscriptBox["1", 
               SubscriptBox["\[Mu]", "1"]]}]]]}]], "/", "\[ImaginaryI]"}], "//.", 
        RowBox[{
         RowBox[{
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], "//.", 
      RowBox[{
       SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["D", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond31No\[Beta]", 
            RowBox[{"1", ",", 
             SubscriptBox["dot", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]]]}]], "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
          " ", 
          RowBox[{
           RowBox[{
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], "]"}], ",", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "^", "3"}]}], "]"}], "/", 
      "\[ImaginaryI]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond31No\[Beta]", 
      RowBox[{"1", ",", 
       SubscriptBox["dot", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]]}]], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["A", 
            RowBox[{"3", ",", "1"}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["B", 
            RowBox[{"3", ",", "1"}]], "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["C", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["D", 
            RowBox[{"3", ",", "1"}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond31No\[Beta]", 
         RowBox[{"1", ",", 
          SubscriptBox["dot", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]]}]], ",", 
        SubscriptBox["\[Lambda]", "2"]}], "]"}], "/", "\[ImaginaryI]"}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["F", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond31No\[Beta]", 
        RowBox[{"1", ",", 
         SubscriptBox["dot", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]]}]], ",", 
       RowBox[{
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"3", ",", "1"}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["cond31No\[Beta]", 
          RowBox[{"1", ",", 
           SubscriptBox["dot", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]]}]], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], " ", "->", " ", "0"}]}], " ", "//.",
         " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], " ", "->", " ", "0"}]}], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8585971254925117`*^9, 3.858597134733491*^9}, {
  3.8631857389193697`*^9, 3.8631858368293686`*^9}, {3.8631858778688374`*^9, 
  3.863185880567648*^9}, {3.8631859175482845`*^9, 3.8631859201200204`*^9}, {
  3.8631859699674096`*^9, 3.8631859704442453`*^9}},
 CellLabel->
  "In[169]:=",ExpressionUUID->"2de7bf3c-6dfd-4f72-bcdf-3fb2024963a1"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.86318742453275*^9},
 CellLabel->
  "Out[169]=",ExpressionUUID->"8fb558df-f8a2-4af1-b383-603c9c354ae5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.8631874245483723`*^9},
 CellLabel->
  "Out[170]=",ExpressionUUID->"f80dc147-6e4f-494e-88ae-68364ff2ba2e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.8631874245483723`*^9},
 CellLabel->
  "Out[171]=",ExpressionUUID->"85b3b33e-d051-4a4d-a2b8-628a940fa9c7"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.8631874247670507`*^9},
 CellLabel->
  "Out[175]=",ExpressionUUID->"e1f05b64-b904-49ed-940e-b5283969e134"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.8631874247826695`*^9},
 CellLabel->
  "Out[176]=",ExpressionUUID->"fa3a1648-eb49-4239-aa64-9da39f7e1dfa"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.8631874247982907`*^9},
 CellLabel->
  "Out[177]=",ExpressionUUID->"ef9238da-3c30-4a08-ae72-5ed9c233db54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  FractionBox[
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["c", "0", "4"]}], ")"}]}], 
   SubsuperscriptBox["c", "0", "2"]]}]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.8631874473731475`*^9},
 CellLabel->
  "Out[183]=",ExpressionUUID->"5c7939fc-3b0b-4726-b6af-31cf2ac3dd05"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], "+", 
     SubsuperscriptBox["c", "0", "2"], "-", 
     SubsuperscriptBox["c", "0", "6"], "+", 
     RowBox[{"\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "8"]}]}], ")"}]}], 
  SubsuperscriptBox["c", "0", "3"]]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.86318744748251*^9},
 CellLabel->
  "Out[184]=",ExpressionUUID->"f07f1adb-5363-42c1-88cb-edeef288e535"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubsuperscriptBox["c", "0", "2"]}], "+", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "16"]}], "+", 
    RowBox[{"\[Alpha]", " ", 
     SubsuperscriptBox["\[Omega]", "2", "4"]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"13", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"56", "+", 
       RowBox[{"17", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
       RowBox[{"10", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"28", " ", "\[Alpha]"}], "+", 
       RowBox[{"22", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}], "-", 
    RowBox[{"10", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", "2", "2"], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
       RowBox[{"44", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
       RowBox[{"13", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{"16", "-", 
       RowBox[{"5", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "2"]}], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.863187448279109*^9},
 CellLabel->
  "Out[185]=",ExpressionUUID->"3f30ae5a-e1a0-4b40-9f50-5c60bb334948"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "6"]}], "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "10"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "12"]}]}], 
  RowBox[{"12", " ", 
   SubsuperscriptBox["c", "0", "5"]}]]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.863187449185046*^9},
 CellLabel->
  "Out[186]=",ExpressionUUID->"cd953b3d-001f-49d9-a5ae-b3f6c42ec9a9"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.863187449216287*^9},
 CellLabel->
  "Out[187]=",ExpressionUUID->"24fb16b8-e9b3-41d2-a349-09cb7f831603"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   SubsuperscriptBox["c", "0", "4"]}], 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"]}]]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.863187449231906*^9},
 CellLabel->
  "Out[188]=",ExpressionUUID->"7a21f2f6-49ee-4b11-b593-e089888d9f96"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "3"}], "+", 
    SubsuperscriptBox["c", "0", "4"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.863187449231906*^9},
 CellLabel->
  "Out[189]=",ExpressionUUID->"c2435062-313f-4b69-a198-537b86728aa8"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], "+", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{"2", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "10"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "12"]}]}], 
  RowBox[{"8", " ", 
   SubsuperscriptBox["c", "0", "4"]}]]], "Output",
 CellChangeTimes->{3.858597135885606*^9, 3.858597519165469*^9, 
  3.858690364090602*^9, 3.8587753737682333`*^9, 3.8588712438237*^9, 
  3.858890510779872*^9, 3.8589481771635137`*^9, 3.858966998879545*^9, 
  3.858979779579502*^9, 3.859042993296002*^9, 3.8590480853086915`*^9, 
  3.8593935385884295`*^9, 3.860783137343066*^9, 3.8609544335292783`*^9, 
  3.8610294569117584`*^9, 3.8611354036272955`*^9, 3.8631857771328917`*^9, 
  3.8631858378689256`*^9, 3.863185881863823*^9, 3.863185920527356*^9, 
  3.863185970888295*^9, 3.863187449247547*^9},
 CellLabel->
  "Out[190]=",ExpressionUUID->"7667c8a3-c404-4066-9be9-f601f4493627"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Proofs", " ", "of", " ", "identities", " ", "for", " ", 
    "capitalized", " ", 
    RowBox[{"coefficients", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["A", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["A", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["B", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["B", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], "-", 
      SubscriptBox["C", 
       RowBox[{"3", ",", "1"}]]}], " ", "/.", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "j_"], ":>", " ", 
      RowBox[{"\[Omega]", "[", "j", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["D", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "-", 
     SubscriptBox["D", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["E", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["E", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["F", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["F", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["G", 
      RowBox[{"3", ",", "1"}]], "-", 
     SubscriptBox["G", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8585989773389945`*^9, 3.8585989989140844`*^9}, {
  3.8588713692498474`*^9, 3.85887137207996*^9}, {3.863185890150907*^9, 
  3.8631859048411217`*^9}, {3.863185982606674*^9, 3.863185983165117*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"b67c92c7-3483-4db2-8e59-0122c00fb23d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.863187449372509*^9},
 CellLabel->
  "Out[191]=",ExpressionUUID->"5897750c-2335-47dd-bb93-07d303e22c03"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.8631874493881283`*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"8af31147-30fa-4e04-b193-70ad578e8364"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.8631874494037485`*^9},
 CellLabel->
  "Out[193]=",ExpressionUUID->"02183812-ebbd-4885-b3d6-15d3dd522a13"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.8631874494193473`*^9},
 CellLabel->
  "Out[194]=",ExpressionUUID->"1617ce87-42fe-42f6-b1ec-4822630d6e4e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.863187449434987*^9},
 CellLabel->
  "Out[195]=",ExpressionUUID->"1f529c59-8a3b-4824-997c-cedc155bfaa4"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.863187449434987*^9},
 CellLabel->
  "Out[196]=",ExpressionUUID->"a1906518-6bf2-4b2e-b4d2-13585ba163e5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8585989846361794`*^9, 3.8585989993045816`*^9}, 
   3.8586904167120523`*^9, 3.8587754035254545`*^9, 3.8588713727201996`*^9, 
   3.8588905418792458`*^9, 3.858948205773465*^9, 3.8589670215948076`*^9, 
   3.8589798184297705`*^9, 3.8590430264586077`*^9, 3.8590481109109325`*^9, 
   3.8593936619309807`*^9, 3.8607831676313066`*^9, 3.860954466290204*^9, 
   3.86102949368513*^9, 3.861135435811308*^9, 3.8631859056194506`*^9, 
   3.8631859925324025`*^9, 3.8631874494506083`*^9},
 CellLabel->
  "Out[197]=",ExpressionUUID->"f20364bb-cf58-425f-b116-06092648b31e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "1", ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "2"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "1"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", 
              SubscriptBox["g", 
               RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["T", 
           RowBox[{"2", ",", "1"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["V", 
           RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]], "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "1"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["U", 
        RowBox[{"2", ",", "1"}]]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "3"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "2"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["A", 
               RowBox[{"3", ",", "1"}]], "*", 
              SubscriptBox["\[Lambda]", "2"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["B", 
               RowBox[{"3", ",", "1"}]], "*", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["C", 
               RowBox[{"3", ",", "1"}]]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["D", 
               RowBox[{"3", ",", "1"}]], "*", 
              SuperscriptBox[
               SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], 
        ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["E", 
           RowBox[{"3", ",", "1"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["F", 
           RowBox[{"3", ",", "1"}]], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["G", 
           RowBox[{"3", ",", "1"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"3", ",", "1"}]], "-", 
     SubscriptBox["cond", 
      RowBox[{"3", ",", "1", ",", "v2"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8585996110443544`*^9, 3.8585996911688905`*^9}, {
   3.8588714996281705`*^9, 3.858871514381694*^9}, {3.858890558398763*^9, 
   3.8588905592223525`*^9}, {3.859389412134387*^9, 3.859389412150007*^9}, 
   3.8593918013194323`*^9, {3.863185934366595*^9, 3.863185935169365*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"d1e35333-ca18-43ea-8bec-a77fec553109"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8631859426881504`*^9, 3.8631859953600597`*^9, 
  3.8631874497161474`*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"15ee0c53-b971-4ef5-b530-7a2b4a3a1000"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Express", " ", "the", " ", "solvability", " ", "conditions", 
    " ", "with", " ", "symbolic", " ", 
    RowBox[{"variables", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "2"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symV", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]], "*", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SubscriptBox["\[Mu]", "1"]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]], "*", 
        SubscriptBox["symU", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Lambda]", "3"], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["r", "2"], 
               SubscriptBox["\[Mu]", "1"], "*", 
               SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], "*", 
               SubscriptBox["\[Lambda]", "2"]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["symB", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], "*", 
               SubscriptBox["r", "1"], 
               SubscriptBox["\[Mu]", "1"]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], "*", 
               SuperscriptBox[
                SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], 
         ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symE", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{
           SubscriptBox["symF", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{
           SubscriptBox["symG", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["symV", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "->", " ", 
       SubscriptBox["symU", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"3", ",", "0", ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["symB", 
           RowBox[{"3", ",", "0"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"], "*", 
          SubscriptBox["symC", 
           RowBox[{"3", ",", "0"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symD", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["symE", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["symB", 
           RowBox[{"3", ",", "0"}]]}], "-", 
         RowBox[{"\[ImaginaryI]", "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"], "*", 
          SubscriptBox["symC", 
           RowBox[{"3", ",", "0"}]]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"3", ",", "1", ",", "v2"}]], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "2"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", "g"]}]}], ")"}]}], "-", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}], "-", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symV", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]], "*", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SubscriptBox["\[Mu]", "1"]}], "-", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SubscriptBox["symU", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]], "*", 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Lambda]", "3"], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["r", "2"], 
               SubscriptBox["\[Mu]", "1"], "*", 
               SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}], "*", 
               SubscriptBox["\[Lambda]", "2"]}], "-", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["symB", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], "*", 
               SubscriptBox["r", "1"], 
               SubscriptBox["\[Mu]", "1"]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], "*", 
               SuperscriptBox[
                SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], 
         ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], "*", 
           SubscriptBox["symE", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "-", 
          RowBox[{
           SubscriptBox["symF", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{
           SubscriptBox["symG", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["symV", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "->", " ", 
       SubscriptBox["symU", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8586901037549443`*^9, 3.858690180327593*^9}, {
   3.858690255793076*^9, 3.8586903089980173`*^9}, {3.858690350127623*^9, 
   3.858690351112113*^9}, {3.8586904540996914`*^9, 3.8586905482482634`*^9}, {
   3.8586908225155935`*^9, 3.858690931863533*^9}, {3.858690998518097*^9, 
   3.858691056855341*^9}, 3.8586910974869814`*^9, {3.858872034750442*^9, 
   3.8588721267610736`*^9}, {3.859389412165634*^9, 3.8593894122378254`*^9}, {
   3.859391801350686*^9, 3.859391801350686*^9}, {3.8631861373591504`*^9, 
   3.863186152144602*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"65bc6409-5187-4f53-be61-22a7067ab4d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Solve", " ", "the", " ", "solvability", " ", "conditions", " ", 
    "for", " ", 
    SubscriptBox["\[Lambda]", "3"], " ", "and", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"+", 
        RowBox[{"/", 
         RowBox[{"-", "1"}]}]}]}]], "."}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["symLambdaBeta", "3"], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Refine", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"Refine", "[", 
             RowBox[{
              RowBox[{"Simplify", "[", 
               RowBox[{"Refine", "[", 
                RowBox[{
                 RowBox[{"Simplify", "[", 
                  RowBox[{
                   RowBox[{"Refine", "[", 
                    RowBox[{
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Solve", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}], ",", "v2"}]], "==", "0"}], " ", "&&", 
                    "\[IndentingNewLine]", " ", 
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"3", ",", "0", ",", "v2"}]], "==", "0"}], " ", "&&",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"3", ",", "1", ",", "v2"}]], "==", "0"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "3"], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}], "}"}]}], "]"}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symV", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "2"], "->", "symLambda2"}]}], 
                    " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "->", "symBeta0neg1"}]}], " ", "//.",
                     " ", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]], "->", "symBeta0pos1"}]}], "]"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]], ">", "0"}], ",", 
                    RowBox[{
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], ">", "0"}], ",", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "}"}]}], "]"}], 
                   " ", "//.", 
                   RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], "]"}], ",", 
                 RowBox[{
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], ">", "0"}]}], "]"}], "]"}], ",", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], "<", "0"}]}], "]"}], "//.", " ", 
            RowBox[{
             SubscriptBox["symT", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", 
             RowBox[{
              SubscriptBox["e", "2"], "/", "4"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SubscriptBox["e", "BW"]}], "+", 
              RowBox[{
               SubscriptBox["e", "2"], " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"]}]}], "<", "0"}], ",", 
            RowBox[{
             SubscriptBox["e", "2"], ">", "0"}]}], "}"}]}], "]"}], "//.", " ", 
        RowBox[{
         SubscriptBox["e", "BW"], "->", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox["\[CapitalDelta]", "BW"], "2"], "/", 
           RowBox[{"(", 
            RowBox[{"8", "*", 
             SubscriptBox["e", "2"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["e", "2"], "*", 
           RowBox[{
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "2"], "/", "8"}]}]}]}]}], "]"}], ",", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "BW"], ">", "0"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8590440241336794`*^9, 3.859044055652728*^9}, {
   3.859044094206741*^9, 3.859044173758211*^9}, 3.859044341993184*^9, 
   3.8590464127041388`*^9, {3.8590465218585253`*^9, 3.859046527840973*^9}, {
   3.8590465694757338`*^9, 3.859046600477169*^9}, {3.8593938758848305`*^9, 
   3.859393880024602*^9}, {3.863184810523035*^9, 3.8631848280836363`*^9}, {
   3.8631861579703045`*^9, 3.8631861757806263`*^9}, {3.863187306847864*^9, 
   3.863187306847864*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"2a39c9fc-ad08-4912-b3e8-f274161b3dce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Lambda]", "3"], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"32", " ", 
        SubscriptBox["e", "2"], " ", 
        SubscriptBox["\[CapitalDelta]", "BW"], " ", 
        SubsuperscriptBox["symT", 
         RowBox[{"2", ",", "0"}], "2"]}]], 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubsuperscriptBox["e", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SubscriptBox["c", "g"], " ", 
                SubscriptBox["r", "1"]}], "+", 
               RowBox[{"\[ImaginaryI]", " ", 
                SubscriptBox["\[CapitalDelta]", "BW"]}]}], ")"}], " ", 
             SubscriptBox["symD", 
              RowBox[{"3", ",", "0"}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["r", "1"], " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["e", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["e", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "1"]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[CapitalDelta]", "BW"]}]}], ")"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], ")"}]}], "+", 
                  RowBox[{"8", " ", 
                   SubscriptBox["r", "1"], " ", 
                   SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}]}], ")"}]}], "+", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["e", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "1"]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[CapitalDelta]", "BW"]}]}], ")"}], " ", 
                   SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                  RowBox[{"8", " ", 
                   SubscriptBox["r", "1"], " ", 
                   SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                SubscriptBox["symG", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubsuperscriptBox["\[CapitalDelta]", "BW", "3"], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["c", "g"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
                SubscriptBox["e", "2"], " ", 
                SubscriptBox["r", "2"], " ", 
                SubscriptBox["\[CapitalDelta]", "BW"]}], "+", 
               RowBox[{
                SubscriptBox["r", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SubsuperscriptBox["\[CapitalDelta]", "BW", "2"]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["e", "2", "2"], " ", 
                   SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["r", "1"], " ", 
             SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
             SubscriptBox["symB", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["e", "2", "2"], " ", 
             SubscriptBox["r", "1"], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubscriptBox["symB", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["e", "2"], " ", 
             SubscriptBox["\[CapitalDelta]", "BW"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "16"}], " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["e", "2"], " ", 
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                  RowBox[{"16", " ", 
                   SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}], 
          " ", 
          SubsuperscriptBox["symT", 
           RowBox[{"2", ",", "0"}], "2"]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["e", "2", "2"], " ", 
        SubscriptBox["\[CapitalDelta]", "BW"], " ", 
        SubsuperscriptBox["symS", 
         RowBox[{"2", ",", "0"}], "2"], " ", 
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SubscriptBox["r", "1"], " ", 
            SubscriptBox["symB", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]]}], "-", 
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        RowBox[{"8", " ", 
         SubscriptBox["c", "g"], " ", 
         SubscriptBox["r", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubsuperscriptBox["e", "2", "2"], " ", 
            SubscriptBox["symD", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubsuperscriptBox["symS", 
             RowBox[{"2", ",", "0"}], "2"]}], "+", 
           RowBox[{
            SubscriptBox["e", "2"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubsuperscriptBox["\[CapitalDelta]", "BW", "2"]}], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["e", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 RowBox[{
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", "BW"], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[CapitalDelta]", "BW"], "+", 
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["e", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        RowBox[{
         SubscriptBox["e", "2"], " ", 
         SubscriptBox["\[CapitalDelta]", "BW"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]]}], "-", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["r", "1"], " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", "0"}]]}], "+", 
                 RowBox[{"32", " ", 
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 RowBox[{"32", " ", 
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]]}], "+", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "-", 
           RowBox[{"8", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
        RowBox[{
         SubsuperscriptBox["e", "2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "\[ImaginaryI]"}], " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]]}], "-", 
                 RowBox[{"8", " ", 
                  SubscriptBox["r", "1"], " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubsuperscriptBox["symS", 
                RowBox[{"2", ",", "0"}], "2"]}], "+", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]]}], "-", 
                 RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                 RowBox[{"32", " ", 
                  SubscriptBox["r", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}]}], ")"}]}], "+", 
                 RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "-", 
           RowBox[{"8", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["e", "2", "2"], " ", 
        SubscriptBox["\[CapitalDelta]", "BW"], " ", 
        SubsuperscriptBox["symS", 
         RowBox[{"2", ",", "0"}], "2"], " ", 
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SubscriptBox["r", "1"], " ", 
            SubscriptBox["symB", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        RowBox[{"8", " ", 
         SubscriptBox["c", "g"], " ", 
         SubscriptBox["r", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubsuperscriptBox["e", "2", "2"], " ", 
            SubscriptBox["symD", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubsuperscriptBox["symS", 
             RowBox[{"2", ",", "0"}], "2"]}], "+", 
           RowBox[{
            SubscriptBox["e", "2"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["e", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", "BW"], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[CapitalDelta]", "BW"], "-", 
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["e", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        RowBox[{
         SubscriptBox["e", "2"], " ", 
         SubscriptBox["\[CapitalDelta]", "BW"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["r", "1"], " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", "0"}]]}], "+", 
                 RowBox[{"32", " ", "\[ImaginaryI]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]]}], "-", 
                 RowBox[{"8", " ", 
                  SubscriptBox["r", "1"], " ", 
                  SubscriptBox["symB", 
                   RowBox[{"3", ",", "0"}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
        RowBox[{
         SubsuperscriptBox["e", "2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["r", "1"], " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubsuperscriptBox["symS", 
                RowBox[{"2", ",", "0"}], "2"]}], "+", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]]}], "-", 
                 RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
                 RowBox[{"32", " ", 
                  SubscriptBox["r", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}]}], ")"}]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"8", " ", 
                    SubscriptBox["r", "1"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "-", 
           RowBox[{"8", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8631874721768813`*^9},
 CellLabel->
  "Out[203]=",ExpressionUUID->"24384e40-f81f-4cf2-b38f-3f494b085bf6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Look", " ", "at", " ", "numerator", " ", "of", " ", 
     "unbounded", " ", "terms", " ", "of", " ", 
     SubscriptBox["\[Lambda]", "3"], " ", "as", " ", 
     SubscriptBox["\[CapitalDelta]", "BW"]}], "->", 
    RowBox[{"0", " ", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"symLambda3", " ", "=", " ", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        SubscriptBox["\[Lambda]", "3"], "//.", 
        SubscriptBox["symLambdaBeta", "3"]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"symLambda3Re", "=", 
     RowBox[{
      RowBox[{"ComplexExpand", "[", "symLambda3", "]"}], "//.", 
      RowBox[{"\[ImaginaryI]", "->", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"3", ",", "R"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"4", "*", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], "2"], "/", 
       SubscriptBox["e", "2"]}], "*", 
      RowBox[{"Factor", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"symLambda3Re", "/", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["r", "1"], "*", 
             SubscriptBox["\[Mu]", "1"]}], ")"}]}], "]"}], ",", 
         RowBox[{"1", "/", 
          SubscriptBox["\[CapitalDelta]", "BW"]}]}], "]"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"symLambda3ReNoSing", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"symLambda3Re", "/", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["r", "1"], "*", 
           SubscriptBox["\[Mu]", "1"]}], ")"}]}], "]"}], "-", 
       RowBox[{
        SubscriptBox["sym\[CapitalLambda]", 
         RowBox[{"3", ",", "R"}]], "*", 
        RowBox[{
         SubscriptBox["e", "2"], "/", 
         RowBox[{"(", 
          RowBox[{"4", "*", 
           SuperscriptBox[
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "2"], "*", 
           SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}]}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"symLambda3Re", "-", 
     RowBox[{
      SubscriptBox["r", "1"], "*", 
      SubscriptBox["\[Mu]", "1"], "*", 
      RowBox[{"(", 
       RowBox[{"symLambda3ReNoSing", "+", " ", 
        RowBox[{
         SubscriptBox["e", "2"], "*", 
         RowBox[{
          SubscriptBox["sym\[CapitalLambda]", 
           RowBox[{"3", ",", "R"}]], "/", 
          RowBox[{"(", 
           RowBox[{"4", "*", 
            SuperscriptBox[
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]], "2"], "*", 
            SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}]}]}]}], ")"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8590468873517666`*^9, 3.8590469545386534`*^9}, {
   3.8590470800062037`*^9, 3.859047092851804*^9}, {3.859047234679181*^9, 
   3.8590472568065796`*^9}, {3.8590473015137615`*^9, 3.859047304623993*^9}, {
   3.8590481620766582`*^9, 3.859048195263093*^9}, {3.8607832549674115`*^9, 
   3.860783258559848*^9}, 3.860787352567342*^9, {3.860788493309493*^9, 
   3.8607885120179634`*^9}, {3.860788676155286*^9, 3.8607887083623896`*^9}, {
   3.860788746202053*^9, 3.860788750204376*^9}, {3.860788798790139*^9, 
   3.8607888241875763`*^9}, {3.8607888575315704`*^9, 3.860788952986537*^9}, {
   3.8607892103452506`*^9, 3.860789252947797*^9}, {3.86095532199759*^9, 
   3.860955353987505*^9}, {3.860955419857351*^9, 3.8609554217834077`*^9}, {
   3.8609556024099245`*^9, 3.8609556079886584`*^9}, {3.860955646448781*^9, 
   3.8609556546647835`*^9}, {3.8609558776693125`*^9, 3.86095588847946*^9}, {
   3.8609559764417515`*^9, 3.860955998067871*^9}, {3.860956052520312*^9, 
   3.860956102386488*^9}, {3.860956335638116*^9, 3.8609563424751616`*^9}, {
   3.860956470406161*^9, 3.8609565344885764`*^9}, {3.860956816461632*^9, 
   3.8609569083167067`*^9}, {3.860956965749525*^9, 3.860957079169606*^9}, {
   3.860957218369869*^9, 3.8609573184767094`*^9}, {3.8609573698111143`*^9, 
   3.860957397851842*^9}, {3.8609574525838118`*^9, 3.860957521599061*^9}, {
   3.860957572874256*^9, 3.8609575746441417`*^9}, {3.860957746837943*^9, 
   3.8609577601856985`*^9}, 3.8609635799340277`*^9, {3.8609636694721727`*^9, 
   3.860963694272385*^9}, {3.8631848284961605`*^9, 3.8631848284961605`*^9}, {
   3.8631863843354206`*^9, 3.8631864104177065`*^9}, {3.8631873076132574`*^9, 
   3.863187307644492*^9}},
 CellLabel->
  "In[204]:=",ExpressionUUID->"2e8debda-9594-4155-bccc-fed4716c8695"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SubscriptBox["symE", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]]}], "+", 
  RowBox[{
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["symB", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["symF", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      SubscriptBox["symB", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubscriptBox["c", "g"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["symD", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]]}], "+", 
     RowBox[{
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.8607884776017065`*^9, 3.8607885152032747`*^9, {3.860788679138712*^9, 
   3.8607887113307123`*^9}, 3.8607887506571693`*^9, 3.8607888245312138`*^9, {
   3.8607889112018614`*^9, 3.860788953861251*^9}, 3.8607892545252256`*^9, 
   3.8609544929778967`*^9, 3.860955354971627*^9, 3.8609554226890306`*^9, 
   3.8609556107151785`*^9, 3.86095565521454*^9, 3.8609558906170464`*^9, {
   3.8609559798180466`*^9, 3.8609559991530905`*^9}, {3.860956064591983*^9, 
   3.860956103730008*^9}, {3.860956338710434*^9, 3.860956343561551*^9}, {
   3.860956474086713*^9, 3.860956536036216*^9}, {3.8609568744110622`*^9, 
   3.860956909247655*^9}, {3.8609570071534553`*^9, 3.8609570807361803`*^9}, {
   3.86095726313247*^9, 3.860957319347689*^9}, 3.8609573993397865`*^9, 
   3.8609574634894085`*^9, 3.860957522395435*^9, 3.860957576036014*^9, 
   3.8609577611556945`*^9, 3.8609635822621803`*^9, 3.8609636742041736`*^9, 
   3.8609637235672398`*^9, 3.8610295315859075`*^9, 3.8611354835361576`*^9, {
   3.8631863772888737`*^9, 3.863186410909401*^9}, 3.863187472458041*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"1d09c6a5-05ca-4104-8b2d-c6a6d647f23d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8607884776017065`*^9, 3.8607885152032747`*^9, {3.860788679138712*^9, 
   3.8607887113307123`*^9}, 3.8607887506571693`*^9, 3.8607888245312138`*^9, {
   3.8607889112018614`*^9, 3.860788953861251*^9}, 3.8607892545252256`*^9, 
   3.8609544929778967`*^9, 3.860955354971627*^9, 3.8609554226890306`*^9, 
   3.8609556107151785`*^9, 3.86095565521454*^9, 3.8609558906170464`*^9, {
   3.8609559798180466`*^9, 3.8609559991530905`*^9}, {3.860956064591983*^9, 
   3.860956103730008*^9}, {3.860956338710434*^9, 3.860956343561551*^9}, {
   3.860956474086713*^9, 3.860956536036216*^9}, {3.8609568744110622`*^9, 
   3.860956909247655*^9}, {3.8609570071534553`*^9, 3.8609570807361803`*^9}, {
   3.86095726313247*^9, 3.860957319347689*^9}, 3.8609573993397865`*^9, 
   3.8609574634894085`*^9, 3.860957522395435*^9, 3.860957576036014*^9, 
   3.8609577611556945`*^9, 3.8609635822621803`*^9, 3.8609636742041736`*^9, 
   3.8609637235672398`*^9, 3.8610295315859075`*^9, 3.8611354835361576`*^9, {
   3.8631863772888737`*^9, 3.863186410909401*^9}, 3.8631874724736624`*^9},
 CellLabel->
  "Out[208]=",ExpressionUUID->"081969cb-960b-4582-9c72-e1e4c1048390"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"3", ",", "R"}]], "//.", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], "->", "0"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"3", ",", "R"}]], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", "0"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                   RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                  RowBox[{
                   SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["C", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", 
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["D", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symE", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["E", 
                  RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], "->", " ", 
                SubscriptBox["S", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["T", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symU", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["U", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], "->", " ", 
             SubscriptBox["S", 
              RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["T", 
             RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "g"], "->", 
       SubscriptBox["c", 
        SubscriptBox["g", 
         RowBox[{"1", ",", "1"}]]]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "0"], "->", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.863186869111689*^9, 3.863186967810505*^9}},
 CellLabel->
  "In[209]:=",ExpressionUUID->"1dd242da-acaa-4ef4-ab61-44cf481d7ac7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SubscriptBox["symE", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["symB", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["symF", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "+", 
  RowBox[{
   SubscriptBox["c", "g"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["symD", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.863186883503129*^9, 3.8631869201628914`*^9}, 
   3.8631869695994625`*^9, 3.8631874726610813`*^9},
 CellLabel->
  "Out[209]=",ExpressionUUID->"0a4db113-15e7-4a78-93df-328f8473fb07"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.863186883503129*^9, 3.8631869201628914`*^9}, 
   3.8631869695994625`*^9, 3.8631874726767235`*^9},
 CellLabel->
  "Out[210]=",ExpressionUUID->"b3f4913b-bf60-4d00-9f4d-ebe88bbf95d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["sym\[CapitalLambda]", 
    RowBox[{"3", ",", "R", ",", "v2"}]], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["sym\[CapitalLambda]", 
        RowBox[{"3", ",", "R"}]], "-", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["sym\[CapitalLambda]", 
          RowBox[{"3", ",", "R"}]], "//.", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "->", "0"}]}], ")"}]}], ")"}], "/", 
     SuperscriptBox[
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]], "2"]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8631864535434127`*^9, 3.8631864541950474`*^9}},
 CellLabel->
  "In[211]:=",ExpressionUUID->"754ada5d-0aa3-4e3d-8e50-be54162ac47e"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "g"], " ", 
     SubscriptBox["symA", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.863186455735824*^9, 3.8631869814081063`*^9, 
  3.8631874727548246`*^9},
 CellLabel->
  "Out[211]=",ExpressionUUID->"5fe4b642-0883-4620-9b1b-ba9993b4da3e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["c", "g"], "*", 
      SubscriptBox["A", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]]}], "-", 
     SubscriptBox["B", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     RowBox[{"2", "*", 
      SubscriptBox["T", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}]}], "//.", 
    RowBox[{
     SubscriptBox["c", "g"], "->", 
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.863186500526258*^9, 3.863186500958811*^9}},
 CellLabel->
  "In[212]:=",ExpressionUUID->"e028a244-067d-4110-b8fa-0da8de67a235"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8631865020516477`*^9, 3.863186983253704*^9, 
  3.8631874728329024`*^9},
 CellLabel->
  "Out[212]=",ExpressionUUID->"8398727d-8c5f-4400-9547-13ae0a9e6a50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"symLambda3Re", "-", 
                    RowBox[{
                    SubscriptBox["r", "1"], "*", 
                    SubscriptBox["\[Mu]", "1"], "*", 
                    RowBox[{"(", 
                    RowBox[{"symLambda3ReNoSing", "+", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "*", 
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"3", ",", "R", ",", "v2"}]], "/", 
                    RowBox[{"(", 
                    RowBox[{"4", "*", 
                    SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}]}]}]}], 
                    ")"}]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                   RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                  RowBox[{
                   SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["C", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symD", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["D", 
                  RowBox[{"3", ",", "0"}]]}]}], "//.", 
               RowBox[{
                SubscriptBox["symE", 
                 RowBox[{"3", ",", "0"}]], "->", " ", 
                SubscriptBox["E", 
                 RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["S", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symT", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["T", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symU", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", " ", 
             SubscriptBox["U", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["S", 
             RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]], "->", " ", 
           SubscriptBox["T", 
            RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
         RowBox[{
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", "*", 
              RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"16", "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
            ")"}]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "g"], "->", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "//.", 
    RowBox[{
     SubscriptBox["c", "0"], "->", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8631865194374633`*^9, 3.863186519860693*^9}, 
   3.8631873076757383`*^9},
 CellLabel->
  "In[213]:=",ExpressionUUID->"47e1cbbe-5f3f-4cc1-8d7d-87fb0f9fd32c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.863186522263948*^9, 3.8631870082731905`*^9, 
  3.8631874730047417`*^9},
 CellLabel->
  "Out[213]=",ExpressionUUID->"03743cf6-3f28-444f-b6d6-0e3c31f2dbe2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["sym\[CapitalLambda]", 
    RowBox[{"3", ",", "R", ",", "M"}]], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"3", ",", "R", ",", "v2"}]], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", " ", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "/", 
                    SubscriptBox["e", "2"]}]}], "]"}]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                   RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                  RowBox[{
                   SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["C", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", 
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["D", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symE", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["E", 
                  RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], "->", " ", 
                SubscriptBox["S", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["T", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symU", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["U", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], "->", " ", 
             SubscriptBox["S", 
              RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["T", 
             RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "g"], "->", 
       SubscriptBox["c", 
        SubscriptBox["g", 
         RowBox[{"1", ",", "1"}]]]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "0"], "->", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.861029608687709*^9, 3.861029651083848*^9}, {
  3.8631848106388245`*^9, 3.8631848286106815`*^9}, {3.8631867525036087`*^9, 
  3.863186780598277*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"fc77bfb1-2915-491d-ade8-0e29741bfbe1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"Sech", "[", "\[Alpha]", "]"}], "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "13"}], "-", 
      RowBox[{"128", " ", 
       SuperscriptBox["\[Alpha]", "2"]}], "+", 
      RowBox[{"8", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "9"}], "+", 
         RowBox[{"8", " ", 
          SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"6", " ", "\[Alpha]"}], "]"}]}], "-", 
      RowBox[{"5", " ", 
       RowBox[{"Cosh", "[", 
        RowBox[{"8", " ", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{"96", " ", "\[Alpha]", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{"16", " ", "\[Alpha]", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{"4", " ", "\[Alpha]", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"8", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"32", " ", 
    SqrtBox[
     RowBox[{"Tanh", "[", "\[Alpha]", "]"}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "\[Alpha]"}]}], ")"}], " ", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SuperscriptBox[
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "\[Alpha]"}]}], ")"}], " ", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SuperscriptBox[
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8610296528433237`*^9, 3.861135484962897*^9, 3.8631865357750497`*^9, {
   3.8631867567418203`*^9, 3.863186782577674*^9}, 3.8631870101636086`*^9, 
   3.8631874740044203`*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"d973f76c-091a-41b6-9685-63bccec46d3e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"3", ",", "R", ",", "M"}]], "+", 
                    RowBox[{"4", "*", 
                    SubscriptBox["e", "BW"]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                   RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                  RowBox[{
                   SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["C", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symD", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["D", 
                  RowBox[{"3", ",", "0"}]]}]}], "//.", 
               RowBox[{
                SubscriptBox["symE", 
                 RowBox[{"3", ",", "0"}]], "->", " ", 
                SubscriptBox["E", 
                 RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["S", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symT", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["T", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symU", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", " ", 
             SubscriptBox["U", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["S", 
             RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]], "->", " ", 
           SubscriptBox["T", 
            RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
         RowBox[{
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", "*", 
              RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"16", "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
            ")"}]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "g"], "->", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "//.", 
    RowBox[{
     SubscriptBox["c", "0"], "->", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.863186783832317*^9, 3.8631868404923596`*^9}},
 CellLabel->
  "In[215]:=",ExpressionUUID->"13242b5d-a6e5-450c-91bb-cfc6e8efe90c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8631868420082817`*^9, 3.8631870123049116`*^9, 
  3.8631874746916995`*^9},
 CellLabel->
  "Out[215]=",ExpressionUUID->"8e982ef7-ae1c-44a4-ba2d-3c6897d3e1b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Plot", "[", 
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"3", ",", "R", ",", "M"}]], ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "0", ",", "3.15"}], "}"}], ",", 
    RowBox[{"Ticks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0.5", ",", "1", ",", "1.5", ",", "2", ",", "2.5", ",", 
         "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "->", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "3.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", " ", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Thickness", "[", "0.01", "]"}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "->", 
     RowBox[{"Directive", "[", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"Arrowheads", "[", "0.035", "]"}], ",", 
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"Thickness", "[", "0.004", "]"}]}], "}"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.861029698255777*^9, 3.861029708608475*^9}},
 CellLabel->
  "In[216]:=",ExpressionUUID->"c35eb5e5-db9e-4a42-91eb-7a48a0777dae"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.01], Opacity[1.], 
      LineBox[CompressedData["
1:eJwBsQJO/SFib1JlAgAAACoAAAACAAAAARuRUKiB8j8AAAAAAAD4Px74LzEe
hfI/o+sCSGfd9z9K4OXHGYnyP+Fga3K4tfc/orBR9RCR8j+t7Pc4wmb3P1JR
KVD/oPI/4uGLR2/K9j+yktgF3MDyP16MUesNmPU/cBU3cZUA8z9XyDSxW0vz
P+wa9EcIgPM/WJ2Gk4wV7j/awn8UWYTzPxbXjWKwz+0/yGoL4amI8z8ZEBbe
EYrtP6W6InpLkfM/0DvXuoz/7D9eWlGsjqLzP1owR0Ja7es/0ZmuEBXF8z/R
c1mEF9TpP7YYadkhCvQ/u63ADkbM5T+AFt5qO5T0P38SNxTYs9w/RHvdGXiY
9D9PEQkaCUXcPwjg3Mi0nPQ/OTYuk5PW2z+PqdsmLqX0P+dRGlyz+to/njzZ
4iC29D8/bX3ME0fZP7xi1FoG2PQ/TVsI2wXw1T/4rspK0Rv1P7s8tzxpAM8/
b0e3Kmej9T87VrbNtDqsP5JneRJbp/U/fD4szm2SqT+0hzv6Tqv1P5tDwvoE
7KY/+se/yTaz9T/8w+avxqShP4RIyGgGw/U/8/PziJexjD+aSdmmpeL1Pw50
023m2pq/xEv7IuQh9j9ZXiDQqKi6vxpQPxthoPY/Q6kbYkUG0L9gSTeBqLL3
P+3W4msx8OC/YhreF76y+D9oAsKnSwbov8AgdEvMrfk/G5KUIZ4I7r+4F3r0
J776P0KMETKu2fG/bOYuzlG8+z8OJH6Uwir0v7ulUx3Jz/w/sj1OJ31i9r9m
mmcJOd79P5AGzzPiUPi/zWYqJnfa/j/9ffM6Ae/5v84jXbgC7P8/8k5BJtmE
+79GXJ89rnUAQJUwIooT3fy/UsGHbdfyAEA5CndsqRL+v6seKFinegFAu5/Y
VpdH/78fNcvoctIBQAAAAAAAAADAogFYNA==
       "]]},
     Annotation[#, "Charting`Private`Tag$98240#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[{
     GrayLevel[0], 
     Arrowheads[0.035], FontSize -> 18, 
     Thickness[0.004]}],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 3.25}, {-2., 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{{{0, 
      FormBox["0", TraditionalForm]}, {0.5, 
      FormBox["0.5`", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}, {1.5, 
      FormBox["1.5`", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}, {2.5, 
      FormBox["2.5`", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}}, {{-2, 
      FormBox[
       RowBox[{"-", "2"}], TraditionalForm]}, {-1, 
      FormBox[
       RowBox[{"-", "1"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{3.8610297092957716`*^9, 3.861135485216436*^9, 
  3.8631865420311317`*^9, 3.8631870210893497`*^9, 3.8631874748635197`*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"2e273f3d-b65a-4b84-b830-064ad8f67eaa"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", " ", "At", " ", "this", " ", "stage"}], ",", " ", 
    RowBox[{
     SubscriptBox["r", "1"], " ", "is", " ", "determined", " ", "by", " ", 
     "the", " ", "regular", " ", "curve", " ", 
     RowBox[{"condition", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["r", "1"], "=", "0"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8610295942735014`*^9, 3.8610295947149954`*^9}, {
  3.8610297184654884`*^9, 3.8610297257478914`*^9}, {3.8631870245929427`*^9, 
  3.863187033212315*^9}},
 CellLabel->
  "In[217]:=",ExpressionUUID->"498b767f-aff4-481a-984c-15fd805e48c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"symLambda3Im", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", "symLambda3"}], "]"}], "//.", 
       RowBox[{"\[ImaginaryI]", "->", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"symLambda3ImR2", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"symLambda3Im", ",", 
        SubscriptBox["r", "2"]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"3", ",", "I"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"symLambda3Im", "*", "32", " ", 
       SubscriptBox["e", "2"], "*", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], "2"], "/", 
        SubscriptBox["\[Mu]", "1"]}]}], "//.", 
      RowBox[{
       SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8609637066059475`*^9, 3.860963708670143*^9}, {
   3.860964345408181*^9, 3.860964372897381*^9}, 3.8609644591859846`*^9, {
   3.8609658334082313`*^9, 3.8609658483076916`*^9}, 3.8631848286106815`*^9, {
   3.8631870467126904`*^9, 3.863187054906621*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"463b38f1-0a68-4739-8673-450e904d8f45"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["\[CapitalDelta]", "BW", "2"]}], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{"16", " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["symC", 
        RowBox[{"3", ",", "0"}]]}], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], "-", 
     RowBox[{
      SubscriptBox["symG", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["symC", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
  RowBox[{
   SubsuperscriptBox["e", "2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SubscriptBox["symD", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]]}], "+", 
     RowBox[{
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.860964342075141*^9, 3.8609643738218613`*^9, {3.8609658358447666`*^9, 
   3.8609658487932696`*^9}, 3.861029541223606*^9, 3.861029730030158*^9, 
   3.8611354904063063`*^9, 3.863187056234314*^9, 3.8631871655842047`*^9, 
   3.8631874893194804`*^9},
 CellLabel->
  "Out[220]=",ExpressionUUID->"05ea54c5-e30a-4ed6-a3bb-c3467665bffc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", " ", "Final", " ", "expression", " ", "for", " ", 
     SubscriptBox["\[Lambda]", "3"], " ", "on", " ", "half"}], "-", 
    RowBox[{"loop", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["symLambda3", "v2"], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"\[ImaginaryI]", "*", "symLambda3Im"}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.859047052976327*^9, 3.859047280212088*^9, {3.8607897707452135`*^9, 
   3.8607898430502415`*^9}, {3.8631875231944838`*^9, 3.863187537397339*^9}},
 CellLabel->
  "In[224]:=",ExpressionUUID->"f57df061-aa19-4d52-9e01-c6e2dba4b9a8"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"32", " ", 
     SubscriptBox["e", "2"], " ", 
     SubsuperscriptBox["symT", 
      RowBox[{"2", ",", "0"}], "2"]}]], 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SubsuperscriptBox["e", "2", "2"], " ", 
       SubscriptBox["symD", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["e", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["e", "2"], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]]}], "-", 
            RowBox[{"8", " ", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["e", "2"], " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["symG", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          SubscriptBox["e", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"32", " ", 
             SubscriptBox["c", "g"], " ", 
             SubscriptBox["r", "2"]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["e", "2"]}], " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"16", " ", 
                SubscriptBox["symD", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
       SubsuperscriptBox["symT", 
        RowBox[{"2", ",", "0"}], "2"]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{3.863187064919403*^9, 3.8631874940878143`*^9, 
  3.863187538334349*^9},
 CellLabel->
  "Out[224]=",ExpressionUUID->"7e3c3cad-8639-4236-898f-be1341c41e10"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.859047459517758*^9, 3.8590474598303432`*^9}, 
   3.859391801428772*^9, 3.8593941349700704`*^9, {3.8607898703756514`*^9, 
   3.8607898767201138`*^9}, {3.8610295678276324`*^9, 
   3.8610295750692143`*^9}},ExpressionUUID->"fb4c5459-ded0-4bd6-858c-\
96ba82b952e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", " ", "Obtain", " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"+", 
        RowBox[{"/", 
         RowBox[{"-", "1"}]}]}]}]], " ", "on", " ", "half"}], "-", 
    RowBox[{"loop", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"symBeta1neg1", "=", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "//.", 
       SubscriptBox["symLambdaBeta", "3"]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"symBeta1pos1", "=", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "//.", 
       SubscriptBox["symLambdaBeta", "3"]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8590473142823734`*^9, 3.8590473566349306`*^9}, {
  3.8590473895071154`*^9, 3.859047428885427*^9}, {3.8631875096952953`*^9, 
  3.8631875207103667`*^9}},
 CellLabel->
  "In[225]:=",ExpressionUUID->"fadba8c0-49fd-4af7-a7c8-7cd9d7028ce3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SubscriptBox["symC", 
         RowBox[{"3", ",", "0"}]]}], "-", 
       RowBox[{
        SubscriptBox["symA", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
     SubsuperscriptBox["symT", 
      RowBox[{"2", ",", "0"}], "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["symT", 
      RowBox[{"2", ",", "0"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
              SubscriptBox["symD", 
               RowBox[{"3", ",", "0"}]]}], "+", 
             RowBox[{"32", " ", 
              SubscriptBox["symC", 
               RowBox[{"3", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"32", " ", 
              SubscriptBox["symG", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", "BW"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[CapitalDelta]", "BW"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]]}], "+", 
             RowBox[{"8", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["symC", 
               RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"8", " ", 
        SubscriptBox["\[CapitalDelta]", "BW"], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["e", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["symD", 
            RowBox[{"3", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubsuperscriptBox["symS", 
            RowBox[{"2", ",", "0"}], "2"]}], "+", 
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[CapitalDelta]", "BW"], " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["symD", 
               RowBox[{"3", ",", "0"}]]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["symE", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[CapitalDelta]", "BW"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubsuperscriptBox["symT", 
            RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"8", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubsuperscriptBox["symT", 
         RowBox[{"2", ",", "0"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.863187497602312*^9, 3.8631875415524607`*^9},
 CellLabel->
  "Out[225]=",ExpressionUUID->"01d0ea70-09a1-47c8-875b-6dac617b7ba2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["symC", 
         RowBox[{"3", ",", "0"}]]}], "+", 
       RowBox[{
        SubscriptBox["symA", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
     SubsuperscriptBox["symT", 
      RowBox[{"2", ",", "0"}], "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{
     SubscriptBox["e", "2"], " ", 
     SubscriptBox["symT", 
      RowBox[{"2", ",", "0"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
              SubscriptBox["symD", 
               RowBox[{"3", ",", "0"}]]}], "+", 
             RowBox[{"32", " ", 
              SubscriptBox["symC", 
               RowBox[{"3", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"32", " ", 
              SubscriptBox["symG", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", "BW"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[CapitalDelta]", "BW"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]]}], "-", 
             RowBox[{"8", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["symC", 
               RowBox[{"3", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{"8", " ", 
        SubscriptBox["\[CapitalDelta]", "BW"], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["e", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["symD", 
            RowBox[{"3", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubsuperscriptBox["symS", 
            RowBox[{"2", ",", "0"}], "2"]}], "+", 
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", 
              SubscriptBox["\[CapitalDelta]", "BW"], " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["symD", 
               RowBox[{"3", ",", "0"}]]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["symE", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}], "-", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[CapitalDelta]", "BW"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Mu]", "1"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubsuperscriptBox["symT", 
            RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "-", 
       RowBox[{"8", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubsuperscriptBox["symT", 
         RowBox[{"2", ",", "0"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.863187497602312*^9, 3.863187542636041*^9},
 CellLabel->
  "Out[226]=",ExpressionUUID->"6b443ee0-f73c-42bf-a12d-bfaf7fb02887"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Obtain", " ", "the", " ", "particular", " ", 
    RowBox[{"solution", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["partIHT", "3"], "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["IHT", "3"], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", "7", ",", "8", ",", "9"}], 
          "}"}]}], "]"}], "]"}], "/.", " ", 
      RowBox[{
       SubscriptBox["s", "j_"], "\[RuleDelayed]", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Omega]", "j"], "2"], "*", 
        RowBox[{
         SubscriptBox["C", "j"], "/", "j"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ", 
     "at", " ", "this", " ", 
     RowBox[{"order", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", "3"], " ", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"partsoln", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["IHT", "3"], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2", ",", "3", ",", "7", ",", "8", ",", "9"}], 
            "}"}]}], "]"}], "]"}], "/.", " ", 
        RowBox[{
         SubscriptBox["s", "j_"], "\[RuleDelayed]", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Omega]", "j"], "^", "2"}], "*", 
          RowBox[{
           SubscriptBox["C", "j"], "/", 
           RowBox[{"(", "j", ")"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3", ",", "7", ",", "8", ",", "9"}], 
          "}"}], "]"}], "]"}], ",", "3"}], "]"}], "]"}]}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "S", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.858599569926217*^9, {3.8587789619122953`*^9, 3.858778970685295*^9}, {
   3.8587790049021325`*^9, 3.8587790109348783`*^9}, {3.8587790879743567`*^9, 
   3.858779167187317*^9}, 3.858781811409088*^9},
 CellLabel->
  "In[227]:=",ExpressionUUID->"c0bb2204-127d-4281-8450-054e2c02c20a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "4"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"192", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"12", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "4"}], "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "4"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "+", 
            RowBox[{"12", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"48", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"8", "+", 
               RowBox[{"3", " ", 
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "4"}], "2"], " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"1536", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "4"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"78", " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "3"}]}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"61", "+", 
                  RowBox[{"156", " ", 
                   SubscriptBox["N", 
                    RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "4"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"12", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"24", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"28", " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{"7", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "3"}]}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"6", " ", 
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "3"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "-", 
               RowBox[{"3", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "3"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"32", "+", 
               RowBox[{"96", " ", 
                SubscriptBox["N", 
                 RowBox[{"3", ",", "3"}]]}], "+", 
               RowBox[{"3", " ", 
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "4"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"12", " ", 
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                  SubsuperscriptBox["Q", 
                   RowBox[{"1", ",", "1"}], "2"]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"6", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "4"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{"3", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "3"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "4"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"48", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"3", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "4"}], "2"]}]}]], 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"3", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "4"}], "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             RowBox[{"6", " ", 
              SubscriptBox["N", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["c", "0", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              SubscriptBox["h", 
               RowBox[{"2", ",", 
                RowBox[{"-", "3"}]}]]}], "+", 
             RowBox[{"16", " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"12", " ", 
                 SubscriptBox["N", 
                  RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
          RowBox[{"6", " ", 
           SubsuperscriptBox["c", "0", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]]}], "+", 
             RowBox[{"8", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"4", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SubscriptBox["c", "0"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["h", 
               RowBox[{"2", ",", 
                RowBox[{"-", "3"}]}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]]}], "+", 
             RowBox[{"8", " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             RowBox[{"9", " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{"24", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "4"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]], " ", 
                 SubscriptBox["Q", 
                  RowBox[{"1", ",", "1"}]]}], "+", 
                RowBox[{"4", " ", 
                 SubscriptBox["N", 
                  RowBox[{"2", ",", "2"}]], " ", 
                 SubscriptBox["Q", 
                  RowBox[{"1", ",", "1"}]], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}], "+", 
                RowBox[{"4", " ", 
                 SubscriptBox["Q", 
                  RowBox[{"2", ",", "2"}]], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}], "-", 
                RowBox[{"\[ImaginaryI]", " ", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]]}]}], ")"}]}], "-", 
             RowBox[{"8", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]]}], "-", 
             RowBox[{"6", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["\[Phi]", 
               RowBox[{"2", ",", 
                RowBox[{"-", "3"}]}]]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["c", "0", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}]}]], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{
                 SubsuperscriptBox["\[Omega]", 
                  RowBox[{"-", "4"}], "2"], " ", 
                 SubscriptBox["N", 
                  RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "4"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SubscriptBox["h", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", "3"}]}]]}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"3", " ", 
                    SubscriptBox["N", 
                    RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"20", " ", 
                 SubscriptBox["N", 
                  RowBox[{"2", ",", "2"}]], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}], "-", 
                RowBox[{
                 SubsuperscriptBox["Q", 
                  RowBox[{"1", ",", "1"}], "2"], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}], "+", 
                RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                 SubscriptBox["Q", 
                  RowBox[{"2", ",", "2"}]], " ", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]]}], "+", 
                RowBox[{"6", " ", "\[ImaginaryI]", " ", 
                 SubscriptBox["Q", 
                  RowBox[{"1", ",", "1"}]], " ", 
                 SubscriptBox["\[Phi]", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", "3"}]}]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"72", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"8", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "3"}], "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "3"}], "2"], " ", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["\[Mu]", "1"]}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "81"}], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"28", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"56", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"27", " ", "\[Alpha]"}], "+", 
                  RowBox[{"5", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{"24", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "3"}]}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"27", " ", "\[Alpha]"}], "+", 
                    RowBox[{"32", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
            RowBox[{"81", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"56", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"28", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"72", " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"144", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                  RowBox[{"9", " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "3"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]], "+", 
                  RowBox[{
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"28", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"144", " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"7", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"72", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"27", " ", "\[Alpha]"}], "+", 
                  RowBox[{"4", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"12", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{"3", " ", "\[ImaginaryI]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"5", "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                  RowBox[{"6", " ", "\[Alpha]", " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{"72", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"7", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"72", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"27", " ", "\[Alpha]"}], "+", 
                  RowBox[{"96", " ", 
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"13", "+", 
                    RowBox[{"24", " ", "\[Alpha]", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "3"}], "2"], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}]}], ")"}]}], "-", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "3"}]}]]}]}], ")"}]}], "-", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]]}]}], ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"24", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SubsuperscriptBox["c", "0", "3"]}], "-", 
            RowBox[{
             SubscriptBox["c", "0"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "3"}], "2"]}]}], ")"}]}]], 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", "\[Alpha]"}], "+", 
              RowBox[{"32", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", 
                RowBox[{"-", "3"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{"5", "+", 
                 RowBox[{"8", " ", "\[Alpha]", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{"9", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "3"}], "2"], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"36", " ", 
            SubsuperscriptBox["c", "0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", "2"}]}]], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
           "+", 
           RowBox[{"18", " ", 
            SubsuperscriptBox["c", "0", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "-", 
              RowBox[{"4", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "2"}]}]], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "3"}]}]]}]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"8", " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                 RowBox[{"9", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"48", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"12", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 RowBox[{"15", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "-", 
                 RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "-", 
                 RowBox[{"18", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "-", 
                 RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}]}], ")"}]}], "-", 
              RowBox[{"9", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
           "-", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["c", "0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                 RowBox[{"33", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"9", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"72", " ", "\[Alpha]", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"16", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"24", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}], "-", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  RowBox[{"(", 
                   RowBox[{"9", "+", 
                    RowBox[{"8", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}], "2"], " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
                 RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Lambda]", "1"], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"11", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "3"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
                 RowBox[{"16", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 RowBox[{"8", " ", 
                  SubscriptBox["\[Lambda]", "1"], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                 RowBox[{"16", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"48", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"12", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["c", "0", "3"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             RowBox[{"(", 
              RowBox[{"4", "+", 
               RowBox[{"\[Alpha]", " ", 
                SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[Alpha]"}], "+", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]]}], "+", 
            RowBox[{"42", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "3"}]}]]}], "+", 
            RowBox[{"18", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"48", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{"21", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"6", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", "\[Alpha]"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"96", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"7", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"96", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"84", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["N", 
              RowBox[{"3", ",", "3"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "-", 
            RowBox[{"6", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]"}], "+", 
                  RowBox[{"3", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]"}], "+", 
                  RowBox[{"3", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
            RowBox[{"18", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"3", " ", 
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "3"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]], "-", 
               RowBox[{"4", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "-", 
            RowBox[{"8", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "-", 
            RowBox[{"8", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "3"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"32", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]]}], "-", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"4", " ", "\[Alpha]", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"4", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["c", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "+", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"32", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"48", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"8", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"8", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"24", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "3"}]}]]}], "+", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{
                SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["\[Alpha]", "2"]}], "+", 
                  RowBox[{"3", " ", "\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                  SubsuperscriptBox["Q", 
                   RowBox[{"1", ",", "1"}], "2"]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["N", 
              RowBox[{"3", ",", "3"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "-", 
            RowBox[{"3", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubsuperscriptBox["Q", 
              RowBox[{"1", ",", "1"}], "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"12", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["c", "2"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"6", " ", 
             SubscriptBox["\[Lambda]", "2"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]]}], "+", 
            RowBox[{"6", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", 
                 RowBox[{"-", "2"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                  RowBox[{
                   SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{"18", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "3"}]}]]}], "+", 
            RowBox[{"6", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "2"}]}]]}], "-", 
            RowBox[{"6", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", 
              RowBox[{"-", "2"}], "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"48", " ", 
           SubsuperscriptBox["c", "0", "3"]}], "-", 
          RowBox[{"12", " ", 
           SubscriptBox["c", "0"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}]], 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["\[Alpha]", "2"]}], "+", 
                 RowBox[{"3", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["\[Omega]", 
                RowBox[{"-", "2"}], "2"], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"6", " ", 
            SubsuperscriptBox["c", "0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "3"}]}]]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"3", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["N", 
                RowBox[{"3", ",", "3"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"6", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}], "+", 
                 RowBox[{"12", " ", 
                  SubscriptBox["N", 
                   RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"3", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"6", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SubsuperscriptBox["c", "0", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["c", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"8", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "-", 
              RowBox[{"16", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"8", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["c", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
              "-", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", 
                RowBox[{"-", "2"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"8", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "0"}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", "\[Alpha]", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
                ")"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "0"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]]}], "+", 
                 RowBox[{"5", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"3", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"3", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"24", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"3", ",", "3"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}], "-", 
                 RowBox[{"6", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                 RowBox[{
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{"6", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"3", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}]}], ")"}]}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            SubsuperscriptBox["c", "0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{"4", "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}], ")"}]}]}], ")"}], " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]]}], "+", 
              RowBox[{"3", " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"8", " ", "\[Alpha]"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"12", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                 RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}], "2"], " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", 
                   RowBox[{"-", "2"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"6", " ", 
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                    RowBox[{"6", " ", 
                    SubscriptBox["h", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"3", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]], "+", 
                    RowBox[{"12", " ", 
                    SubscriptBox["N", 
                    RowBox[{"3", ",", "3"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"6", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
                 RowBox[{"6", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubsuperscriptBox["Q", 
                    RowBox[{"1", ",", "1"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "-", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
                    RowBox[{"8", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Lambda]", "2"], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "-", 
                    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "2"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Lambda]", "1"], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "2"}]}]]}], "-", 
                    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "3"}]}]]}], "+", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"48", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"12", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "2", "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SubsuperscriptBox["c", "0", "3"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"48", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]]}], "+", 
            RowBox[{"18", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", "1"}]]}], "+", 
            RowBox[{"42", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", "3"}]]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"2", " ", 
                SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"7", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"96", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"84", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["N", 
              RowBox[{"3", ",", "3"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"21", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"96", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"6", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "\[Alpha]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "\[Alpha]"}], "+", 
                  SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{"6", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]"}], "+", 
                  RowBox[{"3", " ", 
                   SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", "2"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]"}], "+", 
                  RowBox[{"3", " ", 
                   SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{"18", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "3"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]], "-", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"3", " ", 
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]]}], "+", 
            RowBox[{"8", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", "3"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"32", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"32", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"48", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "+", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "2"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"4", " ", "\[Alpha]", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"4", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"24", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["c", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["h", 
                   RowBox[{"2", ",", "2"}]], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "1"}]], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"16", " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", "1"}]]}], "+", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "2"}]]}], "+", 
            RowBox[{"12", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "2"}]]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
             SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "2"}]]}], "+", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{"24", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", "3"}]]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", 
               RowBox[{"24", " ", 
                SubscriptBox["N", 
                 RowBox[{"3", ",", "3"}]]}], "-", 
               RowBox[{"3", " ", 
                SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                SubsuperscriptBox["Q", 
                 RowBox[{"1", ",", "1"}], "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["\[Alpha]", "2"]}], "+", 
                  RowBox[{"3", " ", "\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{
                   SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                    SubsuperscriptBox["Q", 
                    RowBox[{"1", ",", "1"}], "2"]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"2", ",", "1"}]]}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
                   SubscriptBox["c", "2"], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Lambda]", "2"], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                   SubscriptBox["Q", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "1"}]]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Lambda]", "1"], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                  RowBox[{"3", " ", "\[ImaginaryI]", " ", 
                   SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"48", " ", 
           SubsuperscriptBox["c", "0", "3"]}], "-", 
          RowBox[{"12", " ", 
           SubscriptBox["c", "0"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}]], 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"6", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["N", 
                RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"6", " ", 
            SubsuperscriptBox["c", "0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "1"}]]}], "-", 
              RowBox[{"6", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "3"}]]}], "-", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1"}]}]], "-", 
              RowBox[{"12", " ", 
               SubscriptBox["N", 
                RowBox[{"3", ",", "3"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"3", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "1"}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SubsuperscriptBox["c", "0", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]], "-", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["c", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"4", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "1"}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "-", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "1"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "3"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{"6", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"8", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"8", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"48", " ", 
               SubscriptBox["Q", 
                RowBox[{"3", ",", "3"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "-", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"10", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["\[Alpha]", "2"], " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["Q", 
                RowBox[{"3", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"4", " ", 
               SubscriptBox["c", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "1"}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "2"}]], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", "1"}]]}], "+", 
              RowBox[{"6", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Alpha]", "2"], " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"4", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{"12", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "3"}]]}]}], ")"}]}], "-", 
           RowBox[{
            SubsuperscriptBox["c", "0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", "2"}]]}], "-", 
                 RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], "-", 
                 RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"12", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"6", " ", 
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "1"}]]}], "+", 
                    RowBox[{"6", " ", 
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "3"}]]}], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{"12", " ", 
                    SubscriptBox["N", 
                    RowBox[{"3", ",", "3"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"3", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"6", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
                 RowBox[{"6", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["Q", 
                    RowBox[{"1", ",", "1"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "-", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
                    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Lambda]", "2"], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "-", 
                    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Lambda]", "1"], " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "2"}]]}], "-", 
                    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "1"}]], "+", 
                    RowBox[{"3", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"72", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"8", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "3", "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"28", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             SubscriptBox["h", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"1", ",", "1"}]], " ", 
             RowBox[{"(", 
              RowBox[{"81", "+", 
               RowBox[{"56", " ", 
                SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"27", " ", "\[Alpha]"}], "+", 
                  RowBox[{"5", " ", 
                   SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{"24", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}], " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", "3"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"27", " ", "\[Alpha]"}], "+", 
                    RowBox[{"32", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
                  RowBox[{"27", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
            RowBox[{"81", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"56", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"7", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"72", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"27", " ", "\[Alpha]"}], "+", 
                  RowBox[{"96", " ", 
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"13", "+", 
                    RowBox[{"24", " ", "\[Alpha]", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"16", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], " ", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", "2"}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubscriptBox["\[Lambda]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", 
                   SubscriptBox["h", 
                    RowBox[{"2", ",", "3"}]]}], "+", 
                  RowBox[{"9", " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
               RowBox[{"8", " ", 
                SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]], "+", 
                  RowBox[{
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"28", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"28", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"7", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"8", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Alpha]", " ", 
                   SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]], " ", 
                   SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                  RowBox[{"2", " ", 
                   SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                  RowBox[{"6", " ", "\[Alpha]", " ", 
                   SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                  RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                   SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"72", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["h", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]]}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"\[ImaginaryI]", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"12", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"9", " ", "\[Alpha]", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"5", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"24", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SubsuperscriptBox["c", "0", "3"]}], "-", 
            RowBox[{
             SubscriptBox["c", "0"], " ", 
             SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}]], 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"9", " ", "\[Alpha]"}], "+", 
              RowBox[{"32", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"5", "+", 
                 RowBox[{"8", " ", "\[Alpha]", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"9", " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "3", "2"], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"36", " ", 
            SubsuperscriptBox["c", "0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "2"}]], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "1"}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["c", "0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "1"}]], " ", 
               RowBox[{"(", 
                RowBox[{"9", "+", 
                 RowBox[{"8", " ", 
                  SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"9", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]]}], "+", 
                 RowBox[{"8", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}], " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", "3"}]]}], "+", 
                 RowBox[{"33", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"9", " ", "\[Alpha]", " ", 
                  SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"72", " ", "\[Alpha]", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"16", " ", 
                  SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "-", 
                 RowBox[{"24", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"11", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"2", ",", "2"}]], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
                 RowBox[{"16", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "1"}]]}], "-", 
                 RowBox[{"16", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", "2"}]]}], "+", 
                 RowBox[{
                  SubscriptBox["\[Lambda]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "-", 
                    RowBox[{"8", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{"18", " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["c", "0", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "2"}]], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}], "+", 
           RowBox[{
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"8", " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", "3"}]]}], "+", 
                 RowBox[{"9", " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"72", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["h", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"36", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"36", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"9", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SubscriptBox["h", 
                    RowBox[{"1", ",", "2"}]], " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]]}], "+", 
                    RowBox[{"3", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"1", ",", "1"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"6", " ", "\[Alpha]", " ", 
                    SubscriptBox["Q", 
                    RowBox[{"2", ",", "2"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], "+", 
                    RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"1", ",", "2"}]]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[Phi]", 
                    RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"9", " ", "\[Alpha]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"16", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"5", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "2"}]]}], "+", 
                 RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"192", " ", 
          SubsuperscriptBox["c", "0", "3"]}], "-", 
         RowBox[{"12", " ", 
          SubscriptBox["c", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "4", "2"]}]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "+", 
            RowBox[{"12", " ", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "-", 
         RowBox[{
          SubsuperscriptBox["c", "0", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"48", " ", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]], " ", 
             RowBox[{"(", 
              RowBox[{"8", "+", 
               RowBox[{"3", " ", 
                SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"1536", " ", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"78", " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", "3"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"61", "+", 
                  RowBox[{"156", " ", 
                   SubscriptBox["N", 
                    RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"6", " ", 
          SubsuperscriptBox["c", "0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"12", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"24", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"28", " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"7", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SubscriptBox["h", 
                 RowBox[{"2", ",", "3"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "2"}]], " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]]}], "+", 
               RowBox[{"4", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"6", " ", 
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "3"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "+", 
               RowBox[{"4", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["N", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{"3", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["c", "0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"32", "+", 
               RowBox[{"96", " ", 
                SubscriptBox["N", 
                 RowBox[{"3", ",", "3"}]]}], "+", 
               RowBox[{"3", " ", 
                SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"12", " ", 
                   SubscriptBox["N", 
                    RowBox[{"2", ",", "2"}]]}], "+", 
                  SubsuperscriptBox["Q", 
                   RowBox[{"1", ",", "1"}], "2"]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"6", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "2"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}], "+", 
               RowBox[{"3", " ", 
                SubscriptBox["Q", 
                 RowBox[{"1", ",", "1"}]], " ", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          RowBox[{"48", " ", 
           SubsuperscriptBox["c", "0", "3"]}], "-", 
          RowBox[{"3", " ", 
           SubscriptBox["c", "0"], " ", 
           SubsuperscriptBox["\[Omega]", "4", "2"]}]}]], 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              RowBox[{"3", " ", 
               SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{"6", " ", 
               SubscriptBox["N", 
                RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"3", " ", 
            SubsuperscriptBox["c", "0", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "3"}]]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"12", " ", 
                  SubscriptBox["N", 
                   RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "-", 
           RowBox[{"6", " ", 
            SubsuperscriptBox["c", "0", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "3"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]]}], "+", 
              RowBox[{"9", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"24", " ", 
               SubscriptBox["Q", 
                RowBox[{"3", ",", "3"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["h", 
                   RowBox[{"1", ",", "2"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "+", 
                 RowBox[{"\[ImaginaryI]", " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "2"}]]}]}], ")"}]}], "+", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"6", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "3"}]]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["c", "0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Omega]", "4", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SubscriptBox["h", 
                   RowBox[{"2", ",", "3"}]]}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"3", " ", 
                    SubscriptBox["N", 
                    RowBox[{"3", ",", "3"}]]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"20", " ", 
                  SubscriptBox["N", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "-", 
                 RowBox[{
                  SubsuperscriptBox["Q", 
                   RowBox[{"1", ",", "1"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], "-", 
                 RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"2", ",", "2"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"1", ",", "2"}]]}], "-", 
                 RowBox[{"6", " ", "\[ImaginaryI]", " ", 
                  SubscriptBox["Q", 
                   RowBox[{"1", ",", "1"}]], " ", 
                  SubscriptBox["\[Phi]", 
                   RowBox[{"2", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.858779225098077*^9, 3.8588725901404424`*^9, 
  3.8588906428244405`*^9, 3.8589489562319636`*^9, 3.858968998018518*^9, 
  3.858981789443115*^9, 3.859048243890629*^9, 3.859394182961543*^9, 
  3.8610298245744953`*^9, 3.8611355213948264`*^9, 3.8631875730534163`*^9},
 CellLabel->
  "Out[228]=",ExpressionUUID->"5e3bb989-60a4-4945-a505-c149ce02df56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            SuperscriptBox[
             SubscriptBox["c", "0"], "2"]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["s", 
           RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["C", 
             RowBox[{"-", "1"}]]}], "*", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"3", ",", "0"}]], "\[Rule]", " ", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["IHT", 
               RowBox[{"3", ",", "0"}]], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], "*", 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
            SubscriptBox["c", 
             SubscriptBox["g", 
              RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
         " ", 
         RowBox[{
          SubscriptBox["C", "0"], "\[Rule]", " ", "1"}]}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "0"}]], " ", "\[Rule]", " ", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]], "\[Rule]", " ", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]], "\[Rule]", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"3", ",", "1"}]], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "/", 
            SuperscriptBox[
             SubscriptBox["c", "0"], "2"]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
          RowBox[{
           SubscriptBox["C", "1"], "*", 
           SuperscriptBox[
            SubscriptBox["c", "0"], "2"]}]}]}], "]"}]}]}], 
     "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.858779283521202*^9, 3.8587793449590263`*^9}, {
  3.858779377489646*^9, 3.8587793775364704`*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"29f733e9-612b-43d1-bf8b-0324ffb63467"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SubsuperscriptBox["c", "0", "3"]}]], 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SuperscriptBox["\[Alpha]", "3"], " ", 
         SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"48", " ", "\[Alpha]", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"12", " ", "\[Alpha]", " ", 
         SubsuperscriptBox["c", "0", "6"], " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}]]}], "-", 
           SubscriptBox["h", 
            RowBox[{"1", ",", "0"}]], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", "\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{"48", " ", 
         SubscriptBox["N", 
          RowBox[{"2", ",", "2"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{"3", " ", 
         SubsuperscriptBox["c", "0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Alpha]", "2"], " ", 
            SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[Alpha]", "2"], " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", "\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]]}], "+", 
              RowBox[{"12", " ", "\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"3", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", "\[Alpha]", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"8", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", "\[Alpha]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SubscriptBox["h", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"8", " ", 
               SubscriptBox["r", "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
        RowBox[{
         SubsuperscriptBox["c", "0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["\[Alpha]", "3"], " ", 
            SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"24", " ", "\[Alpha]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
           RowBox[{"24", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"2", ",", 
                RowBox[{"-", "2"}]}]], "+", 
              SubscriptBox["h", 
               RowBox[{"2", ",", "0"}]], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", "1"}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"3", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]]}], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"8", " ", "\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"16", " ", "\[Alpha]", " ", 
               SubscriptBox["r", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"24", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"6", " ", 
         SubsuperscriptBox["c", "0", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"4", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"8", " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "0"}]], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "-", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["c", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "2"}]}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"24", " ", 
         SubscriptBox["c", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "0"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["h", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["h", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{"4", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "2"}]]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Lambda]", "3"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", "\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "+", 
           RowBox[{"\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Lambda]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["c", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]], "-", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}], "-", 
           RowBox[{"4", " ", 
            SubscriptBox["Q", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"3", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "2"}]}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "0"}]]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"2", ",", 
              RowBox[{"-", "2"}]}]]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8593942262898874`*^9, 3.861029837232153*^9, 
  3.8611355226214437`*^9, 3.863187574584197*^9},
 CellLabel->
  "Out[230]=",ExpressionUUID->"22d1ccd3-ca4d-42b0-bb03-f4818a30d252"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"3", ",", "0"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["c", "0", "5"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["h", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], "-", 
          SubscriptBox["h", 
           RowBox[{"1", ",", "1"}]], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]], "-", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], "-", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["c", "0", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["h", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["h", 
            RowBox[{"2", ",", "1"}]]}], "+", 
          RowBox[{"16", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], "+", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "2"}]]}], ")"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{"3", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             SubscriptBox["h", 
              RowBox[{"1", ",", "1"}]], "-", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"2", ",", "0"}]], "+", 
          SubscriptBox["\[Phi]", 
           RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["c", "0", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"2", ",", "0"}]], "+", 
          SubscriptBox["\[Phi]", 
           RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["c", "0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["h", 
            RowBox[{"1", ",", 
             RowBox[{"-", "2"}]}]], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["h", 
            RowBox[{"1", ",", "2"}]], " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]], " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]]}], "+", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]], "+", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Lambda]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}]]}], "+", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], ")"}]}], "-", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "2"}]}]], "+", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "2"}]], "+", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"2", " ", 
                    SubscriptBox["r", "2"]}]}], ")"}], " ", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"0", ",", "0"}]]}], "+", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"2", ",", "0"}]], "+", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"2", ",", "0"}]]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
       "-", 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "1"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["c", "2"], "-", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "0"}]]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["h", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]], "-", 
                SubscriptBox["h", 
                 RowBox[{"1", ",", "1"}]], "+", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]], "-", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
             RowBox[{"4", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"1", ",", "1"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]], "+", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["\[Lambda]", "3"], " ", 
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "0"}]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"4", " ", 
                 SubscriptBox["N", 
                  RowBox[{"2", ",", "2"}]]}], "-", 
                SubsuperscriptBox["Q", 
                 RowBox[{"1", ",", "1"}], "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "1"}]}]], "+", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["\[Lambda]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "0"}]], "+", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "0"}]]}], ")"}]}], "-", 
             RowBox[{"8", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "2"}]}]], "-", 
                SubscriptBox["\[Phi]", 
                 RowBox[{"1", ",", "2"}]]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "-", 
             SubscriptBox["\[Phi]", 
              RowBox[{"2", ",", "1"}]]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8593942262898874`*^9, 3.861029837232153*^9, 
  3.8611355226214437`*^9, 3.863187579773273*^9},
 CellLabel->
  "Out[231]=",ExpressionUUID->"dc34d50c-2448-4131-baf7-6a25672b423a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"3", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SubsuperscriptBox["c", "0", "3"]}]], 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SuperscriptBox["\[Alpha]", "3"], " ", 
         SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], "+", 
        RowBox[{"48", " ", 
         SubscriptBox["N", 
          RowBox[{"2", ",", "2"}]], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"48", " ", "\[Alpha]", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{"12", " ", "\[Alpha]", " ", 
         SubsuperscriptBox["c", "0", "6"], " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["h", 
            RowBox[{"1", ",", "0"}]], "+", 
           SubscriptBox["h", 
            RowBox[{"1", ",", "2"}]], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", "\[Alpha]", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{"3", " ", 
         SubsuperscriptBox["c", "0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Alpha]", "2"], " ", 
            SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["\[Alpha]", "2"], " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", "\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"12", " ", "\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "1"}]]}], "+", 
              RowBox[{"3", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"8", " ", "\[Alpha]", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"8", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", "\[Alpha]", " ", 
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SubscriptBox["h", 
             RowBox[{"2", ",", "1"}]]}], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "1"}]], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["r", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SubsuperscriptBox["c", "0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["\[Alpha]", "3"], " ", 
            SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "-", 
           RowBox[{"24", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"2", ",", "0"}]], "+", 
              SubscriptBox["h", 
               RowBox[{"2", ",", "2"}]], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["h", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]], "+", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", 
                   RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"24", " ", "\[Alpha]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
           RowBox[{"3", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"12", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"12", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"8", " ", "\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"2", ",", "1"}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"24", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"16", " ", "\[Alpha]", " ", 
               SubscriptBox["r", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"8", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"6", " ", 
         SubsuperscriptBox["c", "0", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["h", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "1"}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "0"}]], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["c", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Lambda]", "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{"24", " ", 
         SubscriptBox["c", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Lambda]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["c", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]], "+", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "1"}]]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"0", ",", "0"}]], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "0"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{"\[Alpha]", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"3", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", "2"}]]}], "+", 
              RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"1", ",", "1"}]]}], "+", 
              RowBox[{
               SubscriptBox["h", 
                RowBox[{"1", ",", "1"}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["h", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "3"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["Q", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{
               SubscriptBox["Q", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "1"}]]}], "-", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["N", 
                RowBox[{"2", ",", "2"}]], " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[Phi]", 
                RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8593942262898874`*^9, 3.861029837232153*^9, 
  3.8611355226214437`*^9, 3.8631875813040338`*^9},
 CellLabel->
  "Out[232]=",ExpressionUUID->"55544680-03cf-4a0c-a57a-793a7c260a3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["w", "3"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h", 
          RowBox[{"3", ",", "j"}]], ",", 
         SubscriptBox["\[Phi]", 
          RowBox[{"3", ",", "j"}]]}], "}"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", "*", "j", "*", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
         "]"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox["\[ImaginaryI]", 
        SubscriptBox["c", "0"]]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       FractionBox[
        RowBox[{"-", "\[ImaginaryI]"}], 
        SubscriptBox["c", "0"]]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "0"}]], "*", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}]}]}]], "Input",
 CellChangeTimes->{
  3.858599356470751*^9, {3.858779542153138*^9, 3.8587795889265003`*^9}},
 CellLabel->
  "In[233]:=",ExpressionUUID->"b2efdf9a-8f2b-4444-8d76-b81015cd6dff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["h", 
     RowBox[{"3", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "4"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]]}], 
     SubscriptBox["c", "0"]], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"3", ",", "0"}]], "-", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"3", ",", "1"}]]}], 
     SubscriptBox["c", "0"]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "4"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587796013536763`*^9, 3.858872616860155*^9, 
  3.8588906492146077`*^9, 3.858948962593992*^9, 3.8589690046406755`*^9, 
  3.858981799196072*^9, 3.8590482850444*^9, 3.8593942839303055`*^9, 
  3.861029842750447*^9, 3.8611355279458976`*^9, 3.863187581413373*^9},
 CellLabel->
  "Out[233]=",ExpressionUUID->"ac654c97-5338-464e-8bb3-554d45ad0060"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"VI", ".", " ", "Fourth"}], "-", 
   RowBox[{"Order", " ", "Problem"}]}], "Section"]], "Input",
 CellChangeTimes->{
  3.8587796236352444`*^9, {3.858779654947727*^9, 
   3.858779670891314*^9}},ExpressionUUID->"18ab3049-6067-466a-ad14-\
df6818079cd1"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Define", " ", "operator", " ", 
    SubscriptBox["L", "4"], " ", "for", " ", "numerical", " ", 
    RowBox[{"computations", "."}]}], " ", "**)"}], "\n", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumL", "4"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_", ",", "q3_", ",", "\[Eta]4_", ",", "q4_"}], 
      "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "4"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[ImaginaryI]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    SubscriptBox["r", "3"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "6"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["r", "2"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
                "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], ")"}], 
                    " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
                "+", 
                RowBox[{"\[Kappa]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "6"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SubscriptBox["c", "0"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]4", ",", "x"}], "]"}]}], "-", 
                   RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "6"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], ")"}], 
                    " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                    "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], ")"}], 
                    " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q3", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q4", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
                ")"}], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["C", "\[Kappa]"], " ", 
                 SubscriptBox["c", "4"]}], "+", 
                RowBox[{
                 SubscriptBox["c", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                  ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["c", "0"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "24"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "4"]}], 
                   "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}], "2"], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "3"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]3"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]4"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["s", "\[Kappa]"], " ", 
                 SubscriptBox["r", "3"], 
                 SubscriptBox["\[Mu]", "1"]}], "+", 
                RowBox[{
                 SubscriptBox["C", "\[Kappa]"], " ", 
                 SubscriptBox["r", "2"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}]}], 
                  ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["\[Mu]", "1"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    FractionBox["1", "6"], " ", 
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "3"]}], 
                   "+", 
                   RowBox[{
                    SubscriptBox["s", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["C", "\[Kappa]"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                  ")"}]}]}], ")"}], "*", 
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FractionBox["1", "24"], " ", 
                   SubscriptBox["s", "\[Kappa]"], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "4"]}], 
                  "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SubscriptBox["C", "\[Kappa]"], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SubscriptBox["s", "\[Kappa]"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}], "2"], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["C", "\[Kappa]"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "3"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]3"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]4"}]}], ")"}]}]}], 
                 ")"}]}], ")"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}],
            ",", "kmod"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubsuperscriptBox["c", "0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{"2", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"]}], "+", 
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", 
                SubscriptBox["c", "0"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}], "2"], "-", 
                  RowBox[{"2", " ", 
                   SubscriptBox["c", "0"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["c", "0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "6"}], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]4", ",", "x"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["c", "0"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"q1", ",", "x"}], "]"}], "2"], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["c", "0"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"q1", ",", "x"}], "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["c", "0"], " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["c", "0"]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "3"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
               RowBox[{
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["c", "2"]}], "+", 
                  RowBox[{"D", "[", 
                   RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["c", "4"], "+", 
             RowBox[{
              SubscriptBox["c", "0"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}], "4"], "-", 
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]2", ",", "x"}], "]"}], "2"], "-", 
                RowBox[{"2", " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]3", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}], "*", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"D", "[", 
              RowBox[{"q4", ",", "x"}], "]"}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}]}], 
        "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Define", " ", "operator", " ", 
     SubscriptBox["R", "4"], " ", "for", " ", "numerical", " ", 
     RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["NumR", "4"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_", ",", "q3_", ",", "\[Eta]4_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "4"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox["1", "24"], " ", 
                SubscriptBox["C", "\[Kappa]"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "4"]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                SubscriptBox["s", "\[Kappa]"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Alpha]", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                SubscriptBox["C", "\[Kappa]"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]2"}]}], ")"}], "2"], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]1"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Alpha]", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"\[Kappa]", " ", "\[Eta]3"}]}], ")"}]}]}], 
                 ")"}]}], "+", 
               RowBox[{
                SubscriptBox["s", "\[Kappa]"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Alpha]", " ", 
                   SubscriptBox["r", "3"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]3"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Eta]4"}]}], ")"}]}]}], ")"}], 
             "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", 
              RowBox[{"kmod", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
               RowBox[{"kmod", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["c", "0"]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]4", ",", "x"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"], "-", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}], " ", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{"D", "[", 
                RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8585990078696313`*^9, {3.858781242112686*^9, 3.858781443853568*^9}, {
   3.858781503142877*^9, 3.8587815269470215`*^9}, {3.858781584394802*^9, 
   3.858781625044874*^9}, {3.858781673410035*^9, 3.858781760754591*^9}, {
   3.859389412633589*^9, 3.8593894137132053`*^9}, {3.8593918016630507`*^9, 
   3.859391802116065*^9}, {3.859394369774459*^9, 3.8593943699462757`*^9}},
 CellLabel->
  "In[234]:=",ExpressionUUID->"ff8888b9-f4ae-490e-9ba7-e01e557d6831"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["IHT", "4"], " ", "=", " ", "\[IndentingNewLine]", 
   RowBox[{"NCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], "*", 
       SubscriptBox["w", "3"]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], "*", 
       SubscriptBox["w", "2"]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], "*", 
       SubscriptBox["w", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "4"], "*", 
       SubscriptBox["w", "0"]}], "+", 
      RowBox[{
       SubscriptBox["NumInvR", "0"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SubscriptBox["NumL", "1"], "[", 
           RowBox[{
            SubscriptBox["w", "3"], ",", 
            RowBox[{"GenModulate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
             "]"}], ",", 
            RowBox[{"Cos", "[", "x", "]"}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}]}], "]"}]}], "-", 
         RowBox[{
          SubscriptBox["NumL", "2"], "[", 
          RowBox[{
           SubscriptBox["w", "2"], ",", 
           RowBox[{"GenModulate", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
            "]"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], "*", "x"}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}]}]}], "]"}], "-", 
         RowBox[{
          SubscriptBox["NumL", "3"], "[", 
          RowBox[{
           SubscriptBox["w", "1"], ",", 
           RowBox[{"GenModulate", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
            "]"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], "*", "x"}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"3", ",", "3"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"3", "*", "x"}], "]"}]}]}]}], "]"}], "-", 
         RowBox[{
          SubscriptBox["NumL", "4"], "[", 
          RowBox[{
           SubscriptBox["w", "0"], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]], "*", "x"}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"3", ",", "3"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", "*", "x"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"3", "*", "x"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"2", "*", 
             SubscriptBox["N", 
              RowBox[{"4", ",", "2"}]], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["N", 
              RowBox[{"4", ",", "4"}]], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"4", "*", "x"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"4", ",", "0"}]], "*", "x"}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "2"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}], "+", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"4", ",", "4"}]], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"4", "*", "x"}], "]"}]}]}]}], "]"}], "+", 
         RowBox[{
          SubscriptBox["NumR", "1"], "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["\[Lambda]", "1"], "*", 
             SubscriptBox["w", "2"]}], "+", 
            RowBox[{
             SubscriptBox["\[Lambda]", "2"], "*", 
             SubscriptBox["w", "1"]}], "+", 
            RowBox[{
             SubscriptBox["\[Lambda]", "3"], "*", 
             SubscriptBox["w", "0"]}]}], ",", 
           RowBox[{"GenModulate", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
            "]"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}]}], "]"}], "+", 
         RowBox[{
          SubscriptBox["NumR", "2"], "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             SubscriptBox["\[Lambda]", "1"], "*", 
             SubscriptBox["w", "1"]}], "+", 
            RowBox[{
             SubscriptBox["\[Lambda]", "2"], "*", 
             SubscriptBox["w", "0"]}]}], ",", 
           RowBox[{"GenModulate", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
            "]"}], ",", 
           RowBox[{"Cos", "[", "x", "]"}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["Q", 
             RowBox[{"1", ",", "1"}]], "*", 
            RowBox[{"Sin", "[", "x", "]"}]}], ",", 
           RowBox[{"2", "*", 
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", "*", "x"}], "]"}]}]}], "]"}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          RowBox[{
           SubscriptBox["NumR", "3"], "[", 
           RowBox[{
            SubscriptBox["w", "0"], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"Cos", "[", "x", "]"}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["Q", 
              RowBox[{"1", ",", "1"}]], "*", 
             RowBox[{"Sin", "[", "x", "]"}]}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", "*", "x"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]], "*", "x"}], "+", 
             RowBox[{"2", "*", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]], "*", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", "*", "x"}], "]"}]}]}], ",", 
            RowBox[{"2", "*", 
             SubscriptBox["N", 
              RowBox[{"3", ",", "3"}]], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"3", "*", "x"}], "]"}]}]}], "]"}]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "4"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"GenModulate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "4"}], "]"}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587879791149597`*^9, 3.8587879827075777`*^9}, {
   3.8587880195318565`*^9, 3.858788136818125*^9}, {3.8587881827910366`*^9, 
   3.8587881985767756`*^9}, {3.8587882485956593`*^9, 3.858788309506963*^9}, {
   3.858788343560254*^9, 3.858788362030325*^9}, {3.8587883996309147`*^9, 
   3.8587884230822353`*^9}, {3.8587884809278603`*^9, 3.858788524210135*^9}, 
   3.863187578726735*^9},
 CellLabel->
  "In[236]:=",ExpressionUUID->"e8579ab6-3e54-44b2-a43f-7c79293dbc19"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"625", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", 
          RowBox[{"-", "5"}]], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"48", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "5"}]]}]]}], "+", 
      RowBox[{
       FractionBox["125", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "4"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "+", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "-", 
      RowBox[{
       FractionBox["125", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "-", 
      RowBox[{"5", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "-", 
      RowBox[{"10", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"15", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["3125", "384"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"625", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"384", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "-", 
      FractionBox[
       RowBox[{"125", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"625", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "+", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubsuperscriptBox["N", 
         RowBox[{"2", ",", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "+", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "-", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "+", 
      FractionBox[
       RowBox[{"625", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"48", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "-", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "-", 
      RowBox[{
       FractionBox["125", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"50", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "+", 
      FractionBox[
       RowBox[{"75", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "-", 
      RowBox[{"20", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"125", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "24"], "+", 
      FractionBox[
       RowBox[{"25", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "5"}]]], "-", 
      RowBox[{"10", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"75", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "5"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "5"}]]}]], "-", 
      RowBox[{"15", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"10", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "4"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"32", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      FractionBox[
       RowBox[{"7", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["16", "3"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      FractionBox[
       RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "+", 
      RowBox[{"32", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "4"}]]}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "3"], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["7", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "4"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "4"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "4"}]]], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"81", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", 
          RowBox[{"-", "3"}]], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"16", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "3"}]]}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["27", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "4"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{
       FractionBox["81", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["81", "32"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"32", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"15", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["27", "16"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"7", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"81", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"27", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["9", "16"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["81", "128"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"128", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"81", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["N", 
         RowBox[{"2", ",", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{
       FractionBox["27", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"18", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"15", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"27", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"15", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"27", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "+", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "3"}]]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "3"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "3"}]]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "3"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"12", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "3"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "2"}]]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]], "6"], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "2"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "2"}]]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", 
          RowBox[{"-", "1"}]], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"16", " ", 
         SubscriptBox["C", 
          RowBox[{"-", "1"}]]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"48", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "64"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"64", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{
       FractionBox["1", "24"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "4"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"24", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["N", 
         RowBox[{"2", ",", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "16"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "96"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"96", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"12", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]], "24"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", 
         RowBox[{"-", "1"}]]}]], "+", 
      RowBox[{
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", 
         RowBox[{"-", "1"}]], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", 
        RowBox[{"-", "1"}]]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "0"]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "0"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "0"]}]], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "0"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "0"}]]}], 
       SubscriptBox["C", "0"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "1"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "2"}]}]]}], 
        RowBox[{"48", " ", 
         SubscriptBox["C", "1"]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "96"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"96", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"12", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "16"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "64"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"64", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "3"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "24"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "4"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"24", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["N", 
         RowBox[{"2", ",", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], "24"], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], 
       SubscriptBox["C", "1"]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "+", 
      RowBox[{
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "1"]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["C", "1"]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "2"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "2"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], 
        RowBox[{"3", " ", 
         SubscriptBox["C", "2"]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"12", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "3"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "3"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "3"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"6", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "6"], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "2"]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]], "2"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       SuperscriptBox["\[Alpha]", "3"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "2"]}]], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "1"}]], "-", 
      RowBox[{"2", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "2"}]]}], 
       SubscriptBox["C", "2"]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"27", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "3"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", "0"}]]}], 
        RowBox[{"16", " ", 
         SubscriptBox["C", "3"]}]]}], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"81", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{
       FractionBox["27", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "4"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["81", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "0"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["81", "128"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"128", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"81", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["N", 
         RowBox[{"2", ",", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["27", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"18", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["9", "16"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["81", "32"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"32", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"15", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["9", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["27", "16"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"7", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"16", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"81", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"27", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["9", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"15", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"27", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{
       FractionBox["27", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "3"]}]], "+", 
      FractionBox[
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "+", 
      FractionBox[
       RowBox[{"9", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["9", "8"], " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"15", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"27", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"5", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      FractionBox[
       RowBox[{"27", " ", 
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"\[Alpha]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubscriptBox["s", "3"], " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "3"]}]], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"3", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "3"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "3"]], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "4"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", "1"}]]}], 
        RowBox[{"3", " ", 
         SubscriptBox["C", "4"]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "4"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"32", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "4"]}]], "+", 
      FractionBox[
       RowBox[{"7", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{
       FractionBox["16", "3"], " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "4"]}]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "4"]}]], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "4"]}]], "-", 
      FractionBox[
       RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "4"]}]], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"3", " ", 
        SubscriptBox["C", "4"]}]], "-", 
      RowBox[{"32", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "4"]}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      FractionBox[
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "+", 
      RowBox[{"12", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], "3"], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["7", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       SubscriptBox["C", "4"]], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"4", " ", "\[Alpha]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["s", "4"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "4"}]]}], 
       SubscriptBox["C", "4"]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"625", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["c", "0"], " ", 
         SubscriptBox["s", "5"], " ", 
         SubscriptBox["h", 
          RowBox[{"1", ",", "2"}]]}], 
        RowBox[{"48", " ", 
         SubscriptBox["C", "5"]}]]}], "-", 
      RowBox[{
       FractionBox["125", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "4"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "5"]}]], "-", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "5"]], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], 
       SubscriptBox["C", "5"]], "+", 
      RowBox[{
       FractionBox["125", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "5"]}]], "+", 
      RowBox[{"5", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["C", "5"]], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], 
       SubscriptBox["C", "5"]], "+", 
      RowBox[{"10", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"15", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["3125", "384"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"625", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"384", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "5"]}]], "+", 
      FractionBox[
       RowBox[{"125", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{"625", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "5"]}]], "-", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubsuperscriptBox["N", 
         RowBox[{"2", ",", "2"}], "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "5"]}]], "-", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["C", "5"]}]], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["c", "0"], " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "5"]], "+", 
      FractionBox[
       RowBox[{"625", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"48", " ", 
        SubscriptBox["C", "5"]}]], "+", 
      RowBox[{
       FractionBox["125", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "5"]], "+", 
      RowBox[{
       FractionBox["125", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"50", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["C", "5"]], "+", 
      FractionBox[
       RowBox[{"75", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["C", "5"]}]], "+", 
      RowBox[{"20", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"125", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], "24"], "-", 
      FractionBox[
       RowBox[{"25", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], 
       SubscriptBox["C", "5"]], "-", 
      RowBox[{"10", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"75", " ", 
        SubscriptBox["s", "5"], " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], 
       RowBox[{"8", " ", 
        SubscriptBox["C", "5"]}]], "-", 
      RowBox[{"15", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"10", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "16"], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "2"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "16"], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "4"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"8", " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "8"], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "4"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"8", " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "2"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["r", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"3", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "2"]}], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "16"], "-", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       RowBox[{"4", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"6", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "16"], "+", 
      RowBox[{"3", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["N", 
        RowBox[{"2", ",", "2"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"], " ", 
       SubscriptBox["N", 
        RowBox[{"4", ",", "4"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubsuperscriptBox["Q", 
        RowBox[{"1", ",", "1"}], "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       RowBox[{"2", " ", 
        SubscriptBox["c", "0"]}]], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "4"}]], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], 
       SubscriptBox["c", "0"]], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["N", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"3", ",", "3"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "0"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.863187583647035*^9},
 CellLabel->
  "Out[236]=",ExpressionUUID->"66db9e8b-853d-4c06-96c1-5db3c32458a8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}]}]], "=", 
     RowBox[{
      SubscriptBox["IHT", "4"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"4", ",", "0"}]], "=", 
     RowBox[{
      SubscriptBox["IHT", "4"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "6"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"4", ",", "1"}]], " ", "=", 
     RowBox[{
      SubscriptBox["IHT", "4"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "7"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.858788741147794*^9, 3.8587887481175337`*^9}, {
  3.8587887935920305`*^9, 3.858788830349961*^9}, {3.8587888625802917`*^9, 
  3.8587888660349956`*^9}},
 CellLabel->
  "In[237]:=",ExpressionUUID->"2bbdfddd-bc4d-4902-89f3-bccdf2ba6a5c"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "First", " ", "solvability", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Expand", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "//.", " ", 
                    RowBox[{
                    SubscriptBox["s", 
                    RowBox[{"-", "1"}]], " ", "\[Rule]", " ", 
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["C", 
                    RowBox[{"-", "1"}]]}], "*", 
                    SuperscriptBox[
                    SubscriptBox["c", "0"], "2"]}]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "3"], "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "0"}]]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                   " ", 
                   SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                  SubscriptBox["partsoln", 
                   RowBox[{"2", ",", "0"}]]}], "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", "1"}]]}], "//.", 
                RowBox[{
                 SubscriptBox["partsoln", "1"], "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
              SubscriptBox["partsoln", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "1"}]]}], "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", 
           RowBox[{"-", "1"}]], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{
  3.8587888768339815`*^9, {3.8587889985782447`*^9, 3.8587890044076376`*^9}, {
   3.8587890516796117`*^9, 3.8587890866551623`*^9}, {3.8587891225060325`*^9, 
   3.858789161304323*^9}, {3.85878920757788*^9, 3.8587892143615255`*^9}, {
   3.858789752753776*^9, 3.858789754518832*^9}},
 CellLabel->
  "In[240]:=",ExpressionUUID->"6e009eb7-462f-4bbb-87be-f72242ed57c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond4neg1\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond4neg1\[Beta]", 
      RowBox[{"2", ",", "0"}]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "0"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond4neg1\[Beta]", 
      RowBox[{"2", ",", "1"}]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond4neg1\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["T", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["V", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], "/", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond4neg1\[Beta]", 
      RowBox[{"2", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], "*", 
      SubscriptBox["S", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["cond4neg1\[Beta]", 
      RowBox[{"2", ",", "1"}]], "-", 
     RowBox[{"\[ImaginaryI]", "*", 
      SubscriptBox["U", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond4neg1No\[Beta]", 
      RowBox[{"2", ",", "dot"}]], "=", 
     RowBox[{"Expand", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", 
         RowBox[{"-", "1"}]}]], "/.", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "j_"}]], ":>", " ", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond4neg1No\[Beta]", 
        RowBox[{"2", ",", "dot"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["A", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["C", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["D", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "0"}]]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond4neg1No\[Beta]", 
        RowBox[{"2", ",", "dot"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "0"}]]], " ", "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["E", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SubscriptBox["\[Lambda]", "2"]}], "+", 
       RowBox[{
        SubscriptBox["F", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}], "+", 
       RowBox[{
        SubscriptBox["G", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond4neg1No\[Beta]", 
      RowBox[{"1", ",", "2", ",", "dot"}]], "=", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}]], "/.", 
        RowBox[{
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", "j_"}]], ":>", " ", "0"}]}], " ", "/.", " ", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "j_"}]], ":>", " ", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"1", ",", "2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond4neg1No\[Beta]", 
        RowBox[{"1", ",", "2", ",", "dot"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox[
           SubscriptBox["cond4neg1No\[Beta]", 
            RowBox[{"1", ",", "2", ",", "dot"}]], 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]], "/.", 
          RowBox[{
           SubscriptBox["\[Mu]", "j_"], ":>", "0"}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "4"], "->", " ", "0"}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           SubscriptBox[
            SubscriptBox["cond4neg1No\[Beta]", 
             RowBox[{"1", ",", "2", ",", "dot"}]], 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]], ",", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "//.", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "->", "0"}]}], ")"}], "/", 
       "\[ImaginaryI]"}], " ", "//.", 
      RowBox[{
       SubscriptBox["r", "2"], "->", "0"}]}], " ", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["H", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         SubscriptBox[
          SubscriptBox["cond4neg1No\[Beta]", 
           RowBox[{"1", ",", "2", ",", "dot"}]], 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]], ",", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["I", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox[
         SubscriptBox["cond4neg1No\[Beta]", 
          RowBox[{"1", ",", "2", ",", "dot"}]], 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]], ",", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "4"]}], "]"}], "/", "\[ImaginaryI]"}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["J", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox[
           SubscriptBox["cond4neg1No\[Beta]", 
            RowBox[{"1", ",", "2", ",", "dot"}]], 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}]]], "/", "\[ImaginaryI]"}], "/.", 
         RowBox[{
          SubscriptBox["\[Mu]", "j_"], ":>", "0"}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "4"], "->", " ", "0"}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], "//.", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8587896513353252`*^9, 3.858789653553544*^9}, {
  3.858789790002925*^9, 3.858789839177236*^9}, {3.8631876194997964`*^9, 
  3.8631877662858343`*^9}},
 CellLabel->
  "In[279]:=",ExpressionUUID->"b21e0732-17ff-40e3-bc20-3b2700e0bf3f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.8631877669574966`*^9},
 CellLabel->
  "Out[279]=",ExpressionUUID->"88c6f6b5-05b8-4a49-ad7f-511a7d07c4a3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187766973115*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"7d2d26f2-3f81-490f-80bd-5377ba5654a2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.8631877669887342`*^9},
 CellLabel->
  "Out[281]=",ExpressionUUID->"900c0c92-9747-47ef-aad8-7ae6e975303c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187767098075*^9},
 CellLabel->
  "Out[285]=",ExpressionUUID->"7a5747a9-a2f8-4996-9bdf-4aadc6ff50b7"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187767113694*^9},
 CellLabel->
  "Out[287]=",ExpressionUUID->"ee5ed5c2-4ce7-4ea7-acfd-a3fc788dcb83"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.8631877671293435`*^9},
 CellLabel->
  "Out[288]=",ExpressionUUID->"634658c9-1ac5-4a20-95a1-579a9d465823"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187767176177*^9},
 CellLabel->
  "Out[291]=",ExpressionUUID->"b53994ea-475e-4ffa-9083-a90550a5266a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187767191795*^9},
 CellLabel->
  "Out[293]=",ExpressionUUID->"4cc053a3-8ea8-4c06-ad6e-15228962625a"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"8", " ", 
    SubsuperscriptBox["c", "0", "12"]}], "+", 
   RowBox[{"7", " ", 
    SubsuperscriptBox["c", "0", "2"], " ", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "2"]}], "+", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["c", "0", "6"], " ", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "2"]}], "-", 
   RowBox[{"13", " ", 
    SubsuperscriptBox["c", "0", "10"], " ", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "2"]}], "+", 
   SubsuperscriptBox["\[Omega]", 
    RowBox[{"-", "2"}], "4"], "+", 
   RowBox[{
    SubsuperscriptBox["c", "0", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "16"}], "+", 
      RowBox[{"5", " ", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "-", 
   RowBox[{
    SubsuperscriptBox["c", "0", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"8", "+", 
      RowBox[{"7", " ", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
   RowBox[{"32", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["c", "0", "3"], " ", 
    SubsuperscriptBox["\[Omega]", 
     RowBox[{"-", "2"}], "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}]}], 
  RowBox[{
   SubsuperscriptBox["c", "0", "4"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SubsuperscriptBox["c", "0", "2"]}], "+", 
      SubsuperscriptBox["\[Omega]", 
       RowBox[{"-", "2"}], "2"]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187767319439*^9},
 CellLabel->
  "Out[296]=",ExpressionUUID->"d8927886-d42c-4d2e-b95b-6aa5cc4b7f36"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SubsuperscriptBox["c", "0", "2"]}], "-", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], "3"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"128", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "22"]}], "-", 
    RowBox[{"10", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "6"]}], "+", 
    RowBox[{"3", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", "\[Alpha]"}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "20"], " ", 
     RowBox[{"(", 
      RowBox[{"64", "+", 
       RowBox[{"39", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "18"], " ", 
     RowBox[{"(", 
      RowBox[{"128", "+", 
       RowBox[{"640", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "+", 
       RowBox[{"456", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "-", 
       RowBox[{"81", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"360", "-", 
       RowBox[{"1128", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "-", 
       RowBox[{"594", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "17"}], "+", 
          RowBox[{"107", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"552", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"45", "+", 
          RowBox[{"64", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "-", 
       RowBox[{"38", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "6"]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "32"}], " ", 
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], "-", 
       RowBox[{"276", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "31"}], "+", 
          RowBox[{"61", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{"64", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "6"]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"704", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "+", 
       RowBox[{"456", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"21", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"24", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{"102", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "6"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1152", " ", "\[Alpha]"}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{"19", "+", 
          RowBox[{"92", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{"546", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{"5", " ", 
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"21", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "6"]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"228", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "-", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"61", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "6"]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "16"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"896", " ", "\[Alpha]"}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"300", "+", 
          RowBox[{"48", " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "54"}], "+", 
             RowBox[{"53", " ", "\[Alpha]", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "-", 
    RowBox[{"1024", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "17"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
    RowBox[{"192", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"16", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", "\[Alpha]"}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
    RowBox[{"192", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"256", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"3", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"16", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", "\[Alpha]"}], "+", 
       RowBox[{"48", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "-", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "6"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"16", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "64"}], "+", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "6"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "2"]}], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187769428139*^9},
 CellLabel->
  "Out[297]=",ExpressionUUID->"87e06be0-2727-415e-8827-edc376e14abf"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SubsuperscriptBox["c", "0", "8"]}], ")"}]}], 
   SubsuperscriptBox["c", "0", "4"]]}]], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.863187769521885*^9},
 CellLabel->
  "Out[298]=",ExpressionUUID->"9a26c67e-b03d-43d6-bba2-6eee388d6138"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "4"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "4"], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "+", 
   RowBox[{"3", " ", "\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "6"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[Alpha]", "2"], "-", 
      SuperscriptBox["\[Alpha]", "4"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "+", 
      SuperscriptBox["\[Alpha]", "3"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "10"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "12"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "14"]}]}], 
  RowBox[{"12", " ", 
   SubsuperscriptBox["c", "0", "7"]}]]], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.8631877697093005`*^9},
 CellLabel->
  "Out[299]=",ExpressionUUID->"70053848-beda-4854-b243-3ed4ba728d97"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"9", " ", 
       SubsuperscriptBox["c", "0", "2"]}], "-", 
      SubsuperscriptBox["\[Omega]", 
       RowBox[{"-", "3"}], "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubsuperscriptBox["c", "0", "2"]}], "+", 
       SubsuperscriptBox["\[Omega]", 
        RowBox[{"-", "2"}], "2"]}], ")"}], "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "3"}], "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"]}], "-", 
    RowBox[{"1728", " ", 
     SubsuperscriptBox["c", "0", "18"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "16"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"36", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"147", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "-", 
          RowBox[{"560", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"24", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "441"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}], "+", 
          RowBox[{"5088", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"64", " ", 
           RowBox[{"(", 
            RowBox[{"3", "-", 
             RowBox[{"196", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"72", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"416", "+", 
          RowBox[{"64", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "105"}], "+", 
             RowBox[{"16", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"153", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}], "-", 
          RowBox[{"1984", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"32", " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"784", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"318", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"7", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"15", "+", 
             RowBox[{"224", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "3"}], "2"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{"2304", " ", 
     SubsuperscriptBox["c", "0", "17"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2304", " ", 
        SubsuperscriptBox["c", "2", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "416"}], "-", 
          RowBox[{"6688", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"4608", " ", 
           SubsuperscriptBox["N", 
            RowBox[{"2", ",", "2"}], "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"1161", "-", 
             RowBox[{"784", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"4608", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"36", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "368"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"89", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "49"}], "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{"64", " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["Q", 
              RowBox[{"2", ",", "0"}], "2"], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "9"}], " ", 
        RowBox[{"(", 
         RowBox[{"608", "+", 
          RowBox[{"57", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}], "-", 
          RowBox[{"288", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "32"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"345", "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubsuperscriptBox["c", "2", "2"]}], "+", 
             RowBox[{"97", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"8", " ", 
              SubscriptBox["c", "2"], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]]}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "0"}], "2"]}], "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        SubsuperscriptBox["c", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"128", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1616"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"467", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"428", "+", 
             RowBox[{"576", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{"64", " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["Q", 
              RowBox[{"2", ",", "0"}], "2"], "+", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "480"}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "103"}], "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"29", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["Q", 
                 RowBox[{"2", ",", "0"}], "2"], "-", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["Q", 
                  RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"51", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "-", 
          RowBox[{"288", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubsuperscriptBox["c", "2", "2"]}], "+", 
             RowBox[{"35", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"8", " ", 
              SubscriptBox["c", "2"], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]]}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "0"}], "2"]}], "-", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"72", "+", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["c", "2", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "-", 
          RowBox[{"32", " ", 
           SubsuperscriptBox["N", 
            RowBox[{"2", ",", "2"}], "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "103"}], "+", 
             RowBox[{"36", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["c", "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "-", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["Q", 
                 RowBox[{"2", ",", "0"}], "2"], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["Q", 
                  RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"32", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"]}], "+", 
          RowBox[{"117", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "-", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]]}], ")"}]}], "-", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"13", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "0"}]]}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{"32", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"8", " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "10"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{"9", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"8", "-", 
             RowBox[{"2", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"288", " ", 
        SubscriptBox["c", "4"]}], "+", 
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "216"}], "+", 
          RowBox[{"26", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"90", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
       RowBox[{"216", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"26", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"90", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"576", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"160", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"9", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"832", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"288", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"288", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"288", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"16", " ", 
        SubscriptBox["c", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "54"}], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "12"}], "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"24", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"108", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"10", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"41", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"576", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"416", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"36", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"576", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"63", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}], "-", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["c", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "96"}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"], " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{"63", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "4"]}]}], ")"}]}], "+", 
       RowBox[{"288", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"24", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"189", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"3168", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"256", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"576", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"104", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"14", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}], "+", 
       RowBox[{"36", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["c", "4"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"]}], "+", 
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"180", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "3"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "32"}], "+", 
             RowBox[{"21", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "4"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"180", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"21", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"160", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"720", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"80", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"64", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"72", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"36", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "3"}], "2"], " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.858789654225026*^9, 3.8587897585526943`*^9, {3.858789797615451*^9, 
   3.8587898395363293`*^9}, 3.8587900303323402`*^9, 3.8588898099653864`*^9, 
   3.8588906738090563`*^9, 3.858948996241564*^9, 3.8589690364185247`*^9, 
   3.858981818023794*^9, 3.8590483167247524`*^9, 3.8593946311185336`*^9, 
   3.8610298668203406`*^9, 3.861135530176305*^9, {3.8631876025600815`*^9, 
   3.863187641843498*^9}, 3.863187679492508*^9, 3.8631877716618185`*^9},
 CellLabel->
  "Out[300]=",ExpressionUUID->"17a845f9-a993-425d-b092-f840db4baf22"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox[
     SubscriptBox["cond4neg1No\[Beta]", 
      RowBox[{"1", ",", "2", ",", "dot"}]], 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "4"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["r", "3"], 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "3"], "*", 
          SubscriptBox["I", 
           RowBox[{"4", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["H", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["G", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}], ",", "0", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], "*", 
       SubscriptBox["E", 
        RowBox[{"4", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["J", 
        RowBox[{"4", ",", 
         RowBox[{"-", "1"}], ",", "0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["\[ImaginaryI]", 
        SubscriptBox["c", "0"]], 
       SuperscriptBox[
        SubscriptBox["\[Lambda]", "2"], "2"]}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8587975216121993`*^9, 3.8587975493177967`*^9}, {
   3.858797797898609*^9, 3.8587979342068844`*^9}, {3.8587985022710857`*^9, 
   3.8587985220682335`*^9}, {3.858798555348119*^9, 3.8587985689722047`*^9}, {
   3.8588008627412076`*^9, 3.8588008699472723`*^9}, {3.858891708062292*^9, 
   3.858891726554063*^9}, {3.858892274935051*^9, 3.8588922848103476`*^9}, {
   3.858893108033148*^9, 3.8588931409139357`*^9}, {3.8588932233715067`*^9, 
   3.858893229517374*^9}, {3.858893378052501*^9, 3.858893382893248*^9}, {
   3.858894435174572*^9, 3.8588944410002623`*^9}, 3.8593918021941633`*^9, 
   3.859394369993186*^9},
 CellLabel->
  "In[301]:=",ExpressionUUID->"74541849-78d7-452b-91c5-badd3c34928a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.858797527831547*^9, 3.858797549614549*^9}, {
   3.8587979278649817`*^9, 3.8587979394420776`*^9}, 3.8587985252547503`*^9, 
   3.8587985710652485`*^9, 3.8588008724152255`*^9, 3.8588917469512873`*^9, 
   3.858892287076002*^9, 3.858893234179799*^9, 3.858893383257856*^9, 
   3.8588944431173463`*^9, 3.85894905813297*^9, 3.858969068387653*^9, 
   3.858981945093108*^9, 3.8590483714600925`*^9, 3.8593950128517685`*^9, 
   3.8610299300341535`*^9, {3.8611355586449575`*^9, 3.861135565869026*^9}, 
   3.8631877946320324`*^9},
 CellLabel->
  "Out[301]=",ExpressionUUID->"444bc3e9-e5bf-40e2-92c1-42ed9a43fc18"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"1", ",", "2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond4neg1No\[Beta]", 
        RowBox[{"1", ",", "2", ",", "dot"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["A", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox[
             SubscriptBox["cond4neg1No\[Beta]", 
              RowBox[{"1", ",", "2", ",", "dot"}]], 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]], "/", "\[ImaginaryI]"}], "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
          " ", 
          RowBox[{
           RowBox[{
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], ",", 
         SubscriptBox["\[Mu]", "1"]}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox[
           SubscriptBox["cond4neg1No\[Beta]", 
            RowBox[{"1", ",", "2", ",", "dot"}]], 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]], "//.", 
          RowBox[{
           SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
         " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], ",", 
       SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["D", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox[
        SubscriptBox["cond4neg1No\[Beta]", 
         RowBox[{"1", ",", "2", ",", "dot"}]], 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "3"]}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8587988410896864`*^9, 3.8587988580967484`*^9}, 
   3.858798889341343*^9, {3.8589819466863675`*^9, 3.858981953625042*^9}, {
   3.863187829461703*^9, 3.8631878374037256`*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"b2ca4bf6-6660-4ea1-8aa0-cb3cea557e9e"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "2"}], "+", 
   RowBox[{"\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "+", 
   SubsuperscriptBox["c", "0", "4"], "-", 
   RowBox[{"\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "6"]}]}], 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"]}]]], "Output",
 CellChangeTimes->{3.863187837903564*^9},
 CellLabel->
  "Out[303]=",ExpressionUUID->"3beff666-7df8-484d-9c9d-5a018c24789c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"64", " ", 
     SubsuperscriptBox["c", "0", "8"]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"]}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "\[Alpha]", " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"]}], "-", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "9"}], "-", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Alpha]"}], "+", 
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{"15", "-", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"10", " ", "\[Alpha]"}], "+", 
          RowBox[{"23", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{"44", "-", 
       RowBox[{"16", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"19", " ", "\[Alpha]"}], "+", 
          RowBox[{"48", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"48", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "-", 
          RowBox[{"56", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", "\[Alpha]"}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"4", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"40", " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "29"}], "+", 
          RowBox[{"100", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "2"]}], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"20", "+", 
          RowBox[{"3", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"20", "+", 
          RowBox[{"3", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"6", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]"}], "-", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "\[Alpha]"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Alpha]"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "\[Alpha]"}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "6"}], " ", "\[Alpha]"}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"12", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8631878383565426`*^9},
 CellLabel->
  "Out[304]=",ExpressionUUID->"cda2bc2c-8899-4cfc-abc8-1380809a88cf"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["\[Alpha]", "3"]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{"3", " ", "\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "6"]}], "+", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "10"]}], "-", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "12"]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "14"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "16"]}]}], 
  RowBox[{"16", " ", 
   SubsuperscriptBox["c", "0", "6"]}]]], "Output",
 CellChangeTimes->{3.863187838372164*^9},
 CellLabel->
  "Out[305]=",ExpressionUUID->"aafd0525-dc1e-4966-8056-70d837b02ca5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    SubscriptBox[
     SubscriptBox["cond4neg1No\[Beta]", 
      RowBox[{"1", ",", "2", ",", "dot"}]], 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["E", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Lambda]", "3"]}], "+", 
      RowBox[{
       SubscriptBox["F", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["r", "2"], 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["D", 
        RowBox[{"4", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["A", 
           RowBox[{"4", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         SubscriptBox["C", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858800054280077*^9, 3.8588002074619703`*^9}, {
   3.8588938907552757`*^9, 3.8588939139795833`*^9}, 3.8593918022409873`*^9},
 CellLabel->
  "In[306]:=",ExpressionUUID->"3ec8e13d-c328-48fd-93d6-81de7edf5277"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.858800167396191*^9, 3.8588002081207037`*^9}, 
   3.858800896575443*^9, {3.85889390161562*^9, 3.8588939144814887`*^9}, 
   3.85894906776675*^9, 3.8589690696300173`*^9, 3.8589819908950276`*^9, 
   3.8590483928967876`*^9, 3.859395058791177*^9, 3.8610299442849855`*^9, 
   3.8611355752541733`*^9, 3.8631878542493753`*^9},
 CellLabel->
  "Out[306]=",ExpressionUUID->"985aaa39-077a-468f-8dcc-9bdf3da8ba68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"1", ",", "2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]], "=", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond4neg1No\[Beta]", 
        RowBox[{"1", ",", "2", ",", "dot"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox[
         SubscriptBox["cond4neg1No\[Beta]", 
          RowBox[{"1", ",", "2", ",", "dot"}]], 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]], ",", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "/", "\[ImaginaryI]"}], 
     "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["J", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox[
        SubscriptBox["cond4neg1No\[Beta]", 
         RowBox[{"1", ",", "2", ",", "dot"}]], 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]], "/", "\[ImaginaryI]"}], "/.", 
      RowBox[{
       SubscriptBox["\[Mu]", "j_"], ":>", "0"}]}], " ", "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox[
      SubscriptBox["cond4neg1No\[Beta]", 
       RowBox[{"1", ",", "2", ",", "dot"}]], 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"], "*", 
        SubscriptBox["G", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["J", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], ")"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858800262519122*^9, 3.8588002663637934`*^9}, {
  3.8588002984102993`*^9, 3.8588003094127293`*^9}, {3.8588004359906745`*^9, 
  3.858800454522988*^9}, {3.863187860704276*^9, 
  3.863187879642005*^9}},ExpressionUUID->"6e2431bb-96d4-47da-bfa4-\
d5963b7cca27"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "7"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["c", "0", "8"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     SubscriptBox["N", 
      RowBox[{"2", ",", "2"}]]}], "-", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"4", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "+", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"32", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "-", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{"32", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8631878618757143`*^9, 3.8631878779706855`*^9}},
 CellLabel->
  "Out[311]=",ExpressionUUID->"79a75c11-5860-4b76-8764-dff748fc9c5d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"]}], "-", 
      SubsuperscriptBox["\[Omega]", 
       RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"]}], "-", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
    RowBox[{"48", " ", 
     SubsuperscriptBox["c", "0", "16"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Omega]", "2", "2"], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"11", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"8", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"42", " ", 
              SubscriptBox["N", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"19", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"3", " ", 
              SubscriptBox["N", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"18", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"19", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"3", " ", 
              SubscriptBox["N", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "272"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"84", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"12", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"84", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{"96", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "-", 
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"64", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "48"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"25", "-", 
          RowBox[{"60", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"25", "-", 
          RowBox[{"60", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"59", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"6", " ", 
              SubscriptBox["N", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"32", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["N", 
           RowBox[{"4", ",", "2"}]], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["c", "2"], "-", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"96", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"84", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", 
             RowBox[{"39", " ", 
              SubscriptBox["N", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "-", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["N", 
              RowBox[{"4", ",", "2"}]], "+", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["c", "2"], "-", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"21", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["N", 
              RowBox[{"4", ",", "2"}]], "+", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["c", "2"], "-", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"12", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"12", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"39", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["N", 
                 RowBox[{"4", ",", "2"}]], "+", 
                RowBox[{"4", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["c", "2"], "-", 
                   SubscriptBox["Q", 
                    RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
                 SubscriptBox["Q", 
                  RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"], "+", 
          SubsuperscriptBox["\[Omega]", "2", "2"], "-", 
          RowBox[{"24", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"48", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"19", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"19", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"20", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"36", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Omega]", "2", "2"], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "-", 
          RowBox[{"5", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "-", 
          RowBox[{"10", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "+", 
             RowBox[{"3", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "2", "2"], "-", 
             RowBox[{"24", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["\[Omega]", 
             RowBox[{"-", "2"}], "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "2", "2"], "-", 
             RowBox[{"24", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"36", "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "1"}]]}], "+", 
             RowBox[{"9", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["Q", 
            RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"14", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"64", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"48", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"32", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"480", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"48", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"27", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "3"}]]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["Q", 
            RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "7"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"32", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{"32", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
             RowBox[{"32", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
          RowBox[{"32", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           RowBox[{"(", 
            RowBox[{"16", "+", 
             RowBox[{"3", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "1"}]], "-", 
                RowBox[{"6", " ", 
                 SubscriptBox["Q", 
                  RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["Q", 
                 RowBox[{"3", ",", "1"}]], "-", 
                RowBox[{"6", " ", 
                 SubscriptBox["Q", 
                  RowBox[{"3", ",", "3"}]]}], "+", 
                RowBox[{
                 SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
                 SubscriptBox["Q", 
                  RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8631878618757143`*^9, 3.863187879267144*^9}},
 CellLabel->
  "Out[312]=",ExpressionUUID->"10ef59c6-5827-41ee-8b7c-711eb4a5ebec"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8631878618757143`*^9, 3.8631878795483046`*^9}},
 CellLabel->
  "Out[313]=",ExpressionUUID->"b5b8b2d4-54b6-45c2-b884-5a347cbd2386"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{{3.859050663959688*^9, 
  3.8590506763221884`*^9}},ExpressionUUID->"a668259d-f84d-4d73-99c5-\
155770e8fb17"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}], ",", "v2"}]], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"], "*", 
        SubscriptBox["G", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["J", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], ")"}], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["E", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SubscriptBox["\[Lambda]", "3"]}], "+", 
        RowBox[{
         SubscriptBox["F", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SubscriptBox["r", "2"], 
         SubscriptBox["\[Mu]", "1"]}], "+", 
        RowBox[{
         SubscriptBox["D", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", "*", 
            SubscriptBox["A", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}]}]], "*", 
            SubscriptBox["\[Lambda]", "2"]}], "+", 
           SubscriptBox["C", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}], ")"}], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Lambda]", "4"], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            SubscriptBox["r", "3"], 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", 
             SubscriptBox["g", 
              RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["A", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], "*", 
            SubscriptBox["\[Lambda]", "3"]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            SubscriptBox["B", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], "*", 
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "3"], "*", 
            SubscriptBox["I", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["H", 
                RowBox[{"4", ",", 
                 RowBox[{"-", "1"}]}]], "*", 
               SubscriptBox["\[Lambda]", "2"]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["G", 
                RowBox[{"4", ",", 
                 RowBox[{"-", "1"}], ",", "0", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "*", 
         SubscriptBox["E", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["J", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{
         FractionBox["\[ImaginaryI]", 
          SubscriptBox["c", "0"]], 
         SuperscriptBox[
          SubscriptBox["\[Lambda]", "2"], "2"]}]}], ")"}], ")"}], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["A", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["C", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["D", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["E", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SubscriptBox["\[Lambda]", "2"]}], "+", 
        RowBox[{
         SubscriptBox["F", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SubscriptBox["r", "1"], 
         SubscriptBox["\[Mu]", "1"]}], "+", 
        RowBox[{
         SubscriptBox["G", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}], ")"}], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{"\[ImaginaryI]", "*", 
     SubscriptBox["U", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], "*", 
     SubscriptBox["S", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", 
        SubscriptBox["\[Lambda]", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["T", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["V", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}], "*", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], "-", 
   SubscriptBox["cond", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}], ",", "v2"}]]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8588049265326023`*^9, 3.858804998253846*^9}, {
   3.8588050492539253`*^9, 3.8588050573001375`*^9}, {3.858805101144412*^9, 
   3.8588051931663785`*^9}, {3.858894635272971*^9, 3.858894755812128*^9}, {
   3.858894817851551*^9, 3.8588948282660904`*^9}, 3.8593894138005037`*^9, {
   3.859391802256629*^9, 3.8593918022878823`*^9}, 3.859394370008792*^9, {
   3.8631878968340874`*^9, 3.863187897349554*^9}},
 CellLabel->
  "In[314]:=",ExpressionUUID->"628792cb-5d0c-4824-b1fa-fcee73a32604"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.863187925693905*^9},
 CellLabel->
  "Out[315]=",ExpressionUUID->"a7d7b5c7-fd5d-4818-ab51-93e92bf34a5a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Second", " ", "solvability", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"4", ",", "0"}]], "=", 
    RowBox[{"Expand", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"4", ",", "0"}]], "//.", " ", 
                    RowBox[{
                    SubscriptBox["s", "0"], " ", "\[Rule]", " ", "0"}]}], " ",
                     "//.", " ", 
                    RowBox[{
                    SubscriptBox["C", "0"], "->", " ", "1"}]}], " ", "//.", 
                    " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "0"}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "1"}]]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "3"], "[", 
                    RowBox[{"[", 
                    RowBox[{"4", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                   SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "0"}]]}], "//.", " ", 
                  SubscriptBox["partsoln", 
                   RowBox[{"2", ",", "1"}]]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["partsoln", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                RowBox[{
                 SubscriptBox["partsoln", "1"], "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
               SubscriptBox["partsoln", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
              SubscriptBox["partsoln", 
               RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", "1"}]]}], "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", "0"], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8588053594430103`*^9, 3.858805363723071*^9}, {
  3.858805515369418*^9, 3.8588055361980906`*^9}, {3.8588056766851625`*^9, 
  3.858805709288122*^9}, {3.8588058237932453`*^9, 3.85880598029763*^9}},
 CellLabel->
  "In[325]:=",ExpressionUUID->"4748d497-d020-4045-a1f5-96b647ccdb76"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Coefficient", "[", 
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", "0"}]], ",", 
   SubscriptBox["\[Beta]", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Coefficient", "[", 
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", "0"}]], ",", 
   SubscriptBox["\[Beta]", 
    RowBox[{"3", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Coefficient", "[", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"4", ",", "0"}]], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"3", ",", "1"}]]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "0"}]], "-", 
     RowBox[{"\[ImaginaryI]", "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      SubscriptBox["S", 
       RowBox[{"2", ",", "0"}]], "*", 
      SubscriptBox["\[Mu]", "1"]}]}], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "0"}]], "*", 
      SubscriptBox["T", 
       RowBox[{"2", ",", "0"}]], "*", 
      SuperscriptBox[
       SubscriptBox["\[Mu]", "1"], "2"]}]}], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"2", ",", "0"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "0"}]], "-", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}]}], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "0"}]], "-", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["C", 
           RowBox[{"3", ",", "0"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], "/.", " ", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "j_"}]], ":>", " ", "0"}]}], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "0"}]], "-", 
     RowBox[{"\[ImaginaryI]", "*", 
      SubscriptBox["D", 
       RowBox[{"3", ",", "0"}]], "*", 
      SubscriptBox["\[Lambda]", "2"], "*", 
      SubscriptBox["\[Mu]", "1"], "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "0"}]]}]}], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"1", ",", "0"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "0"}]], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["A", 
          RowBox[{"3", ",", "0"}]], "*", 
         SubscriptBox["\[Lambda]", "2"]}], "-", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["C", 
          RowBox[{"3", ",", "0"}]], "*", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}], "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "1"}]]}]}], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"1", ",", "1"}]]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8588056728266544`*^9, 3.8588056932521687`*^9}, {
  3.8631879451805496`*^9, 3.863187973085586*^9}},
 CellLabel->
  "In[326]:=",ExpressionUUID->"328c6d74-d1ff-478f-a532-10265dcc83dc"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.8631879870374393`*^9}},
 CellLabel->
  "Out[326]=",ExpressionUUID->"f1c64e55-ec53-406f-bc8c-5f5fe59bb478"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.8631879870374393`*^9}},
 CellLabel->
  "Out[327]=",ExpressionUUID->"ad3d640e-1253-4f2a-b878-c02845f4b2d0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.863187987053062*^9}},
 CellLabel->
  "Out[328]=",ExpressionUUID->"cdf331da-27c6-4bdd-bae5-a8a754c62d97"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.8631879870686812`*^9}},
 CellLabel->
  "Out[329]=",ExpressionUUID->"12b8e342-6dac-4b10-b02f-9aa18a904040"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.8631879870686812`*^9}},
 CellLabel->
  "Out[330]=",ExpressionUUID->"f6343ae7-96aa-4ab8-ad79-7e85c5f6e23d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.8631879870843005`*^9}},
 CellLabel->
  "Out[331]=",ExpressionUUID->"b4b343cd-e46a-4596-b2a0-6b620d4f89ff"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.8631879870999203`*^9}},
 CellLabel->
  "Out[332]=",ExpressionUUID->"1fe68cde-fad0-43bb-b68f-a07283154773"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.86318798711554*^9}},
 CellLabel->
  "Out[333]=",ExpressionUUID->"40432689-2721-40c3-aec8-996114c607bd"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.858805986202902*^9, 3.8588953532060833`*^9, 3.858949108230932*^9, 
   3.85896910430449*^9, 3.8589821133060184`*^9, 3.8590489331655254`*^9, 
   3.859395364848816*^9, 3.8610300012109394`*^9, 3.8610301429345493`*^9, 
   3.8611356501702166`*^9, {3.863187973538513*^9, 3.86318798711554*^9}},
 CellLabel->
  "Out[334]=",ExpressionUUID->"750204f0-e0d4-4f83-bd83-3cc64d2a90df"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"4", ",", "0"}]], ",", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "3"]}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"4", ",", "0"}]], ",", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "]"}], ",", 
       RowBox[{
        SubscriptBox["r", "2"], 
        SubscriptBox["\[Mu]", "1"]}]}], "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["D", 
     RowBox[{"4", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "0"}]], ",", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "]"}], ",", 
          SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["F", 
     RowBox[{"4", ",", "0"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "0"}]], ",", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "]"}], ",", 
          SubscriptBox["\[Mu]", "1"]}], "]"}], "/", "\[ImaginaryI]"}], "//.", 
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], "//.", 
      RowBox[{
       SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"4", ",", "0"}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          SubscriptBox["cond", 
           RowBox[{"4", ",", "0"}]], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "]"}], ",", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "3"]}], "]"}], "/", "\[ImaginaryI]"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8588592040425563`*^9, 3.8588592891260033`*^9}, {
  3.858866119625651*^9, 3.8588661417323847`*^9}, {3.8588663771883507`*^9, 
  3.8588663805806046`*^9}, {3.858866497998133*^9, 3.858866532017024*^9}, {
  3.8588666028945093`*^9, 3.85886660386294*^9}, {3.8588666837357583`*^9, 
  3.858866685125967*^9}, {3.858866929887072*^9, 3.8588670093165026`*^9}, {
  3.858895442532076*^9, 3.8588954427357616`*^9}, {3.8588955410973387`*^9, 
  3.858895555716857*^9}, {3.8588955917122087`*^9, 3.8588955932699337`*^9}, {
  3.8588958038616943`*^9, 3.8588958363819313`*^9}, {3.8588959643427477`*^9, 
  3.8588960050974617`*^9}, {3.8588970276884365`*^9, 3.858897055759673*^9}, {
  3.8589821269863677`*^9, 3.8589821294885645`*^9}, {3.8590489468158455`*^9, 
  3.859048949224448*^9}, {3.8593918023034887`*^9, 3.8593918023034887`*^9}, {
  3.8593954591529713`*^9, 3.8593954617339077`*^9}, {3.8631880439000597`*^9, 
  3.863188044478179*^9}},
 CellLabel->
  "In[335]:=",ExpressionUUID->"18f10bac-a49c-41a6-bf28-9903e1a7cb4d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[Alpha]"}], "+", 
    FractionBox["2", 
     SubsuperscriptBox["c", "0", "2"]], "-", 
    SubsuperscriptBox["c", "0", "2"], "+", 
    RowBox[{"\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "4"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.858859260798902*^9, 3.858859290094413*^9}, {
   3.858866137824114*^9, 3.858866142747676*^9}, {3.8588663779693885`*^9, 
   3.858866384673015*^9}, {3.858866514204491*^9, 3.8588665356408434`*^9}, 
   3.8588666058310776`*^9, 3.8588670154448185`*^9, 3.8588955590829897`*^9, 
   3.8588955938507347`*^9, 3.858895836819873*^9, 3.858896007545719*^9, {
   3.858897034666312*^9, 3.8588970587552643`*^9}, 3.858949111617771*^9, 
   3.8589691077894554`*^9, 3.8589821328468328`*^9, 3.8590489527389116`*^9, 
   3.8593953832911606`*^9, 3.8593954651554394`*^9, 3.8610300528902197`*^9, 
   3.8610301570248814`*^9, 3.8611356645522733`*^9, 3.863188048992648*^9},
 CellLabel->
  "Out[337]=",ExpressionUUID->"57abadfb-f24c-4f5b-887f-f8635bc88215"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"64", " ", 
     SubsuperscriptBox["c", "0", "9"]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"]}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "\[Alpha]", " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"]}], "-", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "9"}], "-", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Alpha]"}], "+", 
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{"15", "-", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"10", " ", "\[Alpha]"}], "+", 
          RowBox[{"23", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{"44", "-", 
       RowBox[{"16", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"19", " ", "\[Alpha]"}], "+", 
          RowBox[{"48", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"48", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "-", 
          RowBox[{"56", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", "\[Alpha]"}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"4", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"40", " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "29"}], "+", 
          RowBox[{"100", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "2"]}], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"8", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]"}], "-", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "\[Alpha]"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Alpha]"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Alpha]"}], "-", 
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["c", "2"], "-", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Alpha]"}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"12", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"20", "+", 
          RowBox[{"3", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"20", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Alpha]", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Alpha]", " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.858859260798902*^9, 3.858859290094413*^9}, {
   3.858866137824114*^9, 3.858866142747676*^9}, {3.8588663779693885`*^9, 
   3.858866384673015*^9}, {3.858866514204491*^9, 3.8588665356408434`*^9}, 
   3.8588666058310776`*^9, 3.8588670154448185`*^9, 3.8588955590829897`*^9, 
   3.8588955938507347`*^9, 3.858895836819873*^9, 3.858896007545719*^9, {
   3.858897034666312*^9, 3.8588970587552643`*^9}, 3.858949111617771*^9, 
   3.8589691077894554`*^9, 3.8589821328468328`*^9, 3.8590489527389116`*^9, 
   3.8593953832911606`*^9, 3.8593954651554394`*^9, 3.8610300528902197`*^9, 
   3.8610301570248814`*^9, 3.8611356645522733`*^9, 3.8631880513825073`*^9},
 CellLabel->
  "Out[338]=",ExpressionUUID->"3d1b935f-f6d5-486f-a4ea-34ba55d62830"],

Cell[BoxData[
 FractionBox[
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], "+", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "2"]}], "-", 
     RowBox[{"3", " ", 
      SubsuperscriptBox["c", "0", "4"]}], "+", 
     RowBox[{"5", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "6"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
      SubsuperscriptBox["c", "0", "8"]}], "-", 
     RowBox[{"3", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "10"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubsuperscriptBox["c", "0", "12"]}]}], ")"}]}], 
  RowBox[{"8", " ", 
   SubsuperscriptBox["c", "0", "7"]}]]], "Output",
 CellChangeTimes->{{3.858859260798902*^9, 3.858859290094413*^9}, {
   3.858866137824114*^9, 3.858866142747676*^9}, {3.8588663779693885`*^9, 
   3.858866384673015*^9}, {3.858866514204491*^9, 3.8588665356408434`*^9}, 
   3.8588666058310776`*^9, 3.8588670154448185`*^9, 3.8588955590829897`*^9, 
   3.8588955938507347`*^9, 3.858895836819873*^9, 3.858896007545719*^9, {
   3.858897034666312*^9, 3.8588970587552643`*^9}, 3.858949111617771*^9, 
   3.8589691077894554`*^9, 3.8589821328468328`*^9, 3.8590489527389116`*^9, 
   3.8593953832911606`*^9, 3.8593954651554394`*^9, 3.8610300528902197`*^9, 
   3.8610301570248814`*^9, 3.8611356645522733`*^9, 3.8631880514137497`*^9},
 CellLabel->
  "Out[339]=",ExpressionUUID->"7f8236af-263d-45a6-8bfa-1256f95c6b1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "0"}]], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["D", 
              RowBox[{"4", ",", "0"}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["F", 
              RowBox[{"4", ",", "0"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["G", 
              RowBox[{"4", ",", "0"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858895611202986*^9, 3.858895647296866*^9}, {
   3.8588956818492403`*^9, 3.8588957008955207`*^9}, {3.8588958512693143`*^9, 
   3.8588959136221094`*^9}, {3.8588960212735786`*^9, 
   3.8588960361123266`*^9}, {3.8588970687963486`*^9, 3.85889707016131*^9}, 
   3.859391802319109*^9},
 CellLabel->
  "In[309]:=",ExpressionUUID->"dcd87bff-b16b-4b4a-9e19-07eb26e33fed"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588956147199354`*^9, 3.8588956446421485`*^9}, {
   3.858895683593255*^9, 3.8588957012174816`*^9}, 3.8588959142496724`*^9, {
   3.8588960271005573`*^9, 3.858896037008855*^9}, 3.858897070758106*^9, 
   3.8589491140985856`*^9, 3.858969110177955*^9, 3.8589821398340855`*^9, 
   3.8590489641020765`*^9, 3.8593954881890616`*^9, 3.861030067814753*^9, 
   3.861030162274895*^9, 3.861135666985283*^9},
 CellLabel->
  "Out[309]=",ExpressionUUID->"63e9bc6b-c0e8-43c7-90fc-134d76d4d5e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Proofs", " ", "of", " ", "identities", " ", "for", " ", 
    "capitalized", " ", 
    RowBox[{"coefficients", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["A", 
       RowBox[{"4", ",", 
        RowBox[{"-", "1"}]}]], "/", 
      SubscriptBox["c", "0"]}], "+", 
     SubscriptBox["D", 
      RowBox[{"4", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["F", 
      RowBox[{"4", ",", "0"}]], "-", 
     RowBox[{
      SubscriptBox["C", 
       RowBox[{"4", ",", 
        RowBox[{"-", "1"}]}]], "/", 
      SubscriptBox["c", "0"]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8610302396660013`*^9, 3.8610302594024377`*^9}, {
  3.861030300979225*^9, 3.8610303068091555`*^9}, {3.8610303685143895`*^9, 
  3.861030368782342*^9}, {3.8631880763359437`*^9, 3.863188087835704*^9}},
 CellLabel->
  "In[340]:=",ExpressionUUID->"8cc28d3b-a336-44c5-9427-e58590c690ff"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.861030256715783*^9, 3.8610302596991935`*^9}, 
   3.861030307293256*^9, 3.861030600473074*^9, 3.861135669288518*^9, 
   3.863188088272893*^9},
 CellLabel->
  "Out[340]=",ExpressionUUID->"bb69283c-7bb5-4002-980a-b71cec3239c2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.861030256715783*^9, 3.8610302596991935`*^9}, 
   3.861030307293256*^9, 3.861030600473074*^9, 3.861135669288518*^9, 
   3.863188088288516*^9},
 CellLabel->
  "Out[341]=",ExpressionUUID->"a743b315-cdab-483f-86e9-2773b6bb31d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          SubscriptBox["cond", 
           RowBox[{"4", ",", "0"}]], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]}], "]"}], ",", 
        SubscriptBox["\[Lambda]", "3"]}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["\[Mu]", "1"]}], ")"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          SubscriptBox["cond", 
           RowBox[{"4", ",", "0"}]], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]}], "]"}], ",", 
        RowBox[{
         SubscriptBox["r", "2"], 
         SubscriptBox["\[Mu]", "1"]}]}], "]"}], "/", 
      SubscriptBox["\[Mu]", "1"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"4", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "0"}]], ",", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "]"}], "//.", 
          RowBox[{
           SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", 
         " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], ",", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["H", 
     RowBox[{"4", ",", "0"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"4", ",", "0"}]], ",", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], "]"}], "//.", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "->", " ", "0"}]}], " ", "//.", " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "->", " ", "0"}]}], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "4"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8588961051089106`*^9, 3.858896156165945*^9}, {
  3.8588962060504503`*^9, 3.8588962357534533`*^9}, {3.8588962722394247`*^9, 
  3.8588963049877005`*^9}, {3.8588963467724037`*^9, 3.858896512669903*^9}, {
  3.8589821480214453`*^9, 3.858982150558879*^9}, {3.8590489669607*^9, 
  3.859048971071718*^9}, {3.859391802319109*^9, 3.8593918023503494`*^9}, {
  3.8593955204131174`*^9, 3.859395524211066*^9}, {3.863188104397321*^9, 
  3.863188118147503*^9}},
 CellLabel->
  "In[351]:=",ExpressionUUID->"834328b1-2ce4-4a4c-aba2-1d7ca5aa207f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], "+", 
   RowBox[{"6", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   RowBox[{"12", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "6"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "5"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "+", 
   RowBox[{"6", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "10"]}], "-", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SubsuperscriptBox["c", "0", "12"]}], "+", 
   RowBox[{"8", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
   RowBox[{"8", " ", "\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "9"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["c", "2"]}], "+", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}]}], 
  RowBox[{"8", " ", 
   SubsuperscriptBox["c", "0", "6"]}]]], "Output",
 CellChangeTimes->{
  3.858896118273466*^9, 3.858896156511239*^9, {3.858896221139089*^9, 
   3.8588962363042746`*^9}, {3.858896292455137*^9, 3.858896305270384*^9}, 
   3.8588963743794355`*^9, 3.858896415176238*^9, {3.85889646286054*^9, 
   3.8588964750322733`*^9}, 3.858896514708908*^9, 3.8589491141767077`*^9, 
   3.8589691102779064`*^9, {3.8589821431142817`*^9, 3.8589821509335766`*^9}, 
   3.8590489728991613`*^9, 3.859395494392852*^9, 3.859395524679536*^9, 
   3.8610301669950924`*^9, 3.8611356729704375`*^9, {3.8631880926314077`*^9, 
   3.863188118662793*^9}},
 CellLabel->
  "Out[353]=",ExpressionUUID->"920074ed-b55a-4952-bcb7-c28fb0c16093"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "+", 
     RowBox[{"2", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
      SubsuperscriptBox["c", "0", "4"]}], "-", 
     RowBox[{"6", " ", "\[Alpha]", " ", 
      SubsuperscriptBox["c", "0", "6"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      SubsuperscriptBox["c", "0", "8"]}]}], ")"}]}], 
  RowBox[{"24", " ", 
   SubsuperscriptBox["c", "0", "2"]}]]], "Output",
 CellChangeTimes->{
  3.858896118273466*^9, 3.858896156511239*^9, {3.858896221139089*^9, 
   3.8588962363042746`*^9}, {3.858896292455137*^9, 3.858896305270384*^9}, 
   3.8588963743794355`*^9, 3.858896415176238*^9, {3.85889646286054*^9, 
   3.8588964750322733`*^9}, 3.858896514708908*^9, 3.8589491141767077`*^9, 
   3.8589691102779064`*^9, {3.8589821431142817`*^9, 3.8589821509335766`*^9}, 
   3.8590489728991613`*^9, 3.859395494392852*^9, 3.859395524679536*^9, 
   3.8610301669950924`*^9, 3.8611356729704375`*^9, {3.8631880926314077`*^9, 
   3.8631881186784153`*^9}},
 CellLabel->
  "Out[354]=",ExpressionUUID->"133774a0-43e8-418a-ae6d-23e35d3794d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "0"}]], "-", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["D", 
              RowBox[{"3", ",", "0"}]], "*", 
             SubscriptBox["\[Lambda]", "3"]}], "+", 
            RowBox[{
             SubscriptBox["E", 
              RowBox[{"3", ",", "0"}]], "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            RowBox[{
             SubscriptBox["C", 
              RowBox[{"4", ",", "0"}]], "*", 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            RowBox[{
             SubscriptBox["H", 
              RowBox[{"4", ",", "0"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "3"]}]}], ")"}]}], "-", 
         SuperscriptBox[
          SubscriptBox["\[Lambda]", "2"], "2"]}], ")"}]}]}], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8588965879701753`*^9, 3.8588966297638865`*^9}, {
   3.858896660009954*^9, 3.8588966855142813`*^9}, 3.8593918023659735`*^9},
 CellLabel->
  "In[355]:=",ExpressionUUID->"d9b3e047-0a83-4e53-b7af-71108b2ab168"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8588966858755364`*^9, 3.8589491143329105`*^9, 
  3.858969110440059*^9, 3.85898215793524*^9, 3.859048976024029*^9, 
  3.859395530525158*^9, 3.861030131346882*^9, 3.8610301707153764`*^9, 
  3.8611356756921735`*^9, 3.863188123085862*^9},
 CellLabel->
  "Out[355]=",ExpressionUUID->"72995a4c-0c5c-4d66-a5e9-3025110eb717"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "0"}]], "-", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SubscriptBox["D", 
                RowBox[{"4", ",", "0"}]]}], "*", 
              SubscriptBox["\[Lambda]", "2"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["F", 
               RowBox[{"4", ",", "0"}]]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SuperscriptBox[
               SubscriptBox["\[Mu]", "1"], "2"], "*", 
              SubscriptBox["G", 
               RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["A", 
            RowBox[{"3", ",", "0"}]], "*", 
           SubscriptBox["\[Lambda]", "3"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["B", 
            RowBox[{"3", ",", "0"}]], "*", 
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"]}]}], ")"}]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "]"}], "//.", " ", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"-", "2"}]], "->", " ", 
     RowBox[{"-", 
      SubscriptBox["\[Omega]", "2"]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858896780977739*^9, 3.8588968800649023`*^9}, {
   3.8588969203467107`*^9, 3.8588969332916455`*^9}, {3.858896980047155*^9, 
   3.8588970068916616`*^9}, {3.8588971100486927`*^9, 
   3.8588971526419077`*^9}, {3.8588972279020967`*^9, 3.858897232157234*^9}, {
   3.8588972696997395`*^9, 3.8588974552274127`*^9}, {3.858897486972148*^9, 
   3.8588974870974407`*^9}, 3.8593918023659735`*^9},
 CellLabel->
  "In[356]:=",ExpressionUUID->"d491b881-87f6-49e2-a7d8-1537e0d1d2e1"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588967944402847`*^9, 3.858896880724269*^9}, {
   3.858896924790883*^9, 3.8588969336043887`*^9}, 3.8588969840049615`*^9, 
   3.858897113970473*^9, 3.858897153379427*^9, 3.858897232596485*^9, {
   3.8588973711064124`*^9, 3.8588973936455536`*^9}, {3.8588974461794233`*^9, 
   3.858897455605768*^9}, 3.858897488652529*^9, 3.858949114535984*^9, 
   3.8589691106371346`*^9, 3.858982160030941*^9, 3.8590489789137573`*^9, 
   3.859395536511466*^9, 3.86103017296463*^9, 3.861135677763586*^9, 
   3.8631881261474147`*^9},
 CellLabel->
  "Out[356]=",ExpressionUUID->"8a18eab2-8e2c-459a-a95f-7104cc76afab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "0", ",", "v2"}]], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", "\[ImaginaryI]", "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["T", 
        RowBox[{"2", ",", "0"}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "*", "\[ImaginaryI]", "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["C", 
           RowBox[{"3", ",", "0"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["D", 
          RowBox[{"3", ",", "0"}]], "*", 
         SubscriptBox["\[Lambda]", "2"], "*", 
         SubscriptBox["\[Mu]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "-", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["C", 
           RowBox[{"3", ",", "0"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["D", 
              RowBox[{"4", ",", "0"}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["F", 
              RowBox[{"4", ",", "0"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"], "*", 
             SubscriptBox["G", 
              RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["D", 
              RowBox[{"3", ",", "0"}]], "*", 
             SubscriptBox["\[Lambda]", "3"]}], "+", 
            RowBox[{
             SubscriptBox["E", 
              RowBox[{"3", ",", "0"}]], "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            RowBox[{
             SubscriptBox["H", 
              RowBox[{"4", ",", "0"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
            RowBox[{
             SubscriptBox["C", 
              RowBox[{"4", ",", "0"}]], "*", 
             SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "-", 
         SuperscriptBox[
          SubscriptBox["\[Lambda]", "2"], "2"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["A", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["B", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["D", 
               RowBox[{"4", ",", "0"}]]}], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["F", 
              RowBox[{"4", ",", "0"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"], "*", 
             SubscriptBox["G", 
              RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Factor", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "0"}]], "-", 
      SubscriptBox["cond", 
       RowBox[{"4", ",", "0", ",", "v2"}]]}], "//.", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"-", "2"}]], "->", " ", 
      RowBox[{"-", 
       SubscriptBox["\[Omega]", "2"]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858897576565179*^9, 3.8588979120596676`*^9}, 
   3.858897973631279*^9, {3.859391802381588*^9, 3.8593918024128284`*^9}, {
   3.8631881347448406`*^9, 3.863188134947742*^9}},
 CellLabel->
  "In[358]:=",ExpressionUUID->"30f54c28-f581-46b5-b4a4-c00f1d254e7a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.863188136025524*^9},
 CellLabel->
  "Out[359]=",ExpressionUUID->"ecf52e72-4796-4e5e-aeb3-771dc0e5882b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Third", " ", "solvability", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}]}]], "Input",
 CellChangeTimes->{{3.8588984444312162`*^9, 
  3.8588984514511275`*^9}},ExpressionUUID->"7a722f88-c141-429d-a593-\
88e67925100e"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"4", ",", "1"}]], "=", 
    RowBox[{"Expand", "[", 
     RowBox[{"Dot", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"4", ",", "1"}]], "//.", " ", 
                    RowBox[{
                    SubscriptBox["s", "1"], " ", "\[Rule]", " ", 
                    RowBox[{
                    SubscriptBox["C", "1"], "*", 
                    SuperscriptBox[
                    SubscriptBox["c", "0"], "2"]}]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "3"], "[", 
                    RowBox[{"[", 
                    RowBox[{"4", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "1"}]]}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "0"}]]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"4", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                   " ", 
                   SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                  SubscriptBox["partsoln", 
                   RowBox[{"2", ",", "0"}]]}], "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", "1"}]]}], "//.", 
                RowBox[{
                 SubscriptBox["partsoln", "1"], "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
              SubscriptBox["partsoln", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "1"}]]}], "//.", " ", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], ")"}], ",", 
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", "1"], "]"}], ",", 
         RowBox[{
          SubscriptBox["c", "0"], "\[Element]", " ", "Reals"}]}], "]"}]}], 
      "]"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8588984572426996`*^9, 3.858898509722273*^9}, {
   3.858898614813221*^9, 3.858898651845055*^9}, 3.8588987407221355`*^9},
 CellLabel->
  "In[369]:=",ExpressionUUID->"dac08126-96b4-4d46-8299-d5f9c30069e4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1"}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1"}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "0"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1"}]], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], "-", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["U", 
         RowBox[{"2", ",", "1"}]], "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], "-", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["S", 
         RowBox[{"2", ",", "1"}]], "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "0"}]]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "0"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "2"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["T", 
            RowBox[{"2", ",", "1"}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["V", 
            RowBox[{"2", ",", "1"}]]}]}], ")"}], "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "1"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "1"}]], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], "-", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["E", 
            RowBox[{"3", ",", "1"}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{
           SubscriptBox["F", 
            RowBox[{"3", ",", "1"}]], "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{
           SubscriptBox["G", 
            RowBox[{"3", ",", "1"}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "0"}]]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], "-", 
       RowBox[{
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "3"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "2"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["A", 
               RowBox[{"3", ",", "1"}]], "*", 
              SubscriptBox["\[Lambda]", "2"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["C", 
               RowBox[{"3", ",", "1"}]]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["D", 
               RowBox[{"3", ",", "1"}]], "*", 
              SuperscriptBox[
               SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "1"}]]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8588986754585767`*^9, 3.858898716972379*^9}, {
  3.863188162094573*^9, 3.8631881909121842`*^9}},
 CellLabel->
  "In[379]:=",ExpressionUUID->"e83b6254-65a5-4101-bbd6-fa5c628078f5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.8631881912558203`*^9}},
 CellLabel->
  "Out[379]=",ExpressionUUID->"e0e41bb3-f76c-48fa-aea4-d4d9e3eb5eac"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.8631881912558203`*^9}},
 CellLabel->
  "Out[380]=",ExpressionUUID->"d06590a3-82dc-457e-ae83-324f8c057b17"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.863188191271438*^9}},
 CellLabel->
  "Out[381]=",ExpressionUUID->"43844690-1f1d-449c-b063-efd0f92676cf"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.8631881912870646`*^9}},
 CellLabel->
  "Out[382]=",ExpressionUUID->"a5a1ed9d-8fc0-4e36-936e-9a8a94727578"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.8631881913027067`*^9}},
 CellLabel->
  "Out[383]=",ExpressionUUID->"e223c08a-dcc3-49a4-8d7d-83cada83c030"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.863188191318304*^9}},
 CellLabel->
  "Out[384]=",ExpressionUUID->"cf8967d7-3508-4276-a581-a43efdc4ed97"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.863188191318304*^9}},
 CellLabel->
  "Out[385]=",ExpressionUUID->"1aea9aae-0703-4973-806f-7b4d264fe2f0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.8631881913339214`*^9}},
 CellLabel->
  "Out[386]=",ExpressionUUID->"f462da65-cccf-49eb-ad5c-eb87ee7bce2b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8588987174285946`*^9, 3.8588987454494305`*^9}, 
   3.8589491177118225`*^9, 3.8589691122212505`*^9, 3.8589821758320694`*^9, 
   3.859048990522561*^9, 3.859050171444212*^9, 3.8593955700427647`*^9, {
   3.861031069007591*^9, 3.861031094281001*^9}, 3.861135687921256*^9, {
   3.863188163437913*^9, 3.8631881913495436`*^9}},
 CellLabel->
  "Out[387]=",ExpressionUUID->"a1ac656f-93a7-45ee-a7ea-aceed670a33c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["A", 
   RowBox[{"4", ",", "1"}]], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", "1"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "]"}], ",", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["\[Lambda]", "2"]}]}], "]"}], "/", "\[ImaginaryI]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["A", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], "-", 
   SubscriptBox["A", 
    RowBox[{"4", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["C", 
   RowBox[{"4", ",", "1"}]], " ", "=", "  ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"4", ",", "1"}]], ",", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "]"}], ",", 
       SubscriptBox["\[Mu]", "1"]}], "]"}], "//.", 
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], " ", "//.", 
    RowBox[{
     SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["C", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], "+", 
    SubscriptBox["C", 
     RowBox[{"4", ",", "1"}]]}], "//.", 
   RowBox[{
    SubscriptBox["\[Omega]", 
     RowBox[{"-", "2"}]], "->", " ", 
    RowBox[{"-", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["D", 
   RowBox[{"4", ",", "1"}]], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "]"}], ",", 
     SuperscriptBox[
      SubscriptBox["\[Mu]", "1"], "3"]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["D", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], "+", 
   SubscriptBox["D", 
    RowBox[{"4", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["E", 
   RowBox[{"4", ",", "1"}]], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         SubscriptBox["cond", 
          RowBox[{"4", ",", "1"}]], ",", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], "]"}], ",", 
       SubscriptBox["\[Lambda]", "2"]}], "]"}], "//.", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], "->", " ", "0"}]}], ")"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["E", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], "-", 
    SubscriptBox["E", 
     RowBox[{"4", ",", "1"}]]}], " ", "//.", " ", 
   RowBox[{
    SubscriptBox["\[Omega]", 
     RowBox[{"-", "2"}]], "->", " ", 
    RowBox[{"-", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["G", 
   RowBox[{"4", ",", "1", ",", "0", ",", 
    RowBox[{"-", "1"}]}]], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", "1"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "]"}], ",", 
      SuperscriptBox[
       SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "/", "\[ImaginaryI]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["G", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "+", 
   SubscriptBox["G", 
    RowBox[{"4", ",", "1", ",", "0", ",", 
     RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["G", 
    RowBox[{"4", ",", "1", ",", "0", ",", "1"}]], " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{"Coefficient", "[", 
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "1"}]], ",", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "1"}]]}], "]"}], ",", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "^", "2"}]}], "]"}], "//.", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], ")"}], "/", 
      "\[ImaginaryI]"}], "//.", 
     RowBox[{
      SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}]], "+", 
    SubscriptBox["G", 
     RowBox[{"4", ",", "1", ",", "0", ",", "1"}]]}], " ", "//.", " ", 
   RowBox[{
    SubscriptBox["\[Omega]", 
     RowBox[{"-", "2"}]], "->", " ", 
    RowBox[{"-", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["H", 
   RowBox[{"4", ",", "1"}]], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       SubscriptBox["cond", 
        RowBox[{"4", ",", "1"}]], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "]"}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "^", "2"}], "*", 
      SubscriptBox["\[Lambda]", "2"]}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["H", 
    RowBox[{"4", ",", "1"}]], "-", 
   SubscriptBox["H", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["I", 
   RowBox[{"4", ",", "1"}]], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", "1"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "]"}], ",", 
      SuperscriptBox[
       SubscriptBox["\[Mu]", "1"], "4"]}], "]"}], "/", "\[ImaginaryI]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["I", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], "+", 
   SubscriptBox["I", 
    RowBox[{"4", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["J", 
   RowBox[{"4", ",", "1", ",", "0", ",", 
    RowBox[{"-", "1"}]}]], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"4", ",", "1"}]], ",", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "->", " ", "0"}]}], ")"}], "/", 
    "\[ImaginaryI]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SubscriptBox["J", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "+", 
   SubscriptBox["J", 
    RowBox[{"4", ",", "1", ",", "0", ",", 
     RowBox[{"-", "1"}]}]]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["J", 
   RowBox[{"4", ",", "1", ",", "0", ",", "1"}]], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"4", ",", "1"}]], ",", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "]"}], "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "4"], "->", " ", "0"}]}], "//.", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "->", " ", "0"}]}], " ", "//.", " ", 
       RowBox[{
        RowBox[{
         SubscriptBox["r", "3"], 
         SubscriptBox["\[Mu]", "1"]}], " ", "->", " ", "0"}]}], " ", "//.", 
      " ", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "->", " ", "0"}]}], ")"}], "/", 
    "\[ImaginaryI]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["J", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}], ",", "0", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["J", 
      RowBox[{"4", ",", "1", ",", "0", ",", "1"}]]}], " ", "//.", " ", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"-", "2"}]], "->", " ", 
     RowBox[{"-", 
      SubscriptBox["\[Omega]", "2"]}]}]}], " ", "//.", " ", 
   RowBox[{
    SubscriptBox["\[Omega]", 
     RowBox[{"-", "3"}]], "->", " ", 
    RowBox[{"-", 
     SubscriptBox["\[Omega]", "3"]}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "-", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], " ", "//.", 
                    " ", 
                    RowBox[{
                    SubscriptBox["\[Omega]", 
                    RowBox[{"-", "2"}]], "->", 
                    RowBox[{"-", 
                    SubscriptBox["\[Omega]", "2"]}]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Omega]", 
                    RowBox[{"-", "3"}]], "->", " ", 
                    RowBox[{"-", 
                    SubscriptBox["\[Omega]", "3"]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                    SubscriptBox["c", 
                    SubscriptBox["g", 
                    RowBox[{"1", ",", "1"}]]]}]}], "//.", " ", 
                   RowBox[{
                    SubscriptBox["c", "4"], "->", " ", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"2048", "*", 
                    SubscriptBox["c", "0"]}]], 
                    RowBox[{"(", 
                    RowBox[{"212", "+", 
                    RowBox[{"55", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"98", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"23", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"]}]}]}], "//.",
                   " ", 
                  RowBox[{
                   SubscriptBox["N", 
                    RowBox[{"4", ",", "4"}]], "->", " ", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{"1536", "*", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    ")"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"203", "+", 
                    RowBox[{"347", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"158", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"76", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"23", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "8"]}]}]}], "//.", 
                 RowBox[{
                  SubscriptBox["N", 
                   RowBox[{"4", ",", "2"}]], "->", " ", 
                  RowBox[{
                   FractionBox["1", "6144"], 
                   RowBox[{"(", 
                    RowBox[{"215", "-", 
                    RowBox[{"418", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"472", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"10", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"17", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], "*", 
                   SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "8"]}]}]}], "//.",
                 " ", 
                RowBox[{
                 SubscriptBox["Q", 
                  RowBox[{"4", ",", "0"}]], "->", " ", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"48", "+", 
                    RowBox[{"47", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"512", "*", 
                    SubscriptBox["c", "0"], "*", 
                    SuperscriptBox[
                    RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "7"], "*", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.",
                " ", 
               RowBox[{
                SubscriptBox["Q", 
                 RowBox[{"4", ",", "2"}]], "->", " ", 
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"240", "+", 
                    RowBox[{"82", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"688", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"309", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"7", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], "*", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], ")"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"4", "*", "6144", "*", 
                    SubscriptBox["c", "0"]}], ")"}]}], ")"}]}]}]}], "//.", 
              RowBox[{
               SubscriptBox["Q", 
                RowBox[{"4", ",", "4"}]], "->", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "/", 
                  RowBox[{"(", 
                   RowBox[{"8", "*", "1536", "*", 
                    SubscriptBox["c", "0"], "*", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                   ")"}]}], ")"}], 
                RowBox[{"(", 
                 RowBox[{"408", "+", 
                  RowBox[{"638", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"230", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"171", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"124", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"43", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"6", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"12", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                SuperscriptBox[
                 RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], "*", 
                RowBox[{"Sech", "[", "\[Alpha]", "]"}]}]}]}], "//.", 
             RowBox[{
              SubscriptBox["N", 
               RowBox[{"3", ",", "3"}]], "->", " ", 
              RowBox[{"3", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"14", "+", 
                  RowBox[{"15", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"6", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"2", "*", "256", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"Sinh", "[", "\[Alpha]", "]"}], ")"}], "^", 
                   "6"}]}], ")"}]}]}]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"3", ",", "3"}]], " ", "->", " ", 
             RowBox[{"3", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"26", "-", 
                 RowBox[{"3", "*", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                 RowBox[{"10", "*", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                 RowBox[{"3", "*", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"6", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"6", "*", "256", "*", 
                 SubscriptBox["c", "0"], "*", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"Sinh", "[", "\[Alpha]", "]"}], ")"}], "^", 
                  "6"}]}], ")"}]}]}]}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["Q", 
             RowBox[{"3", ",", "1"}]], "->", " ", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Cosh", "[", 
                 RowBox[{"2", "*", "\[Alpha]"}], "]"}], "*", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{"Cosh", "[", 
                   RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], ")"}]}], ")"}]}], 
             "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", "16", "*", 
               SubscriptBox["c", "0"], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Sinh", "[", "\[Alpha]", "]"}], ")"}], "^", "4"}]}], 
              ")"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], " ", "->", " ", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
           RowBox[{"(", 
            RowBox[{"4", 
             SuperscriptBox[
              SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.", 
        " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "0"], " ", "->", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
    RowBox[{
     SubscriptBox["\[Omega]", "j_"], ":>", " ", 
     RowBox[{"\[Omega]", "[", 
      RowBox[{"j", "+", 
       SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1"}]], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[Lambda]", "4"], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            SubscriptBox["r", "3"], 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", 
             SubscriptBox["g", 
              RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["A", 
             RowBox[{"3", ",", "1"}]], "*", 
            SubscriptBox["\[Lambda]", "3"]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            SubscriptBox["B", 
             RowBox[{"3", ",", "1"}]], "*", 
            SubscriptBox["r", "2"], 
            SubscriptBox["\[Mu]", "1"]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", 
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "3"], "*", 
            SubscriptBox["I", 
             RowBox[{"4", ",", "1"}]]}], "+", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["H", 
                RowBox[{"4", ",", "1"}]], "*", 
               SubscriptBox["\[Lambda]", "2"]}], "+", 
              RowBox[{"\[ImaginaryI]", "*", 
               SubscriptBox["G", 
                RowBox[{"4", ",", "1", ",", "0", ",", "1"}]]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SubscriptBox["E", 
          RowBox[{"4", ",", "1"}]], "*", 
         SubscriptBox["\[Lambda]", "2"]}], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["J", 
          RowBox[{"4", ",", "1", ",", "0", ",", "1"}]]}], "+", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "/", 
          SubscriptBox["c", "0"]}], "*", 
         SuperscriptBox[
          SubscriptBox["\[Lambda]", "2"], "2"]}]}], ")"}], "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}]}], ",", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "1"}]]}], "]"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8588987529264555`*^9, 3.8588989100329514`*^9}, {
   3.8588990034698668`*^9, 3.8588990997632494`*^9}, {3.858899139187316*^9, 
   3.8588994280826826`*^9}, {3.8588994647338543`*^9, 3.858899474115443*^9}, {
   3.858899519543208*^9, 3.8588996027849693`*^9}, {3.858899640789601*^9, 
   3.8588999931075783`*^9}, 3.858900038276327*^9, {3.8589001834379716`*^9, 
   3.858900192301434*^9}, {3.8589002667301817`*^9, 3.8589002974161124`*^9}, 
   3.8589003358366604`*^9, 3.8589003766326556`*^9, {3.8589008211412897`*^9, 
   3.8589008371587925`*^9}, {3.8589011295741415`*^9, 3.858901166594264*^9}, {
   3.858901232115036*^9, 3.8589012411275463`*^9}, {3.8589013390584064`*^9, 
   3.8589013603179407`*^9}, {3.858901396785985*^9, 3.8589020331002293`*^9}, {
   3.8589021257778587`*^9, 3.858902202000095*^9}, {3.8589022480822787`*^9, 
   3.858902305477828*^9}, {3.8589023502282734`*^9, 3.858902375899205*^9}, {
   3.858902434930796*^9, 3.858902801637932*^9}, {3.858902838427348*^9, 
   3.858902852324605*^9}, {3.8589515018919573`*^9, 3.8589515127090855`*^9}, {
   3.85938941383171*^9, 3.8593894138479414`*^9}, {3.859391802444068*^9, 
   3.8593918024597025`*^9}, {3.859394370039996*^9, 3.859394370055617*^9}, {
   3.8593955996830196`*^9, 3.8593956284607334`*^9}, {3.8593957042893257`*^9, 
   3.8593957073976994`*^9}, {3.859395743056096*^9, 3.8593957460395093`*^9}, {
   3.863188174396629*^9, 3.863188394862994*^9}},
 CellLabel->
  "In[411]:=",ExpressionUUID->"6cb3350f-d84b-4a6a-abde-0d528dc6b47a"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "2"}], "+", 
   RowBox[{"\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "2"]}], "+", 
   SubsuperscriptBox["c", "0", "4"], "-", 
   RowBox[{"\[Alpha]", " ", 
    SubsuperscriptBox["c", "0", "6"]}]}], 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"]}]]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883980182667`*^9},
 CellLabel->
  "Out[411]=",ExpressionUUID->"2ce31452-4c0d-435a-91a9-e4d007bb1602"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883980338554`*^9},
 CellLabel->
  "Out[412]=",ExpressionUUID->"e6879661-3718-4074-9e6d-dcdd83185abd"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{
    RowBox[{"64", " ", 
     SubsuperscriptBox["c", "0", "8"]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"]}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "9"}], "-", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Alpha]"}], "+", 
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{"15", "-", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"10", " ", "\[Alpha]"}], "+", 
          RowBox[{"23", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{"44", "-", 
       RowBox[{"16", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"19", " ", "\[Alpha]"}], "+", 
          RowBox[{"48", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", "\[Alpha]"}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          RowBox[{"4", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "48"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "51"}], "+", 
          RowBox[{"56", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"40", " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"2", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "29"}], "+", 
          RowBox[{"100", " ", "\[Alpha]", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{"\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"4", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"20", "+", 
          RowBox[{"3", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"20", "+", 
          RowBox[{"3", " ", "\[Alpha]", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"6", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Alpha]"}], "-", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "\[Alpha]"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Alpha]"}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "\[Alpha]"}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "6"}], " ", "\[Alpha]"}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"12", " ", "\[Alpha]", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"12", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"\[Alpha]", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883983794613`*^9},
 CellLabel->
  "Out[413]=",ExpressionUUID->"e7302cad-4562-48ab-8cc6-e86368c228b4"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883983950834`*^9},
 CellLabel->
  "Out[414]=",ExpressionUUID->"99c3e29e-87d0-4b76-9be4-11e0a5c474b6"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["\[Alpha]", "3"]}], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "2"]}], "-", 
    RowBox[{"3", " ", "\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
     SubsuperscriptBox["c", "0", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "6"]}], "+", 
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
     SubsuperscriptBox["c", "0", "8"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["c", "0", "10"]}], "-", 
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
     SubsuperscriptBox["c", "0", "12"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "14"]}], "+", 
    RowBox[{
     SuperscriptBox["\[Alpha]", "3"], " ", 
     SubsuperscriptBox["c", "0", "16"]}]}], 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "6"]}]]}]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188398426306*^9},
 CellLabel->
  "Out[415]=",ExpressionUUID->"285f17d3-aef3-4bc6-8a80-832ca34fda79"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188398426306*^9},
 CellLabel->
  "Out[416]=",ExpressionUUID->"cb2de350-329d-4cfb-9dc9-0bfe72f8cf66"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"8", " ", 
    SubsuperscriptBox["c", "0", "12"]}], "+", 
   RowBox[{"7", " ", 
    SubsuperscriptBox["c", "0", "2"], " ", 
    SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
   RowBox[{"14", " ", 
    SubsuperscriptBox["c", "0", "6"], " ", 
    SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
   RowBox[{"13", " ", 
    SubsuperscriptBox["c", "0", "10"], " ", 
    SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
   SubsuperscriptBox["\[Omega]", "2", "4"], "+", 
   RowBox[{
    SubsuperscriptBox["c", "0", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "16"}], "+", 
      RowBox[{"5", " ", 
       SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}], "-", 
   RowBox[{
    SubsuperscriptBox["c", "0", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"8", "+", 
      RowBox[{"7", " ", 
       SubsuperscriptBox["\[Omega]", "2", "4"]}]}], ")"}]}], "+", 
   RowBox[{"32", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}], "-", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "5"], " ", 
    SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["c", "0", "3"], " ", 
    SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "2"], "-", 
      SubscriptBox["Q", 
       RowBox[{"2", ",", "0"}]]}], ")"}]}]}], 
  RowBox[{
   SubsuperscriptBox["c", "0", "4"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SubsuperscriptBox["c", "0", "2"]}], "+", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188398504403*^9},
 CellLabel->
  "Out[417]=",ExpressionUUID->"b959a65b-bcd3-48dd-9113-4377079d8ff3"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883985200214`*^9},
 CellLabel->
  "Out[418]=",ExpressionUUID->"da5950b0-d71d-4650-8a09-1ed701a357fa"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "7"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
     SubsuperscriptBox["c", "0", "8"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     SubscriptBox["N", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"4", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "-", 
       RowBox[{"8", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"6", " ", "\[Alpha]", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"32", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "-", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{"32", " ", "\[Alpha]", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}], "-", 
    RowBox[{"32", " ", 
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     SubscriptBox["Q", 
      RowBox[{"2", ",", "2"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883985981216`*^9},
 CellLabel->
  "Out[419]=",ExpressionUUID->"66f26830-7cca-40a4-9109-dadc0d4052a5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188398613742*^9},
 CellLabel->
  "Out[420]=",ExpressionUUID->"a821c5ab-0d71-4967-a51f-3c35db8e0702"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883988793*^9},
 CellLabel->
  "Out[422]=",ExpressionUUID->"0e12db42-06c0-4fae-9de0-3861ef29f47e"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   SuperscriptBox["\[Alpha]", "2"], 
   SubsuperscriptBox["c", "0", "4"]], "-", 
  RowBox[{
   SuperscriptBox["\[Alpha]", "2"], " ", 
   SubsuperscriptBox["c", "0", "4"]}]}]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188398957382*^9},
 CellLabel->
  "Out[423]=",ExpressionUUID->"54ad1815-c380-4788-9f70-046129533cef"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883989730005`*^9},
 CellLabel->
  "Out[424]=",ExpressionUUID->"6cd26cab-51f3-4179-a9b9-95ff1447fda8"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    SuperscriptBox["\[Alpha]", "4"]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "2"]}], "+", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "4"], " ", 
    SubsuperscriptBox["c", "0", "4"]}], "-", 
   RowBox[{"3", " ", "\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "6"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      SuperscriptBox["\[Alpha]", "2"], "+", 
      SuperscriptBox["\[Alpha]", "4"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "8"]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", "+", 
      SuperscriptBox["\[Alpha]", "3"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "10"]}], "-", 
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3"}], "+", 
      SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
    SubsuperscriptBox["c", "0", "12"]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Alpha]", "3"], " ", 
    SubsuperscriptBox["c", "0", "14"]}]}], 
  RowBox[{"12", " ", 
   SubsuperscriptBox["c", "0", "7"]}]]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631883989886413`*^9},
 CellLabel->
  "Out[425]=",ExpressionUUID->"6d4881d4-8a23-4ec6-a057-a1b651477f99"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188399004263*^9},
 CellLabel->
  "Out[426]=",ExpressionUUID->"7c720f39-b822-45a1-8b9c-4631e1e3f8f2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"]}], "-", 
      SubsuperscriptBox["\[Omega]", 
       RowBox[{"-", "2"}], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SubsuperscriptBox["c", "0", "2"]}], "-", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[Omega]", 
       RowBox[{"-", "2"}], "2"]}], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
    RowBox[{"48", " ", 
     SubsuperscriptBox["c", "0", "16"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"11", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"8", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"4", "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"42", " ", 
              SubscriptBox["N", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"19", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"3", " ", 
              SubscriptBox["N", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"18", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"19", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"3", " ", 
              SubscriptBox["N", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "272"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"84", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"12", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"84", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{"96", " ", 
        SubscriptBox["N", 
         RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"64", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", 
      RowBox[{"-", "2"}], "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["c", "2"]}], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "48"}], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"25", "-", 
          RowBox[{"60", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"25", "-", 
          RowBox[{"60", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"59", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"6", " ", 
              SubscriptBox["N", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"32", " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["N", 
           RowBox[{"4", ",", "2"}]], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["c", "2"], "-", 
             SubscriptBox["Q", 
              RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"96", " ", 
        SubscriptBox["N", 
         RowBox[{"3", ",", "3"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"84", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", 
             RowBox[{"39", " ", 
              SubscriptBox["N", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "-", 
          RowBox[{"8", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["N", 
              RowBox[{"4", ",", "2"}]], "+", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["c", "2"], "-", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"21", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["N", 
              RowBox[{"4", ",", "2"}]], "+", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["c", "2"], "-", 
                SubscriptBox["Q", 
                 RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
              SubscriptBox["Q", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "-", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"12", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"12", " ", 
           SubscriptBox["N", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"39", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["N", 
                 RowBox[{"4", ",", "2"}]], "+", 
                RowBox[{"4", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SubscriptBox["c", "2"], "-", 
                   SubscriptBox["Q", 
                    RowBox[{"2", ",", "0"}]]}], ")"}], " ", 
                 SubscriptBox["Q", 
                  RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Omega]", 
           RowBox[{"-", "2"}], "2"], "+", 
          SubsuperscriptBox["\[Omega]", "2", "2"], "-", 
          RowBox[{"24", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"48", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"19", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"19", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"20", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"36", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["\[Omega]", "2", "2"], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "0"}]], "-", 
          RowBox[{"5", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "-", 
          RowBox[{"10", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "+", 
             RowBox[{"3", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
    "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "2", "2"], "-", 
             RowBox[{"24", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SubsuperscriptBox["\[Omega]", 
             RowBox[{"-", "2"}], "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[Omega]", "2", "2"], "-", 
             RowBox[{"24", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"36", "+", 
             RowBox[{"5", " ", 
              SubsuperscriptBox["\[Omega]", 
               RowBox[{"-", "2"}], "2"], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "3"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "1"}]]}], "+", 
             RowBox[{"9", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["Q", 
            RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"14", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"64", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"48", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"32", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"480", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "3"}]]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", 
         RowBox[{"-", "2"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"6", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"48", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"27", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "3"}]]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["Q", 
            RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "2"}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
             RowBox[{"32", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
          RowBox[{"32", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "7"}], " ", 
              SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
             RowBox[{"32", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
          RowBox[{"32", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"28", " ", 
        RowBox[{"(", 
         RowBox[{"16", "+", 
          RowBox[{"3", " ", 
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"16", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "-", 
             RowBox[{"6", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", 
            RowBox[{"-", "2"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "-", 
             RowBox[{"6", " ", 
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]]}], "+", 
             RowBox[{
              SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
              SubscriptBox["Q", 
               RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188400222603*^9},
 CellLabel->
  "Out[427]=",ExpressionUUID->"08f885f0-1b88-4f4f-ae04-488713aad577"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631884002538404`*^9},
 CellLabel->
  "Out[428]=",ExpressionUUID->"3b6ab1fb-24b9-4ca0-a48f-5a727549a623"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["c", "0", "7"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubsuperscriptBox["c", "0", "2"]}], "+", 
       SubsuperscriptBox["\[Omega]", "2", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"9", " ", 
       SubsuperscriptBox["c", "0", "2"]}], "-", 
      SubsuperscriptBox["\[Omega]", "3", "2"]}], ")"}]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"5", " ", 
     SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
     SubsuperscriptBox["\[Omega]", "3", "2"]}], "+", 
    RowBox[{"1728", " ", 
     SubsuperscriptBox["c", "0", "18"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "14"}], " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"416", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "105"}], "+", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["N", 
            RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "16"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"49", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}], "-", 
          RowBox[{"96", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"441", "+", 
          RowBox[{"424", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"64", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"315", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"196", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "14"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"459", "+", 
          RowBox[{"424", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"32", " ", 
        RowBox[{"(", 
         RowBox[{"45", "+", 
          RowBox[{"98", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"288", " ", 
           SubsuperscriptBox["N", 
            RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4464", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"7", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"15", "+", 
             RowBox[{"224", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "3"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
     SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "-", 
    RowBox[{"2304", " ", 
     SubsuperscriptBox["c", "0", "17"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "2"], "-", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "0"}]], "+", 
       SubscriptBox["Q", 
        RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2304"}], " ", 
        SubsuperscriptBox["c", "2", "2"]}], "+", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"441", "+", 
          RowBox[{"418", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "-", 
          RowBox[{"288", " ", 
           SubsuperscriptBox["N", 
            RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3204", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1161"}], "+", 
             RowBox[{"784", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"4608", " ", 
        SubscriptBox["c", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"32", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"414", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "13"}], "+", 
             RowBox[{"144", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{"72", " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["Q", 
              RowBox[{"2", ",", "0"}], "2"], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["c", "0", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"5472", "-", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"648", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"345", "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"513", "+", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["c", "2", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}], "-", 
          RowBox[{"32", " ", 
           SubscriptBox["c", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"97", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "0"}], "2"]}], "+", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["c", "0", "10"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"64", " ", 
        SubsuperscriptBox["c", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "927"}], "-", 
          RowBox[{"934", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"288", " ", 
           SubsuperscriptBox["N", 
            RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "-", 
       RowBox[{"128", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"522", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"107", "+", 
             RowBox[{"144", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{"72", " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["Q", 
              RowBox[{"2", ",", "0"}], "2"], "-", 
             RowBox[{"8", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "-", 
       RowBox[{"32", " ", 
        RowBox[{"(", 
         RowBox[{"135", "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"101", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "-", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["Q", 
                 RowBox[{"2", ",", "0"}], "2"], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["Q", 
                  RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["c", "0", "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "16"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"162", " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"36", " ", 
           SubsuperscriptBox["c", "2", "2"]}], "+", 
          RowBox[{
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "206"}], "+", 
             RowBox[{"72", " ", 
              SubsuperscriptBox["N", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{"72", " ", 
           SubscriptBox["c", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"9", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"35", " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "0"}], "2"]}], "-", 
             RowBox[{"32", " ", 
              SubsuperscriptBox["Q", 
               RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"459", "+", 
          RowBox[{"32", " ", 
           SubsuperscriptBox["c", "2", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}], "-", 
          RowBox[{"64", " ", 
           SubscriptBox["c", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "-", 
          RowBox[{"16", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["N", 
              RowBox[{"2", ",", "2"}]], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["Q", 
                 RowBox[{"2", ",", "0"}], "2"], "+", 
                RowBox[{"8", " ", 
                 SubsuperscriptBox["Q", 
                  RowBox[{"2", ",", "2"}], "2"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"32", " ", 
     SubsuperscriptBox["c", "0", "15"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"117", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "-", 
       RowBox[{"9", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"13", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]]}], ")"}]}], "+", 
       RowBox[{"72", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          SubscriptBox["Q", 
           RowBox[{"3", ",", "1"}]]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "5"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
          RowBox[{"10", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"8", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}]}], ")"}]}], "-", 
       RowBox[{
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"4", " ", 
              SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
              SubscriptBox["N", 
               RowBox[{"2", ",", "2"}]]}]}], ")"}], " ", 
           SubscriptBox["Q", 
            RowBox[{"2", ",", "2"}]]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
           SubscriptBox["Q", 
            RowBox[{"3", ",", "1"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "13"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"288", " ", 
        SubscriptBox["c", "4"]}], "+", 
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "216"}], "+", 
          RowBox[{"90", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}], "+", 
          RowBox[{"26", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"216", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"90", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"26", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"576", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"9", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"160", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"288", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"832", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"288", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"288", " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["c", "0", "11"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"16", " ", 
        SubscriptBox["c", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "54"}], " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
          RowBox[{"12", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"108", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"24", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"10", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"41", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"576", " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"36", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"416", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"576", " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"63", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}], "-", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "9"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["c", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "96"}], "+", 
          RowBox[{"63", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"]}], "+", 
          RowBox[{"8", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "+", 
       RowBox[{"288", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"189", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"24", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"3168", " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"256", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"576", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"104", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"144", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"14", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"36", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["c", "0", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SubscriptBox["c", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"]}], "+", 
       RowBox[{
        SubscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"180", " ", 
           SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
          RowBox[{"32", " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}], "+", 
          RowBox[{"21", " ", 
           SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
           SubsuperscriptBox["\[Omega]", "3", "2"]}]}], ")"}]}], "-", 
       RowBox[{"180", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"32", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "-", 
       RowBox[{"21", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "0"}]]}], "+", 
       RowBox[{"720", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"160", " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"80", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "-", 
       RowBox[{"72", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"64", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["N", 
         RowBox[{"2", ",", "2"}]], " ", 
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]]}], "+", 
       RowBox[{"36", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "-", 
       RowBox[{"16", " ", 
        SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"3", ",", "1"}]]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Omega]", "2", "4"], " ", 
        SubsuperscriptBox["\[Omega]", "3", "2"], " ", 
        SubscriptBox["Q", 
         RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.8631884019095783`*^9},
 CellLabel->
  "Out[429]=",ExpressionUUID->"f9902262-b8bb-40e9-872a-06f4fb0a8fd4"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188401972041*^9},
 CellLabel->
  "Out[430]=",ExpressionUUID->"45b96e24-00df-4d8a-a5ec-cbb886172693"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188403114891*^9},
 CellLabel->
  "Out[431]=",ExpressionUUID->"f2c23f66-d9ba-468a-a5b5-5eda011f7728"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8593957604602065`*^9, {3.8610310697417293`*^9, 3.861031096376749*^9}, 
   3.86113569003969*^9, 3.8631883264897413`*^9, 3.863188404489472*^9},
 CellLabel->
  "Out[432]=",ExpressionUUID->"be79f23c-0ced-4991-ba88-be6537c95489"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1", ",", "v2"}]], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", "\[ImaginaryI]", "*", 
       SubscriptBox["U", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["S", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "2"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "1"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", 
              SubscriptBox["g", 
               RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["T", 
           RowBox[{"2", ",", "1"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["V", 
           RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["E", 
           RowBox[{"3", ",", "1"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{
          SubscriptBox["F", 
           RowBox[{"3", ",", "1"}]], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["G", 
           RowBox[{"3", ",", "1"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", 
              SubscriptBox["g", 
               RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["A", 
              RowBox[{"3", ",", "1"}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["C", 
              RowBox[{"3", ",", "1"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["D", 
              RowBox[{"3", ",", "1"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["G", 
           RowBox[{"4", ",", "1", ",", "0", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["J", 
           RowBox[{"4", ",", "1", ",", "0", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["E", 
           RowBox[{"3", ",", "1"}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{
          SubscriptBox["F", 
           RowBox[{"3", ",", "1"}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["D", 
           RowBox[{"4", ",", "1"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["A", 
              RowBox[{"4", ",", "1"}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            SubscriptBox["C", 
             RowBox[{"4", ",", "1"}]]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "4"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "3"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", 
              SubscriptBox["g", 
               RowBox[{"1", ",", "1"}]]]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["A", 
              RowBox[{"3", ",", "1"}]], "*", 
             SubscriptBox["\[Lambda]", "3"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["B", 
              RowBox[{"3", ",", "1"}]], "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "3"], "*", 
             SubscriptBox["I", 
              RowBox[{"4", ",", "1"}]]}], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["H", 
                 RowBox[{"4", ",", "1"}]], "*", 
                SubscriptBox["\[Lambda]", "2"]}], "+", 
               RowBox[{"\[ImaginaryI]", "*", 
                SubscriptBox["G", 
                 RowBox[{"4", ",", "1", ",", "0", ",", "1"}]]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SubscriptBox["E", 
           RowBox[{"4", ",", "1"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["J", 
           RowBox[{"4", ",", "1", ",", "0", ",", "1"}]]}], "+", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "/", 
           SubscriptBox["c", "0"]}], "*", 
          SuperscriptBox[
           SubscriptBox["\[Lambda]", "2"], "2"]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Factor", "[", 
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1"}]], "-", 
     SubscriptBox["cond", 
      RowBox[{"4", ",", "1", ",", "v2"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.859395799946981*^9, 3.859395822727108*^9}, {
  3.8631887248493133`*^9, 3.8631887260989065`*^9}},
 CellLabel->
  "In[433]:=",ExpressionUUID->"ba5d9d5b-5cbd-423e-aed8-af60fcd84b86"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8631887503297815`*^9},
 CellLabel->
  "Out[434]=",ExpressionUUID->"80850c10-176f-4a07-8c9e-08a7449945f8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Symbolically", " ", "represent", " ", "the", " ", "solvability",
     " ", 
    RowBox[{"conditions", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}], ",", "v2"}]], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"], "*", 
          SubscriptBox["symG", 
           RowBox[{"4", ",", 
            RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symJ", 
           RowBox[{"4", ",", 
            RowBox[{"-", "1"}], ",", "0", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symE", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["\[Lambda]", "3"]}], "+", 
          RowBox[{
           SubscriptBox["symF", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["r", "2"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{
           SubscriptBox["symD", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["symA", 
               RowBox[{"4", ",", 
                RowBox[{"-", "1"}]}]], "*", 
              SubscriptBox["\[Lambda]", "2"]}], "+", 
             SubscriptBox["symC", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[Lambda]", "4"], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["r", "3"], 
              SubscriptBox["\[Mu]", "1"], "*", 
              SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "*", 
              SubscriptBox["\[Lambda]", "3"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SubscriptBox["symB", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "*", 
              SubscriptBox["r", "2"], 
              SubscriptBox["\[Mu]", "1"]}], "+", 
             RowBox[{"\[ImaginaryI]", "*", 
              SuperscriptBox[
               SubscriptBox["\[Mu]", "1"], "3"], "*", 
              SubscriptBox["symI", 
               RowBox[{"4", ",", 
                RowBox[{"-", "1"}]}]]}], "+", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["symH", 
                  RowBox[{"4", ",", 
                   RowBox[{"-", "1"}]}]], "*", 
                 SubscriptBox["\[Lambda]", "2"]}], "+", 
                RowBox[{"\[ImaginaryI]", "*", 
                 SubscriptBox["symG", 
                  RowBox[{"4", ",", 
                   RowBox[{"-", "1"}], ",", "0", ",", 
                   RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["\[Lambda]", "2"], "*", 
           SubscriptBox["symE", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symJ", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}], ",", "0", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          RowBox[{
           FractionBox["\[ImaginaryI]", 
            SubscriptBox["c", "0"]], 
           SuperscriptBox[
            SubscriptBox["\[Lambda]", "2"], "2"]}]}], ")"}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symA", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symD", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "*", 
           SubscriptBox["symE", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{
           SubscriptBox["symF", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          RowBox[{
           SubscriptBox["symG", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "*", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", "*", 
       SubscriptBox["symU", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symT", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symU", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}], "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"4", ",", "0", ",", "v2"}]], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", "\[ImaginaryI]", "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]], "*", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "*", "\[ImaginaryI]", "*", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symC", 
           RowBox[{"3", ",", "0"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", "0"}]], "*", 
         SubscriptBox["\[Lambda]", "2"], "*", 
         SubscriptBox["\[Mu]", "1"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "-", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symC", 
           RowBox[{"3", ",", "0"}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symB", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symD", 
              RowBox[{"4", ",", "0"}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symF", 
              RowBox[{"4", ",", "0"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"], "*", 
             SubscriptBox["symG", 
              RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symD", 
              RowBox[{"3", ",", "0"}]], "*", 
             SubscriptBox["\[Lambda]", "3"]}], "+", 
            RowBox[{
             SubscriptBox["symE", 
              RowBox[{"3", ",", "0"}]], "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            RowBox[{
             SubscriptBox["symH", 
              RowBox[{"4", ",", "0"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
            RowBox[{
             SubscriptBox["symC", 
              RowBox[{"4", ",", "0"}]], "*", 
             SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "-", 
         SuperscriptBox[
          SubscriptBox["\[Lambda]", "2"], "2"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["symB", 
           RowBox[{"3", ",", "0"}]], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["symD", 
               RowBox[{"4", ",", "0"}]]}], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symF", 
              RowBox[{"4", ",", "0"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"], "*", 
             SubscriptBox["symG", 
              RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["symcond", 
      RowBox[{"4", ",", "1", ",", "v2"}]], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "*", "\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{"-", 
         SubscriptBox["symU", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]], "*", 
       SubscriptBox["\[Mu]", "1"], "*", 
       RowBox[{"(", 
        RowBox[{"-", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "2"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "1"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symU", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symF", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          SubscriptBox["symG", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "3"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]]}], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symD", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symG", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symJ", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}], ",", "0", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["\[Lambda]", "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symF", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SubscriptBox["r", "2"], 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symD", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}], "*", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "3"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["symA", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]], "*", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"(", 
             RowBox[{"-", 
              SubscriptBox["symC", 
               RowBox[{"4", ",", 
                RowBox[{"-", "1"}]}]]}], ")"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[Lambda]", "4"], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "3"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]]}], "*", 
             SubscriptBox["\[Lambda]", "3"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             RowBox[{"(", 
              RowBox[{"-", 
               SubscriptBox["symB", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]]}], ")"}], "*", 
             SubscriptBox["r", "2"], 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            RowBox[{"\[ImaginaryI]", "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "3"], "*", 
             RowBox[{"(", 
              RowBox[{"-", 
               SubscriptBox["symI", 
                RowBox[{"4", ",", 
                 RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symH", 
                 RowBox[{"4", ",", 
                  RowBox[{"-", "1"}]}]], "*", 
                SubscriptBox["\[Lambda]", "2"]}], "+", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"(", 
                 RowBox[{"-", 
                  SubscriptBox["symG", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          SubscriptBox["symE", 
           RowBox[{"4", ",", 
            RowBox[{"-", "1"}]}]], "*", 
          SubscriptBox["\[Lambda]", "2"]}], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          RowBox[{"(", 
           RowBox[{"-", 
            SubscriptBox["symJ", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}], ",", "0", ",", 
              RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", "/", 
           SubscriptBox["c", "0"]}], "*", 
          SuperscriptBox[
           SubscriptBox["\[Lambda]", "2"], "2"]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8589028610668297`*^9, {3.8589460216000996`*^9, 3.858946128933428*^9}, 
   3.8589461756380243`*^9, {3.8589462287283707`*^9, 3.8589463354121637`*^9}, {
   3.858946546820014*^9, 3.8589467128521647`*^9}, {3.8589492856374416`*^9, 
   3.8589494384528055`*^9}, {3.858949472720422*^9, 3.858949693831635*^9}, 
   3.85894982500641*^9, {3.8589500711384687`*^9, 3.858950071544589*^9}, 
   3.858951567310608*^9, 3.8589518464080687`*^9, {3.8593894139188743`*^9, 
   3.859389413950759*^9}, {3.8593918025534096`*^9, 3.859391802647129*^9}, {
   3.8593943701337547`*^9, 3.859394370149359*^9}, {3.8631887576582747`*^9, 
   3.8631887733809505`*^9}},
 CellLabel->
  "In[435]:=",ExpressionUUID->"16cde742-a8c1-47ae-8cba-e0c7ab5daca6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Solve", " ", "for", " ", 
    SubscriptBox["\[Lambda]", "4"], " ", "and", " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"2", ",", 
      RowBox[{"+", 
       RowBox[{"/", 
        RowBox[{"-", "1"}]}]}]}]]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["symLambdaBeta", "4"], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Refine", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"Refine", "[", 
             RowBox[{
              RowBox[{"Simplify", "[", 
               RowBox[{"Refine", "[", 
                RowBox[{
                 RowBox[{"Simplify", "[", 
                  RowBox[{
                   RowBox[{"Refine", "[", 
                    RowBox[{
                    RowBox[{"Simplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Solve", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "v2"}]], "==", "0"}], " ", "&&", 
                    "\[IndentingNewLine]", " ", 
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"4", ",", "0", ",", "v2"}]], "==", "0"}], " ", "&&",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    SubscriptBox["symcond", 
                    RowBox[{"4", ",", "1", ",", "v2"}]], "==", "0"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "4"], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"2", ",", "1"}]]}], "}"}]}], "]"}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symV", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "3"], "->", 
                    SubscriptBox["symLambda3", "v2"]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]], "->", "symBeta1neg1"}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]], "->", "symBeta1pos1"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "2"], "->", "symLambda2"}]}], 
                    " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "->", "symBeta0neg1"}]}], " ", "//.",
                     " ", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]], "->", "symBeta0pos1"}]}], "]"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]], ">", "0"}], ",", 
                    RowBox[{
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], ">", "0"}], ",", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "}"}]}], "]"}], 
                   " ", "//.", 
                   RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], "]"}], ",", 
                 RowBox[{
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], ">", "0"}]}], "]"}], "]"}], ",", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], "<", "0"}]}], "]"}], "//.", " ", 
            RowBox[{
             SubscriptBox["symT", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", 
             RowBox[{
              SubscriptBox["e", "2"], "/", "4"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", 
               SubscriptBox["e", "BW"]}], "+", 
              RowBox[{
               SubscriptBox["e", "2"], " ", 
               SubsuperscriptBox["\[Mu]", "1", "2"]}]}], "<", "0"}], ",", 
            RowBox[{
             SubscriptBox["e", "2"], ">", "0"}]}], "}"}]}], "]"}], "//.", " ", 
        RowBox[{
         SubscriptBox["e", "BW"], "->", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            SubscriptBox["\[CapitalDelta]", "BW"], "2"], "/", 
           RowBox[{"(", 
            RowBox[{"8", "*", 
             SubscriptBox["e", "2"]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["e", "2"], "*", 
           RowBox[{
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "2"], "/", "8"}]}]}]}]}], "]"}], ",", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "BW"], ">", "0"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8590532613514843`*^9, 3.8590532676336517`*^9}, {
  3.8590533119839945`*^9, 3.8590534193485036`*^9}, {3.8593961165933127`*^9, 
  3.859396120842431*^9}, {3.8631848107384477`*^9, 3.863184828809632*^9}, {
  3.8631871340671844`*^9, 3.8631871340671844`*^9}, {3.8631887801633005`*^9, 
  3.863188806913576*^9}},
 CellLabel->"",ExpressionUUID->"1e8725b6-ec7d-4bdc-b0ee-57e04e768c04"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Lambda]", "4"], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"256", " ", 
         SubscriptBox["c", "0"], " ", 
         SubsuperscriptBox["e", "2", "2"], " ", 
         SubscriptBox["\[CapitalDelta]", "BW"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "4"]}]], 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["e", "2"], " ", 
           SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], "-", 
             RowBox[{
              SubsuperscriptBox["e", "2", "2"], " ", 
              SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["symT", 
            RowBox[{"2", ",", "0"}], "4"]}], "+", 
          RowBox[{
           SubscriptBox["c", "0"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubsuperscriptBox["\[CapitalDelta]", "BW", "4"], " ", 
              SubsuperscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}], "2"], " ", 
              SubsuperscriptBox["symT", 
               RowBox[{"2", ",", "0"}], "4"]}], "+", 
             RowBox[{
              SubsuperscriptBox["e", "2", "4"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], "2"]}], 
             "+", 
             RowBox[{"2", " ", 
              SubsuperscriptBox["e", "2", "2"], " ", 
              SubsuperscriptBox["symT", 
               RowBox[{"2", ",", "0"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"128", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"]}], "+", 
                RowBox[{"128", " ", "\[ImaginaryI]", " ", 
                 SubscriptBox["c", "g"], " ", 
                 SubscriptBox["r", "3"], " ", 
                 SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                 SubsuperscriptBox["symT", 
                  RowBox[{"2", ",", "0"}], "2"]}], "+", 
                RowBox[{
                 SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{"3", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{"3", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"]}], "+", 
                    RowBox[{"8", " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}]}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{"32", " ", 
              SubscriptBox["e", "2"], " ", 
              SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
              SubsuperscriptBox["symT", 
               RowBox[{"2", ",", "0"}], "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["symC", 
                  RowBox[{"3", ",", "0"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"4", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                   RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
                RowBox[{
                 SubscriptBox["symA", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["symT", 
                  RowBox[{"2", ",", "0"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                   RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                   SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "-", 
                   SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
               ")"}]}], "-", 
             RowBox[{"2", " ", 
              SubsuperscriptBox["e", "2", "3"], " ", 
              SubscriptBox["symT", 
               RowBox[{"2", ",", "0"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    SubsuperscriptBox["symD", 
                    RowBox[{"3", ",", "0"}], "2"]}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                   RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}]}], ")"}]}], "+", 
                RowBox[{"16", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
                   RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["c", "g"]}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"256", " ", 
         SubsuperscriptBox["e", "2", "3"], " ", 
         SubscriptBox["\[CapitalDelta]", "BW"], " ", 
         SubsuperscriptBox["symS", 
          RowBox[{"2", ",", "0"}], "3"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "3"]}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", 
           SubscriptBox["e", "2"], " ", 
           SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], "+", 
             RowBox[{
              SubsuperscriptBox["e", "2", "2"], " ", 
              SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
           SubsuperscriptBox["symS", 
            RowBox[{"2", ",", "0"}], "2"], " ", 
           SubsuperscriptBox["symT", 
            RowBox[{"2", ",", "0"}], "4"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "0"}]]}], 
          SubscriptBox["c", "0"]], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SubsuperscriptBox["\[CapitalDelta]", "BW", "2"]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["e", "2"], " ", 
             SubscriptBox["\[CapitalDelta]", "BW"], " ", 
             SubscriptBox["\[Mu]", "1"]}], "+", 
            FractionBox[
             RowBox[{"8", " ", 
              SubscriptBox["e", "2"], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}], 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]]}], ")"}], " ", 
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"16", " ", 
             SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]]}], "-", 
               RowBox[{
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "3"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["e", "2", "3"], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symA", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}], "-", 
               RowBox[{
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                  RowBox[{"2", " ", 
                   SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                  RowBox[{
                   SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["e", "2"], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"128", " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                  RowBox[{
                   SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "-", 
               RowBox[{"32", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SubsuperscriptBox["e", "2", "2"], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"16", " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"4", " ", 
                   SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                  RowBox[{
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"32", " ", 
                   SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                  RowBox[{
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{"32", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "-", 
                    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"], "+", 
                    RowBox[{
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", "0"}], "2"], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "-", 
                  RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                   SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "0"}]]}], "+", 
                  RowBox[{"32", " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], ")"}]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["\[CapitalDelta]", "BW", "4"], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "4"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "+", 
            RowBox[{
             SubsuperscriptBox["e", "2", "4"], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SubsuperscriptBox["symD", 
                 RowBox[{"3", ",", "0"}], "2"], " ", 
                SubsuperscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}], "2"], " ", 
                SubsuperscriptBox["symS", 
                 RowBox[{"2", ",", "0"}], "2"]}], "-", 
               RowBox[{"8", " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubsuperscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}], "2"], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["symT", 
                 RowBox[{"2", ",", "0"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", 
                   SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", "0"}], "2"], " ", 
                   SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}], "2"]}], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"]}], ")"}]}]}], 
              ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubsuperscriptBox["e", "2", "2"], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"128", " ", 
                SubsuperscriptBox["symC", 
                 RowBox[{"3", ",", "0"}], "2"], " ", 
                SubsuperscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}], "2"], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "+", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubsuperscriptBox["symT", 
                 RowBox[{"2", ",", "0"}], "2"], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "128"}], " ", 
                    SubsuperscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}],
                    " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "-", 
                  RowBox[{"64", " ", "\[ImaginaryI]", " ", 
                   SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                   SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["e", "2"], " ", 
             SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                  RowBox[{
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "-", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "0"}]]}], "-", 
               RowBox[{"32", " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "-", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SubsuperscriptBox["e", "2", "3"], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"64", " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubsuperscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}], "2"], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                  RowBox[{
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"16", " ", 
                   SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "-", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "-", 
                    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "0"}]]}], "-", 
                    RowBox[{"32", " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
                    ")"}]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]], " ", 
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], ",", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"128", " ", 
        SubsuperscriptBox["e", "2", "3"], " ", 
        SubscriptBox["\[CapitalDelta]", "BW"], " ", 
        SubsuperscriptBox["symS", 
         RowBox[{"2", ",", "0"}], "3"], " ", 
        SubsuperscriptBox["symT", 
         RowBox[{"2", ",", "0"}], "3"]}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SubscriptBox["e", "2"], " ", 
          SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], "+", 
            RowBox[{
             SubsuperscriptBox["e", "2", "2"], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
          SubsuperscriptBox["symS", 
           RowBox[{"2", ",", "0"}], "2"], " ", 
          SubsuperscriptBox["symT", 
           RowBox[{"2", ",", "0"}], "4"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "0"}]]}], 
         SubscriptBox["c", "0"]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[CapitalDelta]", "BW", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"32", " ", 
            SubsuperscriptBox["symC", 
             RowBox[{"3", ",", "0"}], "2"]}], "-", 
           RowBox[{"16", " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symC", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            SubsuperscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}], "2"], " ", 
            SubsuperscriptBox["symS", 
             RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "4"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["e", "2", "4"], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symD", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubsuperscriptBox["symS", 
             RowBox[{"2", ",", "0"}], "2"]}], "+", 
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], " ", 
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["symE", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", 
               SubscriptBox["\[CapitalDelta]", "BW"], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["symD", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symE", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "0"}]]}], "+", 
        RowBox[{
         SubsuperscriptBox["e", "2", "2"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "512"}], " ", 
            SubsuperscriptBox["symS", 
             RowBox[{"2", ",", "0"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symC", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{
                SubscriptBox["symG", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "-", 
           RowBox[{
            SubsuperscriptBox["\[CapitalDelta]", "BW", "4"], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              SubsuperscriptBox["symS", 
               RowBox[{"2", ",", "0"}], "2"], "+", 
              RowBox[{
               SubsuperscriptBox["symA", 
                RowBox[{"3", ",", "0"}], "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "+", 
           RowBox[{"256", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{
               SubscriptBox["symG", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["\[CapitalDelta]", "BW", "3"], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"4", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{"8", " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]]}], "+", 
                    RowBox[{"8", " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{"8", " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"16", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{"16", " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{"8", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
                    RowBox[{"16", " ", 
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"16", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "+", 
                 RowBox[{"16", " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{"8", " ", 
         SubscriptBox["e", "2"], " ", 
         SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["symD", 
                 RowBox[{"4", ",", "0"}]]}], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]]}], "-", 
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
           RowBox[{"8", " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", 
               SubsuperscriptBox["symC", 
                RowBox[{"3", ",", "0"}], "2"], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"3", " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "-", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SubsuperscriptBox["e", "2", "3"], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            SubsuperscriptBox["\[CapitalDelta]", "BW", "3"], " ", 
            SubscriptBox["\[Mu]", "1"], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              SubsuperscriptBox["symS", 
               RowBox[{"2", ",", "0"}], "2"], "+", 
              RowBox[{
               SubsuperscriptBox["symA", 
                RowBox[{"3", ",", "0"}], "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]]}], "+", 
           RowBox[{"4", " ", 
            SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["symD", 
                RowBox[{"3", ",", "0"}], "2"], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubsuperscriptBox["symS", 
                RowBox[{"2", ",", "0"}], "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "-", 
              RowBox[{
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"], "+", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", "0"}], "2"], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "-", 
                 RowBox[{
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{"16", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[CapitalDelta]", "BW"], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "0"}]]}], "+", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "2"], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "0"}]]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               SubscriptBox["\[Beta]", 
                RowBox[{"1", ",", "0"}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]]}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "2"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]]}]}], ")"}], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}]}], ")"}], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"], " ", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"64", " ", 
            SubsuperscriptBox["symS", 
             RowBox[{"2", ",", "0"}], "2"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SubscriptBox["symC", 
                   RowBox[{"4", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symH", 
                   RowBox[{"4", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubsuperscriptBox["symS", 
                   RowBox[{"2", ",", "0"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["symF", 
                   RowBox[{"4", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"4", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubscriptBox["symC", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
                  SubscriptBox["symI", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["r", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["c", "g"]}], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "+", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 RowBox[{"2", " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "-", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"], " ", 
                  SubscriptBox["symJ", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.8631891749635315`*^9},
 CellLabel->
  "Out[438]=",ExpressionUUID->"07e9fb3b-336a-46bc-9d9c-40e611a92cf3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"symLambda4", " ", "=", " ", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        SubscriptBox["\[Lambda]", "4"], "//.", 
        SubscriptBox["symLambdaBeta", "4"]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"symLambda4Re", " ", "=", " ", 
    RowBox[{
     RowBox[{"ComplexExpand", "[", "symLambda4", "]"}], "//.", " ", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], "->", "0"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"4", ",", "R", ",", "1"}]], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"256", "*", 
        RowBox[{
         SuperscriptBox[
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]], "4"], "/", 
         SubscriptBox["\[Mu]", "1"]}], "*", "symLambda4Re"}], ",", 
       RowBox[{"1", "/", 
        SubscriptBox["\[CapitalDelta]", "BW"]}]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"4", ",", "R", ",", "2"}]], " ", "=", 
    RowBox[{"Expand", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"-", "256"}], "*", 
       SubscriptBox["c", "0"], "*", 
       SuperscriptBox[
        SubscriptBox["e", "2"], "2"], "*", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], "3"], "/", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}]}], "*", 
       RowBox[{"Simplify", "[", 
        RowBox[{"symLambda4Re", "-", 
         RowBox[{
          SubscriptBox["sym\[CapitalLambda]", 
           RowBox[{"4", ",", "R", ",", "1"}]], "*", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "/", 
           RowBox[{"(", 
            RowBox[{"256", "*", 
             SuperscriptBox[
              SubscriptBox["symT", 
               RowBox[{"2", ",", "0"}]], "4"], "*", 
             SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}]}]}]}], "]"}]}], 
      "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"symLambda4Re", " ", "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Mu]", "1"]}], "*", 
        RowBox[{
         SubscriptBox["\[CapitalDelta]", "BW"], "/", 
         RowBox[{"(", 
          RowBox[{"256", "*", 
           SubscriptBox["c", "0"], "*", 
           SuperscriptBox[
            SubscriptBox["e", "2"], "2"], "*", 
           SuperscriptBox[
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "3"]}], ")"}]}], "*", 
        SubscriptBox["sym\[CapitalLambda]", 
         RowBox[{"4", ",", "R", ",", "2"}]]}], "+", 
       RowBox[{
        SubscriptBox["sym\[CapitalLambda]", 
         RowBox[{"4", ",", "R", ",", "1"}]], "*", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "/", 
         RowBox[{"(", 
          RowBox[{"256", "*", 
           SuperscriptBox[
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "4"], "*", 
           SubscriptBox["\[CapitalDelta]", "BW"]}], ")"}]}]}]}], ")"}]}], 
    "]"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.859053542539136*^9, 3.8590535779071417`*^9}, {
   3.8593964283798723`*^9, 3.859396459353286*^9}, {3.859396519231553*^9, 
   3.859396523215294*^9}, {3.85939658577456*^9, 3.8593966062264166`*^9}, {
   3.8593967002414317`*^9, 3.8593967637767243`*^9}, {3.8593967943076153`*^9, 
   3.8593968572071047`*^9}, {3.859396984987549*^9, 3.859397006307578*^9}, {
   3.8610348547303734`*^9, 3.861034935787054*^9}, {3.861034972872772*^9, 
   3.8610352135930862`*^9}, {3.8610352454024224`*^9, 3.861035257966961*^9}, {
   3.861035293368187*^9, 3.8610356809397893`*^9}, {3.8610357195442724`*^9, 
   3.861035723845396*^9}, {3.861038536857624*^9, 3.861038607538746*^9}, {
   3.8610389376356764`*^9, 3.861038954153988*^9}, {3.863184829269307*^9, 
   3.863184829269307*^9}, {3.863187134793357*^9, 3.8631871348142033`*^9}, 
   3.863189203134162*^9, {3.8631893232170544`*^9, 3.863189369853815*^9}, {
   3.863189426632865*^9, 3.863189428148012*^9}, {3.8631899981977835`*^9, 
   3.8631900082631054`*^9}, {3.8631901436194696`*^9, 3.8631901661199803`*^9}, 
   3.8631902181034784`*^9},
 CellLabel->
  "In[479]:=",ExpressionUUID->"1a1278fe-33c9-42a0-98ee-d5a5fac63a54"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["\[CapitalDelta]", "BW", "3"], " ", 
     SubscriptBox["\[Mu]", "1"]}], 
    RowBox[{"256", " ", 
     SubscriptBox["c", "0"], " ", 
     SubscriptBox["e", "2"]}]]}], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"]}], 
   RowBox[{"256", " ", 
    SubscriptBox["c", "0"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["c", "g"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["e", "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["c", "g"], " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["\[CapitalDelta]", "BW", "3"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}], "2"]}], 
   RowBox[{"256", " ", 
    SubsuperscriptBox["e", "2", "2"]}]], "+", 
  RowBox[{
   FractionBox["3", "128"], " ", 
   SubscriptBox["\[CapitalDelta]", "BW"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
   SubsuperscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}], "2"]}], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
    SubsuperscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}], "2"]}], 
   RowBox[{"256", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["e", "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["e", "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["e", "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SubscriptBox["\[CapitalDelta]", "BW"], " ", 
   SubscriptBox["\[Mu]", "1"], " ", 
   SubscriptBox["symE", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]]}], "-", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SubscriptBox["\[CapitalDelta]", "BW"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
   SubscriptBox["symH", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]]}], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symI", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["e", "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
    SubscriptBox["symI", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symD", 
     RowBox[{"3", ",", "0"}], "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"]}], 
   RowBox[{"64", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "4"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symD", 
     RowBox[{"3", ",", "0"}], "2"], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"128", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "3"]}]], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "2"], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"32", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "3"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "2"], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "3"]}]], "+", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"]}], 
   RowBox[{"32", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "3"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "3"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"128", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"16", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symA", 
     RowBox[{"3", ",", "0"}], "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "2"]}], 
   RowBox[{"64", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symC", 
     RowBox[{"3", ",", "0"}], "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}], "2"]}], 
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"128", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"16", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"128", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"4", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["c", "g"], " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"64", " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"64", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"32", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symH", 
     RowBox[{"4", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}], "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"]}], 
   RowBox[{"64", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Mu]", "1"], " ", 
    SubsuperscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}], "2"], " ", 
    SubsuperscriptBox["symS", 
     RowBox[{"2", ",", "0"}], "2"]}], 
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"128", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"16", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"16", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["c", "g"], " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"64", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"64", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", "0"}]], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symD", 
     RowBox[{"4", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"16", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symF", 
     RowBox[{"4", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symG", 
     RowBox[{"4", ",", "0"}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"16", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symD", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["c", "g"], " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"64", " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubsuperscriptBox["e", "2", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"64", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symC", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symD", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symE", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["r", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symF", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symA", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symG", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], " ", 
    SubscriptBox["symS", 
     RowBox[{"2", ",", "0"}]]}], 
   RowBox[{"8", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["symT", 
     RowBox[{"2", ",", "0"}]]}]], "+", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symG", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["e", "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symG", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]", "BW"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symG", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["e", "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
    SubscriptBox["symG", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]], "-", 
  FractionBox[
   RowBox[{
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["symJ", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}]]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[CapitalDelta]", "BW"]}]]}]], "Output",
 CellChangeTimes->{
  3.863189206932681*^9, 3.8631894291164246`*^9, {3.8631901608555813`*^9, 
   3.8631901674320297`*^9}, 3.863190218759487*^9},
 CellLabel->
  "Out[480]=",ExpressionUUID->"bc7d835e-a9bf-4334-bd2e-a1428eb65218"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "256"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["symC", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["symG", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{
   SubsuperscriptBox["e", "2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SubscriptBox["symD", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["symE", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]]}], "+", 
         RowBox[{
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], "2"]}], "+", 
  RowBox[{"32", " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["symD", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["c", "g"], " ", 
            SubscriptBox["r", "2"]}], "+", 
           SubscriptBox["symC", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           RowBox[{
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["symD", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["symC", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SubscriptBox["symC", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symH", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symS", 
          RowBox[{"2", ",", "0"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symC", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["symF", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symG", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["symC", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symD", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symC", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symC", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
         SubscriptBox["symI", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}], "+", 
        RowBox[{
         SubscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            SubscriptBox["symE", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SubscriptBox["symB", 
                RowBox[{"3", ",", "0"}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "+", 
              RowBox[{"2", " ", 
               SubscriptBox["symF", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}], "-", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symB", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]]}], "+", 
              RowBox[{
               SubscriptBox["c", "g"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{"2", " ", 
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["symG", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["symG", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "-", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["symJ", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.863189206932681*^9, 3.8631894291164246`*^9, {3.8631901608555813`*^9, 
   3.8631901674320297`*^9}, 3.8631902195717473`*^9},
 CellLabel->
  "Out[481]=",ExpressionUUID->"7a3df315-26c7-433a-8fdd-cded8a2c6803"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "3"], " ", 
   SubsuperscriptBox["symD", 
    RowBox[{"3", ",", "0"}], "2"], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]]}], "+", 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "3"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symD", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "-", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symC", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symD", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "3"], " ", 
   SubscriptBox["symD", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symE", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "-", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symD", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symG", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "3"], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symD", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]]}], "-", 
  RowBox[{"2", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "3"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symE", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "+", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symC", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symE", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symG", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "+", 
  RowBox[{"128", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symC", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symG", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "+", 
  RowBox[{"12", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{"32", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symC", 
    RowBox[{"3", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symD", 
    RowBox[{"4", ",", "0"}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "+", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{"12", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symE", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{"32", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symG", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symS", 
    RowBox[{"2", ",", "0"}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "+", 
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "-", 
  RowBox[{
   SubsuperscriptBox["e", "2", "3"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{"64", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["c", "g"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["r", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
   SubsuperscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}], "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "-", 
  RowBox[{"6", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
   SubsuperscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}], "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "-", 
  RowBox[{"64", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["r", "2"], " ", 
   SubscriptBox["symB", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{"32", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symC", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{"32", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
   SubscriptBox["symA", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubscriptBox["symD", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubscriptBox["symE", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{"16", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "2"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
   SubscriptBox["symH", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "-", 
  RowBox[{"64", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
   SubscriptBox["symI", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "-", 
  RowBox[{"64", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"], " ", 
   SubscriptBox["symG", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", 
     RowBox[{"-", "1"}]}]]}], "+", 
  RowBox[{"64", " ", 
   SubscriptBox["c", "0"], " ", 
   SubscriptBox["e", "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"], " ", 
   SubscriptBox["symG", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}]], "Output",
 CellChangeTimes->{
  3.863189206932681*^9, 3.8631894291164246`*^9, {3.8631901608555813`*^9, 
   3.8631901674320297`*^9}, 3.863190220415206*^9},
 CellLabel->
  "Out[482]=",ExpressionUUID->"7bf5152d-688a-4f1c-b97c-fad8dd466994"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.863189206932681*^9, 3.8631894291164246`*^9, {3.8631901608555813`*^9, 
   3.8631901674320297`*^9}, 3.86319022051064*^9},
 CellLabel->
  "Out[483]=",ExpressionUUID->"6f05c78a-eab8-4f44-9770-14ceb3fbacbe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Coefficient", "[", 
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "1"}]], ",", 
                    SubscriptBox["r", "2"]}], "]"}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", "0"}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                   RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                  RowBox[{
                   SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["C", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", 
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["D", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symE", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["E", 
                  RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], "->", " ", 
                SubscriptBox["S", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["symT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["T", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symU", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["U", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], "->", " ", 
             SubscriptBox["S", 
              RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["T", 
             RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
          RowBox[{
           SubscriptBox["N", 
            RowBox[{"2", ",", "2"}]], "->", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"5", "*", 
               RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
              RowBox[{"Cosh", "[", 
               RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"16", "*", 
              RowBox[{
               RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
             ")"}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "g"], "->", 
       SubscriptBox["c", 
        SubscriptBox["g", 
         RowBox[{"1", ",", "1"}]]]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "0"], "->", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["sym\[CapitalLambda]", 
     RowBox[{"4", ",", "R", ",", "1", ",", "1"}]], "=", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          SubscriptBox["sym\[CapitalLambda]", 
           RowBox[{"4", ",", "R", ",", "1"}]], ",", 
          SubscriptBox["r", "2"]}], "]"}], ",", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}], "*", 
     SuperscriptBox[
      SubscriptBox["\[Mu]", "1"], "2"]}]}]}]}]], "Input",
 CellChangeTimes->{{3.8610359663032446`*^9, 3.8610359840261283`*^9}, {
  3.861037207383108*^9, 3.8610372704748335`*^9}, {3.8610373146161165`*^9, 
  3.861037318445996*^9}, {3.861038621775931*^9, 3.861038711790286*^9}, {
  3.8610387419733143`*^9, 3.861038750083642*^9}, {3.8610389608006496`*^9, 
  3.861038969366026*^9}, {3.861050228720473*^9, 3.861050232682371*^9}, {
  3.8631848107852902`*^9, 3.863184829331786*^9}, {3.863190247350499*^9, 
  3.8631902652233396`*^9}},
 CellLabel->
  "In[485]:=",ExpressionUUID->"7301fd50-7351-409a-88be-e0e339e927f9"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8610359680995064`*^9, 3.8610359844945602`*^9}, {
   3.8610372540183897`*^9, 3.861037270756017*^9}, 3.8610373187740107`*^9, {
   3.8610386965617056`*^9, 3.861038712305745*^9}, 3.8610387567592845`*^9, {
   3.861038965708129*^9, 3.861038970147043*^9}, 3.8610502349403553`*^9, 
   3.8611359086798115`*^9, 3.863190266382107*^9},
 CellLabel->
  "Out[485]=",ExpressionUUID->"a0fe0110-5a2b-45ca-96bb-1c4ad0da1200"],

Cell[BoxData[
 RowBox[{"64", " ", 
  SubscriptBox["e", "2"], " ", 
  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "g"], " ", 
     SubscriptBox["symA", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], ")"}], " ", 
  SubsuperscriptBox["symT", 
   RowBox[{"2", ",", "0"}], "4"]}]], "Output",
 CellChangeTimes->{{3.8610359680995064`*^9, 3.8610359844945602`*^9}, {
   3.8610372540183897`*^9, 3.861037270756017*^9}, 3.8610373187740107`*^9, {
   3.8610386965617056`*^9, 3.861038712305745*^9}, 3.8610387567592845`*^9, {
   3.861038965708129*^9, 3.861038970147043*^9}, 3.8610502349403553`*^9, 
   3.8611359086798115`*^9, 3.8631902664601874`*^9},
 CellLabel->
  "Out[486]=",ExpressionUUID->"3aaef6b3-3213-42cb-b924-a166fd68d0c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["sym\[CapitalLambda]", 
      RowBox[{"3", ",", "R"}]], ",", 
     SuperscriptBox[
      SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861039248137151*^9, 3.8610392801859293`*^9}},
 CellLabel->
  "In[487]:=",ExpressionUUID->"c86181bb-aa79-48f2-b5dc-0cb1d8bbf578"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "g"], " ", 
     SubscriptBox["symA", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], ")"}], " ", 
  SubsuperscriptBox["symT", 
   RowBox[{"2", ",", "0"}], "2"]}]], "Output",
 CellChangeTimes->{{3.861039257277196*^9, 3.8610392805763617`*^9}, 
   3.86113590876698*^9, 3.8631902786642714`*^9},
 CellLabel->
  "Out[487]=",ExpressionUUID->"b28fa5c0-e0cf-428c-8cd2-ef1068858f4e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["sym\[CapitalLambda]", 
    RowBox[{"4", ",", "R", ",", "1", ",", "2"}]], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["sym\[CapitalLambda]", 
      RowBox[{"4", ",", "R", ",", "1"}]], "//.", 
     RowBox[{
      SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8610376637220106`*^9, 3.8610376846978025`*^9}, {
  3.8610384498868856`*^9, 3.8610384630449986`*^9}, {3.8610387538968935`*^9, 
  3.8610388000457788`*^9}, {3.861038978477948*^9, 3.86103898436838*^9}},
 CellLabel->
  "In[488]:=",ExpressionUUID->"a41513ca-85e9-4402-ac7a-9c7275d3966a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "256"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["symC", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["symG", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "2"]}], "-", 
  RowBox[{
   SubsuperscriptBox["e", "2", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SubscriptBox["symD", 
        RowBox[{"3", ",", "0"}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], " ", 
       SubscriptBox["symS", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", "0"}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["symE", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]]}], "+", 
         RowBox[{
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["symA", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], "2"]}], "+", 
  RowBox[{"32", " ", 
   SubscriptBox["e", "2"], " ", 
   SubscriptBox["symT", 
    RowBox[{"2", ",", "0"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubscriptBox["symD", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["symC", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], "+", 
           RowBox[{
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["symD", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["symC", 
       RowBox[{"3", ",", "0"}]], " ", 
      SubscriptBox["symS", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         SubscriptBox["symC", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symH", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symS", 
          RowBox[{"2", ",", "0"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["symF", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symG", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubscriptBox["symC", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symD", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symC", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symE", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symG", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symC", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}], "+", 
        RowBox[{
         SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
         SubscriptBox["symI", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["symA", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["symG", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["symC", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "+", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["symG", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["symG", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], "-", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"], " ", 
         SubscriptBox["symJ", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}], ",", "0", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.8631902909451113`*^9},
 CellLabel->
  "Out[488]=",ExpressionUUID->"91fdc96b-50d6-4b8d-a611-8ee30c28cc66"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "1"}]], "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "1", ",", "1"}]], "*", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "1", ",", "2"}]]}], ")"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                   RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                  RowBox[{
                   SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["C", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", 
                RowBox[{
                 SubscriptBox["symD", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["D", 
                  RowBox[{"3", ",", "0"}]]}]}], "//.", 
               RowBox[{
                SubscriptBox["symE", 
                 RowBox[{"3", ",", "0"}]], "->", " ", 
                SubscriptBox["E", 
                 RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["symS", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "->", " ", 
               SubscriptBox["S", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["symT", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["T", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symU", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", " ", 
             SubscriptBox["U", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], "->", " ", 
            SubscriptBox["S", 
             RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]], "->", " ", 
           SubscriptBox["T", 
            RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
         RowBox[{
          SubscriptBox["N", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", "*", 
              RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"16", "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
            ")"}]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["Q", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"32", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "2"], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"16", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["Q", 
        RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
     RowBox[{
      SubscriptBox["c", "g"], "->", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "//.", 
    RowBox[{
     SubscriptBox["c", "0"], "->", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.861050268188611*^9, 3.861050296880956*^9}, 
   3.8610503305021706`*^9, {3.8631848108063307`*^9, 3.86318482938371*^9}},
 CellLabel->
  "In[489]:=",ExpressionUUID->"08c7cb8f-93d3-44a7-8370-9b700c80dab4"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.861050298146002*^9, 3.8610503494407425`*^9, 
  3.8611359240746555`*^9, 3.8631903198812857`*^9},
 CellLabel->
  "Out[489]=",ExpressionUUID->"33e8c214-313c-42e7-8838-c2f0b1e7cc06"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["sym\[CapitalLambda]", 
   RowBox[{"4", ",", "R", ",", "2", ",", "1"}]], "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     SubscriptBox["sym\[CapitalLambda]", 
      RowBox[{"4", ",", "R", ",", "2"}]], ",", 
     SubscriptBox["r", "2"]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["sym\[CapitalLambda]", 
    RowBox[{"4", ",", "R", ",", "2", ",", "2"}]], " ", "=", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["sym\[CapitalLambda]", 
      RowBox[{"4", ",", "R", ",", "2"}]], "//.", " ", 
     RowBox[{
      SubscriptBox["r", "2"], "->", "0"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "2"}]], "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "2", ",", "1"}]], "*", 
                    SubscriptBox["r", "2"]}], "+", 
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "2", ",", "2"}]]}], ")"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], " ", "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                   RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                  RowBox[{
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                   SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", 
                 RowBox[{
                  SubscriptBox["symB", 
                   RowBox[{"3", ",", "0"}]], "->", " ", 
                  SubscriptBox["B", 
                   RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                RowBox[{
                 SubscriptBox["symC", 
                  RowBox[{"3", ",", "0"}]], "->", " ", 
                 SubscriptBox["C", 
                  RowBox[{"3", ",", "0"}]]}]}], "//.", 
               RowBox[{
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]], "->", " ", 
                SubscriptBox["D", 
                 RowBox[{"3", ",", "0"}]]}]}], "//.", 
              RowBox[{
               SubscriptBox["symE", 
                RowBox[{"3", ",", "0"}]], "->", " ", 
               SubscriptBox["E", 
                RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], "->", " ", 
              SubscriptBox["S", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["symT", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", " ", 
             SubscriptBox["T", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
           RowBox[{
            SubscriptBox["symU", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], "->", " ", 
            SubscriptBox["U", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], "->", " ", 
           SubscriptBox["S", 
            RowBox[{"2", ",", "0"}]]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]], "->", " ", 
          SubscriptBox["T", 
           RowBox[{"2", ",", "0"}]]}]}], " ", "//.", 
        RowBox[{
         SubscriptBox["N", 
          RowBox[{"2", ",", "2"}]], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
           ")"}]}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"2", ",", "2"}]], "->", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"2", "*", 
            RowBox[{"Cosh", "[", 
             RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
           RowBox[{"Cosh", "[", 
            RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"32", "*", 
           SubscriptBox["c", "0"], "*", 
           RowBox[{
            RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
           RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "2"], "->", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6", "+", 
          RowBox[{"2", "*", 
           RowBox[{"Cosh", "[", 
            RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
          RowBox[{"Cosh", "[", 
           RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"16", "*", 
          SubscriptBox["c", "0"], "*", 
          RowBox[{
           RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
          RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
     RowBox[{
      SubscriptBox["Q", 
       RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "*", 
         SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
    RowBox[{
     SubscriptBox["c", "g"], "->", 
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{"1", ",", "1"}]]]}]}], "//.", 
   RowBox[{
    SubscriptBox["c", "0"], "->", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.86103730939587*^9, {3.86103774830173*^9, 3.861037789203926*^9}, {
   3.8610378683851137`*^9, 3.8610378832347126`*^9}, {3.8610388207225337`*^9, 
   3.8610388524349947`*^9}, {3.861038992182642*^9, 3.861039003378764*^9}, {
   3.8610503826379857`*^9, 3.861050391583146*^9}, {3.8631848108376083`*^9, 
   3.8631848294149466`*^9}, 3.8631903200062447`*^9},
 CellLabel->
  "In[490]:=",ExpressionUUID->"313ef85e-64b3-43fc-b3d2-f04da46ee630"],

Cell[BoxData[
 RowBox[{"64", " ", 
  SubscriptBox["c", "0"], " ", 
  SubscriptBox["e", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "g"], " ", 
     SubscriptBox["symA", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    SubscriptBox["symB", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]]}], ")"}], " ", 
  SubsuperscriptBox["symT", 
   RowBox[{"2", ",", "0"}], "3"]}]], "Output",
 CellChangeTimes->{3.8631903218523684`*^9},
 CellLabel->
  "Out[490]=",ExpressionUUID->"6939e8a7-4eb7-4c8f-a836-cd1d3f398b64"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], "-", 
     RowBox[{
      SubsuperscriptBox["e", "2", "2"], " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
   SubsuperscriptBox["symT", 
    RowBox[{"2", ",", "0"}], "3"]}], "+", 
  RowBox[{
   SubscriptBox["c", "0"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[CapitalDelta]", "BW", "2"], " ", 
      SubsuperscriptBox["symA", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}], "2"], " ", 
      SubsuperscriptBox["symT", 
       RowBox[{"2", ",", "0"}], "3"]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["e", "2", "2"], " ", 
      SubscriptBox["symT", 
       RowBox[{"2", ",", "0"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["symG", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]]}], "-", 
              RowBox[{"3", " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symG", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"4", " ", 
               SubscriptBox["symD", 
                RowBox[{"4", ",", "0"}]]}]}], ")"}], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{"4", " ", 
            SubscriptBox["symA", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SubscriptBox["symC", 
                RowBox[{"3", ",", "0"}]]}], "+", 
              RowBox[{"3", " ", 
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symS", 
                RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SubscriptBox["symE", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           RowBox[{
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SubsuperscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}], "2"]}], "-", 
              RowBox[{"8", " ", 
               SubscriptBox["symH", 
                RowBox[{"4", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "2"]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["e", "2", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["symD", 
          RowBox[{"3", ",", "0"}], "2"], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         SubscriptBox["symD", 
          RowBox[{"3", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["symA", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            SubscriptBox["symA", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{"32", " ", 
      SubscriptBox["e", "2"], " ", 
      SubsuperscriptBox["symT", 
       RowBox[{"2", ",", "0"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["symC", 
          RowBox[{"3", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SubscriptBox["symG", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{
            SubscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SubscriptBox["symG", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]]}], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["symC", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], "+", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
            SubscriptBox["symT", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
            SubscriptBox["symI", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           SubscriptBox["symG", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}], ",", "0", ",", 
             RowBox[{"-", "1"}]}]], "-", 
           SubscriptBox["symG", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
       ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.863190324633215*^9},
 CellLabel->
  "Out[491]=",ExpressionUUID->"953caabe-0df4-4b81-8c14-afddada04450"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8631903267262983`*^9},
 CellLabel->
  "Out[492]=",ExpressionUUID->"ec2a68d1-d3c5-4c32-92ed-4bfd33e4df8c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Enforcing", " ", "the", " ", "regular", " ", "curve", " ", 
    "condition", " ", "to", " ", "determine", " ", 
    RowBox[{
     SubscriptBox["r", "2"], "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"symr2", " ", "=", " ", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["sym\[CapitalLambda]", 
         RowBox[{"4", ",", "R", ",", "1", ",", "2"}]], "//.", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "->", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"8", "*", 
           RowBox[{
            SubscriptBox["e", "BW"], "/", 
            SubscriptBox["e", "2"]}]}], "]"}]}]}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["sym\[CapitalLambda]", 
        RowBox[{"4", ",", "R", ",", "1", ",", "1"}]], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "->", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"8", "*", 
          RowBox[{
           SubscriptBox["e", "BW"], "/", 
           SubscriptBox["e", "2"]}]}], "]"}]}]}], ")"}]}], " ", 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8611361013599744`*^9, 3.861136106247325*^9}, 
   3.8611363318520107`*^9, 3.8611364281270933`*^9, {3.8611364717121363`*^9, 
   3.861136476559927*^9}, {3.8631848108532066`*^9, 3.86318482949796*^9}, {
   3.863190349722742*^9, 3.8631903631165895`*^9}},
 CellLabel->
  "In[494]:=",ExpressionUUID->"7a7f320d-c42c-4843-ad2b-c33e768dfcbc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "512"}], " ", 
     SubsuperscriptBox["e", "BW", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["symA", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["symD", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["symI", 
         RowBox[{"4", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
     SubsuperscriptBox["symT", 
      RowBox[{"2", ",", "0"}], "4"]}], "+", 
    RowBox[{
     SubsuperscriptBox["e", "2", "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["symD", 
          RowBox[{"3", ",", "0"}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symS", 
          RowBox[{"2", ",", "0"}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["symA", 
             RowBox[{"3", ",", "0"}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           RowBox[{
            SubscriptBox["symE", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
         SubscriptBox["symT", 
          RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"]}], "+", 
    RowBox[{"16", " ", 
     SubscriptBox["e", "2"], " ", 
     SubsuperscriptBox["symT", 
      RowBox[{"2", ",", "0"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SubsuperscriptBox["symC", 
         RowBox[{"3", ",", "0"}], "2"], " ", 
        SubsuperscriptBox["symS", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["symG", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}], "2"], " ", 
        SubsuperscriptBox["symS", 
         RowBox[{"2", ",", "0"}], "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["e", "BW", "2"], " ", 
        SubsuperscriptBox["symA", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}], "2"], " ", 
        SubsuperscriptBox["symT", 
         RowBox[{"2", ",", "0"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["symC", 
         RowBox[{"3", ",", "0"}]], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SubscriptBox["symG", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           SubscriptBox["e", "BW"], " ", 
           SubscriptBox["symA", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["e", "BW"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["symH", 
            RowBox[{"4", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["symD", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["symD", 
               RowBox[{"3", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["symA", 
                  RowBox[{"3", ",", "0"}]], " ", 
                 SubscriptBox["symS", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", "1"}]}]]}], "-", 
                RowBox[{
                 SubscriptBox["symE", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]], " ", 
                 SubscriptBox["symS", 
                  RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
              SubscriptBox["symT", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SubscriptBox["symG", 
               RowBox[{"4", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"4", " ", 
              SubscriptBox["symD", 
               RowBox[{"4", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}], "+", 
             RowBox[{
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["symG", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]], " ", 
                 SubscriptBox["symS", 
                  RowBox[{"2", ",", "0"}]]}], "-", 
                RowBox[{
                 SubscriptBox["symC", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]], " ", 
                 SubscriptBox["symT", 
                  RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SubscriptBox["symT", 
               RowBox[{"2", ",", "0"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                SubscriptBox["symG", 
                 RowBox[{"4", ",", 
                  RowBox[{"-", "1"}], ",", "0", ",", 
                  RowBox[{"-", "1"}]}]], "+", 
                SubscriptBox["symG", 
                 RowBox[{"4", ",", 
                  RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"8", " ", 
     SubsuperscriptBox["e", "2", "2"], " ", 
     SubscriptBox["symT", 
      RowBox[{"2", ",", "0"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["symD", 
         RowBox[{"3", ",", "0"}]], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", "0"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SubscriptBox["symG", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["e", "BW"], " ", 
              SubscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{"2", " ", 
              SubscriptBox["symC", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["symC", 
         RowBox[{"3", ",", "0"}]], " ", 
        SubscriptBox["symS", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["symD", 
            RowBox[{"3", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["symA", 
               RowBox[{"3", ",", "0"}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]]}], "-", 
             RowBox[{
              SubscriptBox["symE", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["symT", 
         RowBox[{"2", ",", "0"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["symC", 
            RowBox[{"4", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["symF", 
            RowBox[{"4", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{
           SubscriptBox["symA", 
            RowBox[{"3", ",", "0"}]], " ", 
           SubscriptBox["symS", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SubscriptBox["symG", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symS", 
               RowBox[{"2", ",", "0"}]]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SubscriptBox["e", "BW"], " ", 
                 SubscriptBox["symA", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]]}], "-", 
                RowBox[{"2", " ", 
                 SubscriptBox["symC", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
              SubscriptBox["symT", 
               RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
          RowBox[{
           SubscriptBox["symS", 
            RowBox[{"2", ",", "0"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SubscriptBox["symC", 
               RowBox[{"4", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              SubscriptBox["symT", 
               RowBox[{"2", ",", "0"}]]}], "-", 
             RowBox[{
              SubscriptBox["symE", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SubscriptBox["symG", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]], " ", 
                 SubscriptBox["symS", 
                  RowBox[{"2", ",", "0"}]]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                   RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                 SubscriptBox["symT", 
                  RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           SubsuperscriptBox["symT", 
            RowBox[{"2", ",", "0"}], "2"], " ", 
           SubscriptBox["symJ", 
            RowBox[{"4", ",", 
             RowBox[{"-", "1"}], ",", "0", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"128", " ", 
    SubscriptBox["e", "2"], " ", 
    SubscriptBox["e", "BW"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "g"], " ", 
       SubscriptBox["symA", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      SubscriptBox["symB", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]]}], ")"}], " ", 
    SubsuperscriptBox["symT", 
     RowBox[{"2", ",", "0"}], "4"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8631903469415264`*^9, 3.863190364241228*^9}},
 CellLabel->
  "Out[494]=",ExpressionUUID->"9563ba35-9709-416e-934c-d4ad7a5e6e3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", "Explicit", " ", "representation", " ", "of", " ", 
    RowBox[{
     SubscriptBox["r", "2"], "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  RowBox[{"Explr2", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "1", ",", "2"}]], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", " ", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "/", 
                    SubscriptBox["e", "2"]}]}], "]"}]}]}], ")"}]}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["sym\[CapitalLambda]", 
                    RowBox[{"4", ",", "R", ",", "1", ",", "1"}]], " ", "//.", 
                    " ", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"8", "*", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "/", 
                    SubscriptBox["e", "2"]}]}], "]"}]}]}], ")"}]}], " ", "//.",
                     " ", 
                    RowBox[{
                    SubscriptBox["e", "BW"], "->", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "*", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "/", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", "0"}]], " ", "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["S", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], "->", " ", 
                    SubscriptBox["S", 
                    RowBox[{"2", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symU", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                    SubscriptBox["U", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", "0"}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], "->", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["B", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["c", "g"], "->", " ", 
                    SubscriptBox["c", 
                    SubscriptBox["g", 
                    RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["F", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["C", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["J", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["e", "2"], "->", " ", 
                    RowBox[{"4", "*", 
                    SubscriptBox["T", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}]}]}], " ", "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["A", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], " ", "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["I", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", "0"}]], "->", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["H", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], "->", " ", 
                    SubscriptBox["G", 
                    RowBox[{"4", ",", "0"}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["E", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], "->", " ", 
                    SubscriptBox["D", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["c", "4"], "->", " ", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"2048", "*", 
                    SubscriptBox["c", "0"]}]], 
                    RowBox[{"(", 
                    RowBox[{"212", "+", 
                    RowBox[{"55", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"98", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"23", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"14", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"]}]}]}], "//.",
                    " ", 
                   RowBox[{
                    SubscriptBox["N", 
                    RowBox[{"4", ",", "4"}]], "->", " ", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", 
                    RowBox[{"(", 
                    RowBox[{"1536", "*", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    ")"}]}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"203", "+", 
                    RowBox[{"347", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"158", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"76", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"23", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "8"]}]}]}], "//.", 
                  RowBox[{
                   SubscriptBox["N", 
                    RowBox[{"4", ",", "2"}]], "->", " ", 
                   RowBox[{
                    FractionBox["1", "6144"], 
                    RowBox[{"(", 
                    RowBox[{"215", "-", 
                    RowBox[{"418", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"472", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"10", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"17", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "8"]}]}]}], "//.",
                  " ", 
                 RowBox[{
                  SubscriptBox["Q", 
                   RowBox[{"4", ",", "0"}]], "->", " ", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"512", "*", 
                    SubscriptBox["c", "0"], "*", 
                    SuperscriptBox[
                    RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "7"], "*", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.",
                 " ", 
                RowBox[{
                 SubscriptBox["Q", 
                  RowBox[{"4", ",", "2"}]], "->", " ", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"240", "+", 
                    RowBox[{"82", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"688", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"309", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"7", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], "*", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"4", "*", "6144", "*", 
                    SubscriptBox["c", "0"]}], ")"}]}], ")"}]}]}]}], "//.", 
               RowBox[{
                SubscriptBox["Q", 
                 RowBox[{"4", ",", "4"}]], "->", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "/", 
                   RowBox[{"(", 
                    RowBox[{"8", "*", "1536", "*", 
                    SubscriptBox["c", "0"], "*", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    ")"}]}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{"408", "+", 
                   RowBox[{"638", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"230", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"171", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"124", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"43", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"12", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "*", 
                 SuperscriptBox[
                  RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], "*", 
                 RowBox[{"Sech", "[", "\[Alpha]", "]"}]}]}]}], "//.", 
              RowBox[{
               SubscriptBox["N", 
                RowBox[{"3", ",", "3"}]], "->", " ", 
               RowBox[{"3", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"14", "+", 
                   RowBox[{"15", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"6", "*", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "*", "256", "*", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Sinh", "[", "\[Alpha]", "]"}], ")"}], "^", 
                    "6"}]}], ")"}]}]}]}]}], "//.", " ", 
             RowBox[{
              SubscriptBox["Q", 
               RowBox[{"3", ",", "3"}]], " ", "->", " ", 
              RowBox[{"3", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"26", "-", 
                  RowBox[{"3", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"10", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"3", "*", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"6", "*", "\[Alpha]"}], "]"}]}]}], ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"6", "*", "256", "*", 
                  SubscriptBox["c", "0"], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"Sinh", "[", "\[Alpha]", "]"}], ")"}], "^", 
                   "6"}]}], ")"}]}]}]}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["Q", 
              RowBox[{"3", ",", "1"}]], "->", " ", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cosh", "[", 
                  RowBox[{"2", "*", "\[Alpha]"}], "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{"2", "+", 
                   RowBox[{"Cosh", "[", 
                    RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], ")"}]}], ")"}]}],
               "/", 
              RowBox[{"(", 
               RowBox[{"2", "*", "16", "*", 
                SubscriptBox["c", "0"], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"Sinh", "[", "\[Alpha]", "]"}], ")"}], "^", "4"}]}],
                ")"}]}]}]}], "//.", 
           RowBox[{
            SubscriptBox["N", 
             RowBox[{"2", ",", "2"}]], "->", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"5", "*", 
                RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
               RowBox[{"Cosh", "[", 
                RowBox[{"3", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"16", "*", 
               RowBox[{
                RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}]}], 
              ")"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["Q", 
            RowBox[{"2", ",", "0"}]], " ", "->", " ", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox[
                SubscriptBox["c", "0"], "4"]}], ")"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"4", 
              SuperscriptBox[
               SubscriptBox["c", "0"], "3"]}], ")"}]}]}]}], " ", " ", "//.", 
         " ", 
         RowBox[{
          SubscriptBox["Q", 
           RowBox[{"2", ",", "2"}]], "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", "*", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"32", "*", 
             SubscriptBox["c", "0"], "*", 
             RowBox[{
              RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", 
        RowBox[{
         SubscriptBox["c", "2"], "->", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "+", 
            RowBox[{"2", "*", 
             RowBox[{"Cosh", "[", 
              RowBox[{"2", "*", "\[Alpha]"}], "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"4", "*", "\[Alpha]"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "*", 
            SubscriptBox["c", "0"], "*", 
            RowBox[{
             RowBox[{"Sinh", "[", "\[Alpha]", "]"}], "^", "3"}], "*", 
            RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], ")"}]}]}]}], "//.", " ", 
       RowBox[{
        SubscriptBox["Q", 
         RowBox[{"1", ",", "1"}]], " ", "\[Rule]", " ", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           SubscriptBox["c", "0"]}], ")"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "0"], " ", "->", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}], " ", "/.", " ", 
     RowBox[{
      SubscriptBox["\[Omega]", "j_"], ":>", " ", 
      RowBox[{"\[Omega]", "[", 
       RowBox[{"j", "+", 
        SubscriptBox["\[Mu]", "0"]}], "]"}]}]}], " ", "//.", " ", 
    RowBox[{
     SubscriptBox["c", "0"], "->", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.861034881703932*^9, 3.8610348832192583`*^9}, {
  3.8610523003907776`*^9, 3.8610523825527425`*^9}, {3.8610524128635073`*^9, 
  3.8610524450116167`*^9}, {3.8631848109840636`*^9, 3.863184829592609*^9}, {
  3.8631903756444035`*^9, 3.8631904086887984`*^9}},
 CellLabel->
  "In[497]:=",ExpressionUUID->"edf7fc16-c5e7-4adc-9c98-b004201f591b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Alpha]", "2"], "-", 
          RowBox[{
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
             RowBox[{"3", " ", "\[Alpha]", " ", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}]}]}], 
         ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox["\[Alpha]", 
                SqrtBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
               SqrtBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}]], "-", 
               RowBox[{"\[Alpha]", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"3", "/", "2"}]]}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Alpha]", "+", 
                RowBox[{"5", " ", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                RowBox[{"2", " ", "\[Alpha]", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
              "2"]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
              RowBox[{"5", "/", "2"}]]}]]}], "+", 
          RowBox[{
           FractionBox["1", "4"], " ", 
           RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Alpha]", "-", 
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Alpha]", "-", 
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               FractionBox["1", "2"]}], " ", 
              SuperscriptBox[
               RowBox[{"Coth", "[", "\[Alpha]", "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Alpha]", "+", 
                RowBox[{"5", " ", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                RowBox[{"2", " ", "\[Alpha]", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}]}], 
             "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"8", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"3", "/", "2"}]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Alpha]", "2"], "-", 
                RowBox[{
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                   RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "2"]}], "-", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
         RowBox[{"5", "/", "2"}]]], 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "-", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
          RowBox[{"2", " ", "\[Alpha]", " ", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SuperscriptBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "-", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
          RowBox[{"2", " ", "\[Alpha]", " ", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           SuperscriptBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Alpha]", "2"], "-", 
          RowBox[{
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"\[Alpha]", " ", 
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
             RowBox[{"3", " ", "\[Alpha]", " ", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}]}]}], 
         ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", 
            RowBox[{"32", " ", 
             SuperscriptBox[
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
              RowBox[{"7", "/", "2"}]]}]], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Alpha]", "+", 
              RowBox[{"5", " ", 
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
              RowBox[{"\[Alpha]", " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Alpha]", "2"], "+", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
              RowBox[{"2", " ", "\[Alpha]", " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
              RowBox[{
               SuperscriptBox["\[Alpha]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              FractionBox[
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["\[Alpha]", 
                   SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                  SqrtBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Alpha]", "+", 
                   RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                   RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                 "2"]}], 
               RowBox[{"8", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"5", "/", "2"}]]}]], "-", 
              RowBox[{
               FractionBox["1", "4"], " ", 
               RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Alpha]", "-", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
               " ", 
               RowBox[{"(", 
                RowBox[{"\[Alpha]", "-", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
               " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox["1", "2"]}], " ", 
                  SuperscriptBox[
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                  " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}]}],
                  "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"8", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                    FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Alpha]", "2"], "-", 
                    RowBox[{
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
              RowBox[{"5", "/", "2"}]]}]], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["\[Alpha]", 
               SqrtBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
              SqrtBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}]], "-", 
              RowBox[{"\[Alpha]", " ", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                RowBox[{"3", "/", "2"}]]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Alpha]", "+", 
               RowBox[{"5", " ", 
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
               RowBox[{"2", " ", "\[Alpha]", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
               SuperscriptBox[
                RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
               RowBox[{"\[Alpha]", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
             "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["1", 
                RowBox[{"32", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                  RowBox[{"7", "/", "2"}]]}]], 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], 
                 ")"}]}]}], "-", 
              RowBox[{
               FractionBox["1", "4"], " ", 
               RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Alpha]", "-", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
               " ", 
               RowBox[{"(", 
                RowBox[{"\[Alpha]", "-", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                 RowBox[{"\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
               " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "3"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                    FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Alpha]", "2"], "-", 
                    RowBox[{
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"]}], "+", 
                    RowBox[{"32", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"26", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"56", "+", 
                    RowBox[{"34", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"40", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"28", " ", "\[Alpha]"}], "+", 
                    RowBox[{"44", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"16", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "-", 
                    RowBox[{"10", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"88", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"52", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{"16", "-", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], "2"]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
          RowBox[{
           FractionBox["1", "4"], " ", 
           RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Alpha]", "-", 
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Alpha]", "-", 
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
             RowBox[{"2", " ", "\[Alpha]", " ", 
              RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"\[Alpha]", " ", 
              SuperscriptBox[
               RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", 
               RowBox[{"128", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"11", "/", "2"}]]}]], 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["\[Alpha]", "2"], "+", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                 RowBox[{"2", " ", "\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], 
                ")"}]}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Alpha]", "2"], " ", 
                RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Alpha]", "+", 
                   RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                   RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                 "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"]}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  RowBox[{"6", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[Alpha]", " ", 
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{"5", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{"3", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Alpha]", "2"], "-", 
                RowBox[{
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                   RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                  ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "3"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "3"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"6", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"]}], "-", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                   RowBox[{"Csch", "[", "\[Alpha]", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "3"]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    FractionBox["3", "8"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                   " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                   " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "4"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                   " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "+", 
                  RowBox[{
                   FractionBox["1", "4"], " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], "3"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                   " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                   " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   SuperscriptBox["\[Alpha]", "3"]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"3", " ", "\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"]}], "+", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "3"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"16", " ", 
                SqrtBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}]], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "3"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "3"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                   FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}], "2"]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], "-", 
                   RowBox[{
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}], "2"]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"32", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "4"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "3"], " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "4"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                  RowBox[{"3", " ", "\[Alpha]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["\[Alpha]", "2"], "-", 
                    SuperscriptBox["\[Alpha]", "4"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "+", 
                  RowBox[{"3", " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    SuperscriptBox["\[Alpha]", "3"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}], "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["\[Alpha]", "3"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"]}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                   FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}], "2"]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"3", " ", 
                SqrtBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Alpha]", "2"], "-", 
                   RowBox[{
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}], "2"]}], ")"}]}], "-", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"32", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"11", "/", "2"}]]}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["\[Alpha]", "2"], "+", 
                 RowBox[{"6", " ", "\[Alpha]", " ", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                 RowBox[{"3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                 RowBox[{"12", " ", "\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "+", 
                 RowBox[{"6", " ", "\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}], "+", 
                 RowBox[{"8", " ", "\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                   RowBox[{"5", "/", "2"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                 RowBox[{"8", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                   RowBox[{"7", "/", "2"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                 RowBox[{"8", " ", "\[Alpha]", " ", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                   RowBox[{"9", "/", "2"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}]}], ")"}]}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], " ",
                 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"]}], "+", 
                  RowBox[{"32", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"4", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                  RowBox[{"8", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"16", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                   RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"26", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"56", "+", 
                    RowBox[{"34", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"40", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"28", " ", "\[Alpha]"}], "+", 
                    RowBox[{"44", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"16", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "-", 
                  RowBox[{"10", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"88", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"52", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                   RowBox[{"(", 
                    RowBox[{"16", "-", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"32", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"11", "/", "2"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], "2"]}], 
               ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"8", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"]}], "+", 
                  RowBox[{"32", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"4", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                  RowBox[{"8", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"16", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                   RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"26", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"56", "+", 
                    RowBox[{"34", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"40", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"28", " ", "\[Alpha]"}], "+", 
                    RowBox[{"44", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"16", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "-", 
                  RowBox[{"10", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"88", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"52", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                   RowBox[{"(", 
                    RowBox[{"16", "-", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], "2"]}], 
               ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"32", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"13", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "-", 
                  RowBox[{"6", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"8", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                  RowBox[{"4", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                   RowBox[{"(", 
                    RowBox[{"7", "+", 
                    RowBox[{
                    FractionBox["3", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9"}], "-", 
                    RowBox[{
                    FractionBox["1", "4"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{"15", "-", 
                    RowBox[{
                    FractionBox["1", "2"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"10", " ", "\[Alpha]"}], "+", 
                    RowBox[{
                    FractionBox["23", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                   RowBox[{"(", 
                    RowBox[{"44", "-", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"19", " ", "\[Alpha]"}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"51", "-", 
                    RowBox[{
                    FractionBox["7", "2"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "12"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9"}], "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"40", " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}]}],
                     "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "29"}], "+", 
                    RowBox[{
                    FractionBox["25", "4"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", "\[Alpha]"}], "-", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "-", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "-", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "\[Alpha]"}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", "\[Alpha]"}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"12", "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "-", 
                    FractionBox[
                    RowBox[{"5", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"20", "+", 
                    RowBox[{"6", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}]}], 
                 ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"64", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]]}], "-", 
                  RowBox[{"32", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
               ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                  SuperscriptBox[
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"32", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"13", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "-", 
                  RowBox[{"6", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"8", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                  RowBox[{"4", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                   RowBox[{"(", 
                    RowBox[{"7", "+", 
                    RowBox[{
                    FractionBox["3", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9"}], "-", 
                    RowBox[{
                    FractionBox["1", "4"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{"15", "-", 
                    RowBox[{
                    FractionBox["1", "2"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"10", " ", "\[Alpha]"}], "+", 
                    RowBox[{
                    FractionBox["23", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                   RowBox[{"(", 
                    RowBox[{"44", "-", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"19", " ", "\[Alpha]"}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"51", "-", 
                    RowBox[{
                    FractionBox["7", "2"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "12"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "9"}], "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"40", " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}]}],
                     "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "29"}], "+", 
                    RowBox[{
                    FractionBox["25", "4"], " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", " ", "\[Alpha]"}], "-", 
                    RowBox[{"4", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "6"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", "\[Alpha]"}], "-", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "-", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"20", "+", 
                    RowBox[{"6", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"20", "+", 
                    RowBox[{"6", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}]}], ")"}]}], ")"}], 
              "/", 
              RowBox[{"(", 
               RowBox[{"4", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"5", "/", "2"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"64", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                  RowBox[{"32", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
               ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{"\[Alpha]", "-", 
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                  RowBox[{"2", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                  RowBox[{"\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                   RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                   " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                  FractionBox[
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                   RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"128", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "11"]}], "-", 
                  RowBox[{"1024", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"17", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "-", 
                  RowBox[{"80", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}], "+", 
                  RowBox[{"128", " ", 
                   SuperscriptBox["\[Alpha]", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}], "-", 
                  RowBox[{"384", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"64", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"12", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"12", " ", "\[Alpha]", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", "\[Alpha]"}], "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"384", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"13", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"256", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"15", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"6", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"4", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "10"], " ", 
                   RowBox[{"(", 
                    RowBox[{"64", "+", 
                    RowBox[{"78", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "9"], " ", 
                   RowBox[{"(", 
                    RowBox[{"128", "+", 
                    RowBox[{"640", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], "+", 
                    RowBox[{"912", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"324", " ", 
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"360", "-", 
                    RowBox[{"1128", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], "-", 
                    RowBox[{"1188", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "17"}], "+", 
                    RowBox[{"107", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{"16", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"64", " ", "\[Alpha]"}], "+", 
                    RowBox[{"96", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"8", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"64", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], "+", 
                    RowBox[{"1104", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"(", 
                    RowBox[{"45", "+", 
                    RowBox[{"64", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "-", 
                    RowBox[{"304", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{"16", " ", "\[Alpha]", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "64"}], "+", 
                    RowBox[{"48", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "32"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"7", "+", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], "-", 
                    RowBox[{"552", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "31"}], "+", 
                    RowBox[{"61", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"512", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"704", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], "+", 
                    RowBox[{"912", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"84", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"24", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"816", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"1152", " ", "\[Alpha]"}], "+", 
                    RowBox[{"24", " ", 
                    RowBox[{"(", 
                    RowBox[{"19", "+", 
                    RowBox[{"92", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2184", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"40", " ", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"21", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"456", " ", 
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"24", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"61", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "3"]}]}], ")"}]}], 
                  "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"896", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"300", "+", 
                    RowBox[{"48", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "54"}], "+", 
                    RowBox[{"106", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"4", " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Alpha]", "2"], "-", 
                  RowBox[{
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"4", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                   RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], "3"]}], 
               ")"}]}], "+", 
             RowBox[{
              FractionBox["1", "4"], " ", 
              SuperscriptBox[
               RowBox[{"Coth", "[", "\[Alpha]", "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Alpha]", "+", 
                RowBox[{"5", " ", 
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                RowBox[{"2", " ", "\[Alpha]", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                RowBox[{"\[Alpha]", " ", 
                 SuperscriptBox[
                  RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox["1", 
                  RowBox[{"32", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]]}]], 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                  " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["\[Alpha]", "2"], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "+", 
                    RowBox[{
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], 
                   ")"}]}]}], "-", 
                RowBox[{
                 FractionBox["1", "4"], " ", 
                 RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Alpha]", "-", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                   RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Alpha]", "-", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                   RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "3"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    SuperscriptBox["\[Alpha]", "2"]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["\[Alpha]", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "16"]}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
                    RowBox[{
                    FractionBox["3", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}], "+", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
                    FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"5", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], 
                    "2"], 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["\[Alpha]", "2"], "-", 
                    RowBox[{
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "\[Alpha]"}], "+", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                    RowBox[{"3", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}], ")"}]}], "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"]}], "+", 
                    RowBox[{"32", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"8", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"8", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                    RowBox[{"16", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"(", 
                    RowBox[{"8", "+", 
                    RowBox[{"26", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"56", "+", 
                    RowBox[{"34", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"40", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"28", " ", "\[Alpha]"}], "+", 
                    RowBox[{"44", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"16", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "-", 
                    RowBox[{"10", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "\[Alpha]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "16"}], " ", "\[Alpha]"}], "-", 
                    RowBox[{"88", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"52", " ", "\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                    RowBox[{"(", 
                    RowBox[{"16", "-", 
                    RowBox[{"10", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Alpha]", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], "2"]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Alpha]", "-", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
                   RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                 "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Alpha]", "-", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
                   RowBox[{"2", " ", "\[Alpha]", " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"\[Alpha]", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], 
                 "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2304", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"17", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}]}], "-", 
                  RowBox[{"1728", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "9"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"60", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], "-", 
                  RowBox[{"192", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"36", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "8"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"36", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "35"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"294", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"64", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{
                    FractionBox["49", "64"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}]}],
                     "+", 
                    RowBox[{"636", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"1764", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "7"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"32", " ", 
                    RowBox[{"(", 
                    RowBox[{"5", "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}]}],
                     "-", 
                    RowBox[{"248", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"612", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"49", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "-", 
                    RowBox[{"14", " ", 
                    RowBox[{"(", 
                    RowBox[{"15", "+", 
                    RowBox[{
                    FractionBox["7", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{
                    FractionBox["159", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "6"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{"72", " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    "-", 
                    RowBox[{"36", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "23"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "-", 
                    RowBox[{"64", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "128"]}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    SuperscriptBox[
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    "2"]}]}], ")"}]}], "-", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "49"}], "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{
                    FractionBox["89", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "416"}], "+", 
                    RowBox[{"18", " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}], "-", 
                    RowBox[{"836", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{"1161", "-", 
                    RowBox[{
                    FractionBox["49", "16"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"144", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"416", "+", 
                    RowBox[{"8", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "105"}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"4", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "18"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"102", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["35", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "-", 
                    RowBox[{
                    FractionBox["1", "32"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "64"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", 
                    SuperscriptBox[
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{"72", "-", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}], "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"16", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "128"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    SuperscriptBox[
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    "2"]}]}], ")"}]}]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "103"}], "+", 
                    RowBox[{
                    FractionBox["9", "64"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"608", "-", 
                    RowBox[{"36", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"228", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"345", "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["97", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{
                    FractionBox["1", "32"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "64"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "-", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", 
                    SuperscriptBox[
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    "2"]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "+", 
                  RowBox[{"32", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"5", "/", "2"}]], " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"30", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"5", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"8", "-", 
                    RowBox[{
                    FractionBox["1", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "5"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "480"}], "+", 
                    RowBox[{"32", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["29", "16"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["1", "128"]}], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    SuperscriptBox[
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    "2"]}]}], ")"}]}]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "103"}], "+", 
                    RowBox[{
                    FractionBox["1", "8"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "101"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], "+", 
                    RowBox[{"64", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FractionBox["1", "128"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "16"], " ", 
                    SuperscriptBox[
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    "2"]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"428", "+", 
                    RowBox[{
                    FractionBox["9", "4"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{
                    FractionBox["467", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "4"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], "2"], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], 
                    ")"}]}], "-", 
                  RowBox[{"32", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"15", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "9"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"13", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "+", 
                    FractionBox[
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], 
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]}]]}], ")"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"234", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"24", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "-", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"9", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"99", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"72", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"18", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"189", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "+", 
                    FractionBox[
                    RowBox[{"12", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"48", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"21", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"36", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{"39", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"512", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"212", "+", 
                    RowBox[{"55", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"98", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"23", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"14", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"36", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"48", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "96"}], "+", 
                    RowBox[{"252", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"48", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "+", 
                  RowBox[{"16", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"13", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"18", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"212", "+", 
                    RowBox[{"55", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"98", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"23", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"14", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"64", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"18", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"54", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"90", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"39", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"30", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "-", 
                    FractionBox[
                    RowBox[{"39", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "216"}], "+", 
                    RowBox[{"360", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], "+", 
                    RowBox[{"156", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "-", 
                  RowBox[{"16", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"11", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"18", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]]}], "+", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"63", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "+", 
                    FractionBox[
                    RowBox[{"54", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"12", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "-", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"6", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"18", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "+", 
                    FractionBox[
                    RowBox[{"39", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"123", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"30", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "+", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"128", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"212", "+", 
                    RowBox[{"55", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"98", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"23", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"14", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"18", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}]}], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "108"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "12"}], "+", 
                    RowBox[{"20", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"8", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}], 
                  "+", 
                  RowBox[{"8", " ", 
                   SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"7", "/", "2"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"45", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"90", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "-", 
                    FractionBox[
                    RowBox[{"9", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"15", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "4"], " ", 
                    RowBox[{"Sinh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"24", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "6"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"4", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    FractionBox[
                    RowBox[{"30", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]], "+", 
                    FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"48", "+", 
                    RowBox[{"47", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"20", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "7"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    RowBox[{"32", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
                    RowBox[{
                    FractionBox["1", 
                    RowBox[{"128", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{"212", "+", 
                    RowBox[{"55", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"98", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], "-", 
                    RowBox[{"23", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"6", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"14", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"8", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"10", " ", "\[Alpha]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "9"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], "-", 
                    FractionBox[
                    RowBox[{"63", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], ")"}], 
                    " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"], " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                    RowBox[{"3", "/", "2"}]]], "+", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"6", "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"Cosh", "[", 
                    RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
                    RowBox[{"Sech", "[", "\[Alpha]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"360", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "32"}], "+", 
                    RowBox[{"84", " ", 
                    SuperscriptBox[
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}], "2"]}]}], ")"}], 
                    " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
                    RowBox[{"16", " ", 
                    SqrtBox[
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], ")"}]}]}], 
                 ")"}]}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"64", " ", 
                SuperscriptBox[
                 RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
                 RowBox[{"11", "/", "2"}]], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
                   RowBox[{"2", " ", 
                    RowBox[{"Tanh", "[", 
                    RowBox[{"2", " ", "\[Alpha]"}], "]"}]}]}], ")"}], "2"], 
                " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"9", " ", 
                   RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
                  RowBox[{"3", " ", 
                   RowBox[{"Tanh", "[", 
                    RowBox[{"3", " ", "\[Alpha]"}], "]"}]}]}], ")"}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SuperscriptBox[
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Alpha]", "-", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
       RowBox[{"2", " ", "\[Alpha]", " ", 
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
       RowBox[{"\[Alpha]", " ", 
        SuperscriptBox[
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Alpha]", " ", 
            RowBox[{"Coth", "[", "\[Alpha]", "]"}]}], "-", 
           RowBox[{"\[Alpha]", " ", 
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Alpha]"}], "+", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
           RowBox[{"\[Alpha]", " ", 
            SuperscriptBox[
             RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]]}], "-", 
      FractionBox[
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "-", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "-", 
          RowBox[{"\[Alpha]", " ", 
           SuperscriptBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}]}], 
       SuperscriptBox[
        RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
        RowBox[{"3", "/", "2"}]]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "16"]}], " ", 
       RowBox[{"Coth", "[", "\[Alpha]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]", "-", 
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "-", 
         RowBox[{"2", " ", "\[Alpha]", " ", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
         RowBox[{"\[Alpha]", " ", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]", "-", 
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "+", 
         RowBox[{"2", " ", "\[Alpha]", " ", 
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "+", 
         RowBox[{"\[Alpha]", " ", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
           RowBox[{"3", "/", "2"}]]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"]}], 
          RowBox[{"4", " ", 
           SqrtBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", 
              RowBox[{"Cosh", "[", 
               RowBox[{"2", " ", "\[Alpha]"}], "]"}]}], "+", 
             RowBox[{"Cosh", "[", 
              RowBox[{"4", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
           RowBox[{"Sech", "[", "\[Alpha]", "]"}]}], 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}]], "-", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}]]}], "+", 
         RowBox[{
          FractionBox["3", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", 
             RowBox[{"Cosh", "[", "\[Alpha]", "]"}]}], "+", 
            RowBox[{"Cosh", "[", 
             RowBox[{"3", " ", "\[Alpha]"}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"Csch", "[", "\[Alpha]", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
           RowBox[{"3", "/", "2"}]]}], "+", 
         SuperscriptBox[
          RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
          RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Alpha]", "+", 
          RowBox[{"5", " ", 
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}]}], "-", 
          RowBox[{"2", " ", "\[Alpha]", " ", 
           SuperscriptBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "2"]}], "-", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "3"], "+", 
          RowBox[{"\[Alpha]", " ", 
           SuperscriptBox[
            RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}], "2"], 
       RowBox[{"16", " ", 
        SuperscriptBox[
         RowBox[{"Tanh", "[", "\[Alpha]", "]"}], 
         RowBox[{"5", "/", "2"}]]}]]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.863190385021744*^9, 3.863190409422954*^9}},
 CellLabel->
  "Out[497]=",ExpressionUUID->"4b61fdc1-f73a-472a-8591-923909133a4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{"Explr2", ",", 
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", "1.363", ",", "10.15"}], "}"}], ",", 
     RowBox[{"Ticks", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "0", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",",
           "7", ",", "8", ",", "9", ",", "10"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "12"}], ",", 
          RowBox[{"-", "9"}], ",", 
          RowBox[{"-", "6"}], ",", 
          RowBox[{"-", "3"}], ",", "0", ",", "3", ",", "6", ",", "9", ",", 
          "12"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "->", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "10.85"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "13"}], ",", "16"}], "}"}]}], "}"}]}], ",", " ", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", "0.01", "]"}], "}"}]}], ",", 
     RowBox[{"AxesStyle", "->", 
      RowBox[{"Directive", "[", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"Arrowheads", "[", "0.035", "]"}], ",", 
         RowBox[{"FontSize", "->", "18"}], ",", 
         RowBox[{"Thickness", "[", "0.004", "]"}]}], "}"}], "]"}]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8610524474314775`*^9, {3.86105247788404*^9, 3.8610527448050575`*^9}, {
   3.861052800854209*^9, 3.8610528017849407`*^9}, {3.863190418378002*^9, 
   3.8631904197525625`*^9}},
 CellLabel->
  "In[498]:=",ExpressionUUID->"8bef914d-c6c4-49a4-891c-0111c907dd63"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.01], Opacity[1.], 
      LineBox[CompressedData["
1:eJwdlWk41XkfxnHsRzr2fTkL/kVKRKXm95UlxpJ9TyEylFM0WlDKksggKVkn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       "]]},
     Annotation[#, "Charting`Private`Tag$213252#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  AxesStyle->Directive[{
     GrayLevel[0], 
     Arrowheads[0.035], FontSize -> 18, 
     Thickness[0.004]}],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 10.85}, {-13., 16.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{{{0, 
      FormBox["0", TraditionalForm]}, {1, 
      FormBox["1", TraditionalForm]}, {2, 
      FormBox["2", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}, {4, 
      FormBox["4", TraditionalForm]}, {5, 
      FormBox["5", TraditionalForm]}, {6, 
      FormBox["6", TraditionalForm]}, {7, 
      FormBox["7", TraditionalForm]}, {8, 
      FormBox["8", TraditionalForm]}, {9, 
      FormBox["9", TraditionalForm]}, {10, 
      FormBox["10", TraditionalForm]}}, {{-12, 
      FormBox[
       RowBox[{"-", "12"}], TraditionalForm]}, {-9, 
      FormBox[
       RowBox[{"-", "9"}], TraditionalForm]}, {-6, 
      FormBox[
       RowBox[{"-", "6"}], TraditionalForm]}, {-3, 
      FormBox[
       RowBox[{"-", "3"}], TraditionalForm]}, {0, 
      FormBox["0", TraditionalForm]}, {3, 
      FormBox["3", TraditionalForm]}, {6, 
      FormBox["6", TraditionalForm]}, {9, 
      FormBox["9", TraditionalForm]}, {12, 
      FormBox["12", TraditionalForm]}}}]], "Output",
 CellChangeTimes->{{3.861052490862255*^9, 3.861052580225356*^9}, {
   3.8610526202398195`*^9, 3.861052745282215*^9}, 3.8610528023296547`*^9, 
   3.861135981651094*^9, 3.86113645706559*^9, 3.8631904211459827`*^9},
 CellLabel->
  "Out[498]=",ExpressionUUID->"bc53aec2-66b7-460f-b481-9818f3dd322e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Obtain", " ", "spectral", " ", "data", " ", "of", " ", "most", 
    " ", "unstable", " ", 
    RowBox[{"eigenvalue", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"symLambdaRe", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"symLambda2", "*", 
        SuperscriptBox["\[Epsilon]", "2"]}], "+", 
       RowBox[{"symLambda4Re", "*", 
        SuperscriptBox["\[Epsilon]", "4"]}]}], "//.", 
      RowBox[{
       SubscriptBox["\[CapitalDelta]", "BW"], "->", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"8", "*", 
         SubscriptBox["e", "2"], "*", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["e", "BW"], "-", 
           RowBox[{
            SubscriptBox["e", "2"], "*", 
            RowBox[{
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"], "/", "8"}]}]}], ")"}]}], 
        "]"}]}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"*", " ", "Leading"}], "-", 
     RowBox[{"order", " ", "behavior", " ", "of", " ", 
      SubscriptBox["\[Mu]", "1"], " ", "for", " ", "most", " ", "unstable", 
      " ", "Floquet", " ", 
      RowBox[{"exponent", "."}]}]}], "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Simplify", "[", 
             RowBox[{"D", "[", 
              RowBox[{"symLambdaRe", ",", 
               SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}], "//.", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], "->", 
             RowBox[{
              SubscriptBox["\[Mu]", 
               SubscriptBox["1", "0"]], "+", 
              RowBox[{
               SuperscriptBox["\[Epsilon]", "2"], "*", 
               SubscriptBox["\[Mu]", 
                SubscriptBox["1", "2"]]}]}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}],
         ",", 
        SuperscriptBox["\[Epsilon]", "2"]}], "]"}], "==", "0"}], ",", 
     RowBox[{"{", 
      SubscriptBox["\[Mu]", 
       SubscriptBox["1", "0"]], "}"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"*", " ", "Next"}], "-", 
     RowBox[{"order", " ", "behavior", " ", "of", " ", 
      SubscriptBox["\[Mu]", "1"], " ", "for", " ", "most", " ", "unstable", 
      " ", "Floquet", " ", 
      RowBox[{"exponent", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["sym\[Mu]", 
     SubscriptBox["1", "2"]], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"FullSimplify", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Coefficient", "[", 
                    RowBox[{
                    RowBox[{"Normal", "[", 
                    RowBox[{"Series", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Simplify", "[", 
                    RowBox[{"D", "[", 
                    RowBox[{"symLambdaRe", ",", 
                    SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", 
                    RowBox[{
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "0"]], "+", 
                    RowBox[{
                    SuperscriptBox["\[Epsilon]", "2"], "*", 
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "2"]]}]}]}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], 
                    "]"}], "]"}], ",", 
                    SuperscriptBox["\[Epsilon]", "4"]}], "]"}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "2"]], "->", "0"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "0"]], "->", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    SqrtBox[
                    SubscriptBox["e", "BW"]]}], 
                    SqrtBox[
                    SubscriptBox["e", "2"]]]}]}], "//.", 
                    RowBox[{
                    SubscriptBox["r", "2"], "->", "symr2"}]}], "]"}], "/", 
                   RowBox[{"Refine", "[", 
                    RowBox[{
                    RowBox[{"FullSimplify", "[", 
                    RowBox[{
                    RowBox[{"Coefficient", "[", 
                    RowBox[{
                    RowBox[{"Coefficient", "[", 
                    RowBox[{
                    RowBox[{"Normal", "[", 
                    RowBox[{"Series", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Simplify", "[", 
                    RowBox[{"D", "[", 
                    RowBox[{"symLambdaRe", ",", 
                    SubscriptBox["\[Mu]", "1"]}], "]"}], "]"}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], "->", 
                    RowBox[{
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "0"]], "+", 
                    RowBox[{
                    SuperscriptBox["\[Epsilon]", "2"], "*", 
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "2"]]}]}]}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], 
                    "]"}], "]"}], ",", 
                    SuperscriptBox["\[Epsilon]", "4"]}], "]"}], ",", 
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "2"]]}], "]"}], "//.", 
                    RowBox[{
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "0"]], "->", 
                    FractionBox[
                    RowBox[{"2", " ", 
                    SqrtBox[
                    SubscriptBox["e", "BW"]]}], 
                    SqrtBox[
                    SubscriptBox["e", "2"]]]}]}], "]"}], ",", 
                    RowBox[{
                    SubscriptBox["e", "2"], ">", "0"}]}], "]"}]}], "//.", " ", 
                  RowBox[{
                   SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                   SubscriptBox["E", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", 
                 RowBox[{
                  SubscriptBox["symF", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "->", 
                  SubscriptBox["F", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], "//.", " ", 
                RowBox[{
                 SubscriptBox["symA", 
                  RowBox[{"3", ",", "0"}]], "->", 
                 SubscriptBox["A", 
                  RowBox[{"3", ",", "0"}]]}]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["symB", 
                 RowBox[{"3", ",", "0"}]], "->", " ", 
                SubscriptBox["B", 
                 RowBox[{"3", ",", "0"}]]}]}], "//.", 
              RowBox[{
               SubscriptBox["symD", 
                RowBox[{"3", ",", "0"}]], "->", 
               SubscriptBox["D", 
                RowBox[{"3", ",", "0"}]]}]}], "//.", 
             RowBox[{
              SubscriptBox["symE", 
               RowBox[{"3", ",", "0"}]], "->", 
              SubscriptBox["E", 
               RowBox[{"3", ",", "0"}]]}]}], "//.", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], "->", 
             SubscriptBox["S", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], "//.", 
           RowBox[{
            SubscriptBox["symS", 
             RowBox[{"2", ",", "0"}]], "->", 
            SubscriptBox["S", 
             RowBox[{"2", ",", "0"}]]}]}], "//.", 
          RowBox[{
           SubscriptBox["symT", 
            RowBox[{"2", ",", "0"}]], "->", " ", 
           SubscriptBox["T", 
            RowBox[{"2", ",", "0"}]]}]}], "//.", 
         RowBox[{
          SubscriptBox["c", "g"], "->", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["e", "2"], ">", "0"}], ",", 
        RowBox[{
         SubscriptBox["e", "BW"], ">", "0"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8611044406608186`*^9, 3.8611044488171062`*^9}, {
   3.8611045220887947`*^9, 3.861104534497702*^9}, {3.8611045899176345`*^9, 
   3.8611046088759885`*^9}, {3.8611046498397713`*^9, 
   3.8611046591534157`*^9}, {3.863184811051615*^9, 3.863184829598048*^9}, 
   3.8631871348766885`*^9, {3.8631904360398254`*^9, 3.863190491774742*^9}, {
   3.86319063908683*^9, 3.863190655585438*^9}, {3.863190701427992*^9, 
   3.8631907370417147`*^9}},ExpressionUUID->"082e8917-adaa-41b2-8c4d-\
9b117ae2feca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Mu]", 
      SubscriptBox["1", "0"]], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SqrtBox[
         SubscriptBox["e", "BW"]]}], 
       SqrtBox[
        SubscriptBox["e", "2"]]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Mu]", 
      SubscriptBox["1", "0"]], "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox[
        SubscriptBox["e", "BW"]]}], 
      SqrtBox[
       SubscriptBox["e", "2"]]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.863190505416979*^9, 3.8631906610680556`*^9},
 CellLabel->
  "Out[506]=",ExpressionUUID->"a7c7c826-031f-4b8e-8180-5cb316da36be"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["e", "2"], " ", 
      SubscriptBox["e", "BW"]}], ")"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["e", "2", "2"], "+", 
     RowBox[{"4", " ", 
      SubscriptBox["c", "0"], " ", 
      SubscriptBox["e", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["symA", 
         RowBox[{"3", ",", 
          RowBox[{"-", "1"}]}], "2"], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["symH", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
     RowBox[{"32", " ", 
      SubscriptBox["c", "0"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["symA", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]], " ", 
         SubscriptBox["symD", 
          RowBox[{"3", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["symI", 
          RowBox[{"4", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"4", " ", 
   SubscriptBox["c", "0"], " ", 
   SubsuperscriptBox["e", "2", "4"]}]]], "Output",
 CellChangeTimes->{3.863190505416979*^9, 3.8631906912098207`*^9},
 CellLabel->
  "Out[507]=",ExpressionUUID->"2f3b60cf-f39e-4529-b050-75acb71e1a39"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Coefficients", " ", "of", " ", "series", " ", "expansion", " ", 
    "for", " ", "real", " ", "part", " ", "of", " ", "most", " ", "unstable", 
    " ", 
    RowBox[{"eigenvalue", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"LambdaMostUnstableRe", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            RowBox[{"Normal", "[", 
             RowBox[{"Series", "[", 
              RowBox[{
               RowBox[{"Simplify", "[", 
                RowBox[{"symLambdaRe", "//.", 
                 RowBox[{
                  SubscriptBox["\[Mu]", "1"], "->", 
                  RowBox[{
                   SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "0"]], "+", 
                   RowBox[{
                    SuperscriptBox["\[Epsilon]", "2"], "*", 
                    SubscriptBox["\[Mu]", 
                    SubscriptBox["1", "2"]]}]}]}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], 
             "]"}], ",", "\[Epsilon]"}], "]"}], "//.", 
          RowBox[{
           SubscriptBox["\[Mu]", 
            SubscriptBox["1", "0"]], "->", 
           FractionBox[
            RowBox[{"2", " ", 
             SqrtBox[
              SubscriptBox["e", "BW"]]}], 
            SqrtBox[
             SubscriptBox["e", "2"]]]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["e", "2"], ">", "0"}], "}"}]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        SubscriptBox["1", "2"]], "->", 
       SubscriptBox["sym\[Mu]", 
        SubscriptBox["1", "2"]]}]}], "//.", 
     RowBox[{
      SubscriptBox["r", "2"], "->", "symr2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.861106876893716*^9, 3.8611069803074865`*^9}, {
   3.8611070133124104`*^9, 3.8611071486611776`*^9}, {3.8611071923646564`*^9, 
   3.861107192755309*^9}, 3.8611371766702566`*^9, {3.861137860471499*^9, 
   3.861137873524722*^9}, {3.8611380116688986`*^9, 3.861138018177005*^9}, {
   3.8611380849290857`*^9, 3.8611381177792807`*^9}, {3.861138204793086*^9, 
   3.861138208222986*^9}, {3.8611390531030207`*^9, 3.8611390585337467`*^9}, {
   3.861139871816304*^9, 3.861139887550399*^9}, {3.86113992313208*^9, 
   3.861139923544057*^9}, {3.863184811441963*^9, 3.8631848298292646`*^9}, {
   3.8631907771023474`*^9, 3.863190799303076*^9}},
 CellLabel->
  "In[510]:=",ExpressionUUID->"ce138119-686f-4db0-82d6-bba94acbee4a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   FractionBox[
    SubscriptBox["e", "BW"], "2"], ",", "0", ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"64", " ", 
      SubscriptBox["e", "2"], " ", 
      SubsuperscriptBox["symT", 
       RowBox[{"2", ",", "0"}], "4"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SubsuperscriptBox["e", "2", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["symD", 
           RowBox[{"3", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["symD", 
           RowBox[{"3", ",", "0"}], "2"], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["symT", 
           RowBox[{"2", ",", "0"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubsuperscriptBox["symA", 
              RowBox[{"3", ",", "0"}], "2"], " ", 
             SubsuperscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}], "2"]}], "+", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                SubscriptBox["e", "BW"], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{
                SubsuperscriptBox["symE", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}], "2"], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["e", "BW"], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      "+", 
      RowBox[{"16", " ", 
       SubsuperscriptBox["symT", 
        RowBox[{"2", ",", "0"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubsuperscriptBox["symC", 
           RowBox[{"3", ",", "0"}], "2"], " ", 
          SubsuperscriptBox["symS", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}], "2"]}], "-", 
         RowBox[{"4", " ", 
          SubsuperscriptBox["symG", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}], "2"], " ", 
          SubsuperscriptBox["symS", 
           RowBox[{"2", ",", "0"}], "2"]}], "+", 
         RowBox[{
          SubsuperscriptBox["e", "BW", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SubsuperscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}], "2"], "-", 
            RowBox[{"4", " ", 
             SubscriptBox["symH", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
          SubsuperscriptBox["symT", 
           RowBox[{"2", ",", "0"}], "2"]}], "+", 
         RowBox[{"8", " ", 
          SubscriptBox["symC", 
           RowBox[{"3", ",", "0"}]], " ", 
          SubscriptBox["symG", 
           RowBox[{"3", ",", 
            RowBox[{"-", "1"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
         RowBox[{"4", " ", 
          SubscriptBox["e", "BW"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symD", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                  RowBox[{
                   SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symH", 
                 RowBox[{"4", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]]}], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                  RowBox[{
                   SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                  RowBox[{
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                   SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["e", "2"], " ", 
       SubscriptBox["symT", 
        RowBox[{"2", ",", "0"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["symC", 
           RowBox[{"3", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["symD", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubsuperscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}], "2"], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["e", "BW"], " ", 
                SubscriptBox["symD", 
                 RowBox[{"3", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["symA", 
                 RowBox[{"3", ",", "0"}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{
                SubscriptBox["symE", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "2"]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["symT", 
           RowBox[{"2", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", 
             SubscriptBox["symC", 
              RowBox[{"4", ",", "0"}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubscriptBox["symG", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symG", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubsuperscriptBox["symS", 
              RowBox[{"2", ",", "0"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubscriptBox["symG", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", "0"}]], " ", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symD", 
              RowBox[{"4", ",", "0"}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["symF", 
              RowBox[{"4", ",", "0"}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symA", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["symC", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symA", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["symC", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symE", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symS", 
              RowBox[{"2", ",", "0"}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["e", "BW"], " ", 
             SubscriptBox["symE", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "2"]}], "-", 
            RowBox[{"4", " ", 
             SubsuperscriptBox["symT", 
              RowBox[{"2", ",", "0"}], "2"], " ", 
             SubscriptBox["symJ", 
              RowBox[{"4", ",", 
               RowBox[{"-", "1"}], ",", "0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symE", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]]}], "-", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", "0"}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                    SubscriptBox["symF", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "512"}], " ", 
                  SubsuperscriptBox["e", "BW", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "4"]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["e", "2", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SubscriptBox["e", "2"], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symC", 
                    RowBox[{"3", ",", "0"}], "2"], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}], "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["e", "BW", "2"], " ", 
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["e", "BW"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
                 RowBox[{"8", " ", 
                  SubsuperscriptBox["e", "2", "2"], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"32", " ", 
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["e", "BW"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["c", "g"], " ", 
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 SubscriptBox["symB", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]]}], ")"}], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "4"]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["symD", 
           RowBox[{"3", ",", "0"}]], " ", 
          SubscriptBox["symS", 
           RowBox[{"2", ",", "0"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SubscriptBox["symG", 
              RowBox[{"3", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["symS", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], " ", 
                SubscriptBox["symS", 
                 RowBox[{"2", ",", "0"}]]}], "+", 
               RowBox[{
                SubscriptBox["e", "BW"], " ", 
                SubscriptBox["symT", 
                 RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
            RowBox[{
             SubscriptBox["symS", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]], " ", 
             SubscriptBox["symT", 
              RowBox[{"2", ",", "0"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["e", "BW"], " ", 
                SubscriptBox["symA", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["symC", 
                 RowBox[{"3", ",", 
                  RowBox[{"-", "1"}]}]]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["c", "g"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "512"}], " ", 
                    SubsuperscriptBox["e", "BW", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symI", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "4"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["e", "2", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"]}], "+", 
                    RowBox[{"16", " ", 
                    SubscriptBox["e", "2"], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symC", 
                    RowBox[{"3", ",", "0"}], "2"], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}], "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{
                    SubsuperscriptBox["e", "BW", "2"], " ", 
                    SubsuperscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["e", "BW"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
                    RowBox[{"8", " ", 
                    SubsuperscriptBox["e", "2", "2"], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"4", " ", 
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["e", "BW"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
                    RowBox[{"4", " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{"32", " ", 
                  SubscriptBox["e", "2"], " ", 
                  SubscriptBox["e", "BW"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["c", "g"], " ", 
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    SubscriptBox["symB", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], ")"}], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "4"]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8631909241515903`*^9},
 CellLabel->
  "Out[510]=",ExpressionUUID->"aedb40b0-84d0-4f78-a4cc-e4c06d017752"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"symLambda4Im", " ", "=", " ", 
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], "*", "symLambda4"}], "]"}], "//.", " ", 
    RowBox[{"\[ImaginaryI]", "->", "0"}]}]}]}]], "Input",
 CellChangeTimes->{{3.861137389145827*^9, 3.861137414772689*^9}, {
  3.861138413656847*^9, 3.8611384332245073`*^9}},
 CellLabel->
  "In[511]:=",ExpressionUUID->"1abe67bc-c792-4a96-8bac-cd5b49c15d9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubscriptBox["c", "g"]}], " ", 
  SubscriptBox["r", "3"], " ", 
  SubscriptBox["\[Mu]", "1"]}]], "Output",
 CellChangeTimes->{{3.861138410141964*^9, 3.861138433953049*^9}, 
   3.8631909245420885`*^9},
 CellLabel->
  "Out[511]=",ExpressionUUID->"30f85621-bb7a-42a8-825f-727fe3a9b6d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Coefficients", " ", "of", " ", "the", " ", "expansion", " ", 
    "for", " ", "the", " ", "imaginary", " ", "part", " ", "of", " ", "the", 
    " ", "most", " ", "unstable", " ", 
    RowBox[{"eigenvalue", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LambdaMostUnstableIm", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"CoefficientList", "[", 
        RowBox[{
         RowBox[{"Normal", "[", 
          RowBox[{"Series", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"\[Epsilon]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["\[Mu]", "1"]}], "*", 
                  SubscriptBox["c", "g"]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"\[Epsilon]", "^", "3"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Simplify", "[", 
                   RowBox[{
                    SubscriptBox["symLambda3", "v2"], "/", "\[ImaginaryI]"}], 
                   "]"}], "//.", 
                  RowBox[{
                   SubscriptBox["r", "2"], "->", "symr2"}]}], ")"}]}]}], "//.", 
              RowBox[{
               SubscriptBox["\[CapitalDelta]", "BW"], "->", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 SubscriptBox["e", "2"], "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"8", "*", 
                    SubscriptBox["e", "BW"]}], "-", 
                   RowBox[{
                    SubscriptBox["e", "2"], "*", 
                    SuperscriptBox[
                    SubscriptBox["\[Mu]", "1"], "2"]}]}], ")"}]}], "]"}]}]}], 
             "//.", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], "->", 
              RowBox[{
               SubscriptBox["\[Mu]", 
                SubscriptBox["1", "0"]], "+", 
               RowBox[{
                SuperscriptBox["\[Epsilon]", "2"], "*", 
                SubscriptBox["\[Mu]", 
                 SubscriptBox["1", "2"]]}]}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}], 
          "]"}], ",", "\[Epsilon]"}], "]"}], "//.", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         SubscriptBox["1", "0"]], "->", 
        FractionBox[
         RowBox[{"2", " ", 
          SqrtBox[
           SubscriptBox["e", "BW"]]}], 
         SqrtBox[
          SubscriptBox["e", "2"]]]}]}], "//.", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        SubscriptBox["1", "2"]], "->", 
       SubscriptBox["sym\[Mu]", 
        SubscriptBox["1", "2"]]}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.86113843964376*^9, 3.861138513357663*^9}, {
   3.861138547018055*^9, 3.8611385491757917`*^9}, {3.861138647845877*^9, 
   3.861138697547515*^9}, {3.861138756737341*^9, 3.8611387570488253`*^9}, {
   3.861138879737257*^9, 3.8611388959092245`*^9}, {3.861139008503275*^9, 
   3.8611390359038043`*^9}, {3.8611390809690285`*^9, 3.861139084234848*^9}, {
   3.861139179198508*^9, 3.861139207357196*^9}, {3.861139249774075*^9, 
   3.8611392839976683`*^9}, {3.8611397590893283`*^9, 3.861139759701295*^9}, {
   3.8611398154115057`*^9, 3.8611398553948765`*^9}, {3.863184811900667*^9, 
   3.8631848299601917`*^9}, 3.863187134933261*^9, {3.863190865520025*^9, 
   3.8631908870020547`*^9}, 
   3.863191320821647*^9},ExpressionUUID->"f56c7404-d985-4157-b8c0-\
7375c785968e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SubscriptBox["c", "g"], " ", 
      SqrtBox[
       SubscriptBox["e", "BW"]]}], 
     SqrtBox[
      SubscriptBox["e", "2"]]]}], ",", "0", ",", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"64", " ", 
      SubsuperscriptBox["e", "2", "4"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", 
         SubscriptBox["c", "g"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["e", "2"], " ", 
            SubscriptBox["e", "BW"]}], ")"}], 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SubsuperscriptBox["e", "2", "2"], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["c", "0"], " ", 
            SubscriptBox["e", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SubsuperscriptBox["symA", 
               RowBox[{"3", ",", 
                RowBox[{"-", "1"}]}], "2"], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["symH", 
                RowBox[{"4", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
           RowBox[{"32", " ", 
            SubscriptBox["c", "0"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["symA", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]]}], "-", 
              RowBox[{"2", " ", 
               SubscriptBox["symI", 
                RowBox[{"4", ",", 
                 RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], 
        SubscriptBox["c", "0"]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["e", "2", 
          RowBox[{"5", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", 
            SubscriptBox["e", "BW"], " ", 
            SubscriptBox["symB", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]], " ", 
            SubsuperscriptBox["symT", 
             RowBox[{"2", ",", "0"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"32", " ", 
               SubscriptBox["e", "BW"], " ", 
               SubscriptBox["symD", 
                RowBox[{"3", ",", 
                 RowBox[{"-", "1"}]}]], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "2"]}], "-", 
              RowBox[{"8", " ", 
               SubscriptBox["e", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "+", 
                 RowBox[{
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "-", 
                 RowBox[{
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
              RowBox[{
               SubsuperscriptBox["e", "2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            SubscriptBox["c", "g"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "256"}], " ", 
               SubsuperscriptBox["e", "BW", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                 RowBox[{"4", " ", 
                  SubscriptBox["symI", 
                   RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "4"]}], "+", 
              RowBox[{
               SubsuperscriptBox["e", "2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                   SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                   SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], "2"]}], "+", 
              RowBox[{"16", " ", 
               SubscriptBox["e", "2"], " ", 
               SubsuperscriptBox["symT", 
                RowBox[{"2", ",", "0"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["symC", 
                   RowBox[{"3", ",", "0"}], "2"], " ", 
                  SubsuperscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}], "2"]}], "-", 
                 RowBox[{"8", " ", 
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]]}], "+", 
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["symG", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                  SubsuperscriptBox["symS", 
                   RowBox[{"2", ",", "0"}], "2"]}], "+", 
                 RowBox[{
                  SubsuperscriptBox["e", "BW", "2"], " ", 
                  SubsuperscriptBox["symA", 
                   RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}], "2"], " ", 
                  SubsuperscriptBox["symT", 
                   RowBox[{"2", ",", "0"}], "2"]}], "+", 
                 RowBox[{"8", " ", 
                  SubscriptBox["e", "BW"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SubscriptBox["symH", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symD", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["symG", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}]]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"16", " ", 
               SubsuperscriptBox["e", "2", "2"], " ", 
               SubscriptBox["symT", 
                RowBox[{"2", ",", "0"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["symD", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["symC", 
                   RowBox[{"3", ",", "0"}]], " ", 
                  SubscriptBox["symS", 
                   RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["symD", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "+", 
                 RowBox[{
                  SubscriptBox["symT", 
                   RowBox[{"2", ",", "0"}]], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubsuperscriptBox["symS", 
                    RowBox[{"2", ",", "0"}], "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symF", 
                    RowBox[{"4", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{"2", " ", 
                    SubscriptBox["symC", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symE", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}], "+", 
                    RowBox[{
                    SubscriptBox["symA", 
                    RowBox[{"3", ",", "0"}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["symG", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symS", 
                    RowBox[{"2", ",", "0"}]]}], "-", 
                    RowBox[{
                    SubscriptBox["symC", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], " ", 
                    SubscriptBox["symT", 
                    RowBox[{"2", ",", "0"}]]}]}], ")"}]}], "-", 
                    RowBox[{"2", " ", 
                    SubsuperscriptBox["symT", 
                    RowBox[{"2", ",", "0"}], "2"], " ", 
                    SubscriptBox["symJ", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          SubscriptBox["e", "BW"]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["c", "g"], " ", 
            SubscriptBox["symA", 
             RowBox[{"3", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           SubscriptBox["symB", 
            RowBox[{"3", ",", 
             RowBox[{"-", "1"}]}]]}], ")"}], " ", 
         SubsuperscriptBox["symT", 
          RowBox[{"2", ",", "0"}], "4"]}], ")"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8631909273085375`*^9},
 CellLabel->
  "Out[512]=",ExpressionUUID->"951ccae8-2404-4c85-bf2f-5dd1ae856ff1"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1024.5, 507.75},
WindowMargins->{{-6, Automatic}, {Automatic, -6}},
FrontEndVersion->"13.0 for Microsoft Windows (64-bit) (December 2, 2021)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"2c0a5e18-2053-4498-b76c-a281b1850d66"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 390, 6, 98, "Title",ExpressionUUID->"32f0f396-b58c-47d4-86c2-4e692fba1a5a"],
Cell[973, 30, 546, 17, 242, "Text",ExpressionUUID->"ff3b8547-2164-4482-a681-083ad2e88a22"],
Cell[1522, 49, 241, 6, 57, "Input",ExpressionUUID->"1a9ce881-903c-404d-8739-0103abd212d2"],
Cell[1766, 57, 11287, 302, 856, "Text",ExpressionUUID->"10a3943b-13f9-458e-82bd-611a36f68f39"],
Cell[13056, 361, 386, 9, 57, "Input",ExpressionUUID->"61b489d5-7900-4c42-8362-0bd039a8a29f"],
Cell[13445, 372, 16802, 390, 1007, "Input",ExpressionUUID->"26298b66-70e7-4ed1-b515-cf00a80d42c4"],
Cell[30250, 764, 387, 9, 57, "Input",ExpressionUUID->"6f25681d-cf72-41ce-9312-ef38a2cb0065"],
Cell[CellGroupData[{
Cell[30662, 777, 13493, 292, 605, "Input",ExpressionUUID->"bb7ca26d-39a4-42ca-8009-40625df1efdb",
 InitializationCell->True],
Cell[44158, 1071, 3135, 43, 32, "Output",ExpressionUUID->"ae085246-2917-4add-81f7-10ee42bce23f"],
Cell[47296, 1116, 3137, 43, 32, "Output",ExpressionUUID->"ad931708-56c8-4920-898b-ea4fe474c915"],
Cell[50436, 1161, 4193, 77, 53, "Output",ExpressionUUID->"a66bab6a-6bf2-421f-b51e-38a3af4ab86f"],
Cell[54632, 1240, 3243, 47, 32, "Output",ExpressionUUID->"1c21aef7-ef9a-4e6a-835d-797d069f45c4"],
Cell[57878, 1289, 3183, 45, 32, "Output",ExpressionUUID->"090d13ec-2a18-43f0-bad9-3497cdd9c2c5"],
Cell[61064, 1336, 3263, 48, 32, "Output",ExpressionUUID->"2698a9ba-0584-4517-91e0-ba10d44064f3"]
}, Open  ]],
Cell[64342, 1387, 663, 12, 48, "Input",ExpressionUUID->"d7bf25bc-27e6-4b59-a0f4-230ee6d5c3b8"],
Cell[65008, 1401, 10720, 228, 371, "Input",ExpressionUUID->"72c1437f-4d3a-4b90-9561-e7fa4c6ad3a4"],
Cell[CellGroupData[{
Cell[75753, 1633, 4033, 102, 106, "Input",ExpressionUUID->"8c8a6821-12f1-4f94-8982-29a51960d00f"],
Cell[79789, 1737, 7312, 223, 133, "Output",ExpressionUUID->"d7b2f2b3-c2d3-4400-b2ab-6ac87874e587"]
}, Open  ]],
Cell[87116, 1963, 1898, 49, 128, "Input",ExpressionUUID->"3cd7ef22-8d0d-4fbb-9585-e45f2d3b22c8"],
Cell[CellGroupData[{
Cell[89039, 2016, 2456, 70, 92, "Input",ExpressionUUID->"2acf2d76-8ff7-4cc6-8991-96a6685fcaba"],
Cell[91498, 2088, 1210, 30, 54, "Output",ExpressionUUID->"65d2b6bc-897b-47aa-807f-c52d82cfe29e"],
Cell[92711, 2120, 561, 10, 32, "Output",ExpressionUUID->"834eefa8-6181-45fb-95bd-147c746c22bc"],
Cell[93275, 2132, 1188, 29, 54, "Output",ExpressionUUID->"e6f425be-4ffd-4d5c-8034-14293c9f8c9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94500, 2166, 7039, 183, 333, "Input",ExpressionUUID->"69da2b8c-9366-444c-a49e-0377597252c8"],
Cell[101542, 2351, 1593, 27, 52, "Output",ExpressionUUID->"0aef7135-53d2-495d-88da-24ad74f7d372"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103172, 2383, 3744, 105, 153, "Input",ExpressionUUID->"f1639467-ce46-425d-974d-6c441f8f5f14"],
Cell[106919, 2490, 1337, 18, 32, "Output",ExpressionUUID->"99abbdf3-b64e-49db-8faa-f12571ad7a80"],
Cell[108259, 2510, 1337, 18, 32, "Output",ExpressionUUID->"2fd45600-c769-4cbd-8a53-1d4e5322fcf2"]
}, Open  ]],
Cell[109611, 2531, 613, 15, 49, "Input",ExpressionUUID->"74ede51c-1bb2-48fb-bfac-d209dcd89d15"],
Cell[CellGroupData[{
Cell[110249, 2550, 2982, 76, 145, "Input",ExpressionUUID->"95aad231-b3cb-4020-9ace-25d6164643aa"],
Cell[113234, 2628, 5538, 140, 104, "Output",ExpressionUUID->"c4dfc6ee-1f39-471a-aae3-1f9f910fd568"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118809, 2773, 5061, 137, 117, "Input",ExpressionUUID->"a13ff59b-7856-43ac-baf3-44714ddd570c"],
Cell[123873, 2912, 2159, 44, 56, "Output",ExpressionUUID->"d9a99597-d084-4f55-83ae-16657d648029"],
Cell[126035, 2958, 2891, 64, 53, "Output",ExpressionUUID->"b0e50b63-a607-46dd-83ed-e53df9fda397"],
Cell[128929, 3024, 2092, 41, 56, "Output",ExpressionUUID->"5244f60d-3cd9-4245-ab32-d70b288d5892"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131058, 3070, 18906, 489, 498, "Input",ExpressionUUID->"93f2e2e1-69ac-40ad-9c13-bf0b0646ebbd"],
Cell[149967, 3561, 1599, 23, 32, "Output",ExpressionUUID->"0160ff5a-581c-4add-93fc-bd4bf334b8db"],
Cell[151569, 3586, 1599, 23, 32, "Output",ExpressionUUID->"1b46abd6-89e0-4970-a357-bcd5ab5fa329"],
Cell[153171, 3611, 1597, 23, 32, "Output",ExpressionUUID->"cc53d8ff-ce3d-411d-bb78-a83d89cf97b7"],
Cell[154771, 3636, 1597, 23, 32, "Output",ExpressionUUID->"fb1fa19b-1420-4d90-b0bd-9871ea310e06"],
Cell[156371, 3661, 1599, 23, 32, "Output",ExpressionUUID->"75975843-f738-473a-8a79-fa0464a7f46c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158007, 3689, 2983, 74, 128, "Input",ExpressionUUID->"f4ed5d58-2348-4d3c-bcef-df755322c494"],
Cell[160993, 3765, 4331, 107, 82, "Output",ExpressionUUID->"e15a29be-a4d4-4c0d-9d96-475dc5f240e6"]
}, Open  ]],
Cell[165339, 3875, 364, 9, 57, "Input",ExpressionUUID->"963de281-4453-4fe8-b797-d86e3aace76f"],
Cell[165706, 3886, 17642, 405, 504, "Input",ExpressionUUID->"c5bbb4b4-efba-48df-95e5-9cc1cf8111a8"],
Cell[CellGroupData[{
Cell[183373, 4295, 6443, 176, 223, "Input",ExpressionUUID->"85f3239a-80fe-48e1-b24b-ec66ea729324"],
Cell[189819, 4473, 50939, 1509, 1042, "Output",ExpressionUUID->"40ed4890-fe17-4e7c-a36e-81265d2f1a57"]
}, Open  ]],
Cell[240773, 5985, 1309, 36, 90, "Input",ExpressionUUID->"eee5d6f5-6526-4088-a224-e9cee611d92b"],
Cell[CellGroupData[{
Cell[242107, 6025, 7590, 195, 390, "Input",ExpressionUUID->"7b100f7e-5a7d-4a29-9e28-971fe38dd069"],
Cell[249700, 6222, 11213, 317, 184, "Output",ExpressionUUID->"a77b8aad-d1a4-419b-a6d4-482b0c53d39d"],
Cell[260916, 6541, 2940, 76, 76, "Output",ExpressionUUID->"c0128ff3-f913-43d6-93e6-3d8e6ff1d53b"],
Cell[263859, 6619, 10329, 291, 184, "Output",ExpressionUUID->"381eae08-96a6-461c-baa7-0c58db5eafd3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[274225, 6915, 4162, 109, 130, "Input",ExpressionUUID->"f7fffafa-2c1e-48cd-8029-01001fa8e0b0"],
Cell[278390, 7026, 1108, 22, 54, "Output",ExpressionUUID->"a70583d1-c749-4d2f-8452-733dd22a2ed6"],
Cell[279501, 7050, 1319, 30, 56, "Output",ExpressionUUID->"3538c0bf-8577-4cf5-b108-235d0e2b1f2f"],
Cell[280823, 7082, 1342, 32, 53, "Output",ExpressionUUID->"e4e97453-e0ef-46a0-828f-cc266a6bc9e9"],
Cell[282168, 7116, 2206, 57, 56, "Output",ExpressionUUID->"722f715a-652e-4951-9559-328484b1597f"]
}, Open  ]],
Cell[284389, 7176, 154, 3, 28, "Input",ExpressionUUID->"1a572e5b-1723-457e-b975-9e266b74a347"],
Cell[CellGroupData[{
Cell[284568, 7183, 7430, 201, 297, "Input",ExpressionUUID->"32554275-2b8d-4252-9834-57f0bb28b1b1"],
Cell[292001, 7386, 587, 8, 32, "Output",ExpressionUUID->"9f2aae48-e7c5-4c5e-a1cf-55bb08c69100"],
Cell[292591, 7396, 607, 9, 48, "Output",ExpressionUUID->"aa515faa-d15e-421e-beb7-d9584b2b7fc0"],
Cell[293201, 7407, 606, 9, 32, "Output",ExpressionUUID->"89671364-2902-47df-a7ac-da4c50860427"],
Cell[293810, 7418, 604, 9, 32, "Output",ExpressionUUID->"183228af-3d31-4dad-a8d0-31210386c0c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294451, 7432, 2657, 73, 92, "Input",ExpressionUUID->"1bf015e2-4f49-412d-be92-4a2408f4a10d"],
Cell[297111, 7507, 707, 10, 32, "Output",ExpressionUUID->"88bbd527-1d56-4935-ae88-f88140de4122"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297855, 7522, 1575, 43, 69, "Input",ExpressionUUID->"6184f214-e240-40f4-b62a-2c4b58a65333"],
Cell[299433, 7567, 1558, 31, 56, "Output",ExpressionUUID->"abe2072e-4091-417f-85eb-0fe2122c628c"],
Cell[300994, 7600, 1306, 24, 54, "Output",ExpressionUUID->"16e1be86-7304-4e83-865c-6c8f0d24d357"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302337, 7629, 1130, 29, 88, "Input",ExpressionUUID->"5fd798eb-1989-4fe0-b6cf-1e53efe40699"],
Cell[303470, 7660, 338, 5, 32, "Output",ExpressionUUID->"46acb370-a2e3-4567-813f-9e0ac30d2d96"],
Cell[303811, 7667, 365, 6, 32, "Output",ExpressionUUID->"d9685f17-e475-4be7-9594-3720fadccaa7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304213, 7678, 1475, 42, 91, "Input",ExpressionUUID->"9171d768-66a4-4e48-8e08-47cfc17ff4be"],
Cell[305691, 7722, 904, 12, 32, "Output",ExpressionUUID->"57f2caf8-9570-4192-8958-ce801192fa68"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306632, 7739, 3115, 88, 111, "Input",ExpressionUUID->"3462fb37-b006-4fb4-8de1-6400ef60c223"],
Cell[309750, 7829, 1495, 27, 54, "Output",ExpressionUUID->"ddd10b2d-2a00-4308-b356-1fd5fae99188"],
Cell[311248, 7858, 1696, 35, 56, "Output",ExpressionUUID->"6164eee9-f4db-4791-a7f3-7ad1d8e1de07"],
Cell[312947, 7895, 1615, 34, 54, "Output",ExpressionUUID->"98837ce3-c707-4de0-9b92-3e76219cd653"],
Cell[314565, 7931, 2409, 54, 56, "Output",ExpressionUUID->"76fc6366-1bbe-4d4b-9497-2430dd4ee00e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[317011, 7990, 7078, 193, 298, "Input",ExpressionUUID->"d9d3fc3c-17a3-4848-ba46-85f685b6c5ed"],
Cell[324092, 8185, 387, 6, 32, "Output",ExpressionUUID->"04d4d453-0369-4ef5-b465-3c12798a8671"],
Cell[324482, 8193, 406, 7, 48, "Output",ExpressionUUID->"86b368b4-f3f5-410b-92b2-385a1d96f8cd"],
Cell[324891, 8202, 368, 5, 32, "Output",ExpressionUUID->"ff6e8ffb-b090-47ab-b2a1-81c530b08ae1"],
Cell[325262, 8209, 368, 5, 32, "Output",ExpressionUUID->"01c031de-f7ac-4862-8b1d-71f64a3efa17"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325667, 8219, 2237, 63, 73, "Input",ExpressionUUID->"641bbf34-dd3f-4b53-914d-a6e593739839"],
Cell[327907, 8284, 836, 11, 32, "Output",ExpressionUUID->"060f80a3-61ff-419f-9f35-24df07fd818a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328780, 8300, 1678, 47, 148, "Input",ExpressionUUID->"b0a506d9-e525-4026-a825-f3251f278f77"],
Cell[330461, 8349, 885, 12, 32, "Output",ExpressionUUID->"cd74cce5-f0f3-49aa-8459-e4423a14db04"],
Cell[331349, 8363, 887, 12, 32, "Output",ExpressionUUID->"62530f0c-3c9c-4b69-99f0-51f36f6f4fb8"],
Cell[332239, 8377, 887, 12, 32, "Output",ExpressionUUID->"f3b9b09e-e29f-49f4-a0c5-5081d13da59b"],
Cell[333129, 8391, 887, 12, 32, "Output",ExpressionUUID->"45a41919-d541-4d67-98dd-3753a094d517"]
}, Open  ]],
Cell[CellGroupData[{
Cell[334053, 8408, 3625, 101, 171, "Input",ExpressionUUID->"b9ef80e0-8b16-44dd-8a84-228a70cad8ba"],
Cell[337681, 8511, 246, 3, 32, "Output",ExpressionUUID->"ad672b53-bf9f-4778-b573-d161ccf44bd6"]
}, Open  ]],
Cell[337942, 8517, 5375, 150, 132, "Input",ExpressionUUID->"a27ffe86-bcea-4e87-a069-51ecc8e9b69f"],
Cell[CellGroupData[{
Cell[343342, 8671, 3206, 80, 155, "Input",ExpressionUUID->"76892369-c2e0-4d71-b904-cfae233ed5f5"],
Cell[346551, 8753, 9996, 296, 351, "Output",ExpressionUUID->"d5b2be79-1a5f-4300-83b6-bd025dfbaa50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356584, 9054, 6920, 156, 157, "Input",ExpressionUUID->"cbd8618b-3200-4b26-a559-2f5db49030b4"],
Cell[363507, 9212, 3774, 112, 102, "Output",ExpressionUUID->"ccb98c45-66ba-47f4-a884-6a98162d4c89"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367318, 9329, 13907, 346, 324, "Input",ExpressionUUID->"d72fc652-400e-4699-8372-7dbd1267a2c6"],
Cell[381228, 9677, 1622, 45, 58, "Output",ExpressionUUID->"e4bcaa45-0c38-4294-8c65-cbc5aa6eaa57"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382887, 9727, 1767, 48, 105, "Input",ExpressionUUID->"39be5729-e3ef-47be-aeb5-94c997f358a0"],
Cell[384657, 9777, 5337, 110, 234, "Output",ExpressionUUID->"507bc525-add3-482d-94f1-b04f2704a02c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390031, 9892, 1679, 43, 109, "Input",ExpressionUUID->"907f1e4e-cdae-4878-aa06-12197b8b277e"],
Cell[391713, 9937, 444, 12, 48, "Output",ExpressionUUID->"ddf55cc3-5214-4317-ad14-bf537bdf2ee4"],
Cell[392160, 9951, 642, 19, 56, "Output",ExpressionUUID->"bc9ff33a-dff5-4105-a404-cdd1f2666f78"],
Cell[392805, 9972, 609, 18, 56, "Output",ExpressionUUID->"d180481f-15d8-43d5-b740-b0ec13548b00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393451, 9995, 2219, 63, 145, "Input",ExpressionUUID->"f833616a-ca60-4bc3-880a-2929d876ea16"],
Cell[395673, 10060, 37844, 995, 634, "Output",ExpressionUUID->"690c8dd7-6c1e-4380-aa3e-cb4465307fda"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433554, 11060, 4640, 131, 98, "Input",ExpressionUUID->"00df7e46-cbf2-4035-9128-b9a0a3970f18"],
Cell[438197, 11193, 6604, 176, 103, "Output",ExpressionUUID->"97755b08-665a-4bbe-9dc8-b59d38eeea08"],
Cell[444804, 11371, 4975, 140, 99, "Output",ExpressionUUID->"30aa60d3-ad13-4d51-8f00-c23ecf2022ab"],
Cell[449782, 11513, 5871, 157, 103, "Output",ExpressionUUID->"3727d6d2-2cbe-463d-92f4-405c2aa15874"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455690, 11675, 45032, 1141, 1158, "Input",ExpressionUUID->"207808fb-7a86-4b39-8a98-de03a0a57ecb"],
Cell[500725, 12818, 1009, 17, 32, "Output",ExpressionUUID->"e143be7d-a681-44a6-82bc-b202f1ff15c0"],
Cell[501737, 12837, 1011, 17, 32, "Output",ExpressionUUID->"07318698-110a-44a4-9085-d63d581f90ce"],
Cell[502751, 12856, 1011, 17, 32, "Output",ExpressionUUID->"ee8c9542-8bad-4c40-90af-56caf6ea456c"],
Cell[503765, 12875, 1009, 17, 32, "Output",ExpressionUUID->"9c057f02-2225-4f94-b811-1c9183ddb618"],
Cell[504777, 12894, 1011, 17, 32, "Output",ExpressionUUID->"53a468b9-0b06-4543-a202-317856fba9e0"],
Cell[505791, 12913, 1011, 17, 32, "Output",ExpressionUUID->"0b05a685-5e46-4ccd-84b4-cd0adb039cd8"],
Cell[506805, 12932, 1009, 17, 32, "Output",ExpressionUUID->"af417c2f-a646-4662-8a83-5ee5d1492997"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507851, 12954, 2528, 69, 150, "Input",ExpressionUUID->"bdcd2f26-0684-4c49-b1cc-6a84eeb902e9"],
Cell[510382, 13025, 4155, 119, 82, "Output",ExpressionUUID->"bc2a8175-713e-4107-9cbe-137c77b22727"]
}, Open  ]],
Cell[514552, 13147, 305, 8, 57, "Input",ExpressionUUID->"bb10e97d-b9cf-4a03-9bb3-100a3f609613"],
Cell[514860, 13157, 27130, 643, 878, "Input",ExpressionUUID->"ebaa48e5-186a-4abd-bd95-9273e755eea3"],
Cell[CellGroupData[{
Cell[542015, 13804, 6166, 166, 206, "Input",ExpressionUUID->"82bd5689-2603-4e99-af0a-d94a05f7a2c1"],
Cell[548184, 13972, 215491, 6302, 4289, "Output",ExpressionUUID->"f6705da9-6664-4949-bb0c-3611e19d5181"]
}, Open  ]],
Cell[763690, 20277, 1028, 33, 90, "Input",ExpressionUUID->"97aa6e72-ae2b-4c16-8add-0563c8067b0d"],
Cell[CellGroupData[{
Cell[764743, 20314, 3485, 90, 197, "Input",ExpressionUUID->"901f460e-a37b-4c1b-972e-195c7f4faf99"],
Cell[768231, 20406, 48204, 1307, 640, "Output",ExpressionUUID->"abf50dc4-1b39-466b-a014-60bb358abdd3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[816472, 21718, 4312, 129, 358, "Input",ExpressionUUID->"872db611-d60d-4871-9ddc-8becd901ecf8"],
Cell[820787, 21849, 649, 10, 32, "Output",ExpressionUUID->"cf22651b-fe81-4ffd-b2e9-8e41eba2a1cf"],
Cell[821439, 21861, 649, 10, 32, "Output",ExpressionUUID->"2f8aa292-9519-4ffe-b672-9848cfec46ee"],
Cell[822091, 21873, 649, 10, 32, "Output",ExpressionUUID->"75232459-da73-46d0-ba06-d5b3ee9c6542"],
Cell[822743, 21885, 649, 10, 32, "Output",ExpressionUUID->"5f6afde8-674a-4df7-84b4-5a36ef0567e7"],
Cell[823395, 21897, 647, 10, 32, "Output",ExpressionUUID->"244c35ce-f1a0-4649-ae1a-111619b841f8"],
Cell[824045, 21909, 647, 10, 32, "Output",ExpressionUUID->"c2830b6b-cc72-41fb-bcac-15393abdc55f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[824729, 21924, 6589, 192, 338, "Input",ExpressionUUID->"1c911b43-ef82-4fe8-b47d-9e314573de13"],
Cell[831321, 22118, 506, 11, 49, "Output",ExpressionUUID->"36fffa73-6122-4dc7-955b-e5b0263ffb15"],
Cell[831830, 22131, 645, 15, 56, "Output",ExpressionUUID->"008d82bd-12ce-4494-93dd-9deaffb09c69"],
Cell[832478, 22148, 5274, 155, 100, "Output",ExpressionUUID->"5f29e5c2-f188-4fc9-9caf-f524a6e5d0cd"],
Cell[837755, 22305, 1354, 37, 56, "Output",ExpressionUUID->"571b559b-cc73-415f-91b6-d6fac905b31b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[839146, 22347, 2251, 59, 58, "Input",ExpressionUUID->"2bc25b57-7db5-476e-a367-5b4eec0fd7e5"],
Cell[841400, 22408, 990, 14, 32, "Output",ExpressionUUID->"94b5e6b8-94ae-45e3-8695-f508f1a5ce47"]
}, Open  ]],
Cell[CellGroupData[{
Cell[842427, 22427, 2229, 63, 119, "Input",ExpressionUUID->"8f861610-a602-4d27-b96e-da55f765ffeb"],
Cell[844659, 22492, 759, 16, 52, "Output",ExpressionUUID->"1290adc6-3c08-4165-ae87-cbe264ac39ef"],
Cell[845421, 22510, 719, 14, 48, "Output",ExpressionUUID->"0237d244-187a-4e08-8cae-609275ec87b3"],
Cell[846143, 22526, 1319, 32, 56, "Output",ExpressionUUID->"4d7abd93-f8c0-44e7-8c48-205363940614"]
}, Open  ]],
Cell[CellGroupData[{
Cell[847499, 22563, 1159, 34, 59, "Input",ExpressionUUID->"46771052-6587-48b0-a0e7-b2321fc6aa25"],
Cell[848661, 22599, 566, 9, 32, "Output",ExpressionUUID->"c5608dfb-e39b-4409-a15b-405a79edd16f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[849264, 22613, 4475, 128, 117, "Input",ExpressionUUID->"9368f784-3a8f-4ab8-875e-5e882b8eb415"],
Cell[853742, 22743, 175, 3, 32, "Output",ExpressionUUID->"947be519-9bc7-4213-b715-be2e0996b2a9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[853954, 22751, 3452, 87, 197, "Input",ExpressionUUID->"fafb2a1a-e1c8-463a-aee6-a872a8bf4ce3"],
Cell[857409, 22840, 8371, 239, 119, "Output",ExpressionUUID->"ede57edc-7e59-40d1-967c-8a48e0505f8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[865817, 23084, 10229, 285, 513, "Input",ExpressionUUID->"3ac6b69c-38ce-4991-904c-50092c1c4eb3"],
Cell[876049, 23371, 1069, 15, 32, "Output",ExpressionUUID->"aa04eef7-fa0d-4c9d-be45-3ba249458a95"],
Cell[877121, 23388, 1071, 15, 32, "Output",ExpressionUUID->"a2fd9a5c-71c6-4180-bff9-00e0c879141b"],
Cell[878195, 23405, 1071, 15, 32, "Output",ExpressionUUID->"962c5c37-c24a-49cd-8866-f232fa36b2e3"],
Cell[879269, 23422, 1069, 15, 32, "Output",ExpressionUUID->"8cc94914-138c-46c4-b127-0522913798a8"],
Cell[880341, 23439, 1069, 15, 32, "Output",ExpressionUUID->"a0ecb679-44fc-45a2-adfe-8b373fb17df8"],
Cell[881413, 23456, 1069, 15, 32, "Output",ExpressionUUID->"ce6b94b2-0dc7-493e-9d5d-566c3d742592"],
Cell[882485, 23473, 1069, 15, 32, "Output",ExpressionUUID->"c7c6d672-c811-44f3-afc8-88038cf29284"],
Cell[883557, 23490, 1071, 15, 32, "Output",ExpressionUUID->"3000cc97-995a-4e25-b405-6b3bee507bd3"],
Cell[884631, 23507, 1220, 21, 54, "Output",ExpressionUUID->"db5c4b1e-76ca-46ea-baac-38563406ad87"],
Cell[885854, 23530, 1235, 22, 52, "Output",ExpressionUUID->"bf0af573-1315-47c2-a276-8f058c56e7eb"],
Cell[887092, 23554, 1795, 38, 56, "Output",ExpressionUUID->"62da9088-ed27-430b-8542-3cc6e881d13f"],
Cell[888890, 23594, 1069, 15, 32, "Output",ExpressionUUID->"0dd55d09-bfaa-45a8-b060-f2b95649d730"],
Cell[889962, 23611, 1069, 15, 32, "Output",ExpressionUUID->"7315c153-df0e-452c-b6ab-8d6691a0a86b"],
Cell[891034, 23628, 1237, 21, 47, "Output",ExpressionUUID->"a8949d6f-a6b7-47bd-8e0d-310f02125ad4"],
Cell[892274, 23651, 1221, 20, 33, "Output",ExpressionUUID->"b6828fcb-5cc9-4c1f-a98f-92ed8b80dfbc"],
Cell[893498, 23673, 1069, 15, 32, "Output",ExpressionUUID->"cac595f9-3d16-42bf-b6c9-f228ecc9937a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[894604, 23693, 2026, 61, 169, "Input",ExpressionUUID->"5fc70bac-a8f0-4c65-9c2d-5590ceed9eb2"],
Cell[896633, 23756, 511, 8, 32, "Output",ExpressionUUID->"049e9c77-fd56-41c6-abce-09a933182f8c"],
Cell[897147, 23766, 509, 8, 32, "Output",ExpressionUUID->"bd300d95-465f-4f94-b48c-cc8f203bb326"],
Cell[897659, 23776, 509, 8, 32, "Output",ExpressionUUID->"d9f141f6-35ea-43c9-9593-57a296fa6978"],
Cell[898171, 23786, 511, 8, 32, "Output",ExpressionUUID->"b99bfe87-6073-4a29-a46d-68a7097c351b"],
Cell[898685, 23796, 511, 8, 32, "Output",ExpressionUUID->"dd4e3826-4ff8-4101-8110-d68c642f15bd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[899233, 23809, 154, 3, 28, InheritFromParent,ExpressionUUID->"b84ff19d-0710-4a76-b668-a11d1d5f89d0"],
Cell[899390, 23814, 511, 8, 32, "Output",ExpressionUUID->"f92eba5e-c7ca-4f78-a405-23e1f6cca3c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[899938, 23827, 3257, 93, 92, "Input",ExpressionUUID->"e5e53fe4-dd9f-496d-8929-bcc609489ff3"],
Cell[903198, 23922, 177, 3, 32, "Output",ExpressionUUID->"673adc19-b757-4277-a786-8d395ae86249"]
}, Open  ]],
Cell[CellGroupData[{
Cell[903412, 23930, 3083, 79, 197, "Input",ExpressionUUID->"2f17ea41-0df3-4503-b12e-43cb74430512"],
Cell[906498, 24011, 40637, 1066, 598, "Output",ExpressionUUID->"58a2eb8c-2f56-4482-bb29-6e9c3a66d26b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[947172, 25082, 12337, 365, 763, "Input",ExpressionUUID->"2de7bf3c-6dfd-4f72-bcdf-3fb2024963a1"],
Cell[959512, 25449, 651, 10, 32, "Output",ExpressionUUID->"8fb558df-f8a2-4af1-b383-603c9c354ae5"],
Cell[960166, 25461, 654, 10, 32, "Output",ExpressionUUID->"f80dc147-6e4f-494e-88ae-68364ff2ba2e"],
Cell[960823, 25473, 654, 10, 32, "Output",ExpressionUUID->"85b3b33e-d051-4a4d-a2b8-628a940fa9c7"],
Cell[961480, 25485, 654, 10, 32, "Output",ExpressionUUID->"e1f05b64-b904-49ed-940e-b5283969e134"],
Cell[962137, 25497, 654, 10, 32, "Output",ExpressionUUID->"fa3a1648-eb49-4239-aa64-9da39f7e1dfa"],
Cell[962794, 25509, 654, 10, 32, "Output",ExpressionUUID->"ef9238da-3c30-4a08-ae72-5ed9c233db54"],
Cell[963451, 25521, 888, 19, 56, "Output",ExpressionUUID->"5c7939fc-3b0b-4726-b6af-31cf2ac3dd05"],
Cell[964342, 25542, 969, 20, 56, "Output",ExpressionUUID->"f07f1adb-5363-42c1-88cb-edeef288e535"],
Cell[965314, 25564, 5065, 138, 100, "Output",ExpressionUUID->"3f30ae5a-e1a0-4b40-9f50-5c60bb334948"],
Cell[970382, 25704, 1658, 41, 56, "Output",ExpressionUUID->"cd953b3d-001f-49d9-a5ae-b3f6c42ec9a9"],
Cell[972043, 25747, 652, 10, 32, "Output",ExpressionUUID->"24fb16b8-e9b3-41d2-a349-09cb7f831603"],
Cell[972698, 25759, 793, 16, 52, "Output",ExpressionUUID->"7a21f2f6-49ee-4b11-b593-e089888d9f96"],
Cell[973494, 25777, 796, 16, 48, "Output",ExpressionUUID->"c2435062-313f-4b69-a198-537b86728aa8"],
Cell[974293, 25795, 1376, 33, 56, "Output",ExpressionUUID->"7667c8a3-c404-4066-9be9-f601f4493627"]
}, Open  ]],
Cell[CellGroupData[{
Cell[975706, 25833, 2236, 67, 209, "Input",ExpressionUUID->"b67c92c7-3483-4db2-8e59-0122c00fb23d"],
Cell[977945, 25902, 602, 9, 32, "Output",ExpressionUUID->"5897750c-2335-47dd-bb93-07d303e22c03"],
Cell[978550, 25913, 604, 9, 32, "Output",ExpressionUUID->"8af31147-30fa-4e04-b193-70ad578e8364"],
Cell[979157, 25924, 604, 9, 32, "Output",ExpressionUUID->"02183812-ebbd-4885-b3d6-15d3dd522a13"],
Cell[979764, 25935, 604, 9, 32, "Output",ExpressionUUID->"1617ce87-42fe-42f6-b1ec-4822630d6e4e"],
Cell[980371, 25946, 602, 9, 32, "Output",ExpressionUUID->"1f529c59-8a3b-4824-997c-cedc155bfaa4"],
Cell[980976, 25957, 602, 9, 32, "Output",ExpressionUUID->"a1906518-6bf2-4b2e-b4d2-13585ba163e5"],
Cell[981581, 25968, 604, 9, 32, "Output",ExpressionUUID->"f20364bb-cf58-425f-b116-06092648b31e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[982222, 25982, 4033, 112, 95, "Input",ExpressionUUID->"d1e35333-ca18-43ea-8bec-a77fec553109"],
Cell[986258, 26096, 206, 4, 32, "Output",ExpressionUUID->"15ee0c53-b971-4ef5-b530-7a2b4a3a1000"]
}, Open  ]],
Cell[986479, 26103, 11721, 328, 298, "Input",ExpressionUUID->"65bc6409-5187-4f53-be61-22a7067ab4d9"],
Cell[CellGroupData[{
Cell[998225, 26435, 6512, 161, 196, "Input",ExpressionUUID->"2a39c9fc-ad08-4912-b3e8-f274161b3dce"],
Cell[1004740, 26598, 32159, 796, 545, "Output",ExpressionUUID->"24384e40-f81f-4cf2-b38f-3f494b085bf6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036936, 27399, 4830, 112, 170, "Input",ExpressionUUID->"2e8debda-9594-4155-bccc-fed4716c8695"],
Cell[1041769, 27513, 3291, 89, 57, "Output",ExpressionUUID->"1d09c6a5-05ca-4104-8b2d-c6a6d647f23d"],
Cell[1045063, 27604, 1180, 17, 32, "Output",ExpressionUUID->"081969cb-960b-4582-9c72-e1e4c1048390"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1046280, 27626, 14014, 350, 330, "Input",ExpressionUUID->"1dd242da-acaa-4ef4-ab61-44cf481d7ac7"],
Cell[1060297, 27978, 1875, 62, 57, "Output",ExpressionUUID->"0a4db113-15e7-4a78-93df-328f8473fb07"],
Cell[1062175, 28042, 231, 4, 32, "Output",ExpressionUUID->"b3f4913b-bf60-4d00-9f4d-ebe88bbf95d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1062443, 28051, 789, 22, 50, "Input",ExpressionUUID->"754ada5d-0aa3-4e3d-8e50-be54162ac47e"],
Cell[1063235, 28075, 512, 16, 35, "Output",ExpressionUUID->"5fe4b642-0883-4620-9b1b-ba9993b4da3e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1063784, 28096, 750, 24, 52, "Input",ExpressionUUID->"e028a244-067d-4110-b8fa-0da8de67a235"],
Cell[1064537, 28122, 204, 4, 32, "Output",ExpressionUUID->"8398727d-8c5f-4400-9547-13ae0a9e6a50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1064778, 28131, 14148, 354, 288, "Input",ExpressionUUID->"47e1cbbe-5f3f-4cc1-8d7d-87fb0f9fd32c"],
Cell[1078929, 28487, 204, 4, 32, "Output",ExpressionUUID->"03743cf6-3f28-444f-b6d6-0e3c31f2dbe2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1079170, 28496, 14243, 353, 310, "Input",ExpressionUUID->"fc77bfb1-2915-491d-ade8-0e29741bfbe1"],
Cell[1093416, 28851, 2467, 70, 78, "Output",ExpressionUUID->"d973f76c-091a-41b6-9685-63bccec46d3e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1095920, 28926, 13676, 343, 288, "Input",ExpressionUUID->"13242b5d-a6e5-450c-91bb-cfc6e8efe90c"],
Cell[1109599, 29271, 206, 4, 32, "Output",ExpressionUUID->"8e982ef7-ae1c-44a4-ba2d-3c6897d3e1b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1109842, 29280, 1521, 43, 91, "Input",ExpressionUUID->"c35eb5e5-db9e-4a42-91eb-7a48a0777dae"],
Cell[1111366, 29325, 3341, 78, 234, "Output",ExpressionUUID->"2e273f3d-b65a-4b84-b830-064ad8f67eaa"]
}, Open  ]],
Cell[1114722, 29406, 720, 17, 86, "Input",ExpressionUUID->"498b767f-aff4-481a-984c-15fd805e48c8"],
Cell[CellGroupData[{
Cell[1115467, 29427, 1506, 39, 127, "Input",ExpressionUUID->"463b38f1-0a68-4739-8673-450e904d8f45"],
Cell[1116976, 29468, 2722, 86, 57, "Output",ExpressionUUID->"05ea54c5-e30a-4ed6-a3bb-c3467665bffc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1119735, 29559, 717, 16, 86, "Input",ExpressionUUID->"f57df061-aa19-4d52-9e01-c6e2dba4b9a8"],
Cell[1120455, 29577, 3117, 92, 79, "Output",ExpressionUUID->"7e3c3cad-8639-4236-898f-be1341c41e10"]
}, Open  ]],
Cell[1123587, 29672, 309, 5, 28, "Input",ExpressionUUID->"fb4c5459-ded0-4bd6-858c-96ba82b952e6"],
Cell[CellGroupData[{
Cell[1123921, 29681, 1214, 34, 89, "Input",ExpressionUUID->"fadba8c0-49fd-4af7-a7c8-7cd9d7028ce3"],
Cell[1125138, 29717, 5483, 151, 122, "Output",ExpressionUUID->"01d0ea70-09a1-47c8-875b-6dac617b7ba2"],
Cell[1130624, 29870, 5511, 152, 122, "Output",ExpressionUUID->"6b443ee0-f73c-42bf-a12d-bfaf7fb02887"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1136172, 30027, 2586, 72, 203, "Input",ExpressionUUID->"c0bb2204-127d-4281-8450-054e2c02c20a"],
Cell[1138761, 30101, 176138, 4283, 2162, "Output",ExpressionUUID->"5e3bb989-60a4-4945-a505-c149ce02df56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1314936, 34389, 4543, 131, 98, "Input",ExpressionUUID->"29f733e9-612b-43d1-bf8b-0324ffb63467"],
Cell[1319482, 34522, 17914, 464, 232, "Output",ExpressionUUID->"22d1ccd3-ca4d-42b0-bb03-f4818a30d252"],
Cell[1337399, 34988, 11217, 310, 162, "Output",ExpressionUUID->"dc34d50c-2448-4131-baf7-6a25672b423a"],
Cell[1348619, 35300, 16774, 426, 232, "Output",ExpressionUUID->"55544680-03cf-4a0c-a57a-793a7c260a3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1365430, 35731, 1710, 53, 90, "Input",ExpressionUUID->"b2efdf9a-8f2b-4444-8d76-b81015cd6dff"],
Cell[1367143, 35786, 4770, 140, 82, "Output",ExpressionUUID->"ac654c97-5338-464e-8bb3-554d45ad0060"]
}, Open  ]],
Cell[1371928, 35929, 296, 8, 48, "Input",ExpressionUUID->"18ab3049-6067-466a-ad14-df6818079cd1"],
Cell[1372227, 35939, 51186, 1190, 1450, "Input",ExpressionUUID->"ff8888b9-f4ae-490e-9ba7-e01e557d6831"],
Cell[CellGroupData[{
Cell[1423438, 37133, 10298, 276, 267, "Input",ExpressionUUID->"e8579ab6-3e54-44b2-a43f-7c79293dbc19"],
Cell[1433739, 37411, 650397, 18953, 12520, "Output",ExpressionUUID->"66db9e8b-853d-4c06-96c1-5db3c32458a8"]
}, Open  ]],
Cell[2084151, 56367, 1087, 34, 109, "Input",ExpressionUUID->"2bbdfddd-bc4d-4902-89f3-bccdf2ba6a5c"],
Cell[2085241, 56403, 4686, 117, 238, "Input",ExpressionUUID->"6e009eb7-462f-4bbb-87be-f72242ed57c1"],
Cell[CellGroupData[{
Cell[2089952, 56524, 12663, 384, 735, "Input",ExpressionUUID->"b21e0732-17ff-40e3-bc20-3b2700e0bf3f"],
Cell[2102618, 56910, 576, 9, 32, "Output",ExpressionUUID->"88c6f6b5-05b8-4a49-ad7f-511a7d07c4a3"],
Cell[2103197, 56921, 574, 9, 32, "Output",ExpressionUUID->"7d2d26f2-3f81-490f-80bd-5377ba5654a2"],
Cell[2103774, 56932, 576, 9, 32, "Output",ExpressionUUID->"900c0c92-9747-47ef-aad8-7ae6e975303c"],
Cell[2104353, 56943, 574, 9, 32, "Output",ExpressionUUID->"7a5747a9-a2f8-4996-9bdf-4aadc6ff50b7"],
Cell[2104930, 56954, 574, 9, 32, "Output",ExpressionUUID->"ee5ed5c2-4ce7-4ea7-acfd-a3fc788dcb83"],
Cell[2105507, 56965, 576, 9, 32, "Output",ExpressionUUID->"634658c9-1ac5-4a20-95a1-579a9d465823"],
Cell[2106086, 56976, 574, 9, 32, "Output",ExpressionUUID->"b53994ea-475e-4ffa-9083-a90550a5266a"],
Cell[2106663, 56987, 574, 9, 32, "Output",ExpressionUUID->"4cc053a3-8ea8-4c06-ad6e-15228962625a"],
Cell[2107240, 56998, 2668, 77, 59, "Output",ExpressionUUID->"d8927886-d42c-4d2e-b95b-6aa5cc4b7f36"],
Cell[2109911, 57077, 10966, 311, 187, "Output",ExpressionUUID->"87e06be0-2727-415e-8827-edc376e14abf"],
Cell[2120880, 57390, 816, 18, 56, "Output",ExpressionUUID->"9a26c67e-b03d-43d6-bba2-6eee388d6138"],
Cell[2121699, 57410, 1851, 48, 56, "Output",ExpressionUUID->"70053848-beda-4854-b243-3ed4ba728d97"],
Cell[2123553, 57460, 33755, 963, 490, "Output",ExpressionUUID->"17a845f9-a993-425d-b092-f840db4baf22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2157345, 58428, 3104, 82, 123, "Input",ExpressionUUID->"74541849-78d7-452b-91c5-badd3c34928a"],
Cell[2160452, 58512, 650, 10, 32, "Output",ExpressionUUID->"444bc3e9-e5bf-40e2-92c1-42ed9a43fc18"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2161139, 58527, 3064, 87, 166, "Input",ExpressionUUID->"b2ca4bf6-6660-4ea1-8aa0-cb3cea557e9e"],
Cell[2164206, 58616, 444, 13, 52, "Output",ExpressionUUID->"3beff666-7df8-484d-9c9d-5a018c24789c"],
Cell[2164653, 58631, 9539, 285, 184, "Output",ExpressionUUID->"cda2bc2c-8899-4cfc-abc8-1380809a88cf"],
Cell[2174195, 58918, 1455, 43, 56, "Output",ExpressionUUID->"aafd0525-dc1e-4966-8056-70d837b02ca5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2175687, 58966, 1471, 43, 58, "Input",ExpressionUUID->"3ec8e13d-c328-48fd-93d6-81de7edf5277"],
Cell[2177161, 59011, 451, 7, 32, "Output",ExpressionUUID->"985aaa39-077a-468f-8dcc-9bdf3da8ba68"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2177649, 59023, 2564, 72, 204, "Input",ExpressionUUID->"6e2431bb-96d4-47da-bfa4-d5963b7cca27"],
Cell[2180216, 59097, 2932, 86, 76, "Output",ExpressionUUID->"79a75c11-5860-4b76-8764-dff748fc9c5d"],
Cell[2183151, 59185, 22451, 653, 316, "Output",ExpressionUUID->"10ef59c6-5827-41ee-8b7c-711eb4a5ebec"],
Cell[2205605, 59840, 181, 3, 32, "Output",ExpressionUUID->"b5b8b2d4-54b6-45c2-b884-5a347cbd2386"]
}, Open  ]],
Cell[2205801, 59846, 173, 3, 48, "Input",ExpressionUUID->"a668259d-f84d-4d73-99c5-155770e8fb17"],
Cell[CellGroupData[{
Cell[2205999, 59853, 7767, 229, 169, "Input",ExpressionUUID->"628792cb-5d0c-4824-b1fa-fcee73a32604"],
Cell[2213769, 60084, 153, 3, 32, "Output",ExpressionUUID->"a7d7b5c7-fd5d-4818-ab51-93e92bf34a5a"]
}, Open  ]],
Cell[2213937, 60090, 4479, 111, 219, "Input",ExpressionUUID->"4748d497-d020-4045-a1f5-96b647ccdb76"],
Cell[CellGroupData[{
Cell[2218441, 60205, 4448, 137, 234, "Input",ExpressionUUID->"328c6d74-d1ff-478f-a532-10265dcc83dc"],
Cell[2222892, 60344, 425, 7, 32, "Output",ExpressionUUID->"f1c64e55-ec53-406f-bc8c-5f5fe59bb478"],
Cell[2223320, 60353, 425, 7, 32, "Output",ExpressionUUID->"ad3d640e-1253-4f2a-b878-c02845f4b2d0"],
Cell[2223748, 60362, 423, 7, 32, "Output",ExpressionUUID->"cdf331da-27c6-4bdd-bae5-a8a754c62d97"],
Cell[2224174, 60371, 425, 7, 32, "Output",ExpressionUUID->"12b8e342-6dac-4b10-b02f-9aa18a904040"],
Cell[2224602, 60380, 425, 7, 32, "Output",ExpressionUUID->"f6343ae7-96aa-4ab8-ad79-7e85c5f6e23d"],
Cell[2225030, 60389, 425, 7, 32, "Output",ExpressionUUID->"b4b343cd-e46a-4596-b2a0-6b620d4f89ff"],
Cell[2225458, 60398, 425, 7, 32, "Output",ExpressionUUID->"1fe68cde-fad0-43bb-b68f-a07283154773"],
Cell[2225886, 60407, 422, 7, 32, "Output",ExpressionUUID->"40432689-2721-40c3-aec8-996114c607bd"],
Cell[2226311, 60416, 422, 7, 32, "Output",ExpressionUUID->"750204f0-e0d4-4f83-bd83-3cc64d2a90df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2226770, 60428, 3887, 102, 131, "Input",ExpressionUUID->"18f10bac-a49c-41a6-bf28-9903e1a7cb4d"],
Cell[2230660, 60532, 1071, 21, 53, "Output",ExpressionUUID->"57abadfb-f24c-4f5b-887f-f8635bc88215"],
Cell[2231734, 60555, 9925, 289, 184, "Output",ExpressionUUID->"3d1b935f-f6d5-486f-a4ea-34ba55d62830"],
Cell[2241662, 60846, 1608, 35, 56, "Output",ExpressionUUID->"7f8236af-263d-45a6-8bfa-1256f95c6b1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2243307, 60886, 1791, 48, 50, "Input",ExpressionUUID->"dcd87bff-b16b-4b4a-9e19-07eb26e33fed"],
Cell[2245101, 60936, 527, 8, 32, "Output",ExpressionUUID->"63e9bc6b-c0e8-43c7-90fc-134d76d4d5e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2245665, 60949, 1118, 31, 107, "Input",ExpressionUUID->"8cc28d3b-a336-44c5-9427-e58590c690ff"],
Cell[2246786, 60982, 275, 5, 32, "Output",ExpressionUUID->"bb69283c-7bb5-4002-980a-b71cec3239c2"],
Cell[2247064, 60989, 275, 5, 32, "Output",ExpressionUUID->"a743b315-cdab-483f-86e9-2773b6bb31d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2247376, 60999, 3265, 91, 132, "Input",ExpressionUUID->"834328b1-2ce4-4a4c-aba2-1d7ca5aa207f"],
Cell[2250644, 61092, 2231, 60, 56, "Output",ExpressionUUID->"920074ed-b55a-4952-bcb7-c28fb0c16093"],
Cell[2252878, 61154, 1400, 33, 56, "Output",ExpressionUUID->"133774a0-43e8-418a-ae6d-23e35d3794d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2254315, 61192, 1545, 42, 50, "Input",ExpressionUUID->"d9b3e047-0a83-4e53-b7af-71108b2ab168"],
Cell[2255863, 61236, 367, 6, 32, "Output",ExpressionUUID->"72995a4c-0c5c-4d66-a5e9-3025110eb717"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2256267, 61247, 2087, 54, 50, "Input",ExpressionUUID->"d491b881-87f6-49e2-a7d8-1537e0d1d2e1"],
Cell[2258357, 61303, 646, 10, 32, "Output",ExpressionUUID->"8a18eab2-8e2c-459a-a95f-7104cc76afab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2259040, 61318, 6044, 174, 114, "Input",ExpressionUUID->"30f54c28-f581-46b5-b4a4-c00f1d254e7a"],
Cell[2265087, 61494, 153, 3, 32, "Output",ExpressionUUID->"ecf52e72-4796-4e5e-aeb3-771dc0e5882b"]
}, Open  ]],
Cell[2265255, 61500, 309, 7, 48, "Input",ExpressionUUID->"7a722f88-c141-429d-a593-88e67925100e"],
Cell[2265567, 61509, 4105, 103, 181, "Input",ExpressionUUID->"dac08126-96b4-4d46-8299-d5f9c30069e4"],
Cell[CellGroupData[{
Cell[2269697, 61616, 5594, 161, 237, "Input",ExpressionUUID->"e83b6254-65a5-4101-bbd6-fa5c628078f5"],
Cell[2275294, 61779, 453, 7, 32, "Output",ExpressionUUID->"e0e41bb3-f76c-48fa-aea4-d4d9e3eb5eac"],
Cell[2275750, 61788, 453, 7, 32, "Output",ExpressionUUID->"d06590a3-82dc-457e-ae83-324f8c057b17"],
Cell[2276206, 61797, 451, 7, 32, "Output",ExpressionUUID->"43844690-1f1d-449c-b063-efd0f92676cf"],
Cell[2276660, 61806, 453, 7, 32, "Output",ExpressionUUID->"a5a1ed9d-8fc0-4e36-936e-9a8a94727578"],
Cell[2277116, 61815, 453, 7, 32, "Output",ExpressionUUID->"e223c08a-dcc3-49a4-8d7d-83cada83c030"],
Cell[2277572, 61824, 451, 7, 32, "Output",ExpressionUUID->"cf8967d7-3508-4276-a581-a43efdc4ed97"],
Cell[2278026, 61833, 451, 7, 32, "Output",ExpressionUUID->"1aea9aae-0703-4973-806f-7b4d264fe2f0"],
Cell[2278480, 61842, 453, 7, 32, "Output",ExpressionUUID->"f462da65-cccf-49eb-ad5c-eb87ee7bce2b"],
Cell[2278936, 61851, 453, 7, 32, "Output",ExpressionUUID->"a1ac656f-93a7-45ee-a7ea-aceed670a33c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2279426, 61863, 28216, 747, 971, "Input",ExpressionUUID->"6cb3350f-d84b-4a6a-abde-0d528dc6b47a"],
Cell[2307645, 62612, 570, 15, 52, "Output",ExpressionUUID->"2ce31452-4c0d-435a-91a9-e4d007bb1602"],
Cell[2308218, 62629, 279, 5, 32, "Output",ExpressionUUID->"e6879661-3718-4074-9e6d-dcdd83185abd"],
Cell[2308500, 62636, 8975, 260, 184, "Output",ExpressionUUID->"e7302cad-4562-48ab-8cc6-e86368c228b4"],
Cell[2317478, 62898, 279, 5, 32, "Output",ExpressionUUID->"99c3e29e-87d0-4b76-9be4-11e0a5c474b6"],
Cell[2317760, 62905, 1636, 46, 56, "Output",ExpressionUUID->"285f17d3-aef3-4bc6-8a80-832ca34fda79"],
Cell[2319399, 62953, 277, 5, 32, "Output",ExpressionUUID->"cb2de350-329d-4cfb-9dc9-0bfe72f8cf66"],
Cell[2319679, 62960, 2175, 64, 59, "Output",ExpressionUUID->"b959a65b-bcd3-48dd-9113-4377079d8ff3"],
Cell[2321857, 63026, 279, 5, 32, "Output",ExpressionUUID->"da5950b0-d71d-4650-8a09-1ed701a357fa"],
Cell[2322139, 63033, 3028, 88, 76, "Output",ExpressionUUID->"66f26830-7cca-40a4-9109-dadc0d4052a5"],
Cell[2325170, 63123, 277, 5, 32, "Output",ExpressionUUID->"a821c5ab-0d71-4967-a51f-3c35db8e0702"],
Cell[2325450, 63130, 275, 5, 32, "Output",ExpressionUUID->"0e12db42-06c0-4fae-9de0-3861ef29f47e"],
Cell[2325728, 63137, 483, 12, 54, "Output",ExpressionUUID->"54ad1815-c380-4788-9f70-046129533cef"],
Cell[2326214, 63151, 279, 5, 32, "Output",ExpressionUUID->"6cd26cab-51f3-4179-a9b9-95ff1447fda8"],
Cell[2326496, 63158, 1596, 46, 56, "Output",ExpressionUUID->"6d4881d4-8a23-4ec6-a057-a1b651477f99"],
Cell[2328095, 63206, 277, 5, 32, "Output",ExpressionUUID->"7c720f39-b822-45a1-8b9c-4631e1e3f8f2"],
Cell[2328375, 63213, 22479, 657, 316, "Output",ExpressionUUID->"08f885f0-1b88-4f4f-ae04-488713aad577"],
Cell[2350857, 63872, 279, 5, 32, "Output",ExpressionUUID->"3b6ab1fb-24b9-4ca0-a48f-5a727549a623"],
Cell[2351139, 63879, 29958, 824, 490, "Output",ExpressionUUID->"f9902262-b8bb-40e9-872a-06f4fb0a8fd4"],
Cell[2381100, 64705, 277, 5, 32, "Output",ExpressionUUID->"45b96e24-00df-4d8a-a5ec-cbb886172693"],
Cell[2381380, 64712, 277, 5, 32, "Output",ExpressionUUID->"f2c23f66-d9ba-468a-a5b5-5eda011f7728"],
Cell[2381660, 64719, 277, 5, 32, "Output",ExpressionUUID->"be79f23c-0ced-4991-ba88-be6537c95489"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2381974, 64729, 7269, 205, 181, "Input",ExpressionUUID->"ba5d9d5b-5cbd-423e-aed8-af60fcd84b86"],
Cell[2389246, 64936, 155, 3, 32, "Output",ExpressionUUID->"80850c10-176f-4a07-8c9e-08a7449945f8"]
}, Open  ]],
Cell[2389416, 64942, 22357, 631, 528, "Input",ExpressionUUID->"16cde742-a8c1-47ae-8cba-e0c7ab5daca6"],
Cell[CellGroupData[{
Cell[2411798, 65577, 6864, 168, 218, "Input",ExpressionUUID->"1e8725b6-ec7d-4bdc-b0ee-57e04e768c04"],
Cell[2418665, 65747, 123007, 2930, 1927, "Output",ExpressionUUID->"07e9fb3b-336a-46bc-9d9c-40e611a92cf3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2541709, 68682, 4506, 110, 152, "Input",ExpressionUUID->"1a1278fe-33c9-42a0-98ee-d5a5fac63a54"],
Cell[2546218, 68794, 31675, 1047, 846, "Output",ExpressionUUID->"bc7d835e-a9bf-4334-bd2e-a1428eb65218"],
Cell[2577896, 69843, 13469, 389, 231, "Output",ExpressionUUID->"7a3df315-26c7-433a-8fdd-cded8a2c6803"],
Cell[2591368, 70234, 9814, 313, 210, "Output",ExpressionUUID->"7bf5152d-688a-4f1c-b97c-fad8dd466994"],
Cell[2601185, 70549, 255, 5, 32, "Output",ExpressionUUID->"6f05c78a-eab8-4f44-9770-14ceb3fbacbe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2601477, 70559, 14991, 370, 329, "Input",ExpressionUUID->"7301fd50-7351-409a-88be-e0e339e927f9"],
Cell[2616471, 70931, 457, 7, 32, "Output",ExpressionUUID->"a0fe0110-5a2b-45ca-96bb-1c4ad0da1200"],
Cell[2616931, 70940, 879, 22, 35, "Output",ExpressionUUID->"3aaef6b3-3213-42cb-b924-a166fd68d0c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2617847, 70967, 439, 11, 50, "Input",ExpressionUUID->"c86181bb-aa79-48f2-b5dc-0cb1d8bbf578"],
Cell[2618289, 70980, 559, 17, 35, "Output",ExpressionUUID->"b28fa5c0-e0cf-428c-8cd2-ef1068858f4e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2618885, 71002, 675, 15, 50, "Input",ExpressionUUID->"a41513ca-85e9-4402-ac7a-9c7275d3966a"],
Cell[2619563, 71019, 10645, 315, 210, "Output",ExpressionUUID->"91fdc96b-50d6-4b8d-a611-8ee30c28cc66"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2630245, 71339, 14070, 351, 289, "Input",ExpressionUUID->"08c7cb8f-93d3-44a7-8370-9b700c80dab4"],
Cell[2644318, 71692, 228, 4, 32, "Output",ExpressionUUID->"33e8c214-313c-42e7-8838-c2f0b1e7cc06"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2644583, 71701, 14886, 374, 351, "Input",ExpressionUUID->"313ef85e-64b3-43fc-b3d2-f04da46ee630"],
Cell[2659472, 72077, 561, 18, 35, "Output",ExpressionUUID->"6939e8a7-4eb7-4c8f-a836-cd1d3f398b64"],
Cell[2660036, 72097, 8340, 244, 144, "Output",ExpressionUUID->"953caabe-0df4-4b81-8c14-afddada04450"],
Cell[2668379, 72343, 155, 3, 32, "Output",ExpressionUUID->"ec2a68d1-d3c5-4c32-92ed-4bfd33e4df8c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2668571, 72351, 1587, 41, 88, "Input",ExpressionUUID->"7a7f320d-c42c-4843-ad2b-c33e768dfcbc"],
Cell[2670161, 72394, 12927, 372, 210, "Output",ExpressionUUID->"9563ba35-9709-416e-934c-d4ad7a5e6e3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2683125, 72771, 27330, 643, 655, "Input",ExpressionUUID->"edf7fc16-c5e7-4adc-9c98-b004201f591b"],
Cell[2710458, 73416, 405305, 8774, 13210, "Output",ExpressionUUID->"4b61fdc1-f73a-472a-8591-923909133a4f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3115800, 82195, 1808, 48, 105, "Input",ExpressionUUID->"8bef914d-c6c4-49a4-891c-0111c907dd63"],
Cell[3117611, 82245, 6144, 128, 221, "Output",ExpressionUUID->"bc53aec2-66b7-460f-b481-9818f3dd322e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3123792, 82378, 9802, 248, 526, "Input",ExpressionUUID->"082e8917-adaa-41b2-8c4d-9b117ae2feca"],
Cell[3133597, 82628, 749, 26, 56, "Output",ExpressionUUID->"a7c7c826-031f-4b8e-8180-5cb316da36be"],
Cell[3134349, 82656, 1372, 44, 57, "Output",ExpressionUUID->"2f3b60cf-f39e-4529-b050-75acb71e1a39"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3135758, 82705, 2729, 65, 195, "Input",ExpressionUUID->"ce138119-686f-4db0-82d6-bba94acbee4a"],
Cell[3138490, 82772, 50343, 1251, 738, "Output",ExpressionUUID->"aedb40b0-84d0-4f78-a4cc-e4c06d017752"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3188870, 84028, 486, 11, 48, "Input",ExpressionUUID->"1abe67bc-c792-4a96-8bac-cd5b49c15d9d"],
Cell[3189359, 84041, 326, 9, 34, "Output",ExpressionUUID->"30f85621-bb7a-42a8-825f-727fe3a9b6d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3189722, 84055, 3684, 90, 231, "Input",ExpressionUUID->"f56c7404-d985-4157-b8c0-7375c785968e"],
Cell[3193409, 84147, 18149, 454, 301, "Output",ExpressionUUID->"951ccae8-2404-4c85-bf2f-5dd1ae856ff1"]
}, Open  ]]
}, Open  ]]
}
]
*)

