(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    760759,      19987]
NotebookOptionsPosition[    742567,      19704]
NotebookOutlinePosition[    742974,      19720]
CellTagsIndexPosition[    742931,      19717]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["WWP Benjamin-Feir Instability in Infinite Depth", "Title",
 CellChangeTimes->{{3.8192388728325577`*^9, 3.8192388826940904`*^9}, {
  3.8193909848370275`*^9, 3.819390986613413*^9}, {3.8359739435520277`*^9, 
  3.83597394405205*^9}, {3.836575147121694*^9, 3.836575154204263*^9}, {
  3.845987011287741*^9, 3.84598701801322*^9}, {3.863191803777553*^9, 
  3.863191814404912*^9}},ExpressionUUID->"ba24433a-2239-4b25-8573-\
ba4631ec5202"],

Cell["\<\

CONTACT INFORMATION :
  
Ryan P. Creedon
Department of Applied Mathematics
University of Washington, Seattle, WA

DIRECTIONS:

To evaluate this file, click the Evaluation tab above and then Evaluate \
Notebook from the drop-down menu. \
\>", "Text",
 CellChangeTimes->{{3.8359739788280864`*^9, 3.8359739993363094`*^9}, {
  3.8359748293243628`*^9, 3.8359748316548395`*^9}, {3.8360662583760843`*^9, 
  3.8360663650634575`*^9}, {3.8631918188326807`*^9, 
  3.8631918192505507`*^9}},ExpressionUUID->"6191803d-c320-4297-8345-\
33ecb4699c97"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"0.", "Notation"}], "Section"]}]], "Input",
 CellChangeTimes->{{3.835974027162642*^9, 3.8359740334637904`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"ccff6626-5de1-4901-a6fd-06a8cd451827"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   StyleBox[
    RowBox[{"STOKES", "  ", "WAVES"}], "Subsubsection"], 
   "\[IndentingNewLine]", 
   StyleBox["\[IndentingNewLine]", "Subsubsection"], 
   RowBox[{
    RowBox[{"\[Alpha]", " ", ":", " ", 
     RowBox[{
     "aspect", " ", "ratio", " ", "of", " ", "dimensional", " ", "Stokes", 
      " ", "waves"}]}], ",", " ", 
    RowBox[{">", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"specified", " ", "by", " ", "user"}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]", " ", ":", " ", 
     RowBox[{"small", "-", 
      RowBox[{"amplitude", " ", "parameter"}]}]}], ",", 
    RowBox[{">", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"specified", " ", "by", " ", "user"}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "0"], " ", ":", " ", 
     RowBox[{"zero", "-", 
      RowBox[{"amplitude", " ", "Stokes", " ", "wave", " ", "velocity"}]}]}], 
    ",", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "0"], " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Tanh", "[", "\[Alpha]", "]"}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Omega]", " ", ":", " ", 
     RowBox[{
     "dispersion", " ", "relation", " ", "of", " ", "nondimensional", " ", 
      "Euler", " ", "equations", " ", "in", " ", "stationary", " ", 
      "frame"}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Omega]", "[", "k", "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Sign", "[", "k", "]"}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"Abs", "[", "k", "]"}], "]"}]}]}], ";"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", " ", ":", " ", 
     RowBox[{
     "dispersion", " ", "relation", " ", "of", " ", "nondimensional", " ", 
      "Euler", " ", "equations", " ", "in", " ", "traveling", " ", 
      "frame"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"k", ",", "\[Sigma]"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["c", "0"]}], "*", "k"}], "+", 
       RowBox[{"\[Sigma]", "*", 
        RowBox[{"\[Omega]", "[", "k", "]"}]}]}]}], " ", ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Sigma]", " ", ":", " ", 
      RowBox[{
      "indicates", " ", "branch", " ", "of", " ", "dispersion", " ", 
       "relation"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"\[Sigma]", " ", "=", " ", 
      RowBox[{"+", 
       RowBox[{"/", 
        RowBox[{"-", " ", "1"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["c", "g"], " ", ":", " ", 
      RowBox[{
      "group", " ", "velocity", " ", "of", " ", "nondimensional", " ", 
       "Euler", " ", "equations", " ", "in", " ", "traveling", " ", 
       "frame"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["c", "g"], "[", 
       RowBox[{"k", ",", "\[Sigma]"}], "]"}], " ", "=", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[CapitalOmega]", "[", 
         RowBox[{"k", ",", "\[Sigma]"}], "]"}], ",", "k"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["c", "j"], " ", ":", " ", 
      RowBox[{"O", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "correction", " ", "of",
        " ", "Stokes", " ", "wave", " ", "velocity"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"see", " ", "Appendix", " ", "A", " ", "in", " ", "manuscript"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{
      SubscriptBox["\[Eta]", 
       SubscriptBox["S", "j"]], " ", ":", " ", 
      RowBox[{"O", 
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "correction", " ", "of",
        " ", "Stokes", " ", "wave", " ", "surface", " ", "displacement"}]}]}],
     ",", " ", 
    RowBox[{
     RowBox[{"see", " ", "Appendix", " ", "A", " ", "in", " ", "manuscript"}],
      ";"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["N", 
      RowBox[{"j", ",", "k"}]], ":", " ", 
     RowBox[{
     "kth", " ", "complex", " ", "Fourier", " ", "series", " ", "coefficient",
       " ", "of", " ", 
      SubscriptBox["\[Eta]", 
       SubscriptBox["S", "j"]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", 
      SubscriptBox["S", "j"]], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "correction", " ", "of", 
      " ", "Stokes", " ", "wave", " ", "horizontal", " ", "velocity", " ", 
      "potential", " ", "along", " ", "surface", " ", "displacement"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Q", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{
     "kth", " ", "complex", " ", "Fourier", " ", "cosine", " ", "series", " ",
       "coefficient", " ", "of", " ", 
      SubscriptBox["q", 
       SubscriptBox["S", "j"]]}]}], ";"}], "\[IndentingNewLine]", 
   StyleBox["\[IndentingNewLine]", "Subsubsection"], 
   StyleBox[
    RowBox[{"BF", " ", "INSTABILITY", " ", "PARAMETERS"}], "Subsubsection"], 
   "\[IndentingNewLine]", 
   StyleBox["\[IndentingNewLine]", "Subsubsection"], 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Lambda]", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "eigenvalue", " ", 
      "correction"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "eigenfunction", " ", 
      "correction"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"j", ",", "\[Nu]"}]], " ", ":", " ", 
     RowBox[{
     "coefficient", " ", "of", " ", "nullspace", " ", "component", " ", "of", 
      " ", 
      SubscriptBox["w", "j"], " ", 
      RowBox[{"(", 
       RowBox[{"here", ",", " ", 
        RowBox[{
         RowBox[{"\[Nu]", " ", "can", " ", "be", " ", "zero", " ", "or"}], 
         " ", "+", 
         RowBox[{"/", 
          RowBox[{"-", "1"}]}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Mu]", "j"], " ", ":", " ", 
     RowBox[{"O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "Floquet", " ", 
      "exponent", " ", "correction"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", "j"], " ", ":", " ", 
     RowBox[{
     "inhomogeneous", " ", "forcing", " ", "terms", " ", "in", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "spectral", " ", 
      "problem"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{"gives", " ", "terms", " ", "proportional", " ", "to", " ", 
      RowBox[{"Exp", "[", "\[ImaginaryI]kx", "]"}], " ", "from", " ", 
      SubscriptBox["IHT", "j"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      RowBox[{
       SubscriptBox["g", 
        RowBox[{"\[Sigma]", ",", "k"}]], " "}]], ":", " ", 
     RowBox[{
      SubscriptBox["c", "g"], "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", "0"], "+", "k"}], ",", "\[Sigma]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["FA", "k"], " ", ":", " ", 
     RowBox[{
     "vector", " ", "given", " ", "by", " ", "Fredholm", " ", "alternative", 
      " ", "to", " ", "enforce", " ", "solvability", " ", "condition", " ", 
      "k"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "j"], " ", ":", " ", 
     RowBox[{"\[Omega]", "[", 
      RowBox[{
       SubscriptBox["\[Mu]", "0"], "+", "j"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{"solvability", " ", "condition", " ", "k", " ", "at", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["partsoln", "j"], " ", ":", " ", 
     RowBox[{"gives", " ", "particular", " ", "solution", " ", "to", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}], " ", "spectral", " ", 
      "problem", " ", "as", " ", "list", " ", "of", " ", "Fourier", " ", 
      "coefficients"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{
     "1", "st", " ", "component", " ", "of", " ", "the", " ", "kth", " ", 
      "complex", " ", "Fourier", " ", "mode", " ", "of", " ", "the", " ", 
      "particular", " ", "solution", " ", "at", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"j", ",", "k"}]], " ", ":", " ", 
     RowBox[{
     "2", "nd", " ", "component", " ", "of", " ", "the", " ", "kth", " ", 
      "complex", " ", "Fourier", " ", "mode", " ", "of", " ", "the", " ", 
      "particular", " ", "solution", " ", "at", " ", "O", 
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", "^", "j"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"NOTE", ":", " ", 
    RowBox[{
    "There", " ", "are", " ", "intermediate", " ", "variables", " ", 
     "introduced", " ", "throughout", " ", "the", " ", 
     RowBox[{"notebook", "."}]}]}]}]}]], "Text",
 CellChangeTimes->{{3.835967494378304*^9, 3.8359678405664425`*^9}, {
  3.8359679064696054`*^9, 3.8359684755830774`*^9}, {3.8359685203027396`*^9, 
  3.835968532292381*^9}, {3.835968716470956*^9, 3.8359687271398926`*^9}, {
  3.8359688136680813`*^9, 3.835968832022024*^9}, {3.835968989245056*^9, 
  3.835969023242552*^9}, {3.8359692057747917`*^9, 3.835969236915213*^9}, {
  3.835969284709839*^9, 3.835969294947506*^9}, {3.83596939832705*^9, 
  3.8359695644186897`*^9}, {3.83596961519704*^9, 3.8359696679086685`*^9}, {
  3.835971565845647*^9, 3.835971593456355*^9}, {3.835972280078453*^9, 
  3.835972281565465*^9}, {3.8359740599094815`*^9, 3.8359740601148305`*^9}, {
  3.8484062755960054`*^9, 3.8484062828461123`*^9}, {3.863191851705318*^9, 
  3.8631918931603312`*^9}},ExpressionUUID->"6bcf5db7-6cd2-4752-9f92-\
acce56985265"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"I", ".", " ", "Useful"}], " ", "Functions"}], 
   "Section"]}]], "Input",
 CellChangeTimes->{{3.819238884200651*^9, 3.8192389095370846`*^9}, {
  3.8224001988803053`*^9, 3.8224002008840256`*^9}, {3.822401321523795*^9, 
  3.8224013249174266`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"bc51a555-ed69-478d-bf82-1344bd2f20c2"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Linearized", " ", "dispersion", " ", "relation", " ", "of", " ", 
    RowBox[{"WWP", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalOmega]", "[", 
      RowBox[{"k_", ",", "\[Sigma]_"}], "]"}], ":=", " ", 
     RowBox[{
      RowBox[{"-", "k"}], "+", 
      RowBox[{"\[Sigma]", "*", 
       RowBox[{"\[Omega]", "[", "k", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Omega]", "[", "k_", "]"}], " ", ":=", " ", 
     RowBox[{
      RowBox[{"Sign", "[", "k", "]"}], "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Abs", "[", "k", "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "*", " ", "nth", " ", "order", " ", "Floquet", " ", "differentiation", 
      " ", "of", " ", 
      RowBox[{"f", ".", " ", "Computes"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Mu]", "0"], "+", 
         SubscriptBox["D", "x"]}], ")"}], "^", 
       RowBox[{"n", "[", 
        RowBox[{"f", "[", "x", "]"}], "]"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"where", " ", 
       SubscriptBox["D", "x"]}], " ", "=", " ", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[ImaginaryI]d", "x"], "."}]}]}]}], " ", "**)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Fdiff", "[", 
      RowBox[{"f_", ",", "n_"}], "]"}], " ", ":=", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"n", "\[Equal]", "0"}], ",", "f", ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Nu]", "-", 
               RowBox[{"\[ImaginaryI]", "*", "diff"}]}], ")"}], "^", "n"}], 
            "]"}], " ", "/.", " ", 
           RowBox[{
            RowBox[{"diff", "^", "j_"}], " ", "\[RuleDelayed]", " ", 
            RowBox[{"D", "[", 
             RowBox[{"f", ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "j"}], "}"}]}], "]"}]}]}], " ", "//.", " ", 
          RowBox[{"diff", " ", "\[Rule]", " ", 
           RowBox[{"D", "[", 
            RowBox[{"f", ",", "x"}], "]"}]}]}], "//.", " ", 
         RowBox[{
          RowBox[{"\[Nu]", "^", "n"}], " ", "\[Rule]", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[Mu]", "0"], "^", "n"}], "*", "f"}]}]}], " ", "//.",
         " ", 
        RowBox[{"\[Nu]", " ", "\[Rule]", " ", 
         SubscriptBox["\[Mu]", "0"]}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Expand", " ", "q", " ", "into", " ", "a", " ", "complex", " ", 
     "Fourier", " ", 
     RowBox[{"sum", ".", " ", "Useful"}], " ", "when", " ", "q", " ", "is", 
     " ", "a", " ", "product", " ", "of", " ", "sinusoidal", " ", 
     RowBox[{"functions", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FourierSum", "[", "q_", "]"}], " ", ":=", " ", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"TrigToExp", "[", "q", "]"}], "]"}], " ", "/.", " ", 
      RowBox[{
       RowBox[{"Exp", "[", "\[Theta]_", "]"}], "\[RuleDelayed]", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"Simplify", "[", "\[Theta]", "]"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "*", " ", "Creates", " ", "list", " ", "of", " ", "complex", " ", 
      "Fourier", " ", "coefficients", " ", "of", " ", "a", " ", "generic", 
      " ", "function", " ", "q", " ", "without", " ", "using", " ", "the", 
      " ", "expensive", " ", "built"}], "-", 
     RowBox[{"in", " ", "FourierCoefficient", " ", "Mathematica", " ", 
      RowBox[{"function", ".", " ", "Must"}], " ", "provide", " ", "a", " ", 
      "list", " ", "of", " ", "desired", " ", "Fourier", " ", "modes", " ", 
      RowBox[{"k", ".", " ", "List"}], " ", "must", "\[IndentingNewLine]", 
      "be", " ", "ordered", " ", "from", " ", "least", " ", "to", " ", 
      RowBox[{"greatest", "."}]}]}], "  ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NCoefficient", "[", 
      RowBox[{"q_", ",", "k_"}], "]"}], " ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"vecpoly", "=", 
        RowBox[{"Expand", "[", " ", 
         RowBox[{
          RowBox[{"z", "^", 
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"k", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"TrigToExp", "[", "q", "]"}], " ", "/.", " ", 
             RowBox[{
              RowBox[{"Exp", "[", "\[Theta]_", "]"}], "\[RuleDelayed]", " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"Simplify", "[", "\[Theta]", "]"}], "]"}]}]}], "/.", 
            " ", 
            RowBox[{
             RowBox[{"Exp", "[", "y_", "]"}], " ", "\[RuleDelayed]", " ", 
             RowBox[{"z", "^", 
              RowBox[{"(", 
               RowBox[{"Simplify", "[", 
                RowBox[{
                 RowBox[{"y", "/", "\[ImaginaryI]"}], "/", "x"}], "]"}], 
               ")"}]}]}]}], ")"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"FourierCoeff", " ", "=", " ", 
        RowBox[{
         RowBox[{"{", "vecpoly", "}"}], " ", "//.", " ", 
         RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "2"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"FourierCoeffj", " ", "=", " ", 
           RowBox[{"Coefficient", "[", 
            RowBox[{"vecpoly", ",", 
             RowBox[{"z", "^", 
              RowBox[{"(", 
               RowBox[{"j", "-", "1"}], ")"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"FourierCoeff", " ", "=", " ", 
           RowBox[{"Append", "[", 
            RowBox[{"FourierCoeff", ",", "FourierCoeffj"}], "]"}]}]}]}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Dimensions", "[", "q", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", ">", " ", "1"}], ",", 
         RowBox[{"FinalFourierCoeff", "=", 
          RowBox[{"Transpose", "[", "FourierCoeff", "]"}]}], ",", 
         RowBox[{"FinalFourierCoeff", " ", "=", " ", "FourierCoeff"}]}], 
        "]"}], ";", "\[IndentingNewLine]", "FinalFourierCoeff"}], ")"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", 
     RowBox[{"NOTE", ":", " ", 
      RowBox[{"q", " ", "must", " ", "be", " ", "a", " ", 
       RowBox[{"vector", ".", " ", "k"}], " ", "must", " ", "be", " ", "a", 
       " ", "vector", " ", "of", " ", "sequential", " ", 
       RowBox[{"integers", "."}]}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "*", " ", "Generate", " ", "the", " ", "nth", " ", "order", " ", 
     "modulation", " ", "of", " ", "a", " ", "list", " ", "of", " ", 
     "wavenumbers", " ", 
     RowBox[{"k", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GenModulate", "[", 
      RowBox[{"k_", ",", "n_"}], "]"}], " ", ":=", "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"S", ",", "P"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"S", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"P", " ", "=", " ", 
           RowBox[{"Union", "[", 
            RowBox[{"S", ",", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "+", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"-", "n"}], ",", "n"}], "]"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"S", " ", "=", " ", "P"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "P"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ", 
      "of", " ", "nth"}], "-", 
     RowBox[{"order", " ", 
      RowBox[{"problem", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"partsoln", "[", 
      RowBox[{"IHT_", ",", "k_", ",", "n_"}], "]"}], ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "S", "]"}], ";", " ", 
       RowBox[{"S", " ", "=", " ", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{"j", " ", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"A", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[ImaginaryI]", "*", 
                 RowBox[{"(", 
                  RowBox[{"k", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], ")"}], "*", 
                 RowBox[{"Abs", "[", 
                  RowBox[{"k", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "]"}]}], ")"}], ",", 
               RowBox[{
                RowBox[{"Abs", "[", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], "]"}], "^", "2"}]}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"(", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ")"}]}]}], "}"}]}], "}"}]}],
           ";", "\[IndentingNewLine]", 
          RowBox[{
           SubscriptBox["w", 
            RowBox[{"n", ",", 
             RowBox[{"k", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]], " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"n", ",", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]], ",", 
             SubscriptBox["\[Phi]", 
              RowBox[{"n", ",", 
               RowBox[{"k", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}]]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           SubscriptBox["soln", "j"], " ", "=", " ", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Simplify", "[", 
             RowBox[{"Solve", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"A", ".", 
                  SubscriptBox["w", 
                   RowBox[{"n", ",", 
                    RowBox[{"k", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]]}], " ", "-", " ", 
                 RowBox[{"IHT", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "j"}], "]"}], "]"}]}], "\[Equal]", 
                "0"}], ",", 
               SubscriptBox["w", 
                RowBox[{"n", ",", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]]}], "]"}], "]"}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"S", "=", 
           RowBox[{"Append", "[", 
            RowBox[{"S", ",", 
             SubscriptBox["soln", "j"]}], "]"}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "S"}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.819238914040369*^9, 3.819238931335683*^9}, {
   3.8195464364800186`*^9, 3.819546437366968*^9}, {3.822400204731432*^9, 
   3.822400265579567*^9}, {3.822400376288105*^9, 3.8224004688432393`*^9}, {
   3.822400513730723*^9, 3.8224005238869734`*^9}, {3.8224005614484057`*^9, 
   3.8224005806500664`*^9}, {3.8224006437796993`*^9, 3.82240064763846*^9}, {
   3.822400796629356*^9, 3.8224008397709475`*^9}, {3.822400968234866*^9, 
   3.822401143844735*^9}, {3.822401191960985*^9, 3.8224012005366144`*^9}, {
   3.8224012747947936`*^9, 3.8224013172608485`*^9}, {3.822401400212161*^9, 
   3.822401412422224*^9}, {3.8224029097501497`*^9, 3.822402940200775*^9}, {
   3.822402983006024*^9, 3.822403105862302*^9}, {3.8224031750596266`*^9, 
   3.822403212563414*^9}, {3.8224034468734493`*^9, 3.82240349363069*^9}, {
   3.8224036573242817`*^9, 3.822403793330802*^9}, {3.822403846361758*^9, 
   3.8224039801203933`*^9}, {3.822404018451494*^9, 3.822404020980733*^9}, {
   3.8224049152297297`*^9, 3.8224049303591084`*^9}, {3.822405839781583*^9, 
   3.8224058611767483`*^9}, {3.8224066746439667`*^9, 3.822406737839921*^9}, {
   3.822406789771857*^9, 3.8224068397005253`*^9}, {3.8224120420444183`*^9, 
   3.8224120468615227`*^9}, {3.8224120830427165`*^9, 3.8224121492771597`*^9}, 
   3.8224122038556404`*^9, {3.822412269171126*^9, 3.822412298934534*^9}, {
   3.8224131826171837`*^9, 3.822413182913395*^9}, {3.8224133316649065`*^9, 
   3.822413383852585*^9}, {3.822413450419058*^9, 3.82241346196122*^9}, 
   3.822417682769392*^9, {3.8224944861133146`*^9, 3.8224944961760607`*^9}, {
   3.823723706653502*^9, 3.8237237191919727`*^9}, {3.82372378891661*^9, 
   3.8237238688079653`*^9}, {3.823724130870166*^9, 3.8237242041876087`*^9}, {
   3.8237245046062384`*^9, 3.823724594830293*^9}, {3.823724711792119*^9, 
   3.823724734967276*^9}, {3.823724771614996*^9, 3.823724775651231*^9}, {
   3.823725148180735*^9, 3.823725151117918*^9}, 3.823725181684894*^9, {
   3.8237252268556104`*^9, 3.8237252479182115`*^9}, {3.823725367375496*^9, 
   3.8237253956901608`*^9}, {3.823726006652844*^9, 3.8237260363304825`*^9}, {
   3.824491256633321*^9, 3.824491373689952*^9}, {3.824491419554398*^9, 
   3.8244914384867983`*^9}, {3.8245034379100485`*^9, 
   3.8245034381813707`*^9}, {3.8359740806924005`*^9, 3.835974081461605*^9}, {
   3.8365847844020863`*^9, 3.836584790220801*^9}, {3.836584827350713*^9, 
   3.836584836404088*^9}, {3.836585140177179*^9, 3.8365851430963326`*^9}, {
   3.836604490590989*^9, 3.83660461636343*^9}, {3.83660470424998*^9, 
   3.8366048377514863`*^9}, 3.836604892670024*^9, {3.8366050492332945`*^9, 
   3.8366050610037947`*^9}, {3.836605820953572*^9, 3.836605826007352*^9}, {
   3.836605917961069*^9, 3.836605948509991*^9}, 3.836606418193098*^9, {
   3.836606492402521*^9, 3.836606549159972*^9}, {3.8366065846974983`*^9, 
   3.836606656416557*^9}, {3.836606759498496*^9, 3.8366067871708856`*^9}, {
   3.8366071352611895`*^9, 3.83660715646146*^9}, {3.845987049717417*^9, 
   3.8459870516856174`*^9}, {3.8484080696155243`*^9, 
   3.8484080748340883`*^9}, {3.8484081295572524`*^9, 
   3.8484081356617374`*^9}, {3.8484081814829874`*^9, 3.848408237739209*^9}, {
   3.8484083752415886`*^9, 3.8484083779354625`*^9}, {3.8537138521828403`*^9, 
   3.853713951239493*^9}, {3.863191915997464*^9, 3.8631919216830425`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"6d280c5f-0bb4-4bf1-b210-00c63f242d94"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"II", ".", " ", "Zeroth"}], "-", 
    RowBox[{"Order", " ", "Problem"}]}], "Section"]}]], "Input",
 CellChangeTimes->{{3.8192416971429358`*^9, 3.8192417128465366`*^9}, {
   3.81939072279646*^9, 3.8193907230712976`*^9}, 3.8359740999354234`*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"46d5fdbf-d4b0-479e-8e9a-f627896a3dff"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", " ", "Zeroth"}], "-", 
    RowBox[{"order", " ", "eigenvalue", " ", "and", " ", "Floquet", " ", 
     RowBox[{"exponent", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Lambda]", "0"], " ", "=", " ", "0"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Mu]", "0"], " ", "=", "0"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Collided", " ", 
     RowBox[{"eigenfunction", "."}]}], "  ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "0"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      RowBox[{"{", 
       RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]], "*", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], "+", " ", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "*", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["FA", 
     RowBox[{"-", "1"}]], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["FA", "0"], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["FA", "1"], " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "the", " ", 
     SubscriptBox["L", "0"], " ", "operator", " ", "for", " ", 
     RowBox[{"computations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"*", 
       RowBox[{
        SubscriptBox["NumL", "0"], "[", 
        RowBox[{"w_", ",", "k_"}], "]"}]}], " ", ":=", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FCoeff", " ", "=", " ", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{"w", ",", "k"}], "]"}]}], ";", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "*", "\[ImaginaryI]", "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Mu]", "0"], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "]"}], "*", 
              RowBox[{"FCoeff", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "j"}], "]"}], "]"}], "*", 
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", "1", "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], 
         "}"}]}], ")"}]}], ";"}], "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"*", 
       RowBox[{
        SubscriptBox["ZeroNumL", "0"], "[", 
        RowBox[{"w_", ",", "k_"}], "]"}]}], " ", ":=", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FCoeff", " ", "=", " ", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{"w", ",", "k"}], "]"}]}], ";", " ", 
        RowBox[{"Clear", "[", "zerointegrand", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"zerointegrand", " ", "=", " ", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             RowBox[{"Sign", "[", 
              SubscriptBox["\[Mu]", "1"], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}], "}"}], 
           ",", "k"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "*", "\[ImaginaryI]", "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Mu]", "0"], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "]"}], "*", 
              RowBox[{"FCoeff", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "j"}], "]"}], "]"}], "*", 
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Length", "[", "k", "]"}], "-", "1"}], ")"}], "/", 
                "2"}]}], "}"}]}], "]"}], "+", 
           RowBox[{"zerointegrand", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Length", "[", "k", "]"}], "+", "1"}], ")"}], "/", 
               "2"}], ",", "1"}], "]"}], "]"}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Mu]", "0"], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "]"}], "*", 
              RowBox[{"FCoeff", "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "j"}], "]"}], "]"}], "*", 
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Length", "[", "k", "]"}], "+", "3"}], ")"}], "/", 
                "2"}], ",", 
               RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", "1", "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], 
         "}"}]}], ")"}]}], ";"}], "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"*", 
       RowBox[{
        SubscriptBox["ZeroNumL", "0"], "[", 
        RowBox[{"w_", ",", "k_"}], "]"}]}], " ", ":=", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Clear", "[", "integrand", "]"}], ";", " ", 
        RowBox[{"Clear", "[", "zerointegrand", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"integrand", " ", "=", " ", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             RowBox[{"Sign", "[", "\[Kappa]", "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}], " ", 
            "}"}], ",", "k"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"zerointegrand", " ", "=", " ", 
         RowBox[{"NCoefficient", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             RowBox[{"Sign", "[", 
              SubscriptBox["\[Mu]", "1"], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}], "}"}], 
           ",", "k"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j", "=", "1"}], ",", 
          RowBox[{"j", "\[LessEqual]", " ", 
           RowBox[{"Length", "[", "k", "]"}]}], ",", 
          RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
              RowBox[{"zerointegrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "=", 
              RowBox[{"integrand", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"1", "*", "\[ImaginaryI]", "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "1"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Exp", "[", 
                 RowBox[{"\[ImaginaryI]", "*", 
                  RowBox[{"k", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"integrand", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                  RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                   RowBox[{"k", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "1", ",", 
                 RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}], "]"}], 
            "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", "*", "1", "*", 
            RowBox[{"Fdiff", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}]}]}]}], 
         "}"}]}], "\[IndentingNewLine]", ")"}]}], ";"}], "**)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumL", "0"], "[", 
      RowBox[{"w_", ",", "k_"}], "]"}], " ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", " ", 
       RowBox[{"Clear", "[", "zerointegrand", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "\[Kappa]", "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "-", 
            RowBox[{"\[ImaginaryI]", "*", "\[Kappa]", "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], " ", 
           "}"}], ",", "k"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "+", 
            RowBox[{"0", "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "k"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"w", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}]}], 
      "\[IndentingNewLine]", ")"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Define", " ", "the", " ", 
     SubscriptBox["R", "0"], " ", "operator", " ", "for", " ", 
     RowBox[{"computations", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"*", 
       RowBox[{
        SubscriptBox["NumR", "0"], "[", 
        RowBox[{"w_", ",", "k_"}], "]"}]}], "  ", ":=", " ", 
      RowBox[{"(", "w", ")"}]}], ";"}], "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumR", "0"], "[", 
      RowBox[{"w_", ",", "k_"}], "]"}], " ", ":=", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", "integrand", "]"}], ";", " ", 
       RowBox[{"Clear", "[", "zerointegrand", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Abs", "[", "\[Kappa]", "]"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "k"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0", "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "+", 
            RowBox[{"0", "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", "k"}], "]"}]}], 
       ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "*", " ", "Maybe", " ", "revert", " ", "back", " ", "to", " ", "old", 
         " ", 
         SubscriptBox["ZeroNumR", "0"], " ", "so", " ", "as", " ", "not", " ",
          "to", " ", "multiply", " ", "by", " ", "an", " ", "operator", " ", 
         RowBox[{"that", "'"}], "s", " ", "not", " ", 
         RowBox[{"invertible", ".", " ", "Nope", "."}]}], " ", "**)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "k", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"k", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"k", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "k", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"w", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
      ")"}]}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.819241725315444*^9, 3.819241780317752*^9}, {
   3.819241820909971*^9, 3.819241880767762*^9}, {3.81924193786286*^9, 
   3.819242004007763*^9}, {3.8192420767412663`*^9, 3.819242265022035*^9}, {
   3.8192424497358303`*^9, 3.8192424847329297`*^9}, {3.819242527149505*^9, 
   3.8192425297975416`*^9}, {3.8192425896535316`*^9, 3.819242589900633*^9}, {
   3.8192426405493617`*^9, 3.8192427228933077`*^9}, 3.819243090465315*^9, {
   3.819243966027495*^9, 3.8192441850177164`*^9}, {3.8192442233623295`*^9, 
   3.8192443454060345`*^9}, {3.8192451593399415`*^9, 3.819245168971573*^9}, {
   3.8192453376221175`*^9, 3.819245530286437*^9}, 3.8193860160488167`*^9, 
   3.8193862575714035`*^9, {3.8193934714913263`*^9, 3.8193934818381205`*^9}, {
   3.819393612432806*^9, 3.819393659366683*^9}, {3.8193936969108567`*^9, 
   3.8193937321746206`*^9}, {3.8193937781981564`*^9, 
   3.8193937844859223`*^9}, {3.819393884837757*^9, 3.819393897500101*^9}, {
   3.8193942219969997`*^9, 3.81939424345294*^9}, {3.819394334069317*^9, 
   3.819394340621751*^9}, {3.8193944729643064`*^9, 3.819394479732456*^9}, {
   3.8193945564125004`*^9, 3.8193947452843237`*^9}, {3.819394779724778*^9, 
   3.819394807531539*^9}, {3.819394844108669*^9, 3.8193948462432384`*^9}, {
   3.8193948826311717`*^9, 3.819394935005147*^9}, {3.819394966796569*^9, 
   3.8193954904674807`*^9}, {3.8193955261707487`*^9, 3.819395531162109*^9}, {
   3.819395564217187*^9, 3.819395591039777*^9}, {3.81939564534703*^9, 
   3.8193957109615936`*^9}, {3.8193970275927553`*^9, 3.819397156072828*^9}, {
   3.8193971918036613`*^9, 3.8193972066234303`*^9}, {3.8193974646958485`*^9, 
   3.8193974662069902`*^9}, {3.8193978756394124`*^9, 
   3.8193978892054744`*^9}, {3.8193979205189404`*^9, 3.819397929326214*^9}, {
   3.8193979768349285`*^9, 3.8193980236286283`*^9}, {3.819398087755932*^9, 
   3.819398094249878*^9}, {3.8193982008704767`*^9, 3.8193982793351336`*^9}, {
   3.8193983389502335`*^9, 3.819398417954151*^9}, {3.8193984609410615`*^9, 
   3.819398461243624*^9}, {3.8193985407425766`*^9, 3.819398541086712*^9}, {
   3.8193985799271455`*^9, 3.8193985892298875`*^9}, {3.8193987468121357`*^9, 
   3.819398766172119*^9}, {3.8193989662617044`*^9, 3.8193989677593946`*^9}, {
   3.8193997606060686`*^9, 3.8193997670043573`*^9}, {3.8193998123887386`*^9, 
   3.8193999166597643`*^9}, {3.8193999739829693`*^9, 
   3.8194000091778994`*^9}, {3.8194000701000175`*^9, 3.819400264466553*^9}, {
   3.8194003037622395`*^9, 3.8194003516021223`*^9}, {3.819400593733073*^9, 
   3.819400611272956*^9}, {3.819400727297849*^9, 3.8194008447434497`*^9}, {
   3.819401275286027*^9, 3.819401275441537*^9}, {3.819401314365915*^9, 
   3.8194013147369623`*^9}, {3.8194023849549513`*^9, 
   3.8194024008597975`*^9}, {3.819404250984436*^9, 3.8194042610146008`*^9}, {
   3.819476965164923*^9, 3.8194769660286555`*^9}, {3.8194770026877775`*^9, 
   3.819477117859742*^9}, {3.819477265406021*^9, 3.819477308718108*^9}, {
   3.8194780514124784`*^9, 3.8194780540653524`*^9}, {3.819478527963314*^9, 
   3.8194785319452143`*^9}, {3.8195005102511263`*^9, 
   3.8195005239531126`*^9}, {3.8195009724493413`*^9, 3.819500999481338*^9}, {
   3.819557746711507*^9, 3.8195577743964424`*^9}, {3.8195808523771687`*^9, 
   3.8195808567371273`*^9}, {3.823723489928599*^9, 3.82372359530783*^9}, {
   3.8237249708067093`*^9, 3.8237250677365975`*^9}, {3.823725111276389*^9, 
   3.8237251307475595`*^9}, 3.823725307458025*^9, {3.8237253457045956`*^9, 
   3.8237253512635527`*^9}, {3.8237254234278216`*^9, 
   3.8237254240511613`*^9}, {3.8237254874378753`*^9, 3.823725491347413*^9}, {
   3.823725673717486*^9, 3.8237256743208785`*^9}, {3.8237260654765463`*^9, 
   3.8237260725931845`*^9}, {3.8237261226204233`*^9, 3.8237261648418756`*^9}, 
   3.8237263322948494`*^9, {3.82372652961141*^9, 3.8237265311453238`*^9}, {
   3.8237265776380863`*^9, 3.8237266520875063`*^9}, {3.8237266920911384`*^9, 
   3.823726695093218*^9}, {3.8237268115809174`*^9, 3.8237268230539618`*^9}, {
   3.823726994237191*^9, 3.8237270503894405`*^9}, {3.823727085904131*^9, 
   3.8237271649755945`*^9}, {3.8237272223356905`*^9, 
   3.8237272246285973`*^9}, {3.823727289388541*^9, 3.82372729080871*^9}, {
   3.823727456486214*^9, 3.823727532611391*^9}, {3.8237276233388605`*^9, 
   3.823727656394708*^9}, {3.823727725597249*^9, 3.8237277258286057`*^9}, {
   3.8237280287677436`*^9, 3.823728054772077*^9}, {3.823728100591852*^9, 
   3.8237281767708983`*^9}, {3.8237282514942336`*^9, 3.823728298289312*^9}, {
   3.823728336951212*^9, 3.8237283903888693`*^9}, {3.8237284706927943`*^9, 
   3.8237285010280075`*^9}, 3.823728701431844*^9, {3.8237333651666155`*^9, 
   3.82373336532323*^9}, {3.824222377622967*^9, 3.8242225554769125`*^9}, {
   3.824222614564618*^9, 3.8242226313960934`*^9}, {3.8242235899894223`*^9, 
   3.824223716980404*^9}, {3.824224071549379*^9, 3.824224202040768*^9}, {
   3.824309675709446*^9, 3.8243096995506935`*^9}, {3.8243098528120003`*^9, 
   3.824309875685455*^9}, {3.8245036045742826`*^9, 3.824503605103162*^9}, {
   3.8245054021703*^9, 3.824505402656122*^9}, {3.824505511842555*^9, 
   3.824505538125615*^9}, {3.835974109858841*^9, 3.8359741376892676`*^9}, {
   3.836581105254405*^9, 3.8365812646448736`*^9}, {3.836581479425105*^9, 
   3.8365814832604265`*^9}, {3.8365845399059563`*^9, 
   3.8365845586625633`*^9}, {3.8365920462990603`*^9, 
   3.8365920606611843`*^9}, {3.8366041382250233`*^9, 
   3.8366041383675156`*^9}, {3.8366052910455484`*^9, 3.8366052912431755`*^9}, 
   3.836605644374127*^9, {3.8459871347531376`*^9, 3.8459871519575377`*^9}, {
   3.845987287604742*^9, 3.8459873130796633`*^9}, {3.84840631548685*^9, 
   3.8484063258757343`*^9}, {3.8484072597201433`*^9, 
   3.8484072672331605`*^9}, {3.8484093665079036`*^9, 3.848409382283405*^9}, {
   3.8514737110639086`*^9, 3.85147372690202*^9}, {3.8514737587108517`*^9, 
   3.8514737835524297`*^9}, {3.851473821810402*^9, 3.8514738720563593`*^9}, {
   3.851473903581375*^9, 3.85147397266748*^9}, {3.851474005308382*^9, 
   3.8514740835474324`*^9}, {3.8514742180045877`*^9, 
   3.8514742182532415`*^9}, {3.852909996208646*^9, 3.8529101143749757`*^9}, {
   3.852910168767765*^9, 3.852910169142646*^9}, {3.8529102090331974`*^9, 
   3.852910209392488*^9}, {3.852910263532098*^9, 3.852910298653329*^9}, {
   3.8529103958600426`*^9, 3.852910396437951*^9}, {3.8529104343310103`*^9, 
   3.8529104743997645`*^9}, {3.852910505650626*^9, 3.8529105611299486`*^9}, {
   3.852910593149692*^9, 3.852910607157773*^9}, {3.8529106871133137`*^9, 
   3.852910687551139*^9}, 3.8529107885886517`*^9, 3.852911555665049*^9, {
   3.8529115977197475`*^9, 3.852911605189024*^9}, {3.852916578155161*^9, 
   3.8529166081193323`*^9}, {3.8529168463589783`*^9, 
   3.8529168628914304`*^9}, {3.8537140015711765`*^9, 
   3.8537140045391564`*^9}, {3.8537141440828986`*^9, 
   3.8537141881287107`*^9}, {3.8537142377222605`*^9, 
   3.8537142411146955`*^9}, {3.853714379794224*^9, 3.8537144089901547`*^9}, {
   3.8537144459125032`*^9, 3.8537144519730487`*^9}, {3.8537145704131517`*^9, 
   3.853714604864787*^9}, {3.853722501826344*^9, 3.853722501983509*^9}, {
   3.8537225673481483`*^9, 3.8537225680856814`*^9}, {3.855360590331202*^9, 
   3.8553605950670986`*^9}, {3.855360683328947*^9, 3.855360745297595*^9}, {
   3.855361442030984*^9, 3.8553614489877796`*^9}, {3.8569081193240995`*^9, 
   3.856908139399968*^9}, {3.859123788906083*^9, 3.859123795516529*^9}, {
   3.863191950589079*^9, 3.8631919718056383`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"2aed997e-c7f5-44d2-a6e1-6c4c599061d1"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, {3.8484063003861957`*^9, 
   3.848406330273447*^9}, 3.8484075102106595`*^9, 3.8484082994396815`*^9, 
   3.848408402062047*^9, 3.8514564220430727`*^9, 3.851466479701442*^9, 
   3.8514670965702796`*^9, 3.851468019345893*^9, 3.8514741296950636`*^9, 
   3.8514742260304356`*^9, 3.8529098246735754`*^9, 3.852910723210174*^9, 
   3.852910795183118*^9, 3.8529115581822987`*^9, 3.8529117091978245`*^9, 
   3.8529168135085573`*^9, 3.85291686892691*^9, 3.852916959530624*^9, 
   3.853714624099402*^9, 3.8537194712540865`*^9, 3.853722503207637*^9, 
   3.85372257130371*^9, 3.854488106755026*^9, 3.855352885584586*^9, 
   3.8553564229170322`*^9, 3.855361357102062*^9, 3.8553615971537375`*^9, 
   3.856908140199577*^9, 3.8591214004609184`*^9, 3.859123838117593*^9, 
   3.859125925555052*^9, 3.859126816682413*^9, 3.8591289488545337`*^9, 
   3.8593781405243406`*^9, 3.8595440969762363`*^9, 3.8606027496862383`*^9, 
   3.860602781682905*^9, 3.8613967275096383`*^9, 3.863191972653144*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"d4e255fb-b52e-4ac2-b36b-706b963f856f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, {3.8484063003861957`*^9, 
   3.848406330273447*^9}, 3.8484075102106595`*^9, 3.8484082994396815`*^9, 
   3.848408402062047*^9, 3.8514564220430727`*^9, 3.851466479701442*^9, 
   3.8514670965702796`*^9, 3.851468019345893*^9, 3.8514741296950636`*^9, 
   3.8514742260304356`*^9, 3.8529098246735754`*^9, 3.852910723210174*^9, 
   3.852910795183118*^9, 3.8529115581822987`*^9, 3.8529117091978245`*^9, 
   3.8529168135085573`*^9, 3.85291686892691*^9, 3.852916959530624*^9, 
   3.853714624099402*^9, 3.8537194712540865`*^9, 3.853722503207637*^9, 
   3.85372257130371*^9, 3.854488106755026*^9, 3.855352885584586*^9, 
   3.8553564229170322`*^9, 3.855361357102062*^9, 3.8553615971537375`*^9, 
   3.856908140199577*^9, 3.8591214004609184`*^9, 3.859123838117593*^9, 
   3.859125925555052*^9, 3.859126816682413*^9, 3.8591289488545337`*^9, 
   3.8593781405243406`*^9, 3.8595440969762363`*^9, 3.8606027496862383`*^9, 
   3.860602781682905*^9, 3.8613967275096383`*^9, 3.863191972668765*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"0c4049b1-f7bb-4289-b907-c0b9c7ca05b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "0"}]], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, {3.8484063003861957`*^9, 
   3.848406330273447*^9}, 3.8484075102106595`*^9, 3.8484082994396815`*^9, 
   3.848408402062047*^9, 3.8514564220430727`*^9, 3.851466479701442*^9, 
   3.8514670965702796`*^9, 3.851468019345893*^9, 3.8514741296950636`*^9, 
   3.8514742260304356`*^9, 3.8529098246735754`*^9, 3.852910723210174*^9, 
   3.852910795183118*^9, 3.8529115581822987`*^9, 3.8529117091978245`*^9, 
   3.8529168135085573`*^9, 3.85291686892691*^9, 3.852916959530624*^9, 
   3.853714624099402*^9, 3.8537194712540865`*^9, 3.853722503207637*^9, 
   3.85372257130371*^9, 3.854488106755026*^9, 3.855352885584586*^9, 
   3.8553564229170322`*^9, 3.855361357102062*^9, 3.8553615971537375`*^9, 
   3.856908140199577*^9, 3.8591214004609184`*^9, 3.859123838117593*^9, 
   3.859125925555052*^9, 3.859126816682413*^9, 3.8591289488545337`*^9, 
   3.8593781405243406`*^9, 3.8595440969762363`*^9, 3.8606027496862383`*^9, 
   3.860602781682905*^9, 3.8613967275096383`*^9, 3.863191972668765*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"791ffaf0-7799-4074-a00d-1c40cb558089"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, {3.8484063003861957`*^9, 
   3.848406330273447*^9}, 3.8484075102106595`*^9, 3.8484082994396815`*^9, 
   3.848408402062047*^9, 3.8514564220430727`*^9, 3.851466479701442*^9, 
   3.8514670965702796`*^9, 3.851468019345893*^9, 3.8514741296950636`*^9, 
   3.8514742260304356`*^9, 3.8529098246735754`*^9, 3.852910723210174*^9, 
   3.852910795183118*^9, 3.8529115581822987`*^9, 3.8529117091978245`*^9, 
   3.8529168135085573`*^9, 3.85291686892691*^9, 3.852916959530624*^9, 
   3.853714624099402*^9, 3.8537194712540865`*^9, 3.853722503207637*^9, 
   3.85372257130371*^9, 3.854488106755026*^9, 3.855352885584586*^9, 
   3.8553564229170322`*^9, 3.855361357102062*^9, 3.8553615971537375`*^9, 
   3.856908140199577*^9, 3.8591214004609184`*^9, 3.859123838117593*^9, 
   3.859125925555052*^9, 3.859126816682413*^9, 3.8591289488545337`*^9, 
   3.8593781405243406`*^9, 3.8595440969762363`*^9, 3.8606027496862383`*^9, 
   3.860602781682905*^9, 3.8613967275096383`*^9, 3.8631919726906157`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"74d73890-9b57-4c87-925a-7b6d98f5e35e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, {3.8484063003861957`*^9, 
   3.848406330273447*^9}, 3.8484075102106595`*^9, 3.8484082994396815`*^9, 
   3.848408402062047*^9, 3.8514564220430727`*^9, 3.851466479701442*^9, 
   3.8514670965702796`*^9, 3.851468019345893*^9, 3.8514741296950636`*^9, 
   3.8514742260304356`*^9, 3.8529098246735754`*^9, 3.852910723210174*^9, 
   3.852910795183118*^9, 3.8529115581822987`*^9, 3.8529117091978245`*^9, 
   3.8529168135085573`*^9, 3.85291686892691*^9, 3.852916959530624*^9, 
   3.853714624099402*^9, 3.8537194712540865`*^9, 3.853722503207637*^9, 
   3.85372257130371*^9, 3.854488106755026*^9, 3.855352885584586*^9, 
   3.8553564229170322`*^9, 3.855361357102062*^9, 3.8553615971537375`*^9, 
   3.856908140199577*^9, 3.8591214004609184`*^9, 3.859123838117593*^9, 
   3.859125925555052*^9, 3.859126816682413*^9, 3.8591289488545337`*^9, 
   3.8593781405243406`*^9, 3.8595440969762363`*^9, 3.8606027496862383`*^9, 
   3.860602781682905*^9, 3.8613967275096383`*^9, 3.8631919726906157`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"a1b092a4-c6dc-4691-a014-0f63be0c516c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8193862581395216`*^9, 3.8193934823743563`*^9, 3.819393663688343*^9, {
   3.819393766411215*^9, 3.8193937849590616`*^9}, 3.819394348255997*^9, 
   3.819394480498003*^9, 3.8193954607587147`*^9, 3.8193955968354893`*^9, 
   3.819397159365617*^9, {3.8193971937454433`*^9, 3.8193972072081776`*^9}, 
   3.819397261419548*^9, 3.819399958595073*^9, 3.8194003836704082`*^9, 
   3.819400613527869*^9, {3.819400780765015*^9, 3.8194008460988197`*^9}, 
   3.819401285475691*^9, 3.819404265384903*^9, 3.819474551396764*^9, 
   3.8194760369186583`*^9, {3.8194772411828604`*^9, 3.8194772788412952`*^9}, 
   3.819477309982724*^9, 3.8194779956942387`*^9, 3.8194780569875603`*^9, {
   3.8194785035943766`*^9, 3.8194785324962406`*^9}, 3.8194977888693733`*^9, 
   3.8195012022032366`*^9, 3.8195464612916155`*^9, 3.81955721941072*^9, 
   3.819557824300597*^9, 3.8195585884074006`*^9, 3.819571755948738*^9, 
   3.819580795663062*^9, 3.819580872335597*^9, 3.819581341594968*^9, 
   3.8237250112010994`*^9, 3.8237254250584607`*^9, 3.8237261653066325`*^9, 
   3.823727165485223*^9, 3.8237272253297615`*^9, 3.8237272911936755`*^9, 
   3.823727669424384*^9, 3.8237277362467947`*^9, 3.823728502364386*^9, 
   3.8237287045393243`*^9, 3.823733396180829*^9, 3.824221238829571*^9, {
   3.824222623227376*^9, 3.824222631854021*^9}, 3.8242227441528606`*^9, 
   3.82422439868535*^9, 3.8242260747545576`*^9, 3.82422870290851*^9, 
   3.8245036256904526`*^9, 3.8245055699911747`*^9, 3.824506777395219*^9, 
   3.8248232362018275`*^9, 3.8248247056261854`*^9, 3.824826091139063*^9, 
   3.8248267233489404`*^9, 3.8248281349629607`*^9, 3.8293036786714616`*^9, 
   3.8294738373421288`*^9, 3.8298257856412272`*^9, 3.829830812215807*^9, 
   3.8298502539167476`*^9, 3.8315178425114636`*^9, 3.832502932235935*^9, 
   3.832767480084309*^9, 3.8343222811126394`*^9, 3.8346727307017455`*^9, 
   3.8359741390408936`*^9, 3.83606424499298*^9, {3.836065085922078*^9, 
   3.8360650863435698`*^9}, 3.8360655387821417`*^9, 3.8365812761824093`*^9, 
   3.8365814842622952`*^9, {3.8365845481469755`*^9, 3.836584559079982*^9}, 
   3.836585154969797*^9, 3.8365913493204894`*^9, 3.836604139879408*^9, 
   3.836605999650304*^9, 3.8366072232612076`*^9, {3.8484063003861957`*^9, 
   3.848406330273447*^9}, 3.8484075102106595`*^9, 3.8484082994396815`*^9, 
   3.848408402062047*^9, 3.8514564220430727`*^9, 3.851466479701442*^9, 
   3.8514670965702796`*^9, 3.851468019345893*^9, 3.8514741296950636`*^9, 
   3.8514742260304356`*^9, 3.8529098246735754`*^9, 3.852910723210174*^9, 
   3.852910795183118*^9, 3.8529115581822987`*^9, 3.8529117091978245`*^9, 
   3.8529168135085573`*^9, 3.85291686892691*^9, 3.852916959530624*^9, 
   3.853714624099402*^9, 3.8537194712540865`*^9, 3.853722503207637*^9, 
   3.85372257130371*^9, 3.854488106755026*^9, 3.855352885584586*^9, 
   3.8553564229170322`*^9, 3.855361357102062*^9, 3.8553615971537375`*^9, 
   3.856908140199577*^9, 3.8591214004609184`*^9, 3.859123838117593*^9, 
   3.859125925555052*^9, 3.859126816682413*^9, 3.8591289488545337`*^9, 
   3.8593781405243406`*^9, 3.8595440969762363`*^9, 3.8606027496862383`*^9, 
   3.860602781682905*^9, 3.8613967275096383`*^9, 3.8631919727062607`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"536aa0e0-deb6-489d-8997-faea3a5aec9a"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"III", ".", " ", "First"}], "-", 
   RowBox[{"Order", " ", "Problem"}]}], "Section"]], "Input",
 CellChangeTimes->{{3.819386261393108*^9, 3.819386340323662*^9}, {
  3.8193863767831154`*^9, 3.819386406608477*^9}, {3.819386445647776*^9, 
  3.819386467276102*^9}, {3.8193865065371904`*^9, 3.819386513284619*^9}, {
  3.81938661082977*^9, 3.8193866286717334`*^9}, {3.8193869302444153`*^9, 
  3.8193869465465*^9}, {3.81939077649224*^9, 3.8193907810907793`*^9}, {
  3.8193908442990108`*^9, 3.8193908519618716`*^9}, {3.8359741464224243`*^9, 
  3.835974148141134*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"b2ff252b-6c85-4372-b9a7-ebedddc8a50a"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumL", "1"], "[", 
      RowBox[{"w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "\[Kappa]", "]"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", "*", 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], "*", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
               RowBox[{"\[ImaginaryI]", "*", "\[Kappa]", "*", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sign", "[", "\[Kappa]", "]"}], "*", 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], "^", "2"}], "*", 
                "\[Eta]1"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], " ", "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], "*", "\[Kappa]", "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", " ", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}], "-", 
            RowBox[{"\[ImaginaryI]", "*", "\[Kappa]", "*", 
             RowBox[{"Abs", "[", "\[Kappa]", "]"}], "*", "\[Eta]1", "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              SubscriptBox["\[Mu]", "1"], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "-", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", " ", 
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1", "*", "\[ImaginaryI]", "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], " ", "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], 
           ")"}]}]}], "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Define", " ", "operator", " ", 
     SubscriptBox["R", "1"], " ", "for", " ", "numerical", " ", 
     RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumR", "1"], "[", 
      RowBox[{"w_", ",", "k_", ",", "\[Eta]1_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Sign", "[", "\[Kappa]", "]"}], "*", 
               SubscriptBox["\[Mu]", "1"]}], "+", 
              RowBox[{
               RowBox[{
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], "^", "2"}], "*", " ", 
               "\[Eta]1"}]}], ")"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Abs", "[", 
             SubscriptBox["\[Mu]", "1"], "]"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "*", " ", "Reverting", " ", "back", " ", "to", " ", "old", " ", 
         RowBox[{
          SubscriptBox["ZeroNumR", "1"], ".", " ", "Nope", "."}]}], " ", 
        "**)"}], "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], " ", ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"1", "*", 
          RowBox[{"D", "[", 
           RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.823730120763512*^9, 3.823730235597124*^9}, {
   3.823730297873085*^9, 3.823730569851227*^9}, {3.8237307437952037`*^9, 
   3.8237309187067013`*^9}, {3.82373101994392*^9, 3.8237310701656094`*^9}, {
   3.8237311040267525`*^9, 3.8237311568496213`*^9}, {3.823731222739846*^9, 
   3.823731301577722*^9}, {3.823731407874816*^9, 3.8237314419051375`*^9}, {
   3.823731490744588*^9, 3.823731566025501*^9}, {3.823731651889974*^9, 
   3.82373170288583*^9}, {3.8237318562493715`*^9, 3.823731890439183*^9}, {
   3.823731969804457*^9, 3.8237319698982053`*^9}, {3.823732130622611*^9, 
   3.8237321449286795`*^9}, {3.823732498530941*^9, 3.823732567507845*^9}, {
   3.82373319656919*^9, 3.823733263743413*^9}, {3.823733307261401*^9, 
   3.8237333169853935`*^9}, 3.823733350270734*^9, {3.823778905764366*^9, 
   3.823778905900287*^9}, {3.823778971432044*^9, 3.8237789733499284`*^9}, {
   3.823779284442354*^9, 3.8237794124203863`*^9}, {3.823779468524021*^9, 
   3.823779482016163*^9}, {3.8237795210944524`*^9, 3.8237795212081895`*^9}, {
   3.8237797260782633`*^9, 3.8237797682668257`*^9}, {3.8237798155819445`*^9, 
   3.8237798318159637`*^9}, {3.823779863124403*^9, 3.8237798860378265`*^9}, {
   3.8237800945585055`*^9, 3.8237801583974743`*^9}, {3.823780247668363*^9, 
   3.823780310751878*^9}, {3.8237804987338796`*^9, 3.8237806693453407`*^9}, {
   3.823780806984108*^9, 3.823780869645839*^9}, {3.823780902834598*^9, 
   3.82378092715761*^9}, {3.8237810305569916`*^9, 3.823781032573603*^9}, {
   3.823781062842615*^9, 3.8237810737424707`*^9}, {3.823781158719718*^9, 
   3.823781211679963*^9}, {3.823781275077838*^9, 3.8237813942151756`*^9}, {
   3.8237814721516333`*^9, 3.8237814778141394`*^9}, {3.8237816997165055`*^9, 
   3.8237818523151846`*^9}, {3.8237819199033303`*^9, 3.823781939755807*^9}, {
   3.824221025685725*^9, 3.8242210553413143`*^9}, {3.8242246308362293`*^9, 
   3.824224641698037*^9}, {3.8245056056072392`*^9, 3.8245056146543536`*^9}, {
   3.8245056764583616`*^9, 3.8245056768794117`*^9}, {3.8245057170375443`*^9, 
   3.8245057174478517`*^9}, {3.82450576157229*^9, 3.8245057977911625`*^9}, {
   3.824506594937441*^9, 3.8245066627037077`*^9}, {3.8245066987020693`*^9, 
   3.8245067107178335`*^9}, {3.8248232555500517`*^9, 3.824823260218587*^9}, {
   3.8248233009515095`*^9, 3.8248235907565207`*^9}, {3.8248236644271393`*^9, 
   3.824823828149666*^9}, {3.8248247875976887`*^9, 3.824824815037686*^9}, {
   3.824825190319507*^9, 3.8248251906328773`*^9}, {3.8248259284296775`*^9, 
   3.824825943533414*^9}, {3.824826329039048*^9, 3.8248263426086006`*^9}, {
   3.8248265478309298`*^9, 3.8248265489529634`*^9}, {3.8248266406751366`*^9, 
   3.8248266708063064`*^9}, {3.8248268540555153`*^9, 3.824826869778305*^9}, {
   3.8248271091350684`*^9, 3.824827119016425*^9}, {3.8248281864093695`*^9, 
   3.824828197460701*^9}, {3.8359741657780495`*^9, 3.83597417684361*^9}, {
   3.8366072505658493`*^9, 3.8366073002317853`*^9}, {3.8366074283029184`*^9, 
   3.836607469713769*^9}, {3.8484062196609373`*^9, 3.8484062235598745`*^9}, {
   3.8484072590846157`*^9, 3.848407267248818*^9}, {3.8484073523762236`*^9, 
   3.848407387910328*^9}, {3.84840743826365*^9, 3.8484074758201103`*^9}, {
   3.8484076478414564`*^9, 3.848407719512896*^9}, {3.8514656120089445`*^9, 
   3.8514656525863266`*^9}, {3.8514657739360514`*^9, 3.851465778674402*^9}, {
   3.8514658093851194`*^9, 3.8514658434994636`*^9}, {3.851465883131791*^9, 
   3.8514659133711767`*^9}, {3.8514659758832693`*^9, 3.85146600790458*^9}, 
   3.851466058988412*^9, {3.8514666500901423`*^9, 3.8514666525059705`*^9}, {
   3.851467255646897*^9, 3.851467257677431*^9}, {3.851474338214351*^9, 
   3.851474355574553*^9}, {3.8529117328791*^9, 3.8529117368833323`*^9}, {
   3.8529118269407*^9, 3.852911836179246*^9}, {3.852916634509269*^9, 
   3.852916689594268*^9}, {3.8529167477455997`*^9, 3.85291674807362*^9}, {
   3.852917368446743*^9, 3.85291736981876*^9}, {3.852917443661105*^9, 
   3.8529174467382545`*^9}, {3.853714784818085*^9, 3.8537151734961166`*^9}, {
   3.853715219377942*^9, 3.853715222332651*^9}, {3.8537152919008904`*^9, 
   3.8537153137543635`*^9}, {3.853715367051139*^9, 3.853715387934136*^9}, {
   3.855356236289159*^9, 3.855356248695117*^9}, {3.8553610991459665`*^9, 
   3.855361136126773*^9}, {3.8553614604005203`*^9, 3.8553614864490633`*^9}, {
   3.85912407253307*^9, 3.8591241161173925`*^9}, {3.859124189944488*^9, 
   3.859124192805842*^9}, {3.863191992537339*^9, 3.863191999795019*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"b2189f75-f1ec-4645-a3e0-f26b6afca0d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", "of", " ", 
    "O", 
    RowBox[{"(", "\[Epsilon]", ")"}], " ", 
    RowBox[{"problem", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["IHT", "1"], "=", 
   RowBox[{"NCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], "*", 
       RowBox[{
        SubscriptBox["ZeroNumR", "0"], "[", 
        RowBox[{
         SubscriptBox["w", "0"], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], "]"}]}], "  ", 
      "-", " ", 
      RowBox[{
       SubscriptBox["ZeroNumL", "1"], "[", 
       RowBox[{
        SubscriptBox["w", "0"], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}]}], "]"}]}], ",", 
     RowBox[{"GenModulate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], "]"}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8237317383835154`*^9, 3.823731836881159*^9}, {
   3.823731947571501*^9, 3.8237319781405544`*^9}, {3.8237320364913483`*^9, 
   3.823732045213525*^9}, {3.823732261943244*^9, 3.823732431022925*^9}, {
   3.8237332351411076`*^9, 3.8237332388450155`*^9}, 3.8237789030127716`*^9, {
   3.823779552040561*^9, 3.8237795523108463`*^9}, {3.8237796487870264`*^9, 
   3.823779654983917*^9}, {3.8242208460712194`*^9, 3.8242208497894497`*^9}, {
   3.824220880781387*^9, 3.824221001378784*^9}, {3.8242210864388375`*^9, 
   3.8242211436059675`*^9}, {3.8242212719810658`*^9, 
   3.8242214650057497`*^9}, {3.8242215039419847`*^9, 
   3.8242215477569914`*^9}, {3.8242216586200705`*^9, 
   3.8242216685083485`*^9}, {3.8242220109968233`*^9, 
   3.8242220169249897`*^9}, {3.8242221330660095`*^9, 
   3.8242221335553837`*^9}, {3.824222167255204*^9, 3.8242221677645664`*^9}, {
   3.824222764890852*^9, 3.824222775331682*^9}, {3.8242246737384863`*^9, 
   3.824224703570613*^9}, {3.824224792644012*^9, 3.8242248224024887`*^9}, {
   3.8242249222652297`*^9, 3.824225029964205*^9}, {3.8242262982997694`*^9, 
   3.8242263003123837`*^9}, {3.8248280626165934`*^9, 
   3.8248280668879795`*^9}, {3.835974182025835*^9, 3.835974192586668*^9}, {
   3.836581588538974*^9, 3.8365816072594953`*^9}, 3.8484079655313964`*^9, {
   3.84840924033889*^9, 3.8484092407760606`*^9}, {3.8514671340169277`*^9, 
   3.8514671390324984`*^9}, {3.853715466709279*^9, 3.8537154727704487`*^9}, {
   3.853715507424843*^9, 3.8537155137703915`*^9}, {3.853715546993141*^9, 
   3.8537156080065503`*^9}, {3.853719362369234*^9, 3.8537194127519193`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"093b7eb1-fb36-4e6d-85a1-e0e97ae5156a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      SubscriptBox["\[Lambda]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], ",", "0", ",", 
     RowBox[{
      SubscriptBox["\[Lambda]", "1"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]], ",", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}]}], ",", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.848407966211816*^9, 3.8484084201485767`*^9, 
  3.848409243505788*^9, 3.8514564573885307`*^9, 3.8514671452116117`*^9, 
  3.851468034986899*^9, 3.851474375068162*^9, 3.8529122084337363`*^9, 
  3.852917048011262*^9, 3.853715426471219*^9, 3.853715473816955*^9, 
  3.853715527632504*^9, 3.853719485894909*^9, 3.854488121865147*^9, 
  3.8553529000493016`*^9, 3.855356435298685*^9, 3.855361369916136*^9, 
  3.8553616067316084`*^9, 3.856908160207855*^9, 3.859124234549019*^9, 
  3.8591259448211265`*^9, 3.8591268253827343`*^9, 3.8591289541163073`*^9, 
  3.859378157353744*^9, 3.859544101837022*^9, 3.8606027887561717`*^9, 
  3.8613967279782367`*^9, 3.8631920045901155`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"35da03a7-d449-4f8e-a70a-527cc63b6f8f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", 
     "proportional", " ", "to", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], ",", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"0", "*", "\[ImaginaryI]", "*", "x"}], "]"}], ",", " ", 
    RowBox[{"and", " ", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}], "."}]}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"1", ",", "0"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"1", ",", "1"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8242216715744386`*^9, 3.824221730843285*^9}, {
   3.8242221162148485`*^9, 3.824222124011792*^9}, {3.824222187213083*^9, 
   3.824222252407871*^9}, {3.824222968111846*^9, 3.8242229952590322`*^9}, 
   3.8242268005315742`*^9, 3.8242287250331883`*^9, {3.824231360445175*^9, 
   3.8242313890706234`*^9}, 3.824825466933957*^9, {3.8248255287992907`*^9, 
   3.8248255304825277`*^9}, 3.8248281668796005`*^9, {3.8365816749176326`*^9, 
   3.836581695824127*^9}, {3.8484079756439962`*^9, 3.848408003817713*^9}, {
   3.863192007453142*^9, 3.863192009669113*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"a4c3e96e-070e-4ab6-867b-9e09162da1d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      SubscriptBox["IHT", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]], ",", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["FA", 
        RowBox[{"-", "1"}]], "]"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      SubscriptBox["IHT", 
       RowBox[{"1", ",", "0"}]], ",", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["FA", "0"], "]"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Dot", "[", 
     RowBox[{
      SubscriptBox["IHT", 
       RowBox[{"1", ",", "1"}]], ",", 
      RowBox[{"Conjugate", "[", 
       SubscriptBox["FA", "1"], "]"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.836581752719364*^9, 3.836581832360428*^9}, {
   3.8365818651948013`*^9, 3.836581901782962*^9}, {3.8365821239507875`*^9, 
   3.836582154338666*^9}, {3.836582203014144*^9, 3.836582242250846*^9}, {
   3.836582331899331*^9, 3.836582335293679*^9}, 3.8365852182712235`*^9, {
   3.848408444471059*^9, 3.84840849705585*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"22f0f201-a85d-4cd8-8f8d-32b24c7e7f6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Lambda]", "1"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
  SubscriptBox["\[Beta]", 
   RowBox[{"0", ",", 
    RowBox[{"-", "1"}]}]]}]], "Output",
 CellChangeTimes->{3.8365818666828365`*^9, 3.8365819042355275`*^9, 
  3.8365821384088135`*^9, 3.8365822217795143`*^9, 3.836582335910542*^9, 
  3.836585219907984*^9, 3.8365853149300857`*^9, 3.8366075446755857`*^9, 
  3.848408501500143*^9, 3.848409251462708*^9, 3.851456465958418*^9, 
  3.851467154551206*^9, 3.8514680416124754`*^9, 3.851474411525149*^9, 
  3.852912224750702*^9, 3.852917063129027*^9, 3.853715622239812*^9, 
  3.853719495769483*^9, 3.854488130693718*^9, 3.855352920507268*^9, 
  3.8553564407182517`*^9, 3.8553613795065403`*^9, 3.855361614215013*^9, 
  3.856908170203867*^9, 3.859124247584272*^9, 3.8591259491478605`*^9, 
  3.8591268297875533`*^9, 3.859128956849804*^9, 3.8593781621178384`*^9, 
  3.8595441098849096`*^9, 3.860602791714602*^9, 3.8613967281812963`*^9, 
  3.8631920126617002`*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"0d41ae51-a065-43b0-ad3c-b9c3b5c0b3c0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8365818666828365`*^9, 3.8365819042355275`*^9, 
  3.8365821384088135`*^9, 3.8365822217795143`*^9, 3.836582335910542*^9, 
  3.836585219907984*^9, 3.8365853149300857`*^9, 3.8366075446755857`*^9, 
  3.848408501500143*^9, 3.848409251462708*^9, 3.851456465958418*^9, 
  3.851467154551206*^9, 3.8514680416124754`*^9, 3.851474411525149*^9, 
  3.852912224750702*^9, 3.852917063129027*^9, 3.853715622239812*^9, 
  3.853719495769483*^9, 3.854488130693718*^9, 3.855352920507268*^9, 
  3.8553564407182517`*^9, 3.8553613795065403`*^9, 3.855361614215013*^9, 
  3.856908170203867*^9, 3.859124247584272*^9, 3.8591259491478605`*^9, 
  3.8591268297875533`*^9, 3.859128956849804*^9, 3.8593781621178384`*^9, 
  3.8595441098849096`*^9, 3.860602791714602*^9, 3.8613967281812963`*^9, 
  3.863192012677302*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"0a6a871e-c7e0-4a04-99ff-4f4832fd2d25"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SubscriptBox["\[Lambda]", "1"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
  SubscriptBox["\[Beta]", 
   RowBox[{"0", ",", "1"}]]}]], "Output",
 CellChangeTimes->{3.8365818666828365`*^9, 3.8365819042355275`*^9, 
  3.8365821384088135`*^9, 3.8365822217795143`*^9, 3.836582335910542*^9, 
  3.836585219907984*^9, 3.8365853149300857`*^9, 3.8366075446755857`*^9, 
  3.848408501500143*^9, 3.848409251462708*^9, 3.851456465958418*^9, 
  3.851467154551206*^9, 3.8514680416124754`*^9, 3.851474411525149*^9, 
  3.852912224750702*^9, 3.852917063129027*^9, 3.853715622239812*^9, 
  3.853719495769483*^9, 3.854488130693718*^9, 3.855352920507268*^9, 
  3.8553564407182517`*^9, 3.8553613795065403`*^9, 3.855361614215013*^9, 
  3.856908170203867*^9, 3.859124247584272*^9, 3.8591259491478605`*^9, 
  3.8591268297875533`*^9, 3.859128956849804*^9, 3.8593781621178384`*^9, 
  3.8595441098849096`*^9, 3.860602791714602*^9, 3.8613967281812963`*^9, 
  3.863192012677302*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"af594ff5-1083-41f0-bd01-f5144ad05ff5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Group", " ", 
    RowBox[{"velocities", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["c", 
     SubscriptBox["g", 
      RowBox[{"1", ",", "1"}]]], "=", "\[IndentingNewLine]", 
    RowBox[{"Simplify", "[", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[CapitalOmega]", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Sign", "\[Prime]",
             MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
           "0"}]}], " ", "//.", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["Sign", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
          "0"}]}], "//.", " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["Abs", "\[Prime]",
           MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
         RowBox[{
          RowBox[{"Abs", "[", "k", "]"}], "/", "k"}]}]}], " ", "//.", " ", 
       RowBox[{"k", " ", "\[Rule]", " ", "1"}]}], " ", "]"}], "]"}]}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]], "=", "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"\[CapitalOmega]", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Sign", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
           "0"}]}], " ", "//.", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["Abs", "\[Prime]",
            MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"Abs", "[", "k", "]"}], "/", "k"}]}]}], "//.", " ", 
        RowBox[{"k", " ", "\[Rule]", " ", 
         RowBox[{"-", "1"}]}]}], " ", "]"}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}]]], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"\[CapitalOmega]", "[", 
              RowBox[{"k", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Sign", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
           "0"}]}], " ", "//.", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["Abs", "\[Prime]",
            MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"Abs", "[", "k", "]"}], "/", "k"}]}]}], "//.", " ", 
        RowBox[{"k", " ", "\[Rule]", " ", "1"}]}], " ", "]"}], "]"}]}], " ", 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", 
      SubscriptBox["g", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}]]], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"\[CapitalOmega]", "[", 
              RowBox[{"k", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "1"}], "}"}]}], "]"}], " ", "//.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["Sign", "\[Prime]",
              MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
            "0"}]}], " ", "//.", " ", 
          RowBox[{
           RowBox[{
            SuperscriptBox["Sign", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
           "0"}]}], "  ", "//.", " ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["Abs", "\[Prime]",
            MultilineFunction->None], "[", "k", "]"}], " ", "\[Rule]", " ", 
          RowBox[{
           RowBox[{"Abs", "[", "k", "]"}], "/", "k"}]}]}], "//.", " ", 
        RowBox[{"k", " ", "\[Rule]", " ", 
         RowBox[{"-", "1"}]}]}], " ", "]"}], "]"}]}], " ", ";"}]}]}]], "Input",
 CellChangeTimes->{{3.836582398598183*^9, 3.8365824049908524`*^9}, {
  3.836582457792816*^9, 3.836582621785325*^9}, {3.8365826743470926`*^9, 
  3.836582703285268*^9}, {3.836582783409891*^9, 3.836582828357714*^9}, {
  3.83658286744064*^9, 3.836582872640882*^9}, {3.836582910741265*^9, 
  3.8365829261769195`*^9}, {3.836582983626109*^9, 3.8365830883293867`*^9}, {
  3.836583286578891*^9, 3.8365833113323755`*^9}, {3.836583346952676*^9, 
  3.8365833541905766`*^9}, {3.836583388598711*^9, 3.836583405758993*^9}, {
  3.8365853850054216`*^9, 3.8365853980858016`*^9}, {3.848408545101119*^9, 
  3.848408710755874*^9}, {3.8631920203389783`*^9, 3.863192036112236*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"b732a4b8-174a-48f4-bbff-1fb524aef1fd"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", "2"]}]], "Output",
 CellChangeTimes->{{3.8365824627656145`*^9, 3.8365826225257907`*^9}, {
   3.836582681426772*^9, 3.8365826909993334`*^9}, 3.8365828308937874`*^9, {
   3.8365828679833493`*^9, 3.8365828738043013`*^9}, 3.8365829270063195`*^9, 
   3.836582995192747*^9, {3.8365830687315016`*^9, 3.8365830902119293`*^9}, 
   3.836583311942136*^9, 3.8365833554727645`*^9, 3.8365848496485233`*^9, 
   3.8365852318533077`*^9, 3.8365853927165995`*^9, 3.8366075513686953`*^9, 
   3.848408549777294*^9, 3.848408610306801*^9, 3.8484086433356185`*^9, 
   3.8484086751777306`*^9, 3.8484087114073567`*^9, 3.848409256038308*^9, 
   3.8514564736810007`*^9, 3.8514671591002812`*^9, 3.851468043503127*^9, 
   3.8529170780578613`*^9, 3.8537156361136794`*^9, 3.85371949914625*^9, 
   3.8544881341702194`*^9, 3.855352923535782*^9, 3.855356442929221*^9, 
   3.85536161810417*^9, 3.856908175710179*^9, 3.8591242564128504`*^9, 
   3.8591259511003695`*^9, 3.8591268316495376`*^9, 3.859128958304592*^9, 
   3.85937816471082*^9, 3.859544117166525*^9, 3.860602793536358*^9, 
   3.861396728306258*^9, 3.863192036431991*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"bc84d4bd-6c77-4e12-92be-a2f74e637847"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", "Solvability", " ", "conditions"}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{"2", "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["c", "g"]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"1", ",", "1"}]], " ", "=", " ", 
     RowBox[{"2", "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "*", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         SubscriptBox["c", "g"]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]], " ", "-", " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Dot", "[", 
        RowBox[{
         SubscriptBox["IHT", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]], ",", 
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", 
           RowBox[{"-", "1"}]], "]"}]}], "]"}], "]"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"1", ",", "1"}]], " ", "-", " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Dot", "[", 
        RowBox[{
         SubscriptBox["IHT", 
          RowBox[{"1", ",", "1"}]], ",", 
         RowBox[{"Conjugate", "[", 
          SubscriptBox["FA", "1"], "]"}]}], "]"}], "]"}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.836583439607668*^9, 3.8365835949439764`*^9}, 
   3.8365836796547976`*^9, {3.836583755442839*^9, 3.836583768451266*^9}, {
   3.8365850121883926`*^9, 3.836585111392171*^9}, 3.8365852426538963`*^9, {
   3.8365853556649723`*^9, 3.8365853700888042`*^9}, {3.8365856697650404`*^9, 
   3.8365856898831234`*^9}, 3.836585830138629*^9, {3.836586108475399*^9, 
   3.836586149829177*^9}, {3.8484087944972124`*^9, 3.848408852130307*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"fe4d1756-facd-459a-9098-fbb87c602195"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8365835629728355`*^9, 3.8365835954065886`*^9}, 
   3.8365836802838306`*^9, {3.836583757375491*^9, 3.8365837690849705`*^9}, {
   3.836585037954858*^9, 3.836585059173772*^9}, {3.836585101095063*^9, 
   3.8365851119324284`*^9}, {3.836585234666058*^9, 3.836585243094597*^9}, {
   3.8365853565982018`*^9, 3.8365853704086695`*^9}, {3.8365856815487595`*^9, 
   3.836585690307869*^9}, 3.8365861312271523`*^9, 3.836607557125615*^9, {
   3.848408843306723*^9, 3.848408854619651*^9}, 3.8484092601815453`*^9, 
   3.851456478457041*^9, 3.851467162981739*^9, 3.8514680449829626`*^9, 
   3.8529170819539814`*^9, 3.853715640206088*^9, 3.8537195033324366`*^9, 
   3.854488137600259*^9, 3.855352926046966*^9, 3.8553564459179926`*^9, 
   3.8553616215749235`*^9, 3.856908179312476*^9, 3.8591242593364854`*^9, 
   3.859125953271532*^9, 3.859126833555172*^9, 3.8591289594135957`*^9, 
   3.8593781668663397`*^9, 3.8595441201655827`*^9, 3.860602794764513*^9, 
   3.861396728415595*^9, 3.863192039741437*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"086b83af-1322-42a0-bf1f-4d7b90849586"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8365835629728355`*^9, 3.8365835954065886`*^9}, 
   3.8365836802838306`*^9, {3.836583757375491*^9, 3.8365837690849705`*^9}, {
   3.836585037954858*^9, 3.836585059173772*^9}, {3.836585101095063*^9, 
   3.8365851119324284`*^9}, {3.836585234666058*^9, 3.836585243094597*^9}, {
   3.8365853565982018`*^9, 3.8365853704086695`*^9}, {3.8365856815487595`*^9, 
   3.836585690307869*^9}, 3.8365861312271523`*^9, 3.836607557125615*^9, {
   3.848408843306723*^9, 3.848408854619651*^9}, 3.8484092601815453`*^9, 
   3.851456478457041*^9, 3.851467162981739*^9, 3.8514680449829626`*^9, 
   3.8529170819539814`*^9, 3.853715640206088*^9, 3.8537195033324366`*^9, 
   3.854488137600259*^9, 3.855352926046966*^9, 3.8553564459179926`*^9, 
   3.8553616215749235`*^9, 3.856908179312476*^9, 3.8591242593364854`*^9, 
   3.859125953271532*^9, 3.859126833555172*^9, 3.8591289594135957`*^9, 
   3.8593781668663397`*^9, 3.8595441201655827`*^9, 3.860602794764513*^9, 
   3.861396728415595*^9, 3.863192039741437*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"a7c2b5c7-4a77-4208-ac2e-8f41f41ec852"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", " ", "From", " ", "solvability", " ", "conditions"}], ",", 
    " ", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[ImaginaryI]\[Mu]", "1"]}], 
      SubscriptBox["c", "g"]}]}], ",", " ", 
    RowBox[{
     RowBox[{"where", " ", 
      SubscriptBox["c", "g"]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2."}]}]}], " ", "**)"}]}]], "Input",
 CellChangeTimes->{{3.836586166535922*^9, 3.836586218860746*^9}, {
  3.836586263721674*^9, 3.8365862642442474`*^9}, {3.8484089325590725`*^9, 
  3.848408941885844*^9}, {3.8631920650328045`*^9, 
  3.863192068364742*^9}},ExpressionUUID->"0ea3e94f-b8b9-497b-8cb9-\
9401561351ac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ", 
     "at", " ", "this", " ", "order"}], ",", " ", 
    RowBox[{
     RowBox[{"starting", " ", "with", " ", "the", " ", "non"}], "-", 
     RowBox[{"Fredholm", " ", 
      RowBox[{"modes", "."}]}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["partIHT", "1"], "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "1"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", "1"], " ", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"partsoln", "[", 
      RowBox[{
       SubscriptBox["partIHT", "1"], ",", 
       RowBox[{
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}], "]"}], "]"}], ",", "1"}], "]"}], 
     "]"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "S", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8242363620454884`*^9, 3.824236430147499*^9}, {
   3.824236478483627*^9, 3.8242364954275956`*^9}, {3.824236626766796*^9, 
   3.8242366605112877`*^9}, {3.8242440868414907`*^9, 
   3.8242440903540964`*^9}, {3.8242443402081003`*^9, 3.824244369151651*^9}, {
   3.8242444163694906`*^9, 3.824244431187025*^9}, {3.824244485304977*^9, 
   3.8242445172152805`*^9}, {3.8242445500340548`*^9, 3.824244589494547*^9}, {
   3.824245530784767*^9, 3.8242455552340937`*^9}, {3.8245086764695807`*^9, 
   3.8245086857291894`*^9}, {3.824508882492077*^9, 3.8245088901707954`*^9}, {
   3.8359742335258236`*^9, 3.8359742511064196`*^9}, {3.836586317054388*^9, 
   3.836586360695044*^9}, 3.8365864263946757`*^9, {3.836586479409106*^9, 
   3.836586547246324*^9}, {3.848408909682231*^9, 3.848408962720645*^9}, {
   3.8484090267757196`*^9, 3.848409067742317*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"45b99b82-18f2-410b-8eb4-b6d0343a4b61"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.824244597120138*^9, 3.824245560508648*^9, {3.8245087331647005`*^9, 
   3.8245087485375953`*^9}, 3.8245088917527523`*^9, 3.824828218506803*^9, 
   3.8293037323566217`*^9, 3.829473876857999*^9, 3.8298258187551813`*^9, 
   3.829830835947282*^9, 3.8298502799776087`*^9, {3.8315178778131638`*^9, 
   3.8315178927068176`*^9}, 3.8325029440944085`*^9, 3.8327674920706964`*^9, 
   3.8343222995870414`*^9, 3.8346727466921926`*^9, 3.8359742526046567`*^9, 
   3.8360642473251905`*^9, 3.8360650882879505`*^9, 3.8360655406974907`*^9, 
   3.8365865647413087`*^9, 3.8366075831398945`*^9, 3.8484089741222706`*^9, {
   3.848409054106328*^9, 3.8484090700417576`*^9}, 3.848409264988221*^9, 
   3.8514564842346845`*^9, 3.851467179280048*^9, 3.85146804813792*^9, 
   3.8529170901753917`*^9, 3.8537156529273453`*^9, 3.853719506659453*^9, 
   3.8544881429767904`*^9, 3.8553529289541063`*^9, 3.855356448869731*^9, 
   3.855361624701666*^9, 3.856908194012355*^9, 3.859124268805809*^9, 
   3.859125955867841*^9, 3.8591268362886705`*^9, 3.859128961584752*^9, 
   3.8593781714794965`*^9, 3.8595441240894003`*^9, 3.860602797354738*^9, 
   3.86139672907164*^9, 3.8631920738294477`*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"9313d4b8-bcb2-4e49-b376-48333407e4f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Obtain", " ", "the", " ", "particular", " ", "solution", " ", 
     "at", " ", "this", " ", "order"}], ",", " ", 
    RowBox[{
    "starting", " ", "with", " ", "the", " ", "\[IndentingNewLine]", 
     "Fredholm", " ", 
     RowBox[{"modes", "."}]}]}], " ", "**)"}], " ", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["IHT", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]], "//.", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]]}]}], " ", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["IHT", 
       RowBox[{"1", ",", "0"}]], "//.", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], " ", "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["IHT", 
       RowBox[{"1", ",", "1"}]], "//.", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.836607842149844*^9, 3.8366078473358335`*^9}, {
   3.8366078793752513`*^9, 3.8366079010739717`*^9}, {3.8484094297509727`*^9, 
   3.848409433932025*^9}, {3.8484110926533394`*^9, 3.8484111165677648`*^9}, 
   3.8484112210848694`*^9, {3.848411298562544*^9, 3.8484113043245044`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"88f7e02f-c226-4c4d-969d-02c10cdcea69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", 
      RowBox[{"-", "1"}]}]]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", 
      RowBox[{"-", "1"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.836607847902434*^9, {3.83660788028811*^9, 3.836607901391734*^9}, 
   3.8484094346582284`*^9, {3.848411103019042*^9, 3.848411125880185*^9}, 
   3.8484112228007975`*^9, 3.8514564885235395`*^9, 3.851467186030963*^9, 
   3.851468051983424*^9, 3.8529170939864535`*^9, 3.8537156808642445`*^9, 
   3.853719510646332*^9, 3.8544881468320246`*^9, 3.8553529314315453`*^9, 
   3.855356451715523*^9, 3.8553616294277782`*^9, 3.8569082102076693`*^9, 
   3.8591242834133463`*^9, 3.8591259584139247`*^9, 3.859126839443931*^9, 
   3.8591289640711555`*^9, 3.859378175243911*^9, 3.8595441266351833`*^9, 
   3.8606027999965467`*^9, 3.8613967293527966`*^9, 3.863192080182434*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"2a242193-fb47-4456-b0cf-4f07e44bfdbf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "0"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.836607847902434*^9, {3.83660788028811*^9, 3.836607901391734*^9}, 
   3.8484094346582284`*^9, {3.848411103019042*^9, 3.848411125880185*^9}, 
   3.8484112228007975`*^9, 3.8514564885235395`*^9, 3.851467186030963*^9, 
   3.851468051983424*^9, 3.8529170939864535`*^9, 3.8537156808642445`*^9, 
   3.853719510646332*^9, 3.8544881468320246`*^9, 3.8553529314315453`*^9, 
   3.855356451715523*^9, 3.8553616294277782`*^9, 3.8569082102076693`*^9, 
   3.8591242834133463`*^9, 3.8591259584139247`*^9, 3.859126839443931*^9, 
   3.8591289640711555`*^9, 3.859378175243911*^9, 3.8595441266351833`*^9, 
   3.8606027999965467`*^9, 3.8613967293527966`*^9, 3.863192080182434*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"54112b0e-ec2b-4673-950c-70c5148b6532"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "1"}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    SubscriptBox["\[Mu]", "1"], " ", 
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "1"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.836607847902434*^9, {3.83660788028811*^9, 3.836607901391734*^9}, 
   3.8484094346582284`*^9, {3.848411103019042*^9, 3.848411125880185*^9}, 
   3.8484112228007975`*^9, 3.8514564885235395`*^9, 3.851467186030963*^9, 
   3.851468051983424*^9, 3.8529170939864535`*^9, 3.8537156808642445`*^9, 
   3.853719510646332*^9, 3.8544881468320246`*^9, 3.8553529314315453`*^9, 
   3.855356451715523*^9, 3.8553616294277782`*^9, 3.8569082102076693`*^9, 
   3.8591242834133463`*^9, 3.8591259584139247`*^9, 3.859126839443931*^9, 
   3.8591289640711555`*^9, 3.859378175243911*^9, 3.8595441266351833`*^9, 
   3.8606027999965467`*^9, 3.8613967293527966`*^9, 3.863192080202934*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"80e3f8e3-b4d8-493d-8f9d-165cd1265e00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["IHT", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]], "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]]}]}], " ", "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"1", ",", "0"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SubscriptBox["IHT", 
             RowBox[{"1", ",", "0"}]], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], " ", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]], " ", "\[Rule]", " ", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"1", ",", "1"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", " ", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]], "\[Rule]", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["IHT", 
            RowBox[{"1", ",", "1"}]], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], " ", "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8365880076359816`*^9, {3.836588842831197*^9, 3.8365889437154408`*^9}, {
   3.836589052672431*^9, 3.836589076699498*^9}, 3.836589106784465*^9, {
   3.8365891730454283`*^9, 3.8365891937634892`*^9}, {3.8365893459850783`*^9, 
   3.8365893618543243`*^9}, {3.8365897979176674`*^9, 3.836589899951764*^9}, {
   3.836589959261092*^9, 3.836589964054367*^9}, {3.836590063290547*^9, 
   3.836590114078697*^9}, {3.836590147641199*^9, 3.836590196020345*^9}, {
   3.836590259698617*^9, 3.836590280598693*^9}, {3.8365908966317225`*^9, 
   3.8365909211454525`*^9}, {3.848411173526764*^9, 3.8484111929933176`*^9}, {
   3.8484112323885164`*^9, 3.848411253838771*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"bd6d911a-b83b-4d12-bdbb-c91a9ba9bb93"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8365888726659355`*^9, 3.836588944007207*^9}, {
   3.8365890557377787`*^9, 3.8365890770288906`*^9}, 3.8365891071636095`*^9, {
   3.836589174411733*^9, 3.8365891942755413`*^9}, {3.8365893497583046`*^9, 
   3.8365893630692616`*^9}, 3.8365898031714225`*^9, {3.836589835168369*^9, 
   3.8365898462460546`*^9}, 3.8365899007611675`*^9, 3.836589964645814*^9, 
   3.836590114535653*^9, 3.8365901652992086`*^9, 3.8365902022941923`*^9, 
   3.836590281905922*^9, 3.8365909227882233`*^9, 3.83660760619059*^9, 
   3.8484112563893924`*^9, 3.8514564930134897`*^9, 3.851467189998786*^9, 
   3.851468053785693*^9, 3.8529171013173857`*^9, 3.8537163511127367`*^9, 
   3.8537195137703323`*^9, 3.85448815038624*^9, 3.8553529344199247`*^9, 
   3.855356454662464*^9, 3.8553616318821535`*^9, 3.856908234763178*^9, 
   3.8591242856001425`*^9, 3.8591259609755974`*^9, 3.8591268415875435`*^9, 
   3.859128965383235*^9, 3.859378178383526*^9, 3.859544130305896*^9, 
   3.860602801220584*^9, 3.861396729462134*^9, 3.8631920827884827`*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"03b3400a-afd0-4a8b-a2b8-942968565ff6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"1", ",", "0"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "0"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8365888726659355`*^9, 3.836588944007207*^9}, {
   3.8365890557377787`*^9, 3.8365890770288906`*^9}, 3.8365891071636095`*^9, {
   3.836589174411733*^9, 3.8365891942755413`*^9}, {3.8365893497583046`*^9, 
   3.8365893630692616`*^9}, 3.8365898031714225`*^9, {3.836589835168369*^9, 
   3.8365898462460546`*^9}, 3.8365899007611675`*^9, 3.836589964645814*^9, 
   3.836590114535653*^9, 3.8365901652992086`*^9, 3.8365902022941923`*^9, 
   3.836590281905922*^9, 3.8365909227882233`*^9, 3.83660760619059*^9, 
   3.8484112563893924`*^9, 3.8514564930134897`*^9, 3.851467189998786*^9, 
   3.851468053785693*^9, 3.8529171013173857`*^9, 3.8537163511127367`*^9, 
   3.8537195137703323`*^9, 3.85448815038624*^9, 3.8553529344199247`*^9, 
   3.855356454662464*^9, 3.8553616318821535`*^9, 3.856908234763178*^9, 
   3.8591242856001425`*^9, 3.8591259609755974`*^9, 3.8591268415875435`*^9, 
   3.859128965383235*^9, 3.859378178383526*^9, 3.859544130305896*^9, 
   3.860602801220584*^9, 3.861396729462134*^9, 3.8631920828041286`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"0befa646-ccb6-4013-bf68-aa8dd0956a58"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8365888726659355`*^9, 3.836588944007207*^9}, {
   3.8365890557377787`*^9, 3.8365890770288906`*^9}, 3.8365891071636095`*^9, {
   3.836589174411733*^9, 3.8365891942755413`*^9}, {3.8365893497583046`*^9, 
   3.8365893630692616`*^9}, 3.8365898031714225`*^9, {3.836589835168369*^9, 
   3.8365898462460546`*^9}, 3.8365899007611675`*^9, 3.836589964645814*^9, 
   3.836590114535653*^9, 3.8365901652992086`*^9, 3.8365902022941923`*^9, 
   3.836590281905922*^9, 3.8365909227882233`*^9, 3.83660760619059*^9, 
   3.8484112563893924`*^9, 3.8514564930134897`*^9, 3.851467189998786*^9, 
   3.851468053785693*^9, 3.8529171013173857`*^9, 3.8537163511127367`*^9, 
   3.8537195137703323`*^9, 3.85448815038624*^9, 3.8553529344199247`*^9, 
   3.855356454662464*^9, 3.8553616318821535`*^9, 3.856908234763178*^9, 
   3.8591242856001425`*^9, 3.8591259609755974`*^9, 3.8591268415875435`*^9, 
   3.859128965383235*^9, 3.859378178383526*^9, 3.859544130305896*^9, 
   3.860602801220584*^9, 3.861396729462134*^9, 3.863192082819725*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"3d067d80-25d1-4bce-8c47-35fc91d3cfca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Check", " ", "that", " ", "the", " ", "Fredholm", " ", 
    "particular", " ", "solutions", " ", "are", " ", 
    RowBox[{"correct", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["ZeroNumL", "0"], "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]], ",", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}]]}], "}"}], "*", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "//.", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], ")"}], ",", 
         RowBox[{"{", 
          RowBox[{"-", "1"}], "}"}]}], "]"}], "-", 
       RowBox[{
        SubscriptBox["IHT", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["ZeroNumL", "0"], "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["h", 
              RowBox[{"1", ",", "0"}]], ",", 
             SubscriptBox["\[Phi]", 
              RowBox[{"1", ",", "0"}]]}], "}"}], "//.", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "0"}]]}], ")"}], ",", 
         RowBox[{"{", "0", "}"}]}], "]"}], "-", 
       SubscriptBox["IHT", 
        RowBox[{"1", ",", "0"}]]}], "//.", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["ZeroNumL", "0"], "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SubscriptBox["h", 
               RowBox[{"1", ",", "1"}]], ",", 
              SubscriptBox["\[Phi]", 
               RowBox[{"1", ",", "1"}]]}], "}"}], "*", 
            RowBox[{"Exp", "[", 
             RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], "//.", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "1"}]]}], ")"}], ",", 
         RowBox[{"{", "1", "}"}]}], "]"}], "-", 
       RowBox[{
        SubscriptBox["IHT", 
         RowBox[{"1", ",", "1"}]], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}]}], "//.", " ", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "*", 
        SubscriptBox["\[Mu]", "1"], "*", 
        SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8365909987605596`*^9, 3.8365910804344215`*^9}, {
   3.8365911246646566`*^9, 3.8365911855547876`*^9}, {3.8365912639813385`*^9, 
   3.8365912642472577`*^9}, 3.8366076266578507`*^9, {3.8366077099212093`*^9, 
   3.8366077291092587`*^9}, {3.836607941192624*^9, 3.8366079711339717`*^9}, {
   3.836608004750267*^9, 3.8366082535781136`*^9}, {3.8484113376953793`*^9, 
   3.8484113733524995`*^9}, {3.8537163615667048`*^9, 3.853716436912903*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"6f5a91bf-ad9e-4101-883e-4ed020863a8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, {3.848411365432674*^9, 3.8484113747991877`*^9}, 
   3.8514564970906525`*^9, 3.8514672031679354`*^9, 3.851468056243899*^9, 
   3.8529171112122335`*^9, {3.853716398907463*^9, 3.8537164376314096`*^9}, 
   3.853719518741609*^9, 3.854488153484914*^9, 3.855352937865721*^9, 
   3.855356459147193*^9, 3.855361636393605*^9, 3.8569082424528284`*^9, 
   3.859124291178866*^9, 3.8591259647117844`*^9, 3.85912684480526*^9, 
   3.859128966570385*^9, 3.8593781822303047`*^9, 3.859544135183137*^9, 
   3.8606028025080957`*^9, 3.8613967295870953`*^9, 3.863192085035078*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"1c3c7a63-46dc-4ed5-be13-dc59e20d6216"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, {3.848411365432674*^9, 3.8484113747991877`*^9}, 
   3.8514564970906525`*^9, 3.8514672031679354`*^9, 3.851468056243899*^9, 
   3.8529171112122335`*^9, {3.853716398907463*^9, 3.8537164376314096`*^9}, 
   3.853719518741609*^9, 3.854488153484914*^9, 3.855352937865721*^9, 
   3.855356459147193*^9, 3.855361636393605*^9, 3.8569082424528284`*^9, 
   3.859124291178866*^9, 3.8591259647117844`*^9, 3.85912684480526*^9, 
   3.859128966570385*^9, 3.8593781822303047`*^9, 3.859544135183137*^9, 
   3.8606028025080957`*^9, 3.8613967295870953`*^9, 3.863192085050697*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"6b6c7f3e-605c-4725-847b-f4cb1f59867a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.836591048543702*^9, 3.836591081106341*^9}, {
   3.8365911302394867`*^9, 3.8365911864719467`*^9}, 3.8365912669708505`*^9, 
   3.8366076310947084`*^9, {3.836607717040148*^9, 3.8366077294531655`*^9}, 
   3.836607971722418*^9, {3.836608018908558*^9, 3.8366080401918335`*^9}, {
   3.8366080928328676`*^9, 3.836608109201868*^9}, {3.8366082153154917`*^9, 
   3.8366082375317974`*^9}, {3.848411365432674*^9, 3.8484113747991877`*^9}, 
   3.8514564970906525`*^9, 3.8514672031679354`*^9, 3.851468056243899*^9, 
   3.8529171112122335`*^9, {3.853716398907463*^9, 3.8537164376314096`*^9}, 
   3.853719518741609*^9, 3.854488153484914*^9, 3.855352937865721*^9, 
   3.855356459147193*^9, 3.855361636393605*^9, 3.8569082424528284`*^9, 
   3.859124291178866*^9, 3.8591259647117844`*^9, 3.85912684480526*^9, 
   3.859128966570385*^9, 3.8593781822303047`*^9, 3.859544135183137*^9, 
   3.8606028025080957`*^9, 3.8613967295870953`*^9, 3.863192085050697*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"dd9f4545-e626-4332-9f8c-9b98e50a0b7e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Final", " ", "solution", " ", "for", " ", "the", " ", "O", 
    RowBox[{"(", "\[Epsilon]", ")"}], " ", 
    RowBox[{"problem", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["w", "1"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h", 
          RowBox[{"1", ",", "j"}]], ",", 
         SubscriptBox["\[Phi]", 
          RowBox[{"1", ",", "j"}]]}], "}"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", "*", "j", "*", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]], "*", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.8242370255451097`*^9, 3.824237069106557*^9}, {
  3.824244096930807*^9, 3.8242441318920865`*^9}, {3.8242443855204077`*^9, 
  3.824244409672367*^9}, {3.824245637378871*^9, 3.8242456377474823`*^9}, {
  3.824245684140806*^9, 3.8242457046099596`*^9}, {3.8242457447945557`*^9, 
  3.8242457716378627`*^9}, {3.8243097626122437`*^9, 3.8243098057179384`*^9}, {
  3.8359742915208893`*^9, 3.8359742921143503`*^9}, {3.8366869166108985`*^9, 
  3.83668692736432*^9}, {3.8366869592078342`*^9, 3.8366870529558973`*^9}, {
  3.848411515598692*^9, 3.848411525948182*^9}, {3.855356628944488*^9, 
  3.8553566383881416`*^9}, {3.8569082477414427`*^9, 3.8569082563027163`*^9}, {
  3.863192092656592*^9, 3.8631921014372377`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"277cd90c-1341-4490-b33d-049778e29cda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["h", 
     RowBox[{"1", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"1", ",", "0"}]], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Phi]", 
     RowBox[{"1", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "2"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.824237040424094*^9, 3.824237069511461*^9}, {
   3.8242441005830393`*^9, 3.824244132499463*^9}, {3.824244397942233*^9, 
   3.8242444099905148`*^9}, 3.824245712432865*^9, 3.8245087856159244`*^9, 
   3.8248282439700565`*^9, 3.829303745204534*^9, 3.8294738911545205`*^9, 
   3.829825829975224*^9, 3.829830845373143*^9, 3.8298503321597524`*^9, {
   3.8315178838436003`*^9, 3.8315178998287067`*^9}, 3.832502948440692*^9, 
   3.832767497235362*^9, 3.83432230463995*^9, 3.8346727516105413`*^9, 
   3.835974312748376*^9, 3.8360642477506657`*^9, 3.8360650887373533`*^9, 
   3.836065541158641*^9, 3.8366869287179728`*^9, 3.8366869604506316`*^9, {
   3.8366870459034643`*^9, 3.836687053828573*^9}, 3.8484115420176992`*^9, 
   3.8484116195606413`*^9, 3.851456500724016*^9, 3.8514672090967646`*^9, 
   3.851468057722486*^9, 3.852917115506112*^9, 3.8537164660133886`*^9, 
   3.853719521865582*^9, 3.854488156615867*^9, 3.8553529410488915`*^9, 
   3.8553564618138533`*^9, 3.8553566329738894`*^9, 3.855361640223014*^9, 
   3.8569082573861375`*^9, 3.859124298462043*^9, 3.859125967976358*^9, 
   3.8591268471795177`*^9, 3.859128967991805*^9, 3.859378184635766*^9, 
   3.859544138466154*^9, 3.8606028038729706`*^9, 3.8613967297120557`*^9, {
   3.863192088262*^9, 3.863192101975025*^9}},
 CellLabel->"Out[47]=",ExpressionUUID->"06bf9cd7-0002-4c9e-83ed-4bf53ebfdd5f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"IV", ".", " ", "Second"}], "-", 
    RowBox[{"Order", " ", "Problem"}]}], "Section"]}]], "Input",
 CellChangeTimes->{{3.8242489864841957`*^9, 3.8242489983538294`*^9}, {
  3.8359743185437613`*^9, 3.8359743196043673`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"9a02771b-d8ba-4105-a58d-69877eb65e31"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"*", " ", "Define", " ", "operator", " ", 
    SubscriptBox["L", "2"], " ", "for", " ", "numerical", " ", 
    RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumL", "2"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    "\[Eta]1"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "-", 
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", "\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
               ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "+", " ", 
            RowBox[{
             FractionBox["1", "2"], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{"4", " ", 
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", "1", " ", 
                SuperscriptBox["\[Eta]1", "2"]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", "1", " ", 
                "\[Eta]2"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"(", 
               RowBox[{
                SubsuperscriptBox["\[Mu]", "1", "2"], "+", 
                RowBox[{"\[Kappa]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                   RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}]}], ")"}]}]}],
                ")"}], ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", "-", 
            RowBox[{"\[ImaginaryI]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", "\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", 
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                   SuperscriptBox["\[Eta]1", "2"]}], "+", 
                  RowBox[{"2", " ", 
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}], 
                 ")"}]}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"Abs", "[", 
              SubscriptBox["\[Mu]", "1"], "]"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", 
            RowBox[{
             SubscriptBox["r", "1"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"Sign", "[", 
              SubscriptBox["\[Mu]", "1"], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{
              SubscriptBox["\[Mu]", "1"], "^", "2"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "-", 
            RowBox[{"\[ImaginaryI]", "*", 
             SubscriptBox["r", "1"], 
             SubscriptBox["\[Mu]", "1"], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1", " ", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
              RowBox[{"2", " ", "1", " ", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
               RowBox[{"D", "[", 
                RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
          RowBox[{"\[ImaginaryI]", "*", 
           RowBox[{"1", "^", "2"}], "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"D", "[", 
            RowBox[{"\[Eta]1", ",", "x"}], "]"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], " ", 
              SubscriptBox["r", "1"], 
              SubscriptBox["\[Mu]", "1"]}], "+", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["c", "2"], "-", 
             RowBox[{"1", " ", 
              SuperscriptBox[
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}], "-", 
             RowBox[{"D", "[", 
              RowBox[{"q2", ",", "x"}], "]"}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}]}], 
        "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"*", " ", "Define", " ", "operator", " ", 
     SubscriptBox["R", "2"], " ", "for", " ", "numerical", " ", 
     RowBox[{"computations", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumR", "2"], "[", 
      RowBox[{"w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_"}],
       "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "2"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
               SubscriptBox["r", "1"], 
               SubscriptBox["\[Mu]", "1"]}], "+", 
              RowBox[{"4", " ", 
               RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
               RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
               SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
               SuperscriptBox["\[Eta]1", "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
               "\[Eta]2"}]}], ")"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sign", "[", 
             SubscriptBox["\[Mu]", "1"], "]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", " ", 
       RowBox[{"(*", 
        RowBox[{
        "*", " ", "Reverting", " ", "back", " ", "to", " ", "old", " ", 
         RowBox[{
          SubscriptBox["ZeroNumR", "2"], ".", " ", "Was"}], " ", "originally",
          " ", 
         RowBox[{"Sign", "[", 
          RowBox[{"\[Epsilon]", "*", 
           SubscriptBox["\[Mu]", "1"]}], "]"}], "*", 
         SubscriptBox["\[Mu]", "1"], "*", 
         RowBox[{
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ".", " ", "Nope", "."}]}], " ", 
        "**)"}], "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", 
             RowBox[{"1", "^", "2"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
            RowBox[{"2", "*", "1", "*", "1", "*", 
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8242504557490396`*^9, 3.824250510536577*^9}, {
   3.824250558045709*^9, 3.8242505770060053`*^9}, {3.8242506208185444`*^9, 
   3.8242509143633776`*^9}, {3.8242509461004276`*^9, 3.824251186394908*^9}, {
   3.824251245255171*^9, 3.824251246704295*^9}, {3.8242512881226172`*^9, 
   3.824251354633906*^9}, {3.824251413331665*^9, 3.824251413436166*^9}, {
   3.824251447819129*^9, 3.8242514479068565`*^9}, {3.8242515512470913`*^9, 
   3.824251552366618*^9}, {3.8242516279130087`*^9, 3.824251844962574*^9}, {
   3.8242519215605373`*^9, 3.8242519257254066`*^9}, {3.8242519620688934`*^9, 
   3.824252177973816*^9}, 3.8242522349778757`*^9, {3.8242523864856215`*^9, 
   3.8242523932164073`*^9}, {3.8242525148599844`*^9, 
   3.8242525154334764`*^9}, {3.8242525772071695`*^9, 
   3.8242526166905947`*^9}, {3.824252664588333*^9, 3.8242526646960425`*^9}, {
   3.824252696488741*^9, 3.8242528189231086`*^9}, {3.824252869617689*^9, 
   3.8242528704564857`*^9}, {3.8242529034823456`*^9, 3.824253050813654*^9}, {
   3.8243139890760703`*^9, 3.824313990143183*^9}, {3.824508942792533*^9, 
   3.8245090478439474`*^9}, {3.824509081303008*^9, 3.824509097028672*^9}, {
   3.824509147623588*^9, 3.8245091478039427`*^9}, {3.824509257611655*^9, 
   3.824509257690446*^9}, {3.824509292058135*^9, 3.824509345529363*^9}, {
   3.824509392853689*^9, 3.8245094417614098`*^9}, {3.824828337998954*^9, 
   3.824828460106573*^9}, {3.8248284978842793`*^9, 3.8248286353461246`*^9}, {
   3.8248286782416215`*^9, 3.8248286834667177`*^9}, {3.8248287219651794`*^9, 
   3.82482884120378*^9}, {3.8248291009035482`*^9, 3.8248291161234136`*^9}, {
   3.8248292945286865`*^9, 3.8248293164614553`*^9}, {3.8359743401646805`*^9, 
   3.8359743533637943`*^9}, {3.836687158023981*^9, 3.8366872023822885`*^9}, {
   3.848407259227227*^9, 3.8484072672856565`*^9}, {3.848411668844797*^9, 
   3.8484116914333715`*^9}, {3.8484117397644777`*^9, 
   3.8484118208345103`*^9}, {3.8514565439801197`*^9, 
   3.8514565871074452`*^9}, {3.851456641730014*^9, 3.8514566446551447`*^9}, {
   3.8514567250311933`*^9, 3.851456812061587*^9}, {3.851457182253338*^9, 
   3.85145725479235*^9}, {3.851465020302952*^9, 3.8514650220074224`*^9}, {
   3.8514650722964926`*^9, 3.85146514264193*^9}, {3.851465176385463*^9, 
   3.8514652070025344`*^9}, {3.851465366277383*^9, 3.851465397977756*^9}, 
   3.851465745984846*^9, {3.851466204205268*^9, 3.851466209582238*^9}, {
   3.8514662464843206`*^9, 3.8514663357421045`*^9}, {3.851467232842861*^9, 
   3.8514672434391365`*^9}, {3.851467877250066*^9, 3.8514678837185993`*^9}, {
   3.852917267837072*^9, 3.852917270841378*^9}, {3.8529174043498063`*^9, 
   3.852917415547613*^9}, {3.8529175423797283`*^9, 3.8529175596549406`*^9}, {
   3.8529177251105328`*^9, 3.8529177271723976`*^9}, {3.8537165820459237`*^9, 
   3.8537165886581726`*^9}, {3.853716629910488*^9, 3.8537167872334213`*^9}, {
   3.8537168575408525`*^9, 3.8537169417076964`*^9}, {3.8537169954431343`*^9, 
   3.8537170785979958`*^9}, {3.8537171220925407`*^9, 
   3.8537171504894943`*^9}, {3.853717275132721*^9, 3.853717442049079*^9}, {
   3.8537175027539597`*^9, 3.8537175645659513`*^9}, {3.85371760271307*^9, 
   3.853717646738965*^9}, {3.853717786271262*^9, 3.8537178805736732`*^9}, {
   3.85371793314688*^9, 3.853717967707596*^9}, {3.853722046712377*^9, 
   3.853722047056782*^9}, {3.85372209568025*^9, 3.853722095837445*^9}, 
   3.854488017819373*^9, {3.854488058472938*^9, 3.8544880650954995`*^9}, {
   3.8553562794867306`*^9, 3.8553563738484344`*^9}, {3.8553575570422688`*^9, 
   3.855357558886212*^9}, {3.855361264454856*^9, 3.8553613117850704`*^9}, {
   3.855361563796399*^9, 3.855361586618361*^9}, {3.8553619257325783`*^9, 
   3.855361927221182*^9}, {3.8553619628478055`*^9, 3.8553620206768255`*^9}, {
   3.859124349384331*^9, 3.8591243569444*^9}, {3.8591244083790216`*^9, 
   3.85912453285021*^9}, {3.8591247249275527`*^9, 3.859124778726054*^9}, {
   3.859124817522173*^9, 3.859124852663889*^9}, {3.8591249169867687`*^9, 
   3.8591249268778954`*^9}, {3.859125374367953*^9, 3.8591253784136868`*^9}, {
   3.859125894257166*^9, 3.8591258965064707`*^9}, {3.859126100839035*^9, 
   3.859126125580268*^9}, {3.8591264278270583`*^9, 3.8591264305018787`*^9}, {
   3.8591269098083963`*^9, 3.8591269103885565`*^9}, {3.859128352791131*^9, 
   3.8591283810845804`*^9}, {3.859378216815371*^9, 3.8593782168934703`*^9}, {
   3.8593782608681355`*^9, 3.8593782731796885`*^9}, {3.863192115251119*^9, 
   3.8631921226478043`*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"2892aa40-7360-4185-8b84-3ace0f89b41b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", "of", " ", 
    "O", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", "^", "2"}], ")"}], "."}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["IHT", "2"], "=", 
    RowBox[{"NCoefficient", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "*", 
        RowBox[{
         SubscriptBox["ZeroNumR", "0"], "[", 
         RowBox[{
          SubscriptBox["w", "0"], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}]}], "]"}]}], " ", 
       "-", " ", 
       RowBox[{
        SubscriptBox["ZeroNumL", "1"], "[", 
        RowBox[{
         SubscriptBox["w", "1"], ",", 
         RowBox[{"GenModulate", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
          "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}], ",", 
         RowBox[{"Sin", "[", "x", "]"}]}], "]"}], " ", "-", " ", 
       RowBox[{
        SubscriptBox["ZeroNumL", "2"], "[", 
        RowBox[{
         SubscriptBox["w", "0"], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}], ",", 
         RowBox[{"Sin", "[", "x", "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", "*", "x"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"0", "*", "x"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", "*", "x"}], "]"}]}]}]}], "]"}], "+", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], "*", 
        RowBox[{
         SubscriptBox["ZeroNumR", "1"], "[", 
         RowBox[{
          SubscriptBox["w", "0"], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"Cos", "[", "x", "]"}]}], "]"}]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], "*", 
        RowBox[{
         SubscriptBox["ZeroNumR", "0"], "[", 
         RowBox[{
          SubscriptBox["w", "1"], ",", 
          RowBox[{"GenModulate", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
           "]"}]}], "]"}]}]}], " ", ",", 
      RowBox[{"GenModulate", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
       "]"}]}], "]"}]}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.8243035049000626`*^9, {3.8243035962054367`*^9, 3.8243039572277718`*^9}, {
   3.8243039903475065`*^9, 3.8243040201896243`*^9}, 3.8243081837573605`*^9, {
   3.8248293440619564`*^9, 3.824829348247904*^9}, {3.8359744383435135`*^9, 
   3.835974449753024*^9}, {3.8366872591008167`*^9, 3.836687305549447*^9}, {
   3.836688323230062*^9, 3.8366884135150394`*^9}, {3.848411963123127*^9, 
   3.848411988580433*^9}, {3.848412328502356*^9, 3.8484123360530677`*^9}, 
   3.848412419965124*^9, {3.8484128423095875`*^9, 3.848412843601988*^9}, 
   3.84841311979239*^9, {3.851468078064537*^9, 3.8514681151176367`*^9}, 
   3.852917574004096*^9, {3.8537180361306663`*^9, 3.8537180576960287`*^9}, {
   3.853718099704935*^9, 3.8537181223803525`*^9}, {3.853718174297331*^9, 
   3.8537181747346864`*^9}, {3.853719545995713*^9, 3.8537195661255236`*^9}, {
   3.853719600504632*^9, 3.8537196011450524`*^9}, {3.853719900083869*^9, 
   3.853719905425893*^9}, 3.859126865348693*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"d809d491-8a47-48ff-a941-456f6fe8f59e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"9", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "0"}]]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"9", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], "2"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "2"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}], ",", 
     RowBox[{
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], "2"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "1"}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"1", ",", "2"}]], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8593783188540936`*^9, 3.8595441474998007`*^9, 
  3.8606028112269783`*^9, 3.861396730118176*^9, 3.8631921310201173`*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"41a7c287-625e-4df1-b2ee-b3c92cfd0566"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Obtain", " ", "inhomogeneous", " ", "terms", " ", 
     "proportional", " ", "to", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], ",", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"0", "*", "\[ImaginaryI]", "*", "x"}], "]"}], ",", " ", 
    RowBox[{"and", " ", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}], "."}]}]}], " ", "**)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "3"}], "]"}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"2", ",", "0"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "4"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"2", ",", "1"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.8243052492586403`*^9, {3.824307934105904*^9, 3.8243079703116436`*^9}, {
   3.824308080526323*^9, 3.8243081676933184`*^9}, {3.82431169291716*^9, 
   3.824311771462596*^9}, {3.8243126839902415`*^9, 3.824312687796283*^9}, {
   3.824511885286113*^9, 3.8245118922013445`*^9}, {3.8359744616542253`*^9, 
   3.8359744640183077`*^9}, {3.8366873604850073`*^9, 3.836687393437887*^9}, {
   3.836687458197605*^9, 3.836687484221913*^9}, {3.8484130637623987`*^9, 
   3.8484131134266796`*^9}, {3.848413182963228*^9, 3.848413183977525*^9}, {
   3.863192133953342*^9, 3.8631921362682543`*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"7b3453af-a704-4a2c-a93a-4e5b8589ab6f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Dot", "[", 
             RowBox[{
              SubscriptBox["IHT", 
               RowBox[{"2", ",", 
                RowBox[{"-", "1"}]}]], ",", 
              RowBox[{"Conjugate", "[", 
               SubscriptBox["FA", 
                RowBox[{"-", "1"}]], "]"}]}], "]"}], "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
         SubscriptBox["partsoln", 
          RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "*", 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
        SubscriptBox["c", 
         SubscriptBox["g", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]]}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", "0"}]], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{
             SubscriptBox["IHT", 
              RowBox[{"2", ",", "0"}]], ",", 
             RowBox[{"Conjugate", "[", 
              SubscriptBox["FA", "0"], "]"}]}], "]"}], "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", "  ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "\[Rule]", " ", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", "g"]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
         SubscriptBox["c", 
          SubscriptBox["g", 
           RowBox[{"1", ",", "1"}]]]}]}], "]"}], ",", 
      RowBox[{"Assumptions", " ", "\[Rule]", " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Dot", "[", 
             RowBox[{
              SubscriptBox["IHT", 
               RowBox[{"2", ",", "1"}]], ",", 
              RowBox[{"Conjugate", "[", 
               SubscriptBox["FA", "1"], "]"}]}], "]"}], "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
         SubscriptBox["partsoln", 
          RowBox[{"1", ",", "0"}]]}], "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "*", 
          SubscriptBox["\[Mu]", "1"], "*", 
          SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "g"], "\[Rule]", " ", 
        SubscriptBox["c", 
         SubscriptBox["g", 
          RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.836687526280409*^9, 3.836687534067562*^9}, {
   3.8366879450177517`*^9, 3.836687946585737*^9}, {3.836688555634179*^9, 
   3.836688560114268*^9}, {3.8366887284725075`*^9, 3.8366888292217293`*^9}, {
   3.8366888618015327`*^9, 3.836688876034752*^9}, {3.8366889583004704`*^9, 
   3.8366889947306986`*^9}, {3.8366890502668552`*^9, 3.836689130314056*^9}, {
   3.8366906344160604`*^9, 3.8366906598681264`*^9}, {3.836691285535729*^9, 
   3.836691412761921*^9}, {3.836691469125493*^9, 3.836691472588806*^9}, {
   3.8366915180731297`*^9, 3.836691539628474*^9}, {3.836692271589815*^9, 
   3.8366923286144047`*^9}, {3.8366923943968935`*^9, 
   3.8366924190564594`*^9}, {3.8366924975375223`*^9, 3.836692500029627*^9}, {
   3.84841330097224*^9, 3.8484133196933885`*^9}, {3.8484133522210217`*^9, 
   3.848413447537505*^9}, {3.848413559333605*^9, 3.8484135723893394`*^9}, {
   3.8484213425548368`*^9, 3.8484213730810475`*^9}, 3.8484217706530724`*^9, {
   3.8484218327330523`*^9, 3.848421866514599*^9}, {3.848422188825116*^9, 
   3.848422200236229*^9}, {3.8514689393654547`*^9, 3.8514689535181527`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"bd95815d-8443-4b52-b163-9617bf14e110"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Mu]", "1"]}], "-", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593783655443697`*^9, 3.8595441543750896`*^9, 
  3.860602814144739*^9, 3.861396730370988*^9, 3.8631921392432795`*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"22b56a6d-8e19-4b31-bbfd-973beeb04931"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SubsuperscriptBox["\[Mu]", "1", "2"]}], " ", 
  SubscriptBox["\[Beta]", 
   RowBox[{"0", ",", "0"}]]}]], "Output",
 CellChangeTimes->{3.8593783655443697`*^9, 3.8595441543750896`*^9, 
  3.860602814144739*^9, 3.861396730370988*^9, 3.863192139290141*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"7338f0ac-a2cf-459e-91cf-fda87ac67820"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{"4", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "0"}]]}], "+", 
       RowBox[{
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593783655443697`*^9, 3.8595441543750896`*^9, 
  3.860602814144739*^9, 3.861396730370988*^9, 3.863192139327428*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"b8a50956-ff33-4df5-badb-400ff994a703"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "This", " ", "has", " ", "to", " ", "be", " ", "true", " ", "in",
     " ", "order", " ", "for", " ", "the", " ", "second", " ", "solvability", 
    " ", "condition", " ", "to", " ", "be", " ", 
    RowBox[{"satisfied", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Beta]", 
     RowBox[{"0", ",", "0"}]], " ", "=", " ", "0"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.856908324587112*^9, 3.856908354580278*^9}, {
  3.8569085119361725`*^9, 3.856908528068296*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"a108a4a2-9e06-4f37-91c7-a24352d5124e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Clean", " ", "up", " ", "the", " ", "first", " ", "solvability",
     " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["S", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["r", "1"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]], ",", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], "^", "2"}]}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[ImaginaryI]", "*", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], ")"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["U", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "/", "\[ImaginaryI]"}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", 
         "//.", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
         " ", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["V", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]], "/", "\[ImaginaryI]"}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", 
         "//.", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["r", "1"], 
           SubscriptBox["\[Mu]", "1"]}], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
         " ", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], ",", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.836689133211673*^9, 3.8366892811053886`*^9}, {
  3.8366893156214914`*^9, 3.8366893215657945`*^9}, {3.836689390979411*^9, 
  3.836689422438686*^9}, {3.836689517623274*^9, 3.836689609515186*^9}, {
  3.8366899127684164`*^9, 3.8366899487457733`*^9}, {3.83668998998062*^9, 
  3.8366900043919163`*^9}, {3.836690203588502*^9, 3.8366904125567074`*^9}, {
  3.8366918976890163`*^9, 3.836691901236161*^9}, {3.8366920900986896`*^9, 
  3.8366920905286784`*^9}, {3.8366922089862857`*^9, 3.8366922124055276`*^9}, {
  3.8366924267192883`*^9, 3.836692430858803*^9}, {3.8484136670211163`*^9, 
  3.8484136769648547`*^9}, {3.8593782170965433`*^9, 3.859378217112153*^9}, {
  3.859378470058777*^9, 3.8593784747760124`*^9}, {3.863192151823161*^9, 
  3.8631921521568427`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"bf05ea7c-551f-4295-a8f8-e90f010b894e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8366891462385693`*^9, 3.8366891536597824`*^9}, 
   3.8366891850770216`*^9, {3.8366892159750385`*^9, 3.836689281436499*^9}, 
   3.836689322057747*^9, {3.836689411838238*^9, 3.8366894227553663`*^9}, {
   3.836689529016997*^9, 3.8366895530997095`*^9}, {3.8366895882868505`*^9, 
   3.8366896102159023`*^9}, 3.836690005068159*^9, {3.8366902337635026`*^9, 
   3.8366902507748528`*^9}, {3.8366902896980405`*^9, 3.836690337855152*^9}, 
   3.8366904133452487`*^9, 3.836692050901555*^9, 3.8366920913550744`*^9, 
   3.8366921692045608`*^9, 3.8366922180102882`*^9, 3.8366924329586625`*^9, 
   3.848413600174775*^9, 3.8514682661254005`*^9, 3.8529182249306393`*^9, 
   3.856908368201021*^9, 3.8591289903668365`*^9, 3.859378475369593*^9, 
   3.8595441606809077`*^9, 3.8606028176105347`*^9, 3.861396730636528*^9, 
   3.8631921526550293`*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"815dd820-3f58-4eeb-8437-b5f648f9ca60"],

Cell[BoxData[
 FractionBox["1", "4"]], "Output",
 CellChangeTimes->{{3.8366891462385693`*^9, 3.8366891536597824`*^9}, 
   3.8366891850770216`*^9, {3.8366892159750385`*^9, 3.836689281436499*^9}, 
   3.836689322057747*^9, {3.836689411838238*^9, 3.8366894227553663`*^9}, {
   3.836689529016997*^9, 3.8366895530997095`*^9}, {3.8366895882868505`*^9, 
   3.8366896102159023`*^9}, 3.836690005068159*^9, {3.8366902337635026`*^9, 
   3.8366902507748528`*^9}, {3.8366902896980405`*^9, 3.836690337855152*^9}, 
   3.8366904133452487`*^9, 3.836692050901555*^9, 3.8366920913550744`*^9, 
   3.8366921692045608`*^9, 3.8366922180102882`*^9, 3.8366924329586625`*^9, 
   3.848413600174775*^9, 3.8514682661254005`*^9, 3.8529182249306393`*^9, 
   3.856908368201021*^9, 3.8591289903668365`*^9, 3.859378475369593*^9, 
   3.8595441606809077`*^9, 3.8606028176105347`*^9, 3.861396730636528*^9, 
   3.863192152670641*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"c066ecf7-2b7f-40e8-841c-521a8709837a"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.8366891462385693`*^9, 3.8366891536597824`*^9}, 
   3.8366891850770216`*^9, {3.8366892159750385`*^9, 3.836689281436499*^9}, 
   3.836689322057747*^9, {3.836689411838238*^9, 3.8366894227553663`*^9}, {
   3.836689529016997*^9, 3.8366895530997095`*^9}, {3.8366895882868505`*^9, 
   3.8366896102159023`*^9}, 3.836690005068159*^9, {3.8366902337635026`*^9, 
   3.8366902507748528`*^9}, {3.8366902896980405`*^9, 3.836690337855152*^9}, 
   3.8366904133452487`*^9, 3.836692050901555*^9, 3.8366920913550744`*^9, 
   3.8366921692045608`*^9, 3.8366922180102882`*^9, 3.8366924329586625`*^9, 
   3.848413600174775*^9, 3.8514682661254005`*^9, 3.8529182249306393`*^9, 
   3.856908368201021*^9, 3.8591289903668365`*^9, 3.859378475369593*^9, 
   3.8595441606809077`*^9, 3.8606028176105347`*^9, 3.861396730636528*^9, 
   3.863192152670641*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"658668e0-b238-41e4-a640-3dff558d03e3"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{{3.8366891462385693`*^9, 3.8366891536597824`*^9}, 
   3.8366891850770216`*^9, {3.8366892159750385`*^9, 3.836689281436499*^9}, 
   3.836689322057747*^9, {3.836689411838238*^9, 3.8366894227553663`*^9}, {
   3.836689529016997*^9, 3.8366895530997095`*^9}, {3.8366895882868505`*^9, 
   3.8366896102159023`*^9}, 3.836690005068159*^9, {3.8366902337635026`*^9, 
   3.8366902507748528`*^9}, {3.8366902896980405`*^9, 3.836690337855152*^9}, 
   3.8366904133452487`*^9, 3.836692050901555*^9, 3.8366920913550744`*^9, 
   3.8366921692045608`*^9, 3.8366922180102882`*^9, 3.8366924329586625`*^9, 
   3.848413600174775*^9, 3.8514682661254005`*^9, 3.8529182249306393`*^9, 
   3.856908368201021*^9, 3.8591289903668365`*^9, 3.859378475369593*^9, 
   3.8595441606809077`*^9, 3.8606028176105347`*^9, 3.861396730636528*^9, 
   3.863192152692949*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"4bba190a-9fc4-4110-b0fe-fd7f69ec4348"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}], ",", "v2"}]], "=", 
    RowBox[{
     RowBox[{"2", "*", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Lambda]", "2"], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["c", "g"], "*", 
         SubscriptBox["r", "1"], 
         SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "*", 
      SubscriptBox["\[Mu]", "1"]}], " ", "+", 
     RowBox[{"\[ImaginaryI]", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["U", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]], "*", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["T", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]], "*", 
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
           SubscriptBox["V", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]]}], ")"}], "*", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "-", 
    SubscriptBox["cond", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}], ",", "v2"}]]}], " ", "//.", " ", 
   RowBox[{
    SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
    SubscriptBox["c", 
     SubscriptBox["g", 
      RowBox[{"1", ",", "1"}]]]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8366904527260375`*^9, 3.836690596902311*^9}, {
   3.836692122310469*^9, 3.8366921281367273`*^9}, 3.8366924430892496`*^9, {
   3.8366924777417955`*^9, 3.8366924823336554`*^9}, 3.8484136824852405`*^9, 
   3.859378217127777*^9},
 CellLabel->"In[62]:=",ExpressionUUID->"16265d87-68b4-4028-8bcd-1f79964206e4"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836690587803108*^9, 3.8366905974479704`*^9}, 
   3.8366921315670757`*^9, 3.8366921762398663`*^9, 3.8366924388777604`*^9, 
   3.83669248648647*^9, 3.848413646224452*^9, 3.8484136856173944`*^9, 
   3.8514682726114073`*^9, 3.852918235739456*^9, 3.856908432531666*^9, 
   3.8591289931352835`*^9, 3.8593784809965935`*^9, 3.859544164398445*^9, 
   3.8606028199759045`*^9, 3.8613967307458677`*^9, 3.8631921564159503`*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"4429a8ff-b658-4c9e-90b2-86d65199db20"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Clean", " ", "up", " ", "the", " ", "third", " ", "solvability",
     " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["S", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"2", ",", "1"}]], ",", 
        SubscriptBox["\[Mu]", "1"]}], "]"}], "//.", 
      RowBox[{
       SubscriptBox["r", "1"], "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["T", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["cond", 
         RowBox[{"2", ",", "1"}]], "/", 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], ")"}]}], ",", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["U", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", "1"}]], "/", "\[ImaginaryI]"}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "]"}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
        " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
      " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}], " ", "\[Rule]", " ", "0"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["V", 
     RowBox[{"2", ",", "1"}]], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{
          RowBox[{
           SubscriptBox["cond", 
            RowBox[{"2", ",", "1"}]], "/", "\[ImaginaryI]"}], ",", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "]"}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], " ", "\[Rule]", " ", "0"}]}], " ", "//.",
        " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", "\[Rule]", " ", "0"}]}], " ", "//.", 
      " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["r", "1"], 
        SubscriptBox["\[Mu]", "1"]}], " ", "\[Rule]", " ", "0"}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.8366922635526843`*^9, {3.836692514841197*^9, 3.836692743797945*^9}, {
   3.8366929391480827`*^9, 3.836692991955048*^9}, {3.8366930283859544`*^9, 
   3.8366930939630375`*^9}, {3.848413713173518*^9, 3.848413721037915*^9}, {
   3.859378217127777*^9, 3.859378217143391*^9}, {3.8593784935133467`*^9, 
   3.8593784965926533`*^9}, {3.863192164646984*^9, 3.8631921650440187`*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"8105ae77-111a-4da5-bcac-de0aa9562eb5"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, 3.8484137091548915`*^9, 3.8514683279217663`*^9, 
   3.852918435253807*^9, 3.856908539390972*^9, 3.859128996602898*^9, {
   3.8593784908562164`*^9, 3.8593784969362693`*^9}, 3.859544167416314*^9, 
   3.8606028227519855`*^9, 3.8613967308239803`*^9, 3.863192165686983*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"56a4702f-f5f4-42a4-9ff7-0b2004b8b063"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", "4"]}]], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, 3.8484137091548915`*^9, 3.8514683279217663`*^9, 
   3.852918435253807*^9, 3.856908539390972*^9, 3.859128996602898*^9, {
   3.8593784908562164`*^9, 3.8593784969362693`*^9}, 3.859544167416314*^9, 
   3.8606028227519855`*^9, 3.8613967308239803`*^9, 3.8631921657025785`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"50364129-d546-4103-9667-f38f2833de6d"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, 3.8484137091548915`*^9, 3.8514683279217663`*^9, 
   3.852918435253807*^9, 3.856908539390972*^9, 3.859128996602898*^9, {
   3.8593784908562164`*^9, 3.8593784969362693`*^9}, 3.859544167416314*^9, 
   3.8606028227519855`*^9, 3.8613967308239803`*^9, 3.8631921657025785`*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"e96b3e42-dd3e-4fd1-9501-f27bb0251c3e"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.8366925175495243`*^9, 3.8366926094539056`*^9}, {
   3.8366926464791126`*^9, 3.8366927040164323`*^9}, 3.836692744364893*^9, {
   3.8366929704400578`*^9, 3.8366929924807005`*^9}, {3.836693036167287*^9, 
   3.8366930945144606`*^9}, 3.8484137091548915`*^9, 3.8514683279217663`*^9, 
   3.852918435253807*^9, 3.856908539390972*^9, 3.859128996602898*^9, {
   3.8593784908562164`*^9, 3.8593784969362693`*^9}, 3.859544167416314*^9, 
   3.8606028227519855`*^9, 3.8613967308239803`*^9, 3.8631921657182016`*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"aba23865-f8dd-49a3-87a9-8c6c2d40b342"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["cond", 
      RowBox[{"2", ",", "1", ",", "v2"}]], "=", 
     RowBox[{
      RowBox[{"2", "*", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "*", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "2"], "+", 
         RowBox[{"\[ImaginaryI]", "*", 
          SubscriptBox["c", "g"], "*", 
          SubscriptBox["r", "1"], 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"2", ",", "1"}]], "*", 
       SubscriptBox["\[Mu]", "1"]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["U", 
           RowBox[{"2", ",", "1"}]], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["T", 
              RowBox[{"2", ",", "1"}]], "*", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}], "+", 
            SubscriptBox["V", 
             RowBox[{"2", ",", "1"}]]}], ")"}], "*", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"2", ",", "1", ",", "v2"}]], "-", 
      SubscriptBox["cond", 
       RowBox[{"2", ",", "1"}]]}], "//.", " ", 
     RowBox[{
      SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
      SubscriptBox["c", 
       SubscriptBox["g", 
        RowBox[{"1", ",", "1"}]]]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8366928289670663`*^9, 3.8366929247157607`*^9}, {
   3.836693100976225*^9, 3.836693125132848*^9}, 3.8593782171590247`*^9},
 CellLabel->"In[68]:=",ExpressionUUID->"7c07249e-a22e-40f9-b3f0-c3f7cc96967f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8366931255086718`*^9, 3.8484137263188543`*^9, 
  3.851468331370963*^9, 3.8529184386773767`*^9, 3.856908556899576*^9, 
  3.8591289990111265`*^9, 3.8593784997018785`*^9, 3.859544173042674*^9, 
  3.860602824044916*^9, 3.8613967309333076`*^9, 3.8631921688573728`*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"e13bc5e2-5b7d-46a1-93ea-031550941cf2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Symmetries", " ", "that", " ", "appear", " ", "in", " ", 
    "finite", " ", "depth", " ", "also", " ", "appear", " ", "in", " ", 
    "infinite", " ", 
    RowBox[{"depth", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["S", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["T", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["T", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["U", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["U", 
      RowBox[{"2", ",", "1"}]]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["V", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "+", 
     SubscriptBox["V", 
      RowBox[{"2", ",", "1"}]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8366931420804*^9, 3.8366932267566977`*^9}, {
  3.848413737347451*^9, 3.8484137552350388`*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"6dff96f8-2962-4afd-ae1a-3139c2e47947"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.848413739270831*^9, 3.8484137590392237`*^9}, 3.8514683341348124`*^9, 
   3.852918441354085*^9, 3.8569085588302784`*^9, 3.859129000698058*^9, 
   3.8593785017168584`*^9, 3.8595441759011555`*^9, 3.8606028254119935`*^9, 
   3.8613967310114098`*^9, 3.863192172605492*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"d4ab2bb5-ab87-429e-8b91-187f94bb8678"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.848413739270831*^9, 3.8484137590392237`*^9}, 3.8514683341348124`*^9, 
   3.852918441354085*^9, 3.8569085588302784`*^9, 3.859129000698058*^9, 
   3.8593785017168584`*^9, 3.8595441759011555`*^9, 3.8606028254119935`*^9, 
   3.8613967310114098`*^9, 3.863192172605492*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"9e60c824-3805-4e6d-a2d6-de0c125aee71"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.848413739270831*^9, 3.8484137590392237`*^9}, 3.8514683341348124`*^9, 
   3.852918441354085*^9, 3.8569085588302784`*^9, 3.859129000698058*^9, 
   3.8593785017168584`*^9, 3.8595441759011555`*^9, 3.8606028254119935`*^9, 
   3.8613967310114098`*^9, 3.8631921726211376`*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"ec4f4a47-23f9-42a1-8458-fd10715ac96c"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.836693149860794*^9, 3.8366932284523945`*^9}, {
   3.848413739270831*^9, 3.8484137590392237`*^9}, 3.8514683341348124`*^9, 
   3.852918441354085*^9, 3.8569085588302784`*^9, 3.859129000698058*^9, 
   3.8593785017168584`*^9, 3.8595441759011555`*^9, 3.8606028254119935`*^9, 
   3.8613967310114098`*^9, 3.8631921726211376`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"9c30ed76-fb47-4b96-b6fd-73047bd8eee6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], " ", "\[Equal]", " ", "0"}], " ", "&&", " ", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"2", ",", "1"}]], " ", "\[Equal]", " ", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], ",", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.859387032732486*^9, 3.8593870329606466`*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"543ed29f-6be1-426c-a11d-6acc0b3e4494"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "8"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["r", "1"], " ", 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]]}], ")"}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
            SubsuperscriptBox["\[Mu]", "1", "4"]}]], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SubscriptBox["r", "1"], " ", 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         SqrtBox[
          RowBox[{
           SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]]}], ")"}]}]}], 
     ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
            SubsuperscriptBox["\[Mu]", "1", "4"]}]], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8606028413527904`*^9, 3.861396731261325*^9, 
  3.8631921762181134`*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"3398680c-6b1d-4c3a-95e3-9b8725a977ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "I", " ", "can", " ", "still", " ", "choose", " ", "a", " ", 
     "normalization", " ", "for", " ", "the", " ", "eigenfunctions"}], ",", 
    " ", 
    RowBox[{"if", " ", 
     RowBox[{"desired", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["lambdaBeta", "2"], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Refine", "[", 
        RowBox[{
         RowBox[{"FullSimplify", "[", 
          RowBox[{"Refine", "[", 
           RowBox[{
            RowBox[{"Solve", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                SubscriptBox["cond", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]], " ", "\[Equal]", " ", "0"}], " ", "&&",
                " ", 
               RowBox[{
                SubscriptBox["cond", 
                 RowBox[{"2", ",", "1"}]], " ", "\[Equal]", " ", "0"}]}], ",", 
              RowBox[{"{", 
               RowBox[{
                SubscriptBox["\[Lambda]", "2"], ",", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"0", ",", "1"}]]}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               SubscriptBox["\[Mu]", "1"], ">", "0"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], "+", 
                SuperscriptBox[
                 SubscriptBox["\[Mu]", "1"], "2"]}], "<", "0"}]}], "}"}]}], 
           "]"}], "]"}], ",", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "]"}], "//.", 
       RowBox[{
        RowBox[{"8", "-", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}], "->", 
        SuperscriptBox["\[CapitalDelta]", "2"]}]}], ",", 
      RowBox[{"\[CapitalDelta]", ">", "0"}]}], "]"}]}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.85690862694732*^9, 3.8569087368610315`*^9}, 
   3.859145208710005*^9, {3.859284668526944*^9, 3.8592846689018536`*^9}, {
   3.859378537943356*^9, 3.8593786148978434`*^9}, {3.85955091133608*^9, 
   3.8595509330544815`*^9}, {3.8631921843562903`*^9, 3.863192187970334*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"7a726536-63fe-4dfb-826c-5ca3db1ef896"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{"\[CapitalDelta]", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["r", "1"]}]}], ")"}], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "2"], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "8"]}], " ", 
       RowBox[{"(", 
        RowBox[{"\[CapitalDelta]", "-", 
         RowBox[{"4", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["r", "1"]}]}], ")"}], " ", 
       SubscriptBox["\[Mu]", "1"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.859378505731161*^9, {3.859378540801792*^9, 3.8593786160720353`*^9}, 
   3.8595441831060057`*^9, 3.859550933970276*^9, {3.8606028309634495`*^9, 
   3.8606028435482845`*^9}, 3.861396732745227*^9, 3.863192192479354*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"c56f1bf9-7fb3-49f2-ad99-d56f6c83cc58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["partIHT", "2"], "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "2"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "6", ",", "7"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", "2"], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"partsoln", "[", 
            RowBox[{
             SubscriptBox["partIHT", "2"], ",", 
             RowBox[{
              RowBox[{"GenModulate", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}],
                "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "6", ",", "7"}], "}"}], "]"}], 
              "]"}], ",", "2"}], "]"}], "]"}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["partsoln", "1"], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["partsoln", "1"], "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
        SubscriptBox["partsoln", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
       SubscriptBox["partsoln", 
        RowBox[{"1", ",", "0"}]]}], "//.", " ", 
      SubscriptBox["partsoln", 
       RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
     RowBox[{
      SubscriptBox["\[Lambda]", "1"], " ", "->", " ", 
      RowBox[{"\[ImaginaryI]", "*", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "/", "2"}]}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.8529726048710475`*^9, 3.852972718888316*^9}, {
  3.8529728785511336`*^9, 3.8529728888326435`*^9}, {3.852972956861108*^9, 
  3.852973010190221*^9}, {3.852973045837042*^9, 3.852973085855271*^9}, {
  3.852973162342286*^9, 3.8529731893492804`*^9}, {3.852973267758833*^9, 
  3.852973287926427*^9}, {3.859544734135758*^9, 3.8595447344012957`*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"bc283fcb-b6a1-48c0-8dcc-98e22bb4fd30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "8"]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["9", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "8"]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["9", "8"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8529727348634543`*^9, 3.8529727758682475`*^9, 3.85297289067564*^9, {
   3.8529729615427475`*^9, 3.852973011080558*^9}, {3.8529730607667027`*^9, 
   3.8529730867610617`*^9}, 3.8529731912078886`*^9, 3.8529732895675535`*^9, 
   3.8591290461010575`*^9, 3.859378654417469*^9, 3.8595441920770187`*^9, 
   3.8606028973097878`*^9, 3.8613967336364193`*^9, 3.863192250843279*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"8cd71427-f443-4024-9c85-1a4367149227"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  SubscriptBox["partsoln", 
   RowBox[{"2", ",", 
    RowBox[{"-", "1"}]}]], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "\[Rule]", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["IHT", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]], "[", 
               RowBox[{"[", "1", "]"}], "]"}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], "*", 
                SubscriptBox["\[Mu]", "1"], "*", 
                SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]]}]}], "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
         SubscriptBox["partsoln", 
          RowBox[{"1", ",", "0"}]]}], "//.", " ", 
        SubscriptBox["partsoln", 
         RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "2"], " ", "->", " ", 
        RowBox[{"1", "/", "2"}]}]}], " ", "]"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["partsoln", 
   RowBox[{"2", ",", "0"}]], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", 
      RowBox[{"2", ",", "0"}]], "\[Rule]", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                SubscriptBox["IHT", 
                 RowBox[{"2", ",", "0"}]], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], "*", 
                SubscriptBox["\[Mu]", "1"], "*", 
                SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
         SubscriptBox["partsoln", 
          RowBox[{"1", ",", "0"}]]}], "//.", " ", 
        SubscriptBox["partsoln", 
         RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "2"], " ", "->", " ", 
        RowBox[{"1", "/", "2"}]}]}], "]"}]}], ",", 
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "0"}]], " ", "\[Rule]", " ", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["partsoln", 
   RowBox[{"2", ",", "1"}]], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["h", 
      RowBox[{"2", ",", "1"}]], "\[Rule]", " ", "0"}], ",", 
    RowBox[{
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]], "\[Rule]", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               SubscriptBox["IHT", 
                RowBox[{"2", ",", "1"}]], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "//.", " ", 
              RowBox[{
               SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
               RowBox[{
                RowBox[{"-", "\[ImaginaryI]"}], "*", 
                SubscriptBox["\[Mu]", "1"], "*", 
                SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
              SubscriptBox["c", 
               SubscriptBox["g", 
                RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
         SubscriptBox["partsoln", 
          RowBox[{"1", ",", "0"}]]}], "//.", " ", 
        SubscriptBox["partsoln", 
         RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "2"], " ", "->", " ", 
        RowBox[{"1", "/", "2"}]}]}], "]"}]}]}], 
   "}"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.852972907668044*^9, 3.852972913247817*^9}, {
  3.852973023350422*^9, 3.8529730245432987`*^9}, {3.852973353761114*^9, 
  3.8529734302276096`*^9}, {3.8529734878467245`*^9, 3.8529734905384307`*^9}, {
  3.8529735711841564`*^9, 3.852973600979079*^9}, {3.8529736397232847`*^9, 
  3.8529736444175644`*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"108c5540-7390-43f6-8e11-d16158aa2569"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SubscriptBox["\[Lambda]", "2"]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Mu]", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8529729145130672`*^9, 3.8529730263239756`*^9, 3.852973492334568*^9, {
   3.8529735791724634`*^9, 3.85297360210369*^9}, 3.852973646867506*^9, 
   3.859129065461032*^9, 3.859378666840867*^9, 3.8595441951853943`*^9, 
   3.8606029000930295`*^9, 3.861396733730138*^9, 3.8631922533812475`*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"396fdf22-6498-4c35-8aff-d5b67d1b38ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"2", ",", "0"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8529729145130672`*^9, 3.8529730263239756`*^9, 3.852973492334568*^9, {
   3.8529735791724634`*^9, 3.85297360210369*^9}, 3.852973646867506*^9, 
   3.859129065461032*^9, 3.859378666840867*^9, 3.8595441951853943`*^9, 
   3.8606029000930295`*^9, 3.861396733730138*^9, 3.8631922533968725`*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"718275a1-3362-4654-9146-f5d012dd3b6d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"2", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Lambda]", "2"]}], "-", 
          RowBox[{"2", " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8529729145130672`*^9, 3.8529730263239756`*^9, 3.852973492334568*^9, {
   3.8529735791724634`*^9, 3.85297360210369*^9}, 3.852973646867506*^9, 
   3.859129065461032*^9, 3.859378666840867*^9, 3.8595441951853943`*^9, 
   3.8606029000930295`*^9, 3.861396733730138*^9, 3.863192253412489*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"757def59-1887-4240-bebb-18c7ceaa1f29"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["w", "2"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h", 
          RowBox[{"2", ",", "j"}]], ",", 
         SubscriptBox["\[Phi]", 
          RowBox[{"2", ",", "j"}]]}], "}"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", "*", "j", "*", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
         "]"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]], "*", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.8591399162889147`*^9, 3.8591399618965216`*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"bde9050f-0b70-4084-9609-b4ab05a4899a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["h", 
     RowBox[{"2", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"2", ",", "0"}]], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "3"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.859139967004249*^9, 3.859378717964493*^9, 
  3.859544199314845*^9, 3.860602902828899*^9, 3.8613967338707175`*^9, 
  3.863192255648518*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"d4fded18-4bcd-41b2-9b55-3a2f35c84812"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  StyleBox[
   RowBox[{
    RowBox[{"IV", ".", " ", "Third"}], "-", 
    RowBox[{"Order", " ", "Problem"}]}], "Section"]}]], "Input",
 CellChangeTimes->{{3.859139875156845*^9, 3.859139891877183*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"8965acf3-cd80-439d-98d7-17cf2da8a5a9"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumL", "3"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_", ",", "q3_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                     ")"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "-", 
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", "\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                   "\[Eta]1"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"1", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
               ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "+", " ", 
            RowBox[{
             RowBox[{"(", " ", 
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6", " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                  SubscriptBox["c", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{"6", " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["r", "2"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{"6", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                  SubscriptBox["c", "2"], " ", "\[Eta]1"}], "+", 
                 RowBox[{"6", " ", 
                  SuperscriptBox[
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", "1", 
                  " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", "\[Eta]1"}], "+", 
                 RowBox[{"12", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{"9", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SuperscriptBox["\[Eta]1", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "4"], " ", "1", " ", 
                  SuperscriptBox["\[Eta]1", "3"]}], "+", 
                 RowBox[{"12", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                 RowBox[{"6", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", "1", " ",
                   "\[Eta]1", " ", "\[Eta]2"}], "+", 
                 RowBox[{"6", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", "1", " ",
                   "\[Eta]3"}]}], ")"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}]}], ")"}]}], 
               "+", 
               RowBox[{"\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                     ")"}]}]}], ")"}]}]}], ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["r", "2"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{
                  FractionBox["1", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                    ")"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "6"], " ", "\[Kappa]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                    SuperscriptBox["\[Eta]1", "3"]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    "\[Eta]1", " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]3"}]}],
                    ")"}]}]}], ")"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", 
                RowBox[{"Sign", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"]}], "-", 
               RowBox[{
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}], 
             "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sign", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                SubscriptBox["r", "2"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["c", "2"], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                   "\[Eta]1"}]}], ")"}]}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", " ", 
               SubscriptBox["\[Mu]", "1"], " ", 
               SubscriptBox["r", "1"], 
               SubscriptBox["\[Mu]", "1"]}], ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["r", "2"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}]}], ")"}]}], 
              ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"1", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"2", " ", "1", " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"q1", ",", "x"}], "]"}], "2"], "-", 
                RowBox[{"2", " ", "1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
            ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", "1", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}]}], ")"}]}], 
               "+", 
               RowBox[{
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["c", "2"]}], "+", 
                  RowBox[{"D", "[", 
                   RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}], 
            ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "1", " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "-", 
             RowBox[{"D", "[", 
              RowBox[{"q3", ",", "x"}], "]"}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}]}], 
        "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumR", "3"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["1", "6"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["r", "2"], 
                 SubscriptBox["\[Mu]", "1"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox[
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", 
                 SubsuperscriptBox["\[Mu]", "1", "2"], " ", "\[Eta]1"}], "+", 
                RowBox[{"12", " ", 
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                RowBox[{"9", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 SuperscriptBox["\[Eta]1", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "4"], " ", 
                 SuperscriptBox["\[Eta]1", "3"]}], "+", 
                RowBox[{"12", " ", 
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", "\[Eta]1",
                  " ", "\[Eta]2"}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                 "\[Eta]3"}]}], ")"}]}], ")"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Sign", "[", 
                SubscriptBox["\[Mu]", "1"], "]"}], " ", 
               SubscriptBox["r", "2"], 
               SubscriptBox["\[Mu]", "1"]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", "\[Eta]1"}]}], 
             ")"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", " ", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "1"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"], "-", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{"D", "[", 
                RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.852972533546059*^9, 3.8591399108655014`*^9, {3.859139972506297*^9, 
   3.859140124896028*^9}, {3.859140183954352*^9, 3.8591402687250986`*^9}, {
   3.8591403708037996`*^9, 3.85914037572779*^9}, {3.859140430189767*^9, 
   3.859140449541198*^9}, {3.859140523725819*^9, 3.8591405307109785`*^9}, {
   3.859140582396471*^9, 3.859140590787372*^9}, {3.8591406564348106`*^9, 
   3.859140660654948*^9}, {3.85914085283631*^9, 3.859140861680526*^9}, {
   3.8591409248363*^9, 3.859140933540518*^9}, {3.8591413856414967`*^9, 
   3.859141397390921*^9}, {3.859141467040498*^9, 3.859141482679268*^9}, {
   3.8591415631919084`*^9, 3.859141567646027*^9}, {3.8591416315718765`*^9, 
   3.859141643615287*^9}, {3.8591417037153783`*^9, 3.8591417078390226`*^9}, {
   3.859141761491739*^9, 3.8591417688660054`*^9}, {3.859141832545988*^9, 
   3.8591418409182963`*^9}, {3.8591420315073776`*^9, 
   3.8591420341471777`*^9}, {3.85937821723711*^9, 3.8593782175651455`*^9}, {
   3.85937873957953*^9, 3.859378744283659*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"fcb6a558-093e-4ed2-b300-8e3557a20539"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["IHT", "3"], "=", 
   RowBox[{"NCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       RowBox[{
        SubscriptBox["ZeroNumL", "1"], "[", 
        RowBox[{
         SubscriptBox["w", "2"], ",", 
         RowBox[{"GenModulate", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
          "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}], ",", 
         RowBox[{"Sin", "[", "x", "]"}]}], "]"}]}], " ", "-", " ", 
      RowBox[{
       SubscriptBox["ZeroNumL", "2"], "[", 
       RowBox[{
        SubscriptBox["w", "1"], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"0", "*", "x"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", "*", "x"}], "]"}]}]}]}], "]"}], "-", 
      RowBox[{
       SubscriptBox["ZeroNumL", "3"], "[", 
       RowBox[{
        SubscriptBox["w", "0"], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"3", "/", "8"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"3", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "4"}], "*", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{
          RowBox[{"3", "/", "8"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"3", "*", "x"}], "]"}]}]}]}], "]"}], "+", 
      "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["ZeroNumR", "2"], "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Lambda]", "1"], "*", 
         SubscriptBox["w", "0"]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}]}], "]"}], " ", "+", 
      RowBox[{
       SubscriptBox["ZeroNumR", "1"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          SubscriptBox["w", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["w", "0"]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}]}], "]"}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["ZeroNumR", "0"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          SubscriptBox["w", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["w", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "*", 
          SubscriptBox["w", "0"]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"GenModulate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], "]"}]}],
     "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.8591424399598002`*^9, 3.8591425412657824`*^9, {3.85914392841359*^9, 
   3.8591439289601355`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"6b82e894-c72b-4eda-a156-19b2a443d999"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["9", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"45", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"9", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["7", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["25", "6"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], "8"], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"2", ",", "2"}]]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["25", "6"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["7", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["45", "8"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"45", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], "8"], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"9", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], "2"], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      SubscriptBox["h", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], "2"], "+", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      SubscriptBox["h", 
       RowBox[{"2", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "4"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], "2"], "+", 
      FractionBox[
       RowBox[{"7", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"7", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "8"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      SubscriptBox["h", 
       RowBox[{"2", ",", "2"}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "2"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]], "2"], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], "2"], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "8"], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", "1"}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      SubscriptBox["h", 
       RowBox[{"2", ",", "2"}]], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"2", ",", "3"}]]}], "2"], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "8"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.859544216087381*^9, 3.860602908668235*^9, 
  3.8613967351984158`*^9, 3.863192268412453*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"a6036674-1b29-4ef9-9fef-50ad04a57008"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["IHT", 
    RowBox[{"3", ",", 
     RowBox[{"-", "1"}]}]], " ", "=", " ", 
   RowBox[{
    SubscriptBox["IHT", "3"], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "4"}], "]"}], "]"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["IHT", 
   RowBox[{"3", ",", "0"}]], " ", "=", " ", 
  RowBox[{
   SubscriptBox["IHT", "3"], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "5"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["IHT", 
   RowBox[{"3", ",", "1"}]], " ", "=", " ", 
  RowBox[{
   SubscriptBox["IHT", "3"], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "6"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8591426806861486`*^9, 3.859142683513362*^9}, {
   3.85914271753006*^9, 3.859142729797391*^9}, {3.8591428282262435`*^9, 
   3.859142895361211*^9}, {3.8591435136946564`*^9, 3.859143546867689*^9}, {
   3.8591435957331347`*^9, 3.859143788181917*^9}, {3.859143848993839*^9, 
   3.8591438644036927`*^9}, 3.8591439248981543`*^9, {3.859143986616083*^9, 
   3.8591440338148627`*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"d6ab35d9-1f35-4b0c-8cc8-e3550f23bd07"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["3", "8"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["5", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "4"], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", "1"}]]}], "8"], "-", 
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", 
      RowBox[{"-", "2"}]}]], "+", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    SubscriptBox["h", 
     RowBox[{"2", ",", 
      RowBox[{"-", "2"}]}]], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["r", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    FractionBox[
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "2"], "-", 
    RowBox[{
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    FractionBox[
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]], "4"], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8593788620252633`*^9, 3.85954422583642*^9, 
  3.860602913612875*^9, 3.861396735417096*^9, 3.863192274183815*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"8a36db14-fd1b-444c-865c-5f8b59b47a6e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", 
      SubscriptBox["\[Mu]", "1"], "]"}], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Abs", "[", 
      SubscriptBox["\[Mu]", "1"], "]"}], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Abs", "[", 
      SubscriptBox["\[Mu]", "1"], "]"}], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"Abs", "[", 
      SubscriptBox["\[Mu]", "1"], "]"}], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    FractionBox[
     SubscriptBox["h", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]], "2"], "-", 
    FractionBox[
     SubscriptBox["h", 
      RowBox[{"2", ",", "1"}]], "2"], "+", 
    FractionBox[
     RowBox[{"7", " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], "8"], "-", 
    RowBox[{
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    FractionBox[
     RowBox[{"7", " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", "1"}]]}], "8"], "-", 
    RowBox[{
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "2"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "0"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8593788620252633`*^9, 3.85954422583642*^9, 
  3.860602913612875*^9, 3.861396735417096*^9, 3.8631922742198706`*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"0ebf3bc1-af11-4164-a285-78552c651400"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "2"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "2"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "1"}]]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["3", "8"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      SubscriptBox["\[Phi]", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}]]}], "8"], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    FractionBox[
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]], "4"], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{
     FractionBox["5", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "2"}]]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]]}], "-", 
    SubscriptBox["\[Phi]", 
     RowBox[{"2", ",", "2"}]]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "0"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "2"}]]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["h", 
      RowBox[{"1", ",", "2"}]]}], "-", 
    SubscriptBox["h", 
     RowBox[{"2", ",", "2"}]], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{
     SubscriptBox["r", "2"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    FractionBox[
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]], "4"], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    FractionBox[
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]], "2"], "-", 
    RowBox[{
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "-", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]]}], "-", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["c", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "2"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["r", "1"], " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"1", ",", "2"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "1"}]]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"2", ",", "2"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8593788620252633`*^9, 3.85954422583642*^9, 
  3.860602913612875*^9, 3.861396735417096*^9, 3.863192274251111*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"2493cfc0-1e0d-46b9-9f70-a62937236bf8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Dot", "[", 
                  RowBox[{
                   SubscriptBox["IHT", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                   RowBox[{"Conjugate", "[", 
                    SubscriptBox["FA", 
                    RowBox[{"-", "1"}]], "]"}]}], "]"}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["partsoln", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", "0"}]]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "1"}]]}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
         RowBox[{"1", "/", "2"}]}]}], "]"}], ",", 
      RowBox[{"Assumptions", " ", "\[Rule]", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Dot", "[", 
                  RowBox[{
                   SubscriptBox["IHT", 
                    RowBox[{"3", ",", "0"}]], ",", 
                   RowBox[{"Conjugate", "[", 
                    SubscriptBox["FA", "0"], "]"}]}], "]"}], "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", "1"}]}]]}], "//.", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", "0"}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", "1"}]]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "//.", "  ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], " ", "//.", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "1"}]]}], "//.", "  ", 
          RowBox[{
           SubscriptBox["partsoln", "1"], "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "\[Rule]", " ", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           SubscriptBox["c", "g"]}]}]}], "//.", " ", 
        RowBox[{
         SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
         SubscriptBox["c", 
          SubscriptBox["g", 
           RowBox[{"1", ",", "1"}]]]}]}], "]"}], ",", 
      RowBox[{"Assumptions", "->", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"Refine", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Dot", "[", 
                  RowBox[{
                   SubscriptBox["IHT", 
                    RowBox[{"3", ",", "1"}]], ",", 
                   RowBox[{"Conjugate", "[", 
                    SubscriptBox["FA", "1"], "]"}]}], "]"}], "//.", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", "0"}]]}], "//.", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", "1"}]]}], "//.", 
               RowBox[{
                SubscriptBox["partsoln", "2"], "[", 
                RowBox[{"[", 
                 RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", "0"}]]}], "//.", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
         RowBox[{"1", "/", "2"}]}]}], "]"}], ",", 
      RowBox[{"Assumptions", " ", "\[Rule]", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.8591402819592085`*^9, {3.8591442146938243`*^9, 3.8591442896322527`*^9}, {
   3.859144360196294*^9, 3.859144434086993*^9}, {3.859144465398334*^9, 
   3.859144528766693*^9}, {3.859144645922393*^9, 3.859144669269683*^9}, {
   3.8591447036653605`*^9, 3.859144715961117*^9}, {3.8591447659626102`*^9, 
   3.8591447970619426`*^9}, {3.8593846655229626`*^9, 3.859384692571007*^9}, {
   3.85938872252884*^9, 3.8593887407992883`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"afe7b3c8-1541-4e3b-a80b-a8e287cf4cac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["r", "2"]}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593788768397655`*^9, 3.8593846930266676`*^9, 
  3.859388743176015*^9, 3.859544233959256*^9, 3.8606029164210315`*^9, 
  3.861396735729494*^9, 3.863192278076532*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"8859bd23-ead5-4ab0-9f48-e197fa3d55fb"],

Cell[BoxData[
 RowBox[{"\[ImaginaryI]", " ", 
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "0"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593788768397655`*^9, 3.8593846930266676`*^9, 
  3.859388743176015*^9, 3.859544233959256*^9, 3.8606029164210315`*^9, 
  3.861396735729494*^9, 3.8631922780921535`*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"56de189a-7584-4a46-b745-44143e4ac66f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Lambda]", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", "1"}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["r", "2"]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "0"}]]}], "+", 
       RowBox[{"4", " ", 
        SubscriptBox["r", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593788768397655`*^9, 3.8593846930266676`*^9, 
  3.859388743176015*^9, 3.859544233959256*^9, 3.8606029164210315`*^9, 
  3.861396735729494*^9, 3.8631922781390142`*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"acd5d2a1-609a-4b00-9557-661d549a2c8c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["lambda", "3"], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Refine", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             SubscriptBox["\[Lambda]", "3"], "//.", 
             RowBox[{"Solve", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SubscriptBox["cond", 
                  RowBox[{"3", ",", 
                   RowBox[{"-", "1"}]}]], "==", "0"}], "&&", 
                RowBox[{
                 SubscriptBox["cond", 
                  RowBox[{"3", ",", "1"}]], "==", "0"}]}], ",", 
               RowBox[{"{", 
                RowBox[{
                 SubscriptBox["\[Lambda]", "3"], ",", 
                 SubscriptBox["\[Beta]", 
                  RowBox[{"1", ",", "1"}]]}], "}"}]}], "]"}]}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "//.", " ", 
          RowBox[{
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]], "->", " ", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", 
                 RowBox[{"-", "1"}]}]], "+", 
               SubscriptBox["\[Beta]", 
                RowBox[{"0", ",", "1"}]]}], ")"}]}], "/", 
            "\[ImaginaryI]"}]}]}], "//.", 
         RowBox[{
          SubscriptBox["lambdaBeta", "2"], "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "]"}], ",", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "]"}], "//.", 
     RowBox[{"\[CapitalDelta]", "->", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"8", "-", 
        SuperscriptBox[
         SubscriptBox["\[Mu]", "1"], "2"]}], "]"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.859387673411796*^9, 3.859387673585841*^9}, {
  3.8593889110341897`*^9, 3.85938892602271*^9}, {3.8595443866039486`*^9, 
  3.859544387322464*^9}, {3.8606029598483815`*^9, 3.8606029703880844`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"a2f25360-bc5e-4638-ae57-13da2d13841a"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "16"], " ", 
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       SubscriptBox["r", "2"]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"]}], "-", 
    FractionBox[
     RowBox[{"8", " ", 
      SubscriptBox["\[Mu]", "1"]}], 
     SqrtBox[
      RowBox[{"8", "-", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}]]], "-", 
    FractionBox[
     RowBox[{"4", " ", 
      SubscriptBox["r", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "4"}], "+", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}], 
     SqrtBox[
      RowBox[{"8", "-", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}]]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8593876743348017`*^9, 3.859388788029524*^9, 3.8593888285020742`*^9, 
   3.859388927000061*^9, 3.859544239238821*^9, 3.8595443886032705`*^9, {
   3.8606029537705226`*^9, 3.8606029711622796`*^9}, 3.861396736338676*^9, 
   3.863192285494389*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"f3bd069d-5a78-404f-a01a-bcbf2b8ad3e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", "Employ", " ", "the", " ", "regular", " ", "curve", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"Refine", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"Refine", "[", 
             RowBox[{
              RowBox[{"Simplify", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Flatten", "[", 
                   RowBox[{
                    SubscriptBox["\[Lambda]", "3"], "//.", 
                    RowBox[{"Solve", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    SubscriptBox["cond", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "==", "0"}], "&&", 
                    RowBox[{
                    SubscriptBox["cond", 
                    RowBox[{"3", ",", "1"}]], "==", "0"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    SubscriptBox["\[Lambda]", "3"], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}], "}"}]}], "]"}]}], "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "//.", " ", 
                 RowBox[{
                  SubscriptBox["\[Beta]", 
                   RowBox[{"1", ",", "0"}]], "->", " ", 
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "/", 
                   "\[ImaginaryI]"}]}]}], "//.", 
                RowBox[{
                 SubscriptBox["lambdaBeta", "2"], "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "]"}], ",", 
              RowBox[{
               SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "]"}], "]"}], "//.", 
           RowBox[{
            RowBox[{"8", "-", 
             SuperscriptBox[
              SubscriptBox["\[Mu]", "1"], "2"]}], "->", 
            SuperscriptBox["\[CapitalDelta]", "2"]}]}], ",", 
          RowBox[{"\[CapitalDelta]", ">", "0"}]}], "]"}], ",", 
        RowBox[{"1", "/", "\[CapitalDelta]"}]}], "]"}], "==", "0"}], ",", 
     RowBox[{"{", 
      SubscriptBox["r", "1"], "}"}]}], "]"}], "//.", 
   RowBox[{
    SubscriptBox["\[Mu]", "1"], "->", 
    RowBox[{"2", "*", 
     RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.859206733128729*^9, 3.8592067981767693`*^9}, {
   3.859206835891323*^9, 3.859206881143261*^9}, {3.8592069307679443`*^9, 
   3.8592071146189747`*^9}, 3.8593782181274295`*^9, {3.859378912582097*^9, 
   3.8593789421343164`*^9}, {3.859379198588354*^9, 3.8593793832433243`*^9}, {
   3.8593816991250887`*^9, 3.8593817070652437`*^9}, {3.8593829450864506`*^9, 
   3.8593829603045063`*^9}, {3.8593830848214083`*^9, 
   3.8593832171847954`*^9}, {3.859383414822403*^9, 3.859383422042035*^9}, {
   3.8631922900095835`*^9, 3.8631922934669847`*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"3d3491f9-70e1-42cc-8672-6dceaeb2074e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["r", "1"], "\[Rule]", 
    RowBox[{"-", 
     SqrtBox["2"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.859379317552123*^9, 3.8593793457599854`*^9}, {
   3.8593816997363305`*^9, 3.85938170781497*^9}, {3.859382952915762*^9, 
   3.8593829606635733`*^9}, {3.8593830885233355`*^9, 3.8593832177314634`*^9}, 
   3.859383422526249*^9, 3.8593888316544533`*^9, 3.8595442472768803`*^9, 
   3.8606029766344366`*^9, 3.8613967365729766`*^9, {3.8631922881948757`*^9, 
   3.8631922938323927`*^9}},
 CellLabel->"Out[95]=",ExpressionUUID->"30f3b41f-b327-41bc-8f42-aef19a93498a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["lambda", 
    RowBox[{"3", ",", "v2"}]], "=", 
   RowBox[{
    SubscriptBox["lambda", "3"], "//.", " ", 
    RowBox[{
     SubscriptBox["r", "1"], "->", 
     RowBox[{"-", 
      RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.8593888732821603`*^9, {3.859388929600303*^9, 3.8593889716949763`*^9}, {
   3.8595444049746294`*^9, 3.859544408098624*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"4b45c494-86c3-4455-a8c6-e574660e2a2f"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "16"], " ", 
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       SubscriptBox["r", "2"]}], ")"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"]}], "-", 
    FractionBox[
     RowBox[{"8", " ", 
      SubscriptBox["\[Mu]", "1"]}], 
     SqrtBox[
      RowBox[{"8", "-", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}]]], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "4"}], "+", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}], 
     SqrtBox[
      RowBox[{"8", "-", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}]]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593889425670004`*^9, 3.859388982037108*^9, 
  3.8595442502290616`*^9, 3.859544409363812*^9, 3.860602978949771*^9, 
  3.8613967366510735`*^9, 3.8631922967547607`*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"e75e916b-6c61-4941-b86c-b7b1f249a47a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"lambda3Re", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{"ComplexExpand", "[", 
         SubscriptBox["lambda", "3"], "]"}], ",", 
        RowBox[{
         RowBox[{"8", "-", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], ">", "0"}]}], "]"}], "//.", 
      RowBox[{"\[ImaginaryI]", "->", "0"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"lambda3Im", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{"ComplexExpand", "[", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "*", 
          SubscriptBox["lambda", "3"]}], "]"}], ",", 
        RowBox[{
         RowBox[{"8", "-", 
          SuperscriptBox[
           SubscriptBox["\[Mu]", "1"], "2"]}], ">", "0"}]}], "]"}], "//.", 
      RowBox[{"\[ImaginaryI]", "->", "0"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.861400784824951*^9, 3.861400842400165*^9}, {
  3.8614008870357375`*^9, 3.8614009110725555`*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"29f61213-515e-45db-9ba0-f60e45a119d9"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SubscriptBox["\[Mu]", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]}], ")"}]}], 
   RowBox[{"4", " ", 
    SqrtBox[
     RowBox[{"8", "-", 
      SubsuperscriptBox["\[Mu]", "1", "2"]}]]}]]}]], "Output",
 CellChangeTimes->{{3.8614007937162924`*^9, 3.86140084365804*^9}, {
   3.861400889000004*^9, 3.861400911481869*^9}, 3.8631922991140513`*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"764c76ab-75c4-4f83-85b1-2212b13ffe41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "16"]}], " ", 
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{"16", "-", 
    RowBox[{"8", " ", 
     SubscriptBox["r", "2"]}], "+", 
    SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8614007937162924`*^9, 3.86140084365804*^9}, {
   3.861400889000004*^9, 3.861400911481869*^9}, 3.8631922991453*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"25140878-05fb-4fa1-989f-4fb15d423f38"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["lambdaBeta", "3"], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Refine", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"Refine", "[", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Flatten", "[", 
                RowBox[{"Solve", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SubscriptBox["cond", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "==", "0"}], "&&", 
                   RowBox[{
                    SubscriptBox["cond", 
                    RowBox[{"3", ",", "1"}]], "==", "0"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    SubscriptBox["\[Lambda]", "3"], ",", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"1", ",", "1"}]]}], "}"}]}], "]"}], "]"}], "//.", 
               " ", 
               RowBox[{
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", "0"}]], "->", " ", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                    SubscriptBox["\[Beta]", 
                    RowBox[{"0", ",", "1"}]]}], ")"}]}], "/", 
                 "\[ImaginaryI]"}]}]}], "//.", 
              RowBox[{
               SubscriptBox["lambdaBeta", "2"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "//.", 
             RowBox[{
              SubscriptBox["r", "1"], "->", 
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "]"}], ",", 
           RowBox[{
            SubscriptBox["\[Mu]", "1"], ">", "0"}]}], "]"}], "//.", 
         RowBox[{
          RowBox[{"8", "-", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}], "->", 
          RowBox[{"\[CapitalDelta]", "^", "2"}]}]}], "]"}], ",", 
       RowBox[{"\[CapitalDelta]", ">", "0"}]}], "]"}], "//.", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       SuperscriptBox["\[CapitalDelta]", "2"]}], "->", 
      RowBox[{"-", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8595442720096016`*^9, 3.859544283071978*^9}, {
  3.859544340735214*^9, 3.859544342768829*^9}, {3.859544416626941*^9, 
  3.859544468446417*^9}, {3.859550813864482*^9, 3.8595508575989785`*^9}, {
  3.8606030402077074`*^9, 3.8606030946898937`*^9}, {3.8606032034753942`*^9, 
  3.8606032076857643`*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"9a60f75b-e845-4544-9f52-0fb8c5323c9c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Lambda]", "3"], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"16", " ", "\[CapitalDelta]"}]], 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "+", 
            RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}]}], "-", 
         RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
          SubscriptBox["r", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[CapitalDelta]", "2"], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", "1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", 
                SqrtBox["2"]}], "+", 
               RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}], "+", 
               SubscriptBox["\[Mu]", "1"]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Beta]", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"8", " ", "\[CapitalDelta]"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"16", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "-", 
          RowBox[{"4", " ", "\[CapitalDelta]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SqrtBox["2"]}], "+", 
             RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}], "-", 
             SubscriptBox["\[Mu]", "1"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[CapitalDelta]", "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
           SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[CapitalDelta]", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "8"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
           SubscriptBox["\[Mu]", "1"]}], "+", 
          SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8595444261008267`*^9, 3.859544471854184*^9}, 
   3.859550815737108*^9, {3.859550846479546*^9, 3.859550858363679*^9}, {
   3.860603019115266*^9, 3.8606030954901905`*^9}, 3.860603208595315*^9, 
   3.861396738869111*^9, 3.8631923031923656`*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"a64c2471-c94f-4737-8171-9029c593e989"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "*", " ", "Obtain", " ", "asymptotic", " ", "approximation", " ", "of", 
     " ", "figure"}], "-", 
    RowBox[{"eight", " ", 
     RowBox[{"curve", "."}]}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"lambdaO3Re", "=", 
    RowBox[{
     RowBox[{"Refine", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"\[ImaginaryI]", "*", 
             RowBox[{
              SubscriptBox["\[Mu]", "1"], "/", "2"}], "*", "\[Epsilon]"}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Lambda]", "2"], "//.", " ", 
               RowBox[{
                SubscriptBox["lambdaBeta", "2"], "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "*", 
             RowBox[{"\[Epsilon]", "^", "2"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["\[Lambda]", "3"], "//.", 
               SubscriptBox["lambdaBeta", "3"]}], ")"}], "*", 
             SuperscriptBox["\[Epsilon]", "3"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["HOT", 
                RowBox[{"\[Lambda]", ",", "R"}]], "+", 
               RowBox[{"\[ImaginaryI]", "*", 
                SubscriptBox["HOT", 
                 RowBox[{"\[Lambda]", ",", "I"}]]}]}], ")"}], "*", 
             SuperscriptBox["\[Epsilon]", "4"]}]}], "//.", 
           RowBox[{
            SubscriptBox["r", "1"], "->", 
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], " ", "//.", 
          RowBox[{
           SubscriptBox["r", "2"], "->", 
           RowBox[{"13", "/", "8"}]}]}], "//.", " ", 
         RowBox[{"\[CapitalDelta]", "->", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"8", "-", 
            SuperscriptBox[
             SubscriptBox["\[Mu]", "1"], "2"]}], "]"}]}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"8", "-", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}], ">", "0"}]}], "]"}], " ", "//.",
      " ", 
     RowBox[{"\[ImaginaryI]", "->", "0"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"lambdaO3Im", "=", 
    RowBox[{
     RowBox[{"Refine", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"\[ImaginaryI]", "*", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], "/", "2"}], "*", "\[Epsilon]"}], 
              "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Lambda]", "2"], "//.", " ", 
                 RowBox[{
                  SubscriptBox["lambdaBeta", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ")"}], "*", 
               RowBox[{"\[Epsilon]", "^", "2"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["\[Lambda]", "3"], "//.", 
                 SubscriptBox["lambdaBeta", "3"]}], ")"}], "*", 
               SuperscriptBox["\[Epsilon]", "3"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["HOT", 
                  RowBox[{"\[Lambda]", ",", "R"}]], "+", 
                 RowBox[{"\[ImaginaryI]", "*", 
                  SubscriptBox["HOT", 
                   RowBox[{"\[Lambda]", ",", "Im"}]]}]}], ")"}], "*", 
               SuperscriptBox["\[Epsilon]", "4"]}]}], "//.", 
             RowBox[{
              SubscriptBox["r", "1"], "->", 
              RowBox[{"-", 
               RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], " ", "//.", 
            RowBox[{
             SubscriptBox["r", "2"], "->", 
             RowBox[{"13", "/", "8"}]}]}], "//.", " ", 
           RowBox[{"\[CapitalDelta]", "->", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"8", "-", 
              SuperscriptBox[
               SubscriptBox["\[Mu]", "1"], "2"]}], "]"}]}]}], ")"}]}], "]"}], 
       ",", 
       RowBox[{
        RowBox[{"8", "-", 
         SuperscriptBox[
          SubscriptBox["\[Mu]", "1"], "2"]}], ">", "0"}]}], "]"}], " ", "//.",
      " ", 
     RowBox[{"\[ImaginaryI]", "->", "0"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.861397016370672*^9, 3.8613971038650255`*^9}, {
   3.861397171151224*^9, 3.8613973961066103`*^9}, 3.861400713648219*^9, {
   3.8631924025350337`*^9, 3.8631924494564705`*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"32a8b6fb-83bc-410a-a8b0-574483f6f753"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SqrtBox["2"], " ", 
     SuperscriptBox["\[Epsilon]", "3"], " ", 
     SubscriptBox["\[Mu]", "1"]}], 
    SqrtBox[
     RowBox[{"8", "-", 
      SubsuperscriptBox["\[Mu]", "1", "2"]}]]]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "2"]}], 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{"8", "-", 
      SubsuperscriptBox["\[Mu]", "1", "2"]}]]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    SubsuperscriptBox["\[Mu]", "1", "3"]}], 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", 
    SqrtBox[
     RowBox[{"8", "-", 
      SubsuperscriptBox["\[Mu]", "1", "2"]}]]}]], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", 
   SuperscriptBox["\[Epsilon]", "2"], " ", 
   SubscriptBox["\[Mu]", "1"], " ", 
   SqrtBox[
    RowBox[{"8", "-", 
     SubsuperscriptBox["\[Mu]", "1", "2"]}]]}], "+", 
  RowBox[{
   SuperscriptBox["\[Epsilon]", "4"], " ", 
   SubscriptBox["HOT", 
    RowBox[{"\[Lambda]", ",", "R"}]]}]}]], "Output",
 CellChangeTimes->{{3.8613970246706905`*^9, 3.8613970339108515`*^9}, {
   3.861397078750375*^9, 3.8613971046433535`*^9}, {3.8613972229682064`*^9, 
   3.8613972534655714`*^9}, {3.861397292891262*^9, 3.8613973094893456`*^9}, {
   3.8613973562039146`*^9, 3.861397396480929*^9}, 3.861400716955792*^9, {
   3.8631924227328606`*^9, 3.8631924501825953`*^9}},
 CellLabel->
  "Out[102]=",ExpressionUUID->"7428dbf9-c987-4c52-8667-e387489e7daa"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[Epsilon]", " ", 
    SubscriptBox["\[Mu]", "1"]}], "2"], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    SubscriptBox["\[Mu]", "1"]}], 
   SqrtBox["2"]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    SubscriptBox["\[Mu]", "1"]}], "16"], "-", 
  RowBox[{
   FractionBox["1", "16"], " ", 
   SuperscriptBox["\[Epsilon]", "3"], " ", 
   SubsuperscriptBox["\[Mu]", "1", "3"]}], "+", 
  RowBox[{
   SuperscriptBox["\[Epsilon]", "4"], " ", 
   SubscriptBox["HOT", 
    RowBox[{"\[Lambda]", ",", "Im"}]]}]}]], "Output",
 CellChangeTimes->{{3.8613970246706905`*^9, 3.8613970339108515`*^9}, {
   3.861397078750375*^9, 3.8613971046433535`*^9}, {3.8613972229682064`*^9, 
   3.8613972534655714`*^9}, {3.861397292891262*^9, 3.8613973094893456`*^9}, {
   3.8613973562039146`*^9, 3.861397396480929*^9}, 3.861400716955792*^9, {
   3.8631924227328606`*^9, 3.86319245021384*^9}},
 CellLabel->
  "Out[103]=",ExpressionUUID->"38b06e0c-b42b-4f80-9313-cffc42704864"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Eliminate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "r"], "==", "lambdaO3Re"}], "//.", 
         RowBox[{
          SubscriptBox["HOT", 
           RowBox[{"\[Lambda]", ",", "R"}]], "->", "0"}]}], " ", "//.", " ", 
        RowBox[{
         SuperscriptBox["\[Epsilon]", "3"], "->", "0"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "i"], "==", "lambdaO3Im"}], " ", "//.", 
         RowBox[{
          SubscriptBox["HOT", 
           RowBox[{"\[Lambda]", ",", "Im"}]], "->", "0"}]}], "//.", 
        RowBox[{
         SuperscriptBox["\[Epsilon]", "3"], "->", "0"}]}]}], "}"}], ",", 
     SubscriptBox["\[Mu]", "1"]}], "]"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.8614011089492464`*^9, 3.8614011423524475`*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"52826653-68af-4556-bd8c-5badc2b5a75a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     RowBox[{"16", " ", 
      SqrtBox["2"], " ", "\[Epsilon]"}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["\[Epsilon]", "2"]}], "+", 
     RowBox[{"32", " ", 
      SqrtBox["2"], " ", 
      SuperscriptBox["\[Epsilon]", "3"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["\[Epsilon]", "4"]}]}], ")"}], " ", 
   SubsuperscriptBox["\[Lambda]", "r", "2"]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "\[Epsilon]"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Epsilon]", "2"]}]}], ")"}], " ", 
    SubsuperscriptBox["\[Lambda]", "i", "2"]}], "+", 
   SubsuperscriptBox["\[Lambda]", "i", "4"]}]}]], "Output",
 CellChangeTimes->{3.8614011485768967`*^9, 3.8631924527773438`*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"3acd7254-800f-476d-8a4c-6345ae35ee2c"]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{
  3.8614014221282034`*^9},ExpressionUUID->"038edcf3-ce1f-4a8a-abd3-\
8551e7ca00f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Obtain", " ", "asymptotic", " ", "expansion", " ", "of", " ", 
    "Floquet", " ", "exponent", " ", "corresponding", " ", "to", " ", "most", 
    " ", "unstable", " ", 
    RowBox[{"eigenvalue", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"muUnstabEqns", "=", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Numerator", "[", 
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{"lambdaO3Re", ",", 
              SubscriptBox["\[Mu]", "1"]}], "]"}], "/", 
            SuperscriptBox["\[Epsilon]", "2"]}], "]"}], "]"}], "//.", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "->", 
          RowBox[{
           SubscriptBox["\[Mu]", 
            RowBox[{"1", ",", "0"}]], "+", 
           RowBox[{"\[Epsilon]", "*", 
            SubscriptBox["\[Mu]", 
             RowBox[{"1", ",", "1"}]]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], "*", 
            SubscriptBox["HOT", "\[Mu]"]}]}]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
     ",", "\[Epsilon]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8613973973648663`*^9, 3.8613976290390635`*^9}, {
  3.8631924649158635`*^9, 3.8631924796237803`*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"52b86fe5-ee98-4de3-a45f-5dc50ed6a293"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"32", "-", 
    RowBox[{"12", " ", 
     SubsuperscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}], "2"]}], "+", 
    SubsuperscriptBox["\[Mu]", 
     RowBox[{"1", ",", "0"}], "4"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "32"}], " ", 
     SqrtBox["2"]}], "-", 
    RowBox[{"32", " ", 
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]]}], "+", 
    RowBox[{"24", " ", 
     SqrtBox["2"], " ", 
     SubsuperscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}], "3"]}], "-", 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", 
     SubsuperscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}], "4"]}], "-", 
    RowBox[{"24", " ", 
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]], " ", 
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "1"}]]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}], "3"], " ", 
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "1"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8613974111434083`*^9, 3.8613974517813272`*^9}, {
   3.8613975122781467`*^9, 3.86139757631555*^9}, {3.861397614823018*^9, 
   3.8613976313069983`*^9}, 3.8631924801480455`*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"5cf3b996-103e-4e8e-af90-850c17f8c9cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"muUnstabEqns", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "==", "0"}], ",", 
    RowBox[{"{", 
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.86139763620152*^9, 3.8613976523130956`*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"056a45e3-48db-4c1e-a6a5-ec1044ced000"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]], "\[Rule]", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]], "\[Rule]", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SqrtBox["2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "0"}]], "\[Rule]", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8613976529965105`*^9, 3.863192484303963*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"fc2673db-27ba-4ba3-8e30-8767e84d8c97"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"muUnstabEqns", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "//.", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"1", ",", "0"}]], "->", "2"}]}], ")"}], "==", "0"}], ",", 
    RowBox[{"{", 
     SubscriptBox["\[Mu]", 
      RowBox[{"1", ",", "1"}]], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861397674342809*^9, 3.8613977142351475`*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"c4490f10-f96e-484d-9a9a-82e5af2ebe83"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Mu]", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.861397715559904*^9, 3.863192486291497*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"68c8a635-375e-44cc-8aa8-0b2502838efe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Most", " ", "unstable", " ", "eigenvalue", " ", "Floquet", " ", 
    RowBox[{"exponent", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"muUnstabO2", " ", "=", " ", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Epsilon]", "*", 
           SubscriptBox["\[Mu]", "1"], "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Epsilon]", "*", 
              SubscriptBox["r", "1"]}], " ", "+", " ", 
             RowBox[{
              SuperscriptBox["\[Epsilon]", "2"], "*", 
              SubscriptBox["r", "2"]}], " ", "+", " ", 
             RowBox[{
              SuperscriptBox["\[Epsilon]", "3"], "*", 
              SubscriptBox["HOT", "r"]}]}], ")"}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["\[Mu]", "1"], "->", 
           RowBox[{
            SubscriptBox["\[Mu]", 
             RowBox[{"1", ",", "0"}]], "+", 
            RowBox[{
             SubscriptBox["\[Mu]", 
              RowBox[{"1", ",", "1"}]], "*", "\[Epsilon]"}], " ", "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], "*", 
             SubscriptBox["HOT", "\[Mu]"]}]}]}]}], "//.", " ", 
         RowBox[{
          SubscriptBox["r", "1"], "->", 
          RowBox[{"-", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], " ", "//.", 
        RowBox[{
         SubscriptBox["r", "2"], "->", 
         RowBox[{"13", "/", "8"}]}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Mu]", 
         RowBox[{"1", ",", "0"}]], "->", "2"}]}], " ", "//.", " ", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"1", ",", "1"}]], "->", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8613977250590863`*^9, 3.861397940149889*^9}, {
  3.863192491938836*^9, 3.8631925012611966`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"5597274e-583e-4d24-b1cf-f328113e621d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"2", " ", "\[Epsilon]"}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["\[Epsilon]", "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
    SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon], 0, {2, -3}, 1, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.8613979091980157`*^9, 3.8613979405726433`*^9}, 
   3.8631925018577633`*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"a632cd42-b528-4f6c-8c6a-ba24c6c9efb4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Most", " ", "unstable", " ", "eigenvalue", " ", "real", " ", 
    "part", " ", 
    RowBox[{"expansion", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"lambdaO3Re", " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "->", 
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"1", ",", "0"}]], "+", 
         RowBox[{"\[Epsilon]", "*", 
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "1"}]]}], "+", 
         RowBox[{
          SubscriptBox["HOT", "\[Mu]"], "*", 
          SuperscriptBox["\[Epsilon]", "2"]}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"1", ",", "0"}]], "->", " ", "2"}]}], "//.", " ", 
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"1", ",", "1"}]], "->", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8613988625247717`*^9, 3.8613989740648193`*^9}, {
  3.8631925063422813`*^9, 3.863192515546149*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"012ad896-c3b0-4503-8044-6cda48378030"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["\[Epsilon]", "2"], "2"], "-", 
   SuperscriptBox["\[Epsilon]", "3"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
    SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon], 0, {
    Rational[1, 2], -1}, 2, 4, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.861398878953834*^9, {3.8613989646827574`*^9, 3.8613989747677197`*^9}, 
   3.8631925161102095`*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"ba02602a-4575-47f7-ab0b-4e3ff724418d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "*", " ", "Most", " ", "unstable", " ", "eigenvalue", " ", "imaginary", 
    " ", "part", " ", 
    RowBox[{"expansion", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"lambdaO3Im", " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], "->", 
        RowBox[{
         SubscriptBox["\[Mu]", 
          RowBox[{"1", ",", "0"}]], "+", 
         RowBox[{"\[Epsilon]", "*", 
          SubscriptBox["\[Mu]", 
           RowBox[{"1", ",", "1"}]]}], "+", 
         RowBox[{
          SubscriptBox["HOT", "\[Mu]"], "*", 
          SuperscriptBox["\[Epsilon]", "2"]}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["\[Mu]", 
        RowBox[{"1", ",", "0"}]], "->", " ", "2"}]}], "//.", " ", 
     RowBox[{
      SubscriptBox["\[Mu]", 
       RowBox[{"1", ",", "1"}]], "->", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"2", "*", 
        RowBox[{"Sqrt", "[", "2", "]"}]}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861399070745761*^9, 3.8613990885389814`*^9}, {
  3.8631925188520436`*^9, 3.8631925293351297`*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"a5226df2-6d23-40cc-a172-1c4b4d484b5a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\[Epsilon]", "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["\[Epsilon]", "2"]}], "2"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
    SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon], 0, {1, 
    Rational[-3, 2]}, 1, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.861399085546528*^9, 3.8613990890870285`*^9}, 
   3.8631925301654787`*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"b93a7394-f442-4849-9875-a2cd3063a1fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["partIHT", "3"], "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "3"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3", ",", "7", ",", "8", ",", "9"}], 
         "}"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", "3"], " ", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"Simplify", "[", 
                    RowBox[{"partsoln", "[", 
                    RowBox[{
                    SubscriptBox["partIHT", "3"], ",", 
                    RowBox[{
                    RowBox[{"GenModulate", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
                    "3"}], "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"{", 
                    RowBox[{
                    "1", ",", "2", ",", "3", ",", "7", ",", "8", ",", "9"}], 
                    "}"}], "]"}], "]"}], ",", "3"}], "]"}], "]"}], " ", "//.",
                    " ", 
                   RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                  " ", 
                  RowBox[{
                   SubscriptBox["partsoln", "2"], "[", 
                   RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                 " ", 
                 RowBox[{
                  SubscriptBox["partsoln", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
                RowBox[{
                 SubscriptBox["partsoln", "2"], "[", 
                 RowBox[{"[", 
                  RowBox[{"4", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", 
                 RowBox[{"-", "1"}]}]]}], "//.", " ", 
              SubscriptBox["partsoln", 
               RowBox[{"2", ",", "0"}]]}], "//.", " ", 
             SubscriptBox["partsoln", 
              RowBox[{"2", ",", "1"}]]}], "//.", " ", 
            RowBox[{
             SubscriptBox["partsoln", "1"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
           RowBox[{
            SubscriptBox["partsoln", "1"], "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
         SubscriptBox["partsoln", 
          RowBox[{"1", ",", "0"}]]}], "//.", " ", 
        SubscriptBox["partsoln", 
         RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["\[Lambda]", "1"], " ", "->", " ", 
        RowBox[{"\[ImaginaryI]", "*", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], "/", "2"}]}]}]}], "//.", 
      RowBox[{
       SubscriptBox["c", "2"], "->", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8595447459322853`*^9, 3.8595449080866885`*^9}, {
  3.8595449415714865`*^9, 3.859544946198048*^9}, {3.859545377540737*^9, 
  3.8595454055159*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"8dc74e1a-e003-4500-90c2-4d22858dc771"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "4"}]}]], "\[Rule]", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "3"]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "4"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["4", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["3", "4"]}], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       FractionBox[
        RowBox[{"9", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "8"]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "3"}]}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["9", "16"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", "1"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{"21", "+", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Lambda]", "2"]}], "-", 
          SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       FractionBox[
        RowBox[{"29", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", "1"}]]}], "24"], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SubscriptBox["\[Mu]", "1"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", "24"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SubscriptBox["\[Lambda]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "9"}], "+", 
               SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"13", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "-", 
            RowBox[{"6", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"24", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", 
      RowBox[{
       FractionBox["1", "24"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"29", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"21", "-", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["\[Lambda]", "2"]}], "-", 
               SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", "1"}]]}], "+", 
            RowBox[{"4", " ", 
             SubscriptBox["\[Mu]", "1"], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", "1"}]]}], "+", 
            RowBox[{"8", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "2"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "24"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"13", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"9", "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Lambda]", "2"]}], "-", 
            SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "+", 
         RowBox[{"6", " ", 
          SubscriptBox["\[Mu]", "1"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], "+", 
         RowBox[{"24", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SubscriptBox["\[Mu]", "1"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "+", 
         RowBox[{"3", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "3"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["9", "16"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[Mu]", "1"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", "1"}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["h", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      FractionBox[
       RowBox[{"4", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "3"]}], ",", 
     RowBox[{
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["4", "3"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8595449751821322`*^9, {3.8595453837924395`*^9, 3.8595454071247463`*^9}, 
   3.860603223296263*^9, 3.8613967414497814`*^9, 3.863192534088812*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"00a9548e-18f8-49bb-aed9-7f9436f80027"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", "0"}], ",", " ", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "//.", " ", 
                   RowBox[{
                    SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    SubscriptBox["\[Mu]", "1"], "*", 
                    SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                  RowBox[{
                   SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                   SubscriptBox["c", 
                    SubscriptBox["g", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]]}]}], " ", "//.", " ", 
                 RowBox[{
                  SubscriptBox["partsoln", "2"], "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", "0"}]]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["partsoln", "1"], "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "0"}]]}], "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "2"], " ", "->", " ", 
          RowBox[{"1", "/", "2"}]}]}], " ", "]"}]}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"3", ",", "0"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"3", ",", "0"}]], "\[Rule]", " ", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"3", ",", "0"}]], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], " ", "//.", " ", 
                   RowBox[{
                    SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    SubscriptBox["\[Mu]", "1"], "*", 
                    SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                  RowBox[{
                   SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                   SubscriptBox["c", 
                    SubscriptBox["g", 
                    RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", 
                   RowBox[{"-", "1"}]}]]}], "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", "0"}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"2", ",", "1"}]]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["partsoln", "1"], "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "0"}]]}], "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "2"], " ", "->", " ", 
          RowBox[{"1", "/", "2"}]}]}], "]"}]}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "0"}]], " ", "\[Rule]", " ", "0"}]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["partsoln", 
     RowBox[{"3", ",", "1"}]], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]], "\[Rule]", " ", "0"}], ",", 
      RowBox[{
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]], "\[Rule]", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"3", ",", "1"}]], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "//.", " ", 
                   RowBox[{
                    SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "*", 
                    SubscriptBox["\[Mu]", "1"], "*", 
                    SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
                  RowBox[{
                   SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
                   SubscriptBox["c", 
                    SubscriptBox["g", 
                    RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"2", ",", "0"}]]}], "//.", 
                SubscriptBox["partsoln", 
                 RowBox[{"2", ",", "1"}]]}], " ", "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "2"], "[", 
                RowBox[{"[", 
                 RowBox[{"3", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
              RowBox[{
               SubscriptBox["partsoln", "1"], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
             RowBox[{
              SubscriptBox["partsoln", "1"], "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", " ", 
            SubscriptBox["partsoln", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
           SubscriptBox["partsoln", 
            RowBox[{"1", ",", "0"}]]}], "//.", " ", 
          SubscriptBox["partsoln", 
           RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "2"], " ", "->", " ", 
          RowBox[{"1", "/", "2"}]}]}], "]"}]}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8595450472743115`*^9, 3.859545062636656*^9}, {
  3.859545128966564*^9, 3.859545302276638*^9}, {3.8595453589798326`*^9, 
  3.8595453595577483`*^9}, {3.859545450055332*^9, 3.859545468944493*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"661ffe85-8f2c-488d-8d47-f9e2434df425"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}]}]], "\[Rule]", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Lambda]", "3"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{
      FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "-", 
           RowBox[{"8", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"4", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["r", "1"], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "+", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], ")"}]}], "-", 
        RowBox[{"6", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "1"}]]}], "+", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "-", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", 
               SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"0", ",", 
              RowBox[{"-", "1"}]}]]}], "-", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]], "-", 
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"1", ",", "0"}]]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["\[Beta]", 
             RowBox[{"2", ",", 
              RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.859545475680113*^9, 3.8606032304256463`*^9, 
  3.861396742012101*^9, 3.8631925363297853`*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"b88e5c3e-034b-402a-bcae-0088a734c79b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"3", ",", "0"}]], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Lambda]", "2"]}], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"1", ",", "0"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubscriptBox["r", "1"], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", "0"}]]}], "+", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "0"}]]}], ")"}]}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", "0"}]], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.859545475680113*^9, 3.8606032304256463`*^9, 
  3.861396742012101*^9, 3.8631925363297853`*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"7f1234c5-6f09-4581-a92c-16809cf5b268"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h", 
     RowBox[{"3", ",", "1"}]], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", "1"}]], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "8"]}], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "-", 
       RowBox[{"6", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "+", 
       RowBox[{"8", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["\[Lambda]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "+", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SubscriptBox["r", "1"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "+", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", "1"}]]}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "-", 
             RowBox[{"8", " ", "\[ImaginaryI]", " ", 
              SubscriptBox["\[Lambda]", "2"]}]}], ")"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"0", ",", "1"}]]}], "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", "0"}]]}], "-", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.859545475680113*^9, 3.8606032304256463`*^9, 
  3.861396742012101*^9, 3.8631925363981843`*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"0f2e6b58-fbfa-489c-8c1b-1536a3ca61e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["w", "3"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h", 
          RowBox[{"3", ",", "j"}]], ",", 
         SubscriptBox["\[Phi]", 
          RowBox[{"3", ",", "j"}]]}], "}"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{"\[ImaginaryI]", "*", "j", "*", "x"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
         "]"}]}], "}"}]}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[ImaginaryI]"}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], "*", "x"}], "]"}]}], "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]], "*", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", "*", "x"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "0"}]], "*", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}]}]}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.859545526119769*^9, 3.8595455808416224`*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"822202c9-faa2-4bb0-806f-c15237452716"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["h", 
     RowBox[{"3", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["h", 
      RowBox[{"3", ",", "4"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Beta]", 
     RowBox[{"3", ",", "0"}]], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"3", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "4"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "2"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    SubscriptBox["\[Phi]", 
     RowBox[{"3", ",", "0"}]], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "1"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "2"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", "x"}]], " ", 
     SubscriptBox["\[Phi]", 
      RowBox[{"3", ",", "4"}]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.859545581450796*^9, 3.860603233220776*^9, 
  3.8613967423401227`*^9, 3.8631925384744143`*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"d68d05c4-b237-4b9c-9943-8f3ec4f4c32d"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"V", ".", " ", "Fourth"}], "-", 
   RowBox[{"Order", " ", "Problem"}]}], "Section"]], "Input",
 CellChangeTimes->{
  3.859545000259118*^9, {3.8595456080989494`*^9, 3.859545614724472*^9}, 
   3.863192543358568*^9},ExpressionUUID->"690bdfad-58ec-46b9-9f1c-\
57947c0afd07"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumL", "4"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_", ",", "q3_", ",", "\[Eta]4_", ",", "q4_"}], 
      "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "4"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                     ")"}]}], "+", 
                    RowBox[{
                    FractionBox["1", "6"], " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                    SuperscriptBox["\[Eta]1", "3"]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    "\[Eta]1", " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]3"}]}],
                     ")"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                    SubscriptBox["\[Mu]", "1"]}], "-", 
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[ImaginaryI]", " ", "\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                     ")"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                   "\[Eta]1"}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"1", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
               "-", 
               RowBox[{
                RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"1", " ", 
                    SubscriptBox["r", "3"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]4", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q3", ",", "x"}], "]"}]}], "+", 
                    RowBox[{"\[Kappa]", " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q4", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
               " ", ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox["1", "24"], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"24", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  SubscriptBox["c", "4"]}], "+", 
                 RowBox[{"24", " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                  SubscriptBox["c", "2"], " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{"24", " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["r", "3"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{"48", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                  SubscriptBox["c", "2"], " ", 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{"48", " ", 
                  SuperscriptBox[
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", "1", 
                  " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{"48", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["r", "2"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{"12", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                  SubscriptBox["c", "2"], " ", 
                  SuperscriptBox["\[Eta]1", "2"]}], "+", 
                 RowBox[{"36", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", "1", 
                  " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                  SuperscriptBox["\[Eta]1", "2"]}], "+", 
                 RowBox[{"36", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SuperscriptBox["\[Eta]1", "2"]}], "+", 
                 RowBox[{"16", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  SuperscriptBox["\[Eta]1", "3"]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "5"], " ", "1", " ", 
                  SuperscriptBox["\[Eta]1", "4"]}], "+", 
                 RowBox[{"24", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                  SubscriptBox["c", "2"], " ", "\[Eta]2"}], "+", 
                 RowBox[{"24", " ", 
                  SuperscriptBox[
                   RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", "1", 
                  " ", 
                  SubsuperscriptBox["\[Mu]", "1", "2"], " ", "\[Eta]2"}], "+", 
                 RowBox[{"48", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                 RowBox[{"72", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1", " ", 
                  "\[Eta]2"}], "+", 
                 RowBox[{"12", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "4"], " ", "1", " ", 
                  SuperscriptBox["\[Eta]1", "2"], " ", "\[Eta]2"}], "+", 
                 RowBox[{"12", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", "1", " ", 
                  SuperscriptBox["\[Eta]2", "2"]}], "+", 
                 RowBox[{"48", " ", 
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", "1", " ", 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]3"}], "+", 
                 RowBox[{"24", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", "1", " ",
                   "\[Eta]1", " ", "\[Eta]3"}], "+", 
                 RowBox[{"24", " ", 
                  SuperscriptBox[
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", "1", " ",
                   "\[Eta]4"}]}], ")"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                SubscriptBox["r", "2"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}]}], ")"}]}], 
               "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                     ")"}]}]}], ")"}]}], "+", 
               RowBox[{"\[Kappa]", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "3"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                     ")"}]}], "+", 
                  RowBox[{
                   FractionBox["1", "6"], " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                    SuperscriptBox["\[Eta]1", "3"]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    "\[Eta]1", " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]3"}]}],
                     ")"}]}]}], ")"}]}]}], ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["r", "3"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                  SubscriptBox["r", "2"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{
                  FractionBox["1", "2"], " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]2"}]}],
                    ")"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "6"], " ", 
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                    SuperscriptBox["\[Eta]1", "3"]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    "\[Eta]1", " ", "\[Eta]2"}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]3"}]}],
                    ")"}]}], "+", 
                 RowBox[{
                  FractionBox["1", "24"], " ", "\[Kappa]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"24", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox[
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"24", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SuperscriptBox["\[Eta]1", "2"]}], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    SuperscriptBox["\[Eta]1", "3"]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "4"], " ", 
                    SuperscriptBox["\[Eta]1", "4"]}], "+", 
                    RowBox[{"24", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"48", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1", " ", 
                    "\[Eta]2"}], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                    SuperscriptBox["\[Eta]1", "2"], " ", "\[Eta]2"}], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    SuperscriptBox["\[Eta]2", "2"]}], "+", 
                    RowBox[{"24", " ", 
                    RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]3"}], "+", 
                    RowBox[{"24", " ", 
                    SuperscriptBox[
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                    "\[Eta]1", " ", "\[Eta]3"}], "+", 
                    RowBox[{"24", " ", 
                    RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", "\[Eta]4"}]}],
                    ")"}]}]}], ")"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[ImaginaryI]", " ", "1", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Sign", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"Abs", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", 
                   "\[Eta]1"}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", "1", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "\[ImaginaryI]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["c", "2"], " ", 
                    SubscriptBox["\[Mu]", "1"]}], "+", 
                    RowBox[{"1", " ", 
                    SubscriptBox["r", "2"], 
                    SubscriptBox["\[Mu]", "1"]}]}], ")"}]}], "-", 
                  RowBox[{
                   RowBox[{"Sign", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{
                   RowBox[{"Abs", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                  RowBox[{"\[ImaginaryI]", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
                    RowBox[{
                    SubscriptBox["\[Mu]", "1"], " ", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}]}],
               ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Sign", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                SubscriptBox["c", "2"], " ", 
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                SubscriptBox["r", "3"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                RowBox[{"Sign", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", "1", " ", 
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Abs", "[", 
                  SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", "1", " ", 
                "\[Eta]2"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SubsuperscriptBox["\[Mu]", "2", "2"], "+", 
               RowBox[{"2", " ", 
                SubscriptBox["\[Mu]", "1"], " ", 
                SubscriptBox["r", "2"], 
                SubscriptBox["\[Mu]", "1"]}], "+", 
               RowBox[{
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                SubsuperscriptBox["\[Mu]", "1", "2"], " ", "\[Eta]1"}]}], 
              ")"}], "*", 
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[ImaginaryI]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SubscriptBox["r", "3"], 
                  SubscriptBox["\[Mu]", "1"]}], "+", 
                 RowBox[{
                  RowBox[{"Abs", "[", 
                   SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                  SubscriptBox["r", "1"], 
                  SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                 RowBox[{
                  SubscriptBox["\[Mu]", "1"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Sign", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", 
                    SubscriptBox["r", "1"], 
                    SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    SubscriptBox["\[Mu]", "1"], "]"}], " ", "\[Eta]2"}]}], 
                   ")"}]}]}], ")"}]}], ")"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}], "}"}], 
          ",", "kmod"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"1", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "6"}], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]4", ",", "x"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"2", " ", "1", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 SuperscriptBox[
                  RowBox[{"D", "[", 
                   RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"q1", ",", "x"}], "]"}], "2"], "-", 
                RowBox[{"2", " ", "1", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"q1", ",", "x"}], "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                   RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "-", 
                RowBox[{"2", " ", "1", " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "-", 
                  RowBox[{"2", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"]}], "+", 
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]3", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", "1", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}]}], "+", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"D", "[", 
                    RowBox[{"q1", ",", "x"}], "]"}], "2"], "-", 
                  RowBox[{"2", " ", "1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    SubscriptBox["c", "2"]}], "+", 
                    RowBox[{"D", "[", 
                    RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "3"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   SubscriptBox["r", "1"], 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}], "-", 
                  RowBox[{"2", " ", 
                   SubscriptBox["\[Mu]", "1"], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
                   RowBox[{"D", "[", 
                    RowBox[{"\[Eta]2", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SubscriptBox["r", "2"], 
                   SubscriptBox["\[Mu]", "1"]}], "-", 
                  RowBox[{
                   SubscriptBox["\[Mu]", "1"], " ", 
                   SuperscriptBox[
                    RowBox[{"D", "[", 
                    RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"]}]}], ")"}], 
                " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
               RowBox[{
                SubscriptBox["r", "1"], 
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SubscriptBox["c", "2"]}], "+", 
                  RowBox[{"D", "[", 
                   RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "+", 
               RowBox[{
                SubscriptBox["\[Mu]", "1"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], "*", 
           RowBox[{"w", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["c", "4"], "+", 
             RowBox[{"1", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}], "4"], "-", 
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]2", ",", "x"}], "]"}], "2"], "-", 
                RowBox[{"2", " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]3", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{"q1", ",", "x"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SubscriptBox["c", "2"]}], "+", 
                RowBox[{"D", "[", 
                 RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"D", "[", 
              RowBox[{"q4", ",", "x"}], "]"}]}], ")"}], "*", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "x"}], "]"}]}]}]}], 
        "}"}]}], ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["ZeroNumR", "4"], "[", 
      RowBox[{
      "w_", ",", "k_", ",", "\[Eta]1_", ",", "q1_", ",", "\[Eta]2_", ",", 
       "q2_", ",", "\[Eta]3_", ",", "q3_", ",", "\[Eta]4_"}], "]"}], " ", ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clear", "[", 
        RowBox[{"integrand", ",", "zerointegrand"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"kmod", " ", "=", " ", 
        RowBox[{"GenModulate", "[", 
         RowBox[{"k", ",", "4"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"integrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              FractionBox["1", "24"], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"24", " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["r", "3"], 
                 SubscriptBox["\[Mu]", "1"]}], "+", 
                RowBox[{"48", " ", 
                 SuperscriptBox[
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                RowBox[{"48", " ", 
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["r", "2"], 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
                RowBox[{"36", " ", 
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", 
                 SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
                 SuperscriptBox["\[Eta]1", "2"]}], "+", 
                RowBox[{"36", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 SuperscriptBox["\[Eta]1", "2"]}], "+", 
                RowBox[{"16", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["\[Mu]", "1"], " ", 
                 SuperscriptBox["\[Eta]1", "3"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "5"], " ", 
                 SuperscriptBox["\[Eta]1", "4"]}], "+", 
                RowBox[{"24", " ", 
                 SuperscriptBox[
                  RowBox[{"Sign", "[", "\[Kappa]", "]"}], "2"], " ", 
                 SubsuperscriptBox["\[Mu]", "1", "2"], " ", "\[Eta]2"}], "+", 
                RowBox[{"48", " ", 
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["r", "1"], 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]2"}], "+", 
                RowBox[{"72", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1", " ", "\[Eta]2"}],
                 "+", 
                RowBox[{"12", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "4"], " ", 
                 SuperscriptBox["\[Eta]1", "2"], " ", "\[Eta]2"}], "+", 
                RowBox[{"12", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", 
                 SuperscriptBox["\[Eta]2", "2"]}], "+", 
                RowBox[{"48", " ", 
                 RowBox[{"Abs", "[", "\[Kappa]", "]"}], " ", 
                 RowBox[{"Sign", "[", "\[Kappa]", "]"}], " ", 
                 SubscriptBox["\[Mu]", "1"], " ", "\[Eta]3"}], "+", 
                RowBox[{"24", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "3"], " ", "\[Eta]1",
                  " ", "\[Eta]3"}], "+", 
                RowBox[{"24", " ", 
                 SuperscriptBox[
                  RowBox[{"Abs", "[", "\[Kappa]", "]"}], "2"], " ", 
                 "\[Eta]4"}]}], ")"}]}], ")"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"zerointegrand", " ", "=", " ", 
        RowBox[{"NCoefficient", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"Sign", "[", 
                SubscriptBox["\[Mu]", "1"], "]"}], " ", 
               SubscriptBox["r", "3"], 
               SubscriptBox["\[Mu]", "1"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"Abs", "[", 
                SubscriptBox["\[Mu]", "1"], "]"}], " ", 
               RowBox[{"Sign", "[", 
                SubscriptBox["\[Mu]", "1"], "]"}], " ", 
               SubscriptBox["r", "1"], 
               SubscriptBox["\[Mu]", "1"], " ", "\[Eta]1"}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"Abs", "[", 
                 SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", "\[Eta]2"}]}], 
             ")"}], "*", 
            RowBox[{"w", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "kmod"}], "]"}]}], 
       ";", " ", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "\[LessEqual]", " ", 
          RowBox[{"Length", "[", "kmod", "]"}]}], ",", 
         RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kmod", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "==", "0"}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], " ", "=", " ", 
             RowBox[{"zerointegrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", 
             RowBox[{"integrand", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"\[ImaginaryI]", "*", 
                RowBox[{"kmod", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "*", "x"}], "]"}], "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"integrand", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], " ", "//.", " ", 
                RowBox[{"\[Kappa]", " ", "\[Rule]", " ", 
                 RowBox[{"kmod", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", 
               RowBox[{"Length", "[", "kmod", "]"}]}], "}"}]}], "]"}], "]"}], 
          "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "1"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"D", "[", 
                  RowBox[{"\[Eta]1", ",", "x"}], "]"}], "2"], " ", 
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]2", ",", "x"}], "]"}]}], "-", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]4", ",", "x"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"D", "[", 
                 RowBox[{"\[Eta]1", ",", "x"}], "]"}], "3"], "-", 
               RowBox[{"D", "[", 
                RowBox[{"\[Eta]3", ",", "x"}], "]"}]}], ")"}], " ", 
             RowBox[{"D", "[", 
              RowBox[{"q1", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]2", ",", "x"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SubscriptBox["c", "2"]}], "+", 
               RowBox[{"D", "[", 
                RowBox[{"q2", ",", "x"}], "]"}]}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{"\[Eta]1", ",", "x"}], "]"}], " ", 
             RowBox[{"D", "[", 
              RowBox[{"q3", ",", "x"}], "]"}]}]}], ")"}], "*", 
          RowBox[{"w", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}]}], ")"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQreWdfH3ngTeOghEsd0B0SeqvpyDa6WXNMxDd/q3q
HYg+1375PYi+vsXzB4jO2/cVTJtsOsu4C0hL7WpkAtGn1yRzgujtWyW4QLS0
bp0YiBa10xQH0We2uCiB6C3mGcogus14uQ6IttvrYQiiJV+/twXR86rT7EH0
lINqoSDaItAhGkQ/MZ5cAFbvElcEojdollSD6H/7XoPpRM+VLWDz3Xe2gugH
O5Umg+iPjrxTQPTvyc5zQfS16ZrzQLTngzubQXRNpNEWEG0vfXkHiGZaZrUT
RGtMDmDVOwh0D38VmNbranQD0RUdU8D0CY97F+uBtC8f13UQDQB1ib50
  "],
 CellLabel->
  "In[117]:=",ExpressionUUID->"392594e5-79bc-4ad2-9230-03711749f0f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["IHT", "4"], "=", 
   RowBox[{"NCoefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       RowBox[{
        SubscriptBox["ZeroNumL", "1"], "[", 
        RowBox[{
         SubscriptBox["w", "3"], ",", 
         RowBox[{"GenModulate", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
          "]"}], ",", 
         RowBox[{"Cos", "[", "x", "]"}], ",", 
         RowBox[{"Sin", "[", "x", "]"}]}], "]"}]}], " ", "-", " ", 
      RowBox[{
       SubscriptBox["ZeroNumL", "2"], "[", 
       RowBox[{
        SubscriptBox["w", "2"], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
         "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"0", "*", "x"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", "*", "x"}], "]"}]}]}]}], "]"}], "-", 
      RowBox[{
       SubscriptBox["ZeroNumL", "3"], "[", 
       RowBox[{
        SubscriptBox["w", "1"], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"3", "/", "8"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"3", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "4"}], "*", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{
          RowBox[{"3", "/", "8"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"3", "*", "x"}], "]"}]}]}]}], "]"}], "-", 
      RowBox[{
       SubscriptBox["ZeroNumL", "4"], "[", 
       RowBox[{
        SubscriptBox["w", "0"], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"3", "/", "8"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"3", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "4"}], "*", 
          RowBox[{"Sin", "[", "x", "]"}]}], "+", 
         RowBox[{
          RowBox[{"3", "/", "8"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"3", "*", "x"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"17", "/", "24"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", "*", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"1", "/", "3"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", "*", "x"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"7", "/", "24"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", "*", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"1", "/", "3"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"4", "*", "x"}], "]"}]}]}]}], "]"}], "+", 
      RowBox[{
       SubscriptBox["ZeroNumR", "3"], "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Lambda]", "1"], "*", 
         SubscriptBox["w", "0"]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"3", "/", "8"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"3", "*", "x"}], "]"}]}]}], "]"}], "+", 
      "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["ZeroNumR", "2"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          SubscriptBox["w", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["w", "0"]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "1"}], 
         "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}], ",", 
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", "*", "x"}], "]"}]}]}], "]"}], " ", "+", 
      RowBox[{
       SubscriptBox["ZeroNumR", "1"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          SubscriptBox["w", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["w", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "*", 
          SubscriptBox["w", "0"]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "2"}], 
         "]"}], ",", 
        RowBox[{"Cos", "[", "x", "]"}]}], "]"}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["ZeroNumR", "0"], "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[Lambda]", "1"], "*", 
          SubscriptBox["w", "3"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "2"], "*", 
          SubscriptBox["w", "2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "3"], "*", 
          SubscriptBox["w", "1"]}], "+", 
         RowBox[{
          SubscriptBox["\[Lambda]", "4"], "*", 
          SubscriptBox["w", "0"]}]}], ",", 
        RowBox[{"GenModulate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "3"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"GenModulate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", "4"}], "]"}]}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.859545779438094*^9, {3.8595458147861834`*^9, 3.8595458583359823`*^9}, {
   3.8595472113076506`*^9, 3.859547328361218*^9}, {3.859547368655441*^9, 
   3.85954757861992*^9}, {3.859547683671612*^9, 3.8595477128613863`*^9}, 
   3.8631925516857357`*^9},
 CellLabel->
  "In[119]:=",ExpressionUUID->"05e682da-8d66-4573-90de-622bb0b92138"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["200", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["525", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"50", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      FractionBox[
       RowBox[{"200", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "3"], "-", 
      FractionBox[
       RowBox[{"525", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], "8"], "-", 
      RowBox[{"50", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"12", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"28", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["49", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"20", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["49", "3"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"28", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"49", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "3"], "+", 
      RowBox[{"20", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["9", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["27", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["237", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["135", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["39", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1029", "64"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"135", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "8"], "+", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"81", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], "4"], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       RowBox[{"45", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "-", 
      RowBox[{"18", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"9", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["25", "12"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["13", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["25", "12"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["5", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["7", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["25", "6"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], "12"], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["7", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["43", "48"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["7", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "8"], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], "3"], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "3"}]}]]}], "8"], "+", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], "8"], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       RowBox[{"Sign", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sign", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sign", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        RowBox[{"Abs", "[", 
         SubscriptBox["\[Mu]", "1"], "]"}], "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Sign", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Abs", "[", 
        SubscriptBox["\[Mu]", "1"], "]"}], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["43", "48"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["7", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["7", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "3"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], "8"], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]], "4"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"9", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], "8"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      SubscriptBox["\[Phi]", 
       RowBox[{"3", ",", "2"}]]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["25", "12"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["25", "12"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["5", "3"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["13", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["25", "6"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["7", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"25", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "12"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["5", "2"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["r", "1"], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["9", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["27", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["45", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["9", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["27", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "2"}]]}], "+", 
      RowBox[{"3", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"6", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "+", 
      RowBox[{
       FractionBox["1029", "64"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["237", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["135", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["39", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["45", "8"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"135", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], "8"], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"45", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], "8"], "-", 
      RowBox[{
       FractionBox["21", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      FractionBox[
       RowBox[{"81", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], "4"], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"9", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"6", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"18", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["49", "3"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{"12", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"28", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"20", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"24", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{"4", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "+", 
      RowBox[{
       FractionBox["49", "3"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"49", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "1"}]]}], "3"], "-", 
      RowBox[{"28", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"20", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"24", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"8", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["200", "3"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["525", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"50", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      FractionBox[
       RowBox[{"200", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"1", ",", "2"}]]}], "3"], "-", 
      FractionBox[
       RowBox[{"525", " ", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "3"}]]}], "8"], "-", 
      RowBox[{"50", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "8"]}], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "12"], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "16"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}]]}], "2"], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "8"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["5", "4"]}], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "+", 
      FractionBox[
       RowBox[{"15", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "16"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "4"], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "4"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "4"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["5", "8"]}], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]], "16"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", 
          RowBox[{"-", "3"}]}]]}], "2"], "+", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "2"], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "4"], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      SubscriptBox["\[Beta]", 
       RowBox[{"3", ",", 
        RowBox[{"-", "1"}]}]], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"5", " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "2"}]}]]}], "4"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]], "8"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      SubscriptBox["h", 
       RowBox[{"3", ",", 
        RowBox[{"-", "2"}]}]], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "8"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"37", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "48"], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "4"], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "3"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      FractionBox[
       RowBox[{"5", " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      FractionBox[
       RowBox[{"5", " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], "8"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]], "2"], "-", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]], "2"], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["7", "8"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["7", "8"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       RowBox[{"7", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "8"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"7", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "8"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}]}], ",", 
     RowBox[{
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]], "8"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      FractionBox[
       RowBox[{"5", " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], "4"], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "0"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      SubscriptBox["h", 
       RowBox[{"3", ",", "2"}]], "+", 
      FractionBox[
       RowBox[{"37", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "48"], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "8"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "4"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "3"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "2"], "-", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "2"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}]}], ",", 
     RowBox[{
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "16"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"5", " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]]}], "8"], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      FractionBox[
       SubscriptBox["h", 
        RowBox[{"3", ",", "1"}]], "2"], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "3"}]]}], "2"], "+", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "-", 
      RowBox[{
       FractionBox["3", "8"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "0"}]]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", "1"}]]}], "8"], "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      SubscriptBox["\[Beta]", 
       RowBox[{"3", ",", "1"}]], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "0"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "3"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "1"}]]}], "-", 
      FractionBox[
       RowBox[{"5", " ", 
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]]}], "4"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      SubscriptBox["h", 
       RowBox[{"3", ",", "2"}]], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]], "4"], "+", 
      FractionBox[
       RowBox[{"15", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", "1"}]]}], "16"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]], "4"], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"3", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["c", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["r", "1"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "2"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SubscriptBox["h", 
         RowBox[{"1", ",", "1"}]], "16"]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["h", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SubscriptBox["h", 
         RowBox[{"3", ",", "3"}]]}], "2"], "+", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", "1"}]], "8"], "+", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "1"}]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{
       FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "3"}]]}], "+", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}], "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SubscriptBox["h", 
         RowBox[{"1", ",", "2"}]], "8"]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["h", 
        RowBox[{"3", ",", "4"}]]}], "+", 
      FractionBox[
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", "1"}]], "12"], "+", 
      RowBox[{
       FractionBox["3", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"1", ",", "2"}]]}], "+", 
      RowBox[{
       FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"2", ",", "3"}]]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["\[Phi]", 
        RowBox[{"3", ",", "4"}]]}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8631925531327343`*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"da39ee9d-7e10-42f2-bf6f-9b8d17cec8f3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"4", ",", 
       RowBox[{"-", "1"}]}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "4"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "5"}], "]"}], "]"}]}], " ", ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"4", ",", "0"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "4"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "6"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["IHT", 
      RowBox[{"4", ",", "1"}]], " ", "=", " ", 
     RowBox[{
      SubscriptBox["IHT", "4"], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "7"}], "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.859547714696945*^9, {3.8595477520083447`*^9, 3.8595477706511602`*^9}, {
   3.8595478030230293`*^9, 3.859547808418269*^9}, {3.8631925605703945`*^9, 
   3.863192563501968*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"3cbdfd65-8a6a-470e-9cf8-a41f6397e55a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", 
     RowBox[{"-", "1"}]}]], "=", 
   RowBox[{"Refine", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "1"}]}]], ",", 
                    RowBox[{"Conjugate", "[", 
                    SubscriptBox["FA", 
                    RowBox[{"-", "1"}]], "]"}]}], "]"}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["partsoln", "3"], "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "0"}]]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "0"}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "1"}]]}], "//.", " ", 
                   RowBox[{
                    SubscriptBox["partsoln", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                  " ", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], " ", "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"1", ",", "0"}]]}], " ", "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"1", ",", "1"}]]}], "//.", " ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", 
              SubscriptBox["lambdaBeta", "3"]}], "//.", " ", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "0"}]], "->", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], ")"}]}], "/", 
               "\[ImaginaryI]"}]}]}], "//.", 
            RowBox[{
             SubscriptBox["lambdaBeta", "2"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "//.", 
           RowBox[{
            SubscriptBox["r", "1"], "->", 
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//.", 
          RowBox[{
           SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], "*", 
            SubscriptBox["\[Mu]", "1"], "*", 
            SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
          SubscriptBox["c", 
           SubscriptBox["g", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]]}]}], " ", "//.", " ", 
        RowBox[{
         SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
         RowBox[{"1", "/", "2"}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "4"], "->", 
        RowBox[{"1", "/", "2"}]}]}], "]"}], ",", 
     RowBox[{"Assumptions", " ", "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", "0"}]], "=", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"4", ",", "0"}]], ",", 
                    RowBox[{"Conjugate", "[", 
                    SubscriptBox["FA", "0"], "]"}]}], "]"}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "0"}]]}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "1"}]]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "0"}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "1"}]]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                   " ", 
                   RowBox[{
                    SubscriptBox["partsoln", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                  " ", 
                  SubscriptBox["partsoln", 
                   RowBox[{"1", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", "  ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"1", ",", "0"}]]}], " ", "//.", 
                SubscriptBox["partsoln", 
                 RowBox[{"1", ",", "1"}]]}], "//.", "  ", 
               RowBox[{
                SubscriptBox["partsoln", "1"], "[", 
                RowBox[{"[", 
                 RowBox[{"2", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
              SubscriptBox["lambdaBeta", "3"]}], "//.", " ", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "0"}]], "->", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], ")"}]}], "/", 
               "\[ImaginaryI]"}]}]}], "//.", 
            RowBox[{
             SubscriptBox["lambdaBeta", "2"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], " ", "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", 
              RowBox[{"-", "1"}]}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", "2"}]}]}], "//.", 
        RowBox[{
         SubscriptBox["r", "1"], "->", 
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "//.", 
       RowBox[{
        SubscriptBox["c", "4"], "->", 
        RowBox[{"1", "/", "2"}]}]}], "]"}], ",", 
     RowBox[{"Assumptions", "->", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["cond", 
    RowBox[{"4", ",", "1"}]], "=", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    SubscriptBox["IHT", 
                    RowBox[{"4", ",", "1"}]], ",", 
                    RowBox[{"Conjugate", "[", 
                    SubscriptBox["FA", "1"], "]"}]}], "]"}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "0"}]]}], "//.", " ", 
                    SubscriptBox["partsoln", 
                    RowBox[{"3", ",", "1"}]]}], "//.", " ", 
                    RowBox[{
                    SubscriptBox["partsoln", "3"], "[", 
                    RowBox[{"[", 
                    RowBox[{"4", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "0"}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", 
                    RowBox[{"-", "1"}]}]]}], "//.", 
                    SubscriptBox["partsoln", 
                    RowBox[{"2", ",", "1"}]]}], "//.", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
                    " ", 
                    RowBox[{
                    SubscriptBox["partsoln", "2"], "[", 
                    RowBox[{"[", 
                    RowBox[{"4", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
                   RowBox[{
                    SubscriptBox["partsoln", "1"], "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "All"}], "]"}], "]"}]}], "//.", 
                  RowBox[{
                   SubscriptBox["partsoln", "1"], "[", 
                   RowBox[{"[", 
                    RowBox[{"2", ",", "All"}], "]"}], "]"}]}], "//.", " ", 
                 SubscriptBox["partsoln", 
                  RowBox[{"1", ",", "1"}]]}], " ", "//.", " ", 
                SubscriptBox["partsoln", 
                 RowBox[{"1", ",", "0"}]]}], "//.", 
               SubscriptBox["partsoln", 
                RowBox[{"1", ",", 
                 RowBox[{"-", "1"}]}]]}], "//.", 
              SubscriptBox["lambdaBeta", "3"]}], "//.", " ", 
             RowBox[{
              SubscriptBox["\[Beta]", 
               RowBox[{"1", ",", "0"}]], "->", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}]], "+", 
                  SubscriptBox["\[Beta]", 
                   RowBox[{"0", ",", "1"}]]}], ")"}]}], "/", 
               "\[ImaginaryI]"}]}]}], "//.", 
            RowBox[{
             SubscriptBox["lambdaBeta", "2"], "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "All"}], "]"}], "]"}]}], " ", "//.", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], " ", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], "*", 
             SubscriptBox["\[Mu]", "1"], "*", 
             SubscriptBox["c", "g"]}]}]}], " ", "//.", " ", 
          RowBox[{
           SubscriptBox["c", "g"], "\[Rule]", " ", 
           SubscriptBox["c", 
            SubscriptBox["g", 
             RowBox[{"1", ",", "1"}]]]}]}], " ", "//.", " ", 
         RowBox[{
          SubscriptBox["c", "2"], " ", "\[Rule]", " ", 
          RowBox[{"1", "/", "2"}]}]}], "//.", 
        RowBox[{
         SubscriptBox["r", "1"], "->", 
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], " ", "//.", " ", 
       RowBox[{
        SubscriptBox["c", "4"], "->", 
        RowBox[{"1", "/", "2"}]}]}], "]"}], ",", 
     RowBox[{"Assumptions", " ", "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], ">", "0"}]}]}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8595478248809834`*^9, 3.859547855214222*^9}, {
   3.8595479031598673`*^9, 3.8595479303341055`*^9}, {3.8595479619506464`*^9, 
   3.8595480334370537`*^9}, {3.8595481165937195`*^9, 
   3.8595481297856617`*^9}, {3.859548162804555*^9, 3.8595481827072024`*^9}, {
   3.8595482309547515`*^9, 3.859548386382217*^9}, {3.859548934072167*^9, 
   3.8595489966728015`*^9}, {3.8595490404125757`*^9, 
   3.8595490976996365`*^9}, {3.8595492715226135`*^9, 
   3.8595493075374327`*^9}, {3.859549359005969*^9, 3.859549395107978*^9}, {
   3.8595495996144943`*^9, 3.8595495998855505`*^9}, 3.8595496385154543`*^9, {
   3.859549725563383*^9, 3.8595497860496445`*^9}, {3.8595499019049416`*^9, 
   3.859549970363426*^9}, {3.8595504176674767`*^9, 3.859550422300025*^9}, {
   3.859550959358374*^9, 3.8595509963212147`*^9}, {3.8595511317670083`*^9, 
   3.859551151497532*^9}, {3.8595512035420246`*^9, 3.8595512141792717`*^9}, {
   3.8595513360106435`*^9, 3.8595513555105677`*^9}, {3.8595515276709337`*^9, 
   3.8595515278698277`*^9}, {3.859551591259378*^9, 3.859551591573204*^9}, {
   3.8595528502033334`*^9, 3.8595528876870947`*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"13824fb1-155c-4e4a-9579-db0b591ab0d8"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"64", " ", "\[CapitalDelta]"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"128", " ", "\[CapitalDelta]", " ", 
     SubscriptBox["\[Lambda]", "4"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"16", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"11", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"8", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "64"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"3", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"64", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"100", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"24", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
           SubscriptBox["r", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"1", ",", 
             RowBox[{"-", "1"}]}]]}], "-", 
          SubscriptBox["\[Beta]", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", "\[CapitalDelta]", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[CapitalDelta]", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"2", ",", 
             RowBox[{"-", "1"}]}]]}], "+", 
          RowBox[{"4", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8595517285595016`*^9, {3.8595528768793125`*^9, 3.8595528919924307`*^9}, 
   3.8606251391116085`*^9, 3.8613967458108206`*^9, 3.863192570738513*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"f6525514-f534-4501-aabf-1b92b7b26320"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"16", " ", "\[CapitalDelta]"}]], 
   RowBox[{
    SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", " ", 
       RowBox[{"(", 
        RowBox[{"\[CapitalDelta]", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[Mu]", "1"]}]}], ")"}], " ", 
       SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
       SubscriptBox["\[Beta]", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}]]}], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Mu]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", 
                SqrtBox["2"]}], "+", 
               RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}], 
               "+", 
               RowBox[{
                SqrtBox["2"], " ", 
                SuperscriptBox["\[CapitalDelta]", "2"]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", "\[ImaginaryI]", " ", 
                SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
               RowBox[{"3", " ", 
                SuperscriptBox["\[CapitalDelta]", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Mu]", "1"]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               SqrtBox["2"], "+", 
               RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], 
             " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
            SubsuperscriptBox["\[Mu]", "1", "3"]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"8", "+", 
            SuperscriptBox["\[CapitalDelta]", "2"], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
             SubscriptBox["\[Mu]", "1"]}], "-", 
            SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"1", ",", 
            RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", "\[CapitalDelta]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SqrtBox["2"]}], " ", "\[CapitalDelta]", " ", 
          SubscriptBox["\[Mu]", "1"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", 
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"4", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"2", ",", "0"}]]}]}], ")"}]}]}], ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.8595517285595016`*^9, {3.8595528768793125`*^9, 3.8595528919924307`*^9}, 
   3.8606251391116085`*^9, 3.8613967458108206`*^9, 3.863192571016553*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"8983b28f-8320-4b75-91b3-f4bb1f5c8b3c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"256", " ", 
    SuperscriptBox["\[CapitalDelta]", "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "8"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"128", " ", 
     SuperscriptBox["\[CapitalDelta]", "2"], " ", 
     SubscriptBox["\[Lambda]", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
        SubscriptBox["\[Mu]", "1"]}], "+", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "32"}], " ", "\[ImaginaryI]"}], "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "-", 
          RowBox[{"3", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", "\[CapitalDelta]", "-", 
          SuperscriptBox["\[CapitalDelta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[ImaginaryI]"}], "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1024", " ", "\[ImaginaryI]"}], "-", 
          RowBox[{"256", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"104", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          RowBox[{"24", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}], "+", 
          RowBox[{"5", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "4"]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"], " ", 
           SubscriptBox["r", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"20", " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"\[CapitalDelta]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"96", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "-", 
          RowBox[{"8", " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          SuperscriptBox["\[CapitalDelta]", "3"], "-", 
          RowBox[{"32", " ", "\[CapitalDelta]", " ", 
           SubscriptBox["r", "2"]}], "-", 
          RowBox[{"64", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"256", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["\[CapitalDelta]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"512", " ", "\[ImaginaryI]"}], "-", 
          RowBox[{"64", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"20", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          RowBox[{"16", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "4"]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"], " ", 
           SubscriptBox["r", "2"]}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"], " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "32"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"8", " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[CapitalDelta]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"64", " ", "\[CapitalDelta]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", "\[CapitalDelta]", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"2", ",", "0"}]]}], "+", 
          RowBox[{"\[CapitalDelta]", " ", 
           SubscriptBox["\[Beta]", 
            RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.8595517285595016`*^9, {3.8595528768793125`*^9, 3.8595528919924307`*^9}, 
   3.8606251391116085`*^9, 3.8613967458108206`*^9, 3.863192571865057*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"6a031d7f-4f2b-4724-9883-d6a482a280a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"4", ",", 
      RowBox[{"-", "1"}], ",", "v2"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", 
        RowBox[{"-", "1"}]}]], "//.", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "0"}]], "==", "0"}], ",", 
           RowBox[{"{", 
            SubscriptBox["\[Beta]", 
             RowBox[{"2", ",", "0"}]], "}"}]}], "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["cond", 
     RowBox[{"4", ",", "1", ",", "v2"}]], "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      SubscriptBox["cond", 
       RowBox[{"4", ",", "1"}]], "//.", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "0"}]], "==", "0"}], ",", 
           RowBox[{"{", 
            SubscriptBox["\[Beta]", 
             RowBox[{"2", ",", "0"}]], "}"}]}], "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8595519806288595`*^9, 3.8595520449782715`*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"93353b23-f80a-484a-9d06-76a2d8c11b41"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"64", " ", "\[CapitalDelta]"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"128", " ", "\[CapitalDelta]", " ", 
     SubscriptBox["\[Lambda]", "4"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "-", 
    RowBox[{"12", " ", 
     SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"48", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"39", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"16", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "96"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"23", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"192", " ", 
             SqrtBox["2"]}], "+", 
            RowBox[{"164", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}], 
            "+", 
            RowBox[{"24", " ", 
             SqrtBox["2"], " ", 
             SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["\[CapitalDelta]", "3"]}], "-", 
            RowBox[{"32", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
             SubscriptBox["r", "2"]}]}], ")"}], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{"8", "-", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "+", 
          SuperscriptBox["\[CapitalDelta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"16", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", "\[CapitalDelta]", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        SuperscriptBox["\[CapitalDelta]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
    RowBox[{"64", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.85955201421128*^9, 3.8595520457634635`*^9}, 
   3.859552901565989*^9, 3.8606251634022713`*^9, 3.861396750495618*^9, 
   3.86319258897758*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"075a592c-bb3a-44c4-9851-9490228d72a3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"256", " ", 
    SuperscriptBox["\[CapitalDelta]", "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "8"], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"128", " ", 
     SuperscriptBox["\[CapitalDelta]", "2"], " ", 
     SubscriptBox["\[Lambda]", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
        SubscriptBox["\[Mu]", "1"]}], "+", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}], " ", 
     SubscriptBox["\[Beta]", 
      RowBox[{"0", ",", 
       RowBox[{"-", "1"}]}]]}], "+", 
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "-", 
       SubscriptBox["\[Beta]", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}]]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "32"}], " ", "\[ImaginaryI]"}], "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "-", 
          RowBox[{"3", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"3", " ", "\[CapitalDelta]"}], "-", 
          SuperscriptBox["\[CapitalDelta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[ImaginaryI]"}], "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"\[CapitalDelta]", " ", 
     SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"224", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "-", 
          RowBox[{"88", " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"8", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          SuperscriptBox["\[CapitalDelta]", "3"], "-", 
          RowBox[{"32", " ", "\[CapitalDelta]", " ", 
           SubscriptBox["r", "2"]}], "-", 
          RowBox[{"64", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "8"}], "+", 
          SuperscriptBox["\[CapitalDelta]", "2"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1024", " ", "\[ImaginaryI]"}], "-", 
          RowBox[{"384", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"216", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          RowBox[{"24", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}], "+", 
          RowBox[{"5", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "4"]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"], " ", 
           SubscriptBox["r", "2"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "48"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"28", " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
    RowBox[{"256", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["\[CapitalDelta]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}]], "+", 
       SubscriptBox["\[Beta]", 
        RowBox[{"2", ",", "1"}]]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"512", " ", "\[ImaginaryI]"}], "-", 
          RowBox[{"192", " ", 
           SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
          RowBox[{"44", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "+", 
          RowBox[{"16", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "3"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "4"]}], "-", 
          RowBox[{"32", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["\[CapitalDelta]", "2"], " ", 
           SubscriptBox["r", "2"]}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[CapitalDelta]", "3"], " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "32"}], " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"24", " ", "\[CapitalDelta]"}], "+", 
          RowBox[{"4", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["\[CapitalDelta]", "2"]}], "-", 
          SuperscriptBox["\[CapitalDelta]", "3"]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{"16", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[CapitalDelta]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}]}], ")"}]}], "+", 
    RowBox[{"64", " ", "\[CapitalDelta]", " ", 
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "\[CapitalDelta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[ImaginaryI]", " ", 
           SqrtBox["2"]}], "+", "\[CapitalDelta]", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           SubscriptBox["r", "3"]}]}], ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
         ")"}], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}]]}], "+", 
       RowBox[{
        SuperscriptBox["\[CapitalDelta]", "2"], " ", 
        SubscriptBox["\[Beta]", 
         RowBox[{"2", ",", "1"}]]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.85955201421128*^9, 3.8595520457634635`*^9}, 
   3.859552901565989*^9, 3.8606251634022713`*^9, 3.861396750495618*^9, 
   3.8631925896989985`*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"049d4ddc-a596-445b-ad23-b266a7912d83"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["lambdaBeta", "4"], "=", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", 
              RowBox[{"-", "1"}], ",", "v2"}]], "==", "0"}], " ", "&&", " ", 
           RowBox[{
            SubscriptBox["cond", 
             RowBox[{"4", ",", "1", ",", "v2"}]], "==", "0"}]}], ",", 
          RowBox[{"{", 
           RowBox[{
            SubscriptBox["\[Lambda]", "4"], ",", 
            SubscriptBox["\[Beta]", 
             RowBox[{"2", ",", "1"}]]}], "}"}]}], "]"}], "//.", 
        RowBox[{"\[CapitalDelta]", "->", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"8", "-", 
           SuperscriptBox[
            SubscriptBox["\[Mu]", "1"], "2"]}], "]"}]}]}], "]"}], "//.", 
      RowBox[{
       RowBox[{"8", "-", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}], "->", 
       SuperscriptBox["\[CapitalDelta]", "2"]}]}], ",", 
     RowBox[{"\[CapitalDelta]", ">", "0"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.859552054759406*^9, 3.8595521489511604`*^9}, {
  3.8595522904967537`*^9, 3.8595523816966286`*^9}, {3.859647369580168*^9, 
  3.859647373110132*^9}, {3.860625172676508*^9, 3.8606251780222273`*^9}, {
  3.8614015907003574`*^9, 3.8614015934564953`*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"0037f6e5-870d-4aae-b1d5-08b8fd094cfb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Lambda]", "4"], "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"128", " ", 
        SuperscriptBox["\[CapitalDelta]", "3"]}]], 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"128", " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"17", " ", "\[ImaginaryI]"}], "+", 
            RowBox[{"8", " ", 
             SqrtBox["2"], " ", "\[CapitalDelta]"}], "+", 
            RowBox[{"4", " ", "\[CapitalDelta]", " ", 
             SubscriptBox["r", "3"]}]}], ")"}]}], "+", 
         RowBox[{"512", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["2"]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
          SubscriptBox["\[Mu]", "1"]}], "+", 
         RowBox[{"16", " ", 
          RowBox[{"(", 
           RowBox[{"27", "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]", " ", 
             SubscriptBox["r", "3"]}]}], ")"}], " ", 
          SubsuperscriptBox["\[Mu]", "1", "2"]}], "-", 
         RowBox[{"64", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "+", 
            RowBox[{"\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
          SubsuperscriptBox["\[Mu]", "1", "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "92"}], "-", 
            RowBox[{"24", " ", "\[ImaginaryI]", " ", 
             SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
          SubsuperscriptBox["\[Mu]", "1", "4"]}], "+", 
         RowBox[{"5", " ", 
          SubsuperscriptBox["\[Mu]", "1", "6"]}], "+", 
         RowBox[{"32", " ", 
          SubscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"32", "-", 
            RowBox[{"12", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
            SubsuperscriptBox["\[Mu]", "1", "4"]}], ")"}]}]}], ")"}]}]}]}], 
    ",", 
    RowBox[{
     SubscriptBox["\[Beta]", 
      RowBox[{"2", ",", "1"}]], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"16", " ", 
         SuperscriptBox["\[CapitalDelta]", "3"]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", " ", "\[ImaginaryI]", " ", 
          SubsuperscriptBox["\[Mu]", "1", "7"], " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["\[Mu]", "1", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "9"}], " ", "\[ImaginaryI]", " ", 
                SqrtBox["2"]}], "+", 
               RowBox[{"5", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"3", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"151", " ", "\[ImaginaryI]"}], "+", 
               RowBox[{"38", " ", 
                SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
               RowBox[{"24", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["r", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"12", " ", 
                   SqrtBox["2"]}], "+", 
                  RowBox[{
                  "7", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
                 ")"}], " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"1", ",", 
                  RowBox[{"-", "1"}]}]]}], "-", 
               RowBox[{"8", " ", 
                SubscriptBox["\[Beta]", 
                 RowBox[{"2", ",", 
                  RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"49", " ", "\[ImaginaryI]"}], "+", 
                  RowBox[{"6", " ", 
                   SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}]}], "+", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["r", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "8"}], " ", "\[ImaginaryI]", " ", 
                SqrtBox["2"]}], "+", 
               RowBox[{"6", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
         RowBox[{"32", " ", 
          SubscriptBox["\[Mu]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"33", " ", "\[ImaginaryI]"}], "+", 
               RowBox[{"2", " ", 
                SqrtBox["2"], " ", "\[CapitalDelta]"}], "-", 
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SubscriptBox["r", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"8", " ", "\[ImaginaryI]", " ", 
                SqrtBox["2"]}], "-", 
               RowBox[{"2", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{"128", " ", "\[CapitalDelta]", " ", 
          SubscriptBox["\[Beta]", 
           RowBox[{"2", ",", 
            RowBox[{"-", "1"}]}]]}], "+", 
         RowBox[{"8", " ", 
          SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "64"}], " ", "\[ImaginaryI]", " ", 
                SqrtBox["2"]}], "+", 
               RowBox[{"27", " ", "\[CapitalDelta]"}], "-", 
               RowBox[{"8", " ", "\[CapitalDelta]", " ", 
                SubscriptBox["r", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", "\[ImaginaryI]"}], "+", 
               RowBox[{
                SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"6", " ", "\[CapitalDelta]", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
         RowBox[{
          SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"224", " ", "\[ImaginaryI]", " ", 
                SqrtBox["2"]}], "-", 
               RowBox[{"107", " ", "\[CapitalDelta]"}], "+", 
               RowBox[{"8", " ", "\[CapitalDelta]", " ", 
                SubscriptBox["r", "2"]}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"0", ",", 
               RowBox[{"-", "1"}]}]]}], "-", 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"10", " ", "\[ImaginaryI]"}], "+", 
               RowBox[{
                SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}]]}], "+", 
            RowBox[{"4", " ", "\[CapitalDelta]", " ", 
             SubscriptBox["\[Beta]", 
              RowBox[{"2", ",", 
               RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8595520997915816`*^9, {3.859552129811071*^9, 3.859552152418462*^9}, {
   3.8595523046443377`*^9, 3.859552332205775*^9}, {3.8595523738079033`*^9, 
   3.8595523821569014`*^9}, 3.859552910467701*^9, 3.8596474474280386`*^9, 
   3.860625169765137*^9, 3.861396753018034*^9, 3.8614015970879087`*^9, 
   3.8631925952649045`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"a27ac201-9dd1-41b1-8b6c-bf9384525888"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"lambda4Re", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{
         SubscriptBox["\[Lambda]", "4"], "//.", 
         SubscriptBox["lambdaBeta", "4"]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}], "//.", 
     RowBox[{"\[ImaginaryI]", "->", "0"}]}], " ", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.860625187867478*^9, 3.8606252582493787`*^9}, {
  3.8606290735477057`*^9, 3.860629080494529*^9}, {3.861401602449488*^9, 
  3.861401604590973*^9}, {3.8614016507867355`*^9, 3.861401652861999*^9}, {
  3.8614018210676327`*^9, 3.8614018224520664`*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"8b414c66-56d4-4ad9-879d-6c21e0198c6d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"128", " ", 
    SuperscriptBox["\[CapitalDelta]", "3"]}]], 
  RowBox[{
   SubscriptBox["\[Mu]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2176"}], "+", 
     RowBox[{"32", " ", 
      SubscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"32", "-", 
        RowBox[{"12", " ", 
         SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
        SubsuperscriptBox["\[Mu]", "1", "4"]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1024", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{
         SubscriptBox["\[Mu]", "1"], " ", 
         RowBox[{"(", 
          RowBox[{"432", "-", 
           RowBox[{"64", " ", 
            SqrtBox["2"], " ", 
            SubscriptBox["\[Mu]", "1"]}], "-", 
           RowBox[{"92", " ", 
            SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
           RowBox[{"5", " ", 
            SubsuperscriptBox["\[Mu]", "1", "4"]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.860625195996385*^9, 3.8606252589210396`*^9}, 
   3.8606290813536377`*^9, 3.8613967537530975`*^9, 3.8614016060253086`*^9, 
   3.8614016534055915`*^9, 3.861401824899804*^9, 3.8631926009414597`*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"b2bce6cb-f396-422b-9b07-003ecbb349eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"lambda4Im", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            SubscriptBox["\[Lambda]", "4"], "//.", 
            SubscriptBox["lambdaBeta", "4"]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "//.", 
       RowBox[{"\[ImaginaryI]", "->", "0"}]}], "]"}], "//.", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       SuperscriptBox[
        SubscriptBox["\[Mu]", "1"], "2"]}], "->", 
      RowBox[{"-", 
       SuperscriptBox["\[CapitalDelta]", "2"]}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8606253563505163`*^9, 3.8606254629357376`*^9}, {
  3.861401613068339*^9, 3.861401615409021*^9}, {3.8614016552574325`*^9, 
  3.861401656938061*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"515df7aa-fcd9-4585-8fdc-def173b1a52b"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "16"], " ", 
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"16", " ", 
     SqrtBox["2"]}], "+", 
    RowBox[{"8", " ", 
     SubscriptBox["r", "3"]}], "+", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        SubscriptBox["\[Mu]", "1"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8606253672159815`*^9, 3.8606254038810053`*^9}, 
   3.8606254632636013`*^9, 3.861396754050991*^9, 3.8614016164626036`*^9, 
   3.861401657468458*^9, 3.8614018306116753`*^9, 3.8631926028443375`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"a95ec88a-0891-4064-acfd-bc5f686c4f52"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda4ReNumerator", "=", 
   RowBox[{"Numerator", "[", "lambda4Re", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{
  3.8595511760397043`*^9, {3.859552439641646*^9, 3.8595524527438197`*^9}, {
   3.8595529346262827`*^9, 3.85955293562493*^9}, {3.8595530151638374`*^9, 
   3.859553048332945*^9}, {3.859553106588539*^9, 3.8595531540352926`*^9}, {
   3.8595537756383133`*^9, 3.859553776959034*^9}, {3.8596474746041985`*^9, 
   3.859647499589712*^9}, {3.8596477381169395`*^9, 3.8596477403076534`*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"8a53dd71-03ec-4f70-b7a0-f26e89296e7b"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "2176"}], "+", 
    RowBox[{"32", " ", 
     SubscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"32", "-", 
       RowBox[{"12", " ", 
        SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
       SubsuperscriptBox["\[Mu]", "1", "4"]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["\[Mu]", "1"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1024", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{
        SubscriptBox["\[Mu]", "1"], " ", 
        RowBox[{"(", 
         RowBox[{"432", "-", 
          RowBox[{"64", " ", 
           SqrtBox["2"], " ", 
           SubscriptBox["\[Mu]", "1"]}], "-", 
          RowBox[{"92", " ", 
           SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
          RowBox[{"5", " ", 
           SubsuperscriptBox["\[Mu]", "1", "4"]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.859647500542523*^9, 3.8596477409172163`*^9, 
  3.860626513551874*^9, 3.861396754376034*^9, 3.86140173598346*^9, 
  3.8614018330418262`*^9, 3.8631926049897385`*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"c9e13e3b-8653-4661-81f0-e91defd6687c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", "Enforce", " ", "the", " ", "regular", " ", "curve", " ", 
    RowBox[{"condition", "."}]}], " ", "**)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   SubscriptBox["RCC", "4"], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"PolynomialQuotientRemainder", "[", 
      RowBox[{"lambda4ReNumerator", ",", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
        SubscriptBox["\[Mu]", "1"]}], ",", 
       SubscriptBox["\[Mu]", "1"]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.859553219414959*^9, 3.8595532468783503`*^9}, {
  3.8595533096196976`*^9, 3.8595533158303075`*^9}, {3.8596475157754755`*^9, 
  3.859647522964143*^9}, {3.859647560528387*^9, 3.85964758544925*^9}, {
  3.8614017503405924`*^9, 3.8614017589714537`*^9}, {3.8614018437527533`*^9, 
  3.8614018483580413`*^9}, {3.863192608348279*^9, 3.863192616605956*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"8cb5ccea-6e41-4c92-849e-40d6e51736c6"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Mu]", "1"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "544"}], " ", 
     SqrtBox["2"]}], "+", 
    RowBox[{"240", " ", 
     SubscriptBox["\[Mu]", "1"]}], "+", 
    RowBox[{"168", " ", 
     SqrtBox["2"], " ", 
     SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
    RowBox[{"52", " ", 
     SubsuperscriptBox["\[Mu]", "1", "3"]}], "-", 
    RowBox[{"10", " ", 
     SqrtBox["2"], " ", 
     SubsuperscriptBox["\[Mu]", "1", "4"]}], "-", 
    RowBox[{"5", " ", 
     SubsuperscriptBox["\[Mu]", "1", "5"]}], "-", 
    RowBox[{"32", " ", 
     SubscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SqrtBox["2"]}], "+", 
       SubscriptBox["\[Mu]", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       SubsuperscriptBox["\[Mu]", "1", "2"]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8595532482185755`*^9, 3.859553316783433*^9, {3.8596475610750484`*^9, 
   3.8596475866832266`*^9}, 3.859647744340664*^9, 3.8606265166602707`*^9, 
   3.861396754458199*^9, {3.8614017507934575`*^9, 3.861401760519235*^9}, {
   3.861401836338314*^9, 3.861401848720751*^9}, 3.8631926169671564`*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"5475e3f5-cf87-4c60-b4ed-b96594be23c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["RCC", "4"], "//.", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], "->", 
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "*", "2"}]}]}], ")"}], "==", "0"}], 
   ",", 
   RowBox[{"{", 
    SubscriptBox["r", "2"], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.859553370608463*^9, 3.859553407415917*^9}, {
  3.8596476047435904`*^9, 3.859647624448678*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"1a58fe96-0a20-4832-91ee-02fde24341a3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["r", "2"], "\[Rule]", 
    FractionBox["13", "8"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.8595533732096663`*^9, 3.859553407700555*^9}, 
   3.8596476251047144`*^9, 3.8596477458714633`*^9, 3.8613967546198835`*^9, 
   3.8614018546444373`*^9, 3.8631926195222087`*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"909ada84-3368-407c-b8d0-3245903f05f5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"lambda4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"lambda4Im", "*", "\[ImaginaryI]"}], "+", "lambda4Re"}], " ", "//.",
     " ", 
    RowBox[{
     SubscriptBox["r", "2"], "->", 
     RowBox[{"13", "/", "8"}]}]}]}]}]], "Input",
 CellChangeTimes->{
  3.8595532163465185`*^9, {3.859647790982798*^9, 3.859647835556938*^9}, {
   3.861401891194934*^9, 3.8614019077892065`*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"14cb780e-c23a-4d75-8b04-ef4c6a2fe9c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["\[Mu]", "1"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"16", " ", 
      SqrtBox["2"]}], "+", 
     RowBox[{"8", " ", 
      SubscriptBox["r", "3"]}], "+", 
     RowBox[{
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"], " ", 
         SubscriptBox["\[Mu]", "1"]}]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"128", " ", 
     SuperscriptBox["\[CapitalDelta]", "3"]}]], 
   RowBox[{
    SubscriptBox["\[Mu]", "1"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2176"}], "+", 
      RowBox[{"52", " ", 
       RowBox[{"(", 
        RowBox[{"32", "-", 
         RowBox[{"12", " ", 
          SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
         SubsuperscriptBox["\[Mu]", "1", "4"]}], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["\[Mu]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1024", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{
          SubscriptBox["\[Mu]", "1"], " ", 
          RowBox[{"(", 
           RowBox[{"432", "-", 
            RowBox[{"64", " ", 
             SqrtBox["2"], " ", 
             SubscriptBox["\[Mu]", "1"]}], "-", 
            RowBox[{"92", " ", 
             SubsuperscriptBox["\[Mu]", "1", "2"]}], "+", 
            RowBox[{"5", " ", 
             SubsuperscriptBox["\[Mu]", "1", "4"]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{{3.8596478092195544`*^9, 3.859647836540991*^9}, 
   3.8613967549874563`*^9, {3.86140188354361*^9, 3.861401908168955*^9}, 
   3.8631926236882257`*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"dabbe2ff-4bfb-4681-9ccf-f20529547ae7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     SubscriptBox["lambdaBeta", "4"], "//.", 
     RowBox[{
      SubscriptBox["r", "2"], "->", 
      RowBox[{"13", "/", "8"}]}]}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861401928978612*^9, 3.8614020047300596`*^9}, {
  3.86140205539406*^9, 3.86140205597151*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"23812c71-641e-466b-a877-17f7cc8be08a"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Beta]", 
   RowBox[{"2", ",", "1"}]], "\[Rule]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"8", " ", 
     SuperscriptBox["\[CapitalDelta]", "3"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["\[Mu]", "1", "7"], " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"0", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubsuperscriptBox["\[Mu]", "1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SqrtBox["2"]}], "+", 
           RowBox[{"5", " ", "\[ImaginaryI]", " ", "\[CapitalDelta]"}]}], 
          ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"3", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubsuperscriptBox["\[Mu]", "1", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"67", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{"9", " ", 
            SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"3", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
     RowBox[{"32", " ", 
      SubscriptBox["\[Mu]", "1"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"10", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{
            SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "\[ImaginaryI]", " ", 
            SqrtBox["2"]}], "-", "\[CapitalDelta]"}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"4", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
     RowBox[{"4", " ", 
      SubsuperscriptBox["\[Mu]", "1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"56", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{"19", " ", 
            SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", "\[ImaginaryI]", " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"7", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"8", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}], "-", 
     RowBox[{"64", " ", "\[CapitalDelta]", " ", 
      SubscriptBox["\[Beta]", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["\[Mu]", "1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "112"}], " ", "\[ImaginaryI]", " ", 
            SqrtBox["2"]}], "+", 
           RowBox[{"47", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"10", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{
            SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"2", " ", "\[CapitalDelta]", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}], "+", 
     RowBox[{"8", " ", 
      SubsuperscriptBox["\[Mu]", "1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"32", " ", "\[ImaginaryI]", " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"7", " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1"}]}]]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{
            SqrtBox["2"], " ", "\[CapitalDelta]"}]}], ")"}], " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}]}]]}], "+", 
        RowBox[{"3", " ", "\[CapitalDelta]", " ", 
         SubscriptBox["\[Beta]", 
          RowBox[{"2", ",", 
           RowBox[{"-", "1"}]}]]}]}], ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.861401933566785*^9, 3.8614020052847795`*^9}, 
   3.8614020576169376`*^9, 3.8631926268624144`*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"fb48bdbc-0172-41d2-b7c8-a25dc1e1a7f0"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{510.75, 501.},
WindowMargins->{{-5.25, Automatic}, {Automatic, 0}},
FrontEndVersion->"13.0 for Microsoft Windows (64-bit) (December 2, 2021)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8ff1fac1-27ae-4ec2-9ec0-c82a02a74aa2"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 435, 6, 222, "Title",ExpressionUUID->"ba24433a-2239-4b25-8573-ba4631ec5202"],
Cell[1018, 30, 546, 17, 265, "Text",ExpressionUUID->"6191803d-c320-4297-8345-33ecb4699c97"],
Cell[1567, 49, 259, 5, 57, "Input",ExpressionUUID->"ccff6626-5de1-4901-a6fd-06a8cd451827"],
Cell[1829, 56, 10563, 276, 1326, "Text",ExpressionUUID->"6bcf5db7-6cd2-4752-9f92-acce56985265"],
Cell[12395, 334, 407, 9, 57, "Input",ExpressionUUID->"bc51a555-ed69-478d-bf82-1344bd2f20c2"],
Cell[12805, 345, 15839, 361, 1386, "Input",ExpressionUUID->"6d280c5f-0bb4-4bf1-b210-00c63f242d94"],
Cell[28647, 708, 405, 8, 57, "Input",ExpressionUUID->"46d5fdbf-d4b0-479e-8e9a-f627896a3dff"],
Cell[CellGroupData[{
Cell[29077, 720, 27188, 618, 1817, "Input",ExpressionUUID->"2aed997e-c7f5-44d2-a6e1-6c4c599061d1",
 InitializationCell->True],
Cell[56268, 1340, 3287, 45, 32, "Output",ExpressionUUID->"d4e255fb-b52e-4ac2-b36b-706b963f856f"],
Cell[59558, 1387, 3287, 45, 32, "Output",ExpressionUUID->"0c4049b1-f7bb-4289-b907-c0b9c7ca05b4"],
Cell[62848, 1434, 4235, 75, 35, "Output",ExpressionUUID->"791ffaf0-7799-4074-a00d-1c40cb558089"],
Cell[67086, 1511, 3347, 47, 32, "Output",ExpressionUUID->"74d73890-9b57-4c87-925a-7b6d98f5e35e"],
Cell[70436, 1560, 3335, 47, 32, "Output",ExpressionUUID->"a1b092a4-c6dc-4691-a014-0f63be0c516c"],
Cell[73774, 1609, 3366, 48, 32, "Output",ExpressionUUID->"536aa0e0-deb6-489d-8997-faea3a5aec9a"]
}, Open  ]],
Cell[77155, 1660, 685, 12, 48, "Input",ExpressionUUID->"b2ff252b-6c85-4372-b9a7-ebedddc8a50a"],
Cell[77843, 1674, 14860, 320, 923, "Input",ExpressionUUID->"b2189f75-f1ec-4645-a3e0-f26b6afca0d2"],
Cell[CellGroupData[{
Cell[92728, 1998, 2899, 62, 124, "Input",ExpressionUUID->"093b7eb1-fb36-4e6d-85a1-e0e97ae5156a"],
Cell[95630, 2062, 2349, 61, 54, "Output",ExpressionUUID->"35da03a7-d449-4f8e-a70a-527cc63b6f8f"]
}, Open  ]],
Cell[97994, 2126, 2030, 53, 147, "Input",ExpressionUUID->"a4c3e96e-070e-4ab6-867b-9e09162da1d1"],
Cell[CellGroupData[{
Cell[100049, 2183, 1251, 31, 90, "Input",ExpressionUUID->"22f0f201-a85d-4cd8-8f8d-32b24c7e7f6c"],
Cell[101303, 2216, 1181, 23, 34, "Output",ExpressionUUID->"0d41ae51-a065-43b0-ad3c-b9c3b5c0b3c0"],
Cell[102487, 2241, 914, 13, 32, "Output",ExpressionUUID->"0a6a871e-c7e0-4a04-99ff-4f4832fd2d25"],
Cell[103404, 2256, 1159, 22, 34, "Output",ExpressionUUID->"af594ff5-1083-41f0-bd01-f5144ad05ff5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104600, 2283, 6239, 162, 540, "Input",ExpressionUUID->"b732a4b8-174a-48f4-bbff-1fb524aef1fd"],
Cell[110842, 2447, 1222, 18, 48, "Output",ExpressionUUID->"bc84d4bd-6c77-4e12-92be-a2f74e637847"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112101, 2470, 2914, 79, 237, "Input",ExpressionUUID->"fe4d1756-facd-459a-9098-fbb87c602195"],
Cell[115018, 2551, 1113, 15, 32, "Output",ExpressionUUID->"086b83af-1322-42a0-bf1f-4d7b90849586"],
Cell[116134, 2568, 1113, 15, 32, "Output",ExpressionUUID->"a7c2b5c7-4a77-4208-ac2e-8f41f41ec852"]
}, Open  ]],
Cell[117262, 2586, 806, 21, 69, "Input",ExpressionUUID->"0ea3e94f-b8b9-497b-8cb9-9401561351ac"],
Cell[CellGroupData[{
Cell[118093, 2611, 2310, 54, 201, "Input",ExpressionUUID->"45b99b82-18f2-410b-8eb4-b6d0343a4b61"],
Cell[120406, 2667, 2225, 51, 34, "Output",ExpressionUUID->"9313d4b8-bcb2-4e49-b376-48333407e4f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122668, 2723, 2502, 67, 155, "Input",ExpressionUUID->"88f7e02f-c226-4c4d-969d-02c10cdcea69"],
Cell[125173, 2792, 1182, 25, 48, "Output",ExpressionUUID->"2a242193-fb47-4456-b0cf-4f07e44bfdbf"],
Cell[126358, 2819, 1018, 19, 48, "Output",ExpressionUUID->"54112b0e-ec2b-4673-950c-70c5148b6532"],
Cell[127379, 2840, 1159, 24, 48, "Output",ExpressionUUID->"80e3f8e3-b4d8-493d-8f9d-165cd1265e00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128575, 2869, 4057, 109, 312, "Input",ExpressionUUID->"bd6d911a-b83b-4d12-bdbb-c91a9ba9bb93"],
Cell[132635, 2980, 1582, 31, 48, "Output",ExpressionUUID->"03b3400a-afd0-4a8b-a2b8-942968565ff6"],
Cell[134220, 3013, 1515, 28, 48, "Output",ExpressionUUID->"0befa646-ccb6-4013-bf68-aa8dd0956a58"],
Cell[135738, 3043, 1513, 28, 48, "Output",ExpressionUUID->"3d067d80-25d1-4bce-8c47-35fc91d3cfca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137288, 3076, 4663, 128, 349, "Input",ExpressionUUID->"6f5a91bf-ad9e-4101-883e-4ed020863a8b"],
Cell[141954, 3206, 1109, 16, 32, "Output",ExpressionUUID->"1c3c7a63-46dc-4ed5-be13-dc59e20d6216"],
Cell[143066, 3224, 1109, 16, 32, "Output",ExpressionUUID->"6b6c7f3e-605c-4725-847b-f4cb1f59867a"],
Cell[144178, 3242, 1109, 16, 32, "Output",ExpressionUUID->"dd9f4545-e626-4332-9f8c-9b98e50a0b7e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145324, 3263, 2451, 61, 147, "Input",ExpressionUUID->"277cd90c-1341-4490-b33d-049778e29cda"],
Cell[147778, 3326, 4049, 101, 77, "Output",ExpressionUUID->"06bf9cd7-0002-4c9e-83ed-4bf53ebfdd5f"]
}, Open  ]],
Cell[151842, 3430, 383, 8, 57, "Input",ExpressionUUID->"9a02771b-d8ba-4105-a58d-69877eb65e31"],
Cell[152228, 3440, 21800, 485, 1432, "Input",ExpressionUUID->"2892aa40-7360-4185-8b84-3ace0f89b41b"],
Cell[CellGroupData[{
Cell[174053, 3929, 3902, 99, 219, "Input",ExpressionUUID->"d809d491-8a47-48ff-a941-456f6fe8f59e"],
Cell[177958, 4030, 14272, 426, 657, "Output",ExpressionUUID->"41a7c287-625e-4df1-b2ee-b3c92cfd0566"]
}, Open  ]],
Cell[192245, 4459, 2063, 54, 147, "Input",ExpressionUUID->"7b3453af-a704-4a2c-a93a-4e5b8589ab6f"],
Cell[CellGroupData[{
Cell[194333, 4517, 5896, 147, 511, "Input",ExpressionUUID->"bd95815d-8443-4b52-b163-9617bf14e110"],
Cell[200232, 4666, 1067, 29, 48, "Output",ExpressionUUID->"22b56a6d-8e19-4b31-bbfd-973beeb04931"],
Cell[201302, 4697, 373, 8, 34, "Output",ExpressionUUID->"7338f0ac-a2cf-459e-91cf-fda87ac67820"],
Cell[201678, 4707, 1264, 37, 71, "Output",ExpressionUUID->"b8a50956-ff33-4df5-badb-400ff994a703"]
}, Open  ]],
Cell[202957, 4747, 701, 15, 106, "Input",ExpressionUUID->"a108a4a2-9e06-4f37-91c7-a24352d5124e"],
Cell[CellGroupData[{
Cell[203683, 4766, 3894, 105, 249, "Input",ExpressionUUID->"bf05ea7c-551f-4295-a8f8-e90f010b894e"],
Cell[207580, 4873, 955, 13, 32, "Output",ExpressionUUID->"815dd820-3f58-4eeb-8437-b5f648f9ca60"],
Cell[208538, 4888, 973, 14, 48, "Output",ExpressionUUID->"c066ecf7-2b7f-40e8-841c-521a8709837a"],
Cell[209514, 4904, 970, 14, 32, "Output",ExpressionUUID->"658668e0-b238-41e4-a640-3dff558d03e3"],
Cell[210487, 4920, 970, 14, 32, "Output",ExpressionUUID->"4bba190a-9fc4-4110-b0fe-fd7f69ec4348"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211494, 4939, 2246, 67, 93, "Input",ExpressionUUID->"16265d87-68b4-4028-8bcd-1f79964206e4"],
Cell[213743, 5008, 544, 7, 32, "Output",ExpressionUUID->"4429a8ff-b658-4c9e-90b2-86d65199db20"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214324, 5020, 3266, 94, 209, "Input",ExpressionUUID->"8105ae77-111a-4da5-bcac-de0aa9562eb5"],
Cell[217593, 5116, 627, 8, 32, "Output",ExpressionUUID->"56a4702f-f5f4-42a4-9ff7-0b2004b8b063"],
Cell[218223, 5126, 667, 10, 48, "Output",ExpressionUUID->"50364129-d546-4103-9667-f38f2833de6d"],
Cell[218893, 5138, 629, 8, 32, "Output",ExpressionUUID->"e96b3e42-dd3e-4fd1-9501-f27bb0251c3e"],
Cell[219525, 5148, 629, 8, 32, "Output",ExpressionUUID->"aba23865-f8dd-49a3-87a9-8c6c2d40b342"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220191, 5161, 2008, 58, 93, "Input",ExpressionUUID->"7c07249e-a22e-40f9-b3f0-c3f7cc96967f"],
Cell[222202, 5221, 392, 5, 32, "Output",ExpressionUUID->"e13bc5e2-5b7d-46a1-93ea-031550941cf2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[222631, 5231, 1397, 40, 167, "Input",ExpressionUUID->"6dff96f8-2962-4afd-ae1a-3139c2e47947"],
Cell[224031, 5273, 449, 6, 32, "Output",ExpressionUUID->"d4ab2bb5-ab87-429e-8b91-187f94bb8678"],
Cell[224483, 5281, 449, 6, 32, "Output",ExpressionUUID->"9e60c824-3805-4e6d-a2d6-de0c125aee71"],
Cell[224935, 5289, 451, 6, 32, "Output",ExpressionUUID->"ec4f4a47-23f9-42a1-8458-fd10715ac96c"],
Cell[225389, 5297, 451, 6, 32, "Output",ExpressionUUID->"9c30ed76-fb47-4b96-b6fd-73047bd8eee6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[225877, 5308, 670, 18, 49, "Input",ExpressionUUID->"543ed29f-6be1-426c-a11d-6acc0b3e4494"],
Cell[226550, 5328, 3215, 99, 159, "Output",ExpressionUUID->"3398680c-6b1d-4c3a-95e3-9b8725a977ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229802, 5432, 2345, 61, 213, "Input",ExpressionUUID->"7a726536-63fe-4dfb-826c-5ca3db1ef896"],
Cell[232150, 5495, 2095, 58, 85, "Output",ExpressionUUID->"c56f1bf9-7fb3-49f2-ad99-d56f6c83cc58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234282, 5558, 2376, 61, 187, "Input",ExpressionUUID->"bc283fcb-b6a1-48c0-8dcc-98e22bb4fd30"],
Cell[236661, 5621, 3455, 105, 161, "Output",ExpressionUUID->"8cd71427-f443-4024-9c85-1a4367149227"]
}, Open  ]],
Cell[CellGroupData[{
Cell[240153, 5731, 6372, 174, 523, "Input",ExpressionUUID->"108c5540-7390-43f6-8e11-d16158aa2569"],
Cell[246528, 5907, 1621, 46, 77, "Output",ExpressionUUID->"396fdf22-6498-4c35-8aff-d5b67d1b38ad"],
Cell[248152, 5955, 797, 19, 48, "Output",ExpressionUUID->"718275a1-3362-4654-9146-f5d012dd3b6d"],
Cell[248952, 5976, 1342, 35, 77, "Output",ExpressionUUID->"757def59-1887-4240-bebb-18c7ceaa1f29"]
}, Open  ]],
Cell[CellGroupData[{
Cell[250331, 6016, 1584, 47, 128, "Input",ExpressionUUID->"bde9050f-0b70-4084-9609-b4ab05a4899a"],
Cell[251918, 6065, 3729, 110, 97, "Output",ExpressionUUID->"d4fded18-4bcd-41b2-9b55-3a2f35c84812"]
}, Open  ]],
Cell[255662, 6178, 325, 7, 57, "Input",ExpressionUUID->"8965acf3-cd80-439d-98d7-17cf2da8a5a9"],
Cell[255990, 6187, 31680, 740, 2053, "Input",ExpressionUUID->"fcb6a558-093e-4ed2-b300-8e3557a20539"],
Cell[CellGroupData[{
Cell[287695, 6931, 4537, 133, 295, "Input",ExpressionUUID->"6b82e894-c72b-4eda-a156-19b2a443d999"],
Cell[292235, 7066, 50902, 1494, 2311, "Output",ExpressionUUID->"a6036674-1b29-4ef9-9fef-50ad04a57008"]
}, Open  ]],
Cell[CellGroupData[{
Cell[343174, 8565, 1185, 31, 90, "Input",ExpressionUUID->"d6ab35d9-1f35-4b0c-8cc8-e3550f23bd07"],
Cell[344362, 8598, 10815, 339, 517, "Output",ExpressionUUID->"8a36db14-fd1b-444c-865c-5f8b59b47a6e"],
Cell[355180, 8939, 5727, 172, 284, "Output",ExpressionUUID->"0ebf3bc1-af11-4164-a285-78552c651400"],
Cell[360910, 9113, 9921, 300, 479, "Output",ExpressionUUID->"2493cfc0-1e0d-46b9-9f70-a62937236bf8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370868, 9418, 7444, 191, 690, "Input",ExpressionUUID->"afe7b3c8-1541-4e3b-a80b-a8e287cf4cac"],
Cell[378315, 9611, 2078, 60, 92, "Output",ExpressionUUID->"8859bd23-ead5-4ab0-9f48-e197fa3d55fb"],
Cell[380396, 9673, 802, 21, 34, "Output",ExpressionUUID->"56de189a-7584-4a46-b745-44143e4ac66f"],
Cell[381201, 9696, 1958, 55, 92, "Output",ExpressionUUID->"acd5d2a1-609a-4b00-9557-661d549a2c8c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[383196, 9756, 2230, 58, 190, "Input",ExpressionUUID->"a2f25360-bc5e-4638-ae57-13da2d13841a"],
Cell[385429, 9816, 1198, 34, 61, "Output",ExpressionUUID->"f3bd069d-5a78-404f-a01a-bcbf2b8ad3e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386664, 9855, 3468, 81, 252, "Input",ExpressionUUID->"3d3491f9-70e1-42cc-8672-6dceaeb2074e"],
Cell[390135, 9938, 642, 13, 36, "Output",ExpressionUUID->"30f3b41f-b327-41bc-8f42-aef19a93498a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390814, 9956, 535, 15, 49, "Input",ExpressionUUID->"4b45c494-86c3-4455-a8c6-e574660e2a2f"],
Cell[391352, 9973, 1109, 32, 61, "Output",ExpressionUUID->"e75e916b-6c61-4941-b86c-b7b1f249a47a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[392498, 10010, 1221, 32, 194, "Input",ExpressionUUID->"29f61213-515e-45db-9ba0-f60e45a119d9"],
Cell[393722, 10044, 730, 21, 60, "Output",ExpressionUUID->"764c76ab-75c4-4f83-85b1-2212b13ffe41"],
Cell[394455, 10067, 489, 12, 48, "Output",ExpressionUUID->"25140878-05fb-4fa1-989f-4fb15d423f38"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394981, 10084, 2934, 74, 255, "Input",ExpressionUUID->"9a60f75b-e845-4544-9f52-0fb8c5323c9c"],
Cell[397918, 10160, 3093, 83, 135, "Output",ExpressionUUID->"a64c2471-c94f-4737-8171-9029c593e989"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401048, 10248, 4888, 129, 390, "Input",ExpressionUUID->"32a8b6fb-83bc-410a-a8b0-574483f6f753"],
Cell[405939, 10379, 1536, 45, 109, "Output",ExpressionUUID->"7428dbf9-c987-4c52-8667-e387489e7daa"],
Cell[407478, 10426, 1077, 28, 54, "Output",ExpressionUUID->"38b06e0c-b42b-4f80-9313-cffc42704864"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408592, 10459, 1035, 28, 91, "Input",ExpressionUUID->"52826653-68af-4556-bd8c-5badc2b5a75a"],
Cell[409630, 10489, 1038, 30, 58, "Output",ExpressionUUID->"3acd7254-800f-476d-8a4c-6345ae35ee2c"]
}, Open  ]],
Cell[410683, 10522, 149, 3, 48, "Input",ExpressionUUID->"038edcf3-ce1f-4a8a-abd3-8551e7ca00f3"],
Cell[CellGroupData[{
Cell[410857, 10529, 1561, 40, 213, "Input",ExpressionUUID->"52b86fe5-ee98-4de3-a45f-5dc50ed6a293"],
Cell[412421, 10571, 1391, 41, 58, "Output",ExpressionUUID->"5cf3b996-103e-4e8e-af90-850c17f8c9cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413849, 10617, 444, 12, 49, "Input",ExpressionUUID->"056a45e3-48db-4c1e-a6a5-ec1044ced000"],
Cell[414296, 10631, 813, 27, 36, "Output",ExpressionUUID->"fc2673db-27ba-4ba3-8e30-8767e84d8c97"]
}, Open  ]],
Cell[CellGroupData[{
Cell[415146, 10663, 595, 17, 49, "Input",ExpressionUUID->"c4490f10-f96e-484d-9a9a-82e5af2ebe83"],
Cell[415744, 10682, 392, 12, 36, "Output",ExpressionUUID->"68c8a635-375e-44cc-8aa8-0b2502838efe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416173, 10699, 2256, 60, 191, "Input",ExpressionUUID->"5597274e-583e-4d24-b1cf-f328113e621d"],
Cell[418432, 10761, 601, 16, 32, "Output",ExpressionUUID->"a632cd42-b528-4f6c-8c6a-ba24c6c9efb4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[419070, 10782, 1391, 39, 149, "Input",ExpressionUUID->"012ad896-c3b0-4503-8044-6cda48378030"],
Cell[420464, 10823, 643, 18, 50, "Output",ExpressionUUID->"ba02602a-4575-47f7-ab0b-4e3ff724418d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[421144, 10846, 1396, 39, 149, "Input",ExpressionUUID->"a5226df2-6d23-40cc-a172-1c4b4d484b5a"],
Cell[422543, 10887, 617, 17, 50, "Output",ExpressionUUID->"b93a7394-f442-4849-9875-a2cd3063a1fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[423197, 10909, 3865, 100, 311, "Input",ExpressionUUID->"8dc74e1a-e003-4500-90c2-4d22858dc771"],
Cell[427065, 11011, 7779, 237, 407, "Output",ExpressionUUID->"00a9548e-18f8-49bb-aed9-7f9436f80027"]
}, Open  ]],
Cell[CellGroupData[{
Cell[434881, 11253, 8112, 207, 616, "Input",ExpressionUUID->"661ffe85-8f2c-488d-8d47-f9e2434df425"],
Cell[442996, 11462, 2566, 75, 125, "Output",ExpressionUUID->"b88e5c3e-034b-402a-bcae-0088a734c79b"],
Cell[445565, 11539, 970, 29, 48, "Output",ExpressionUUID->"7f1234c5-6f09-4581-a92c-16809cf5b268"],
Cell[446538, 11570, 2400, 68, 97, "Output",ExpressionUUID->"0f2e6b58-fbfa-489c-8c1b-1536a3ca61e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448975, 11643, 1586, 48, 128, "Input",ExpressionUUID->"822202c9-faa2-4bb0-806f-c15237452716"],
Cell[450564, 11693, 4498, 134, 138, "Output",ExpressionUUID->"d68d05c4-b237-4b9c-9943-8f3ec4f4c32d"]
}, Open  ]],
Cell[455077, 11830, 317, 8, 48, "Input",ExpressionUUID->"690bdfad-58ec-46b9-9f1c-57947c0afd07"],
Cell[455397, 11840, 56045, 1261, 3428, "Input",ExpressionUUID->"392594e5-79bc-4ad2-9230-03711749f0f7"],
Cell[CellGroupData[{
Cell[511467, 13105, 7645, 223, 447, "Input",ExpressionUUID->"05e682da-8d66-4573-90de-622bb0b92138"],
Cell[519115, 13330, 144214, 4184, 6756, "Output",ExpressionUUID->"da39ee9d-7e10-42f2-bf6f-9b8d17cec8f3"]
}, Open  ]],
Cell[663344, 17517, 1121, 35, 90, "Input",ExpressionUUID->"3cbdfd65-8a6a-470e-9cf8-a41f6397e55a"],
Cell[CellGroupData[{
Cell[664490, 17556, 15154, 374, 1117, "Input",ExpressionUUID->"13824fb1-155c-4e4a-9579-db0b591ab0d8"],
Cell[679647, 17932, 4697, 134, 180, "Output",ExpressionUUID->"f6525514-f534-4501-aabf-1b92b7b26320"],
Cell[684347, 18068, 3287, 87, 136, "Output",ExpressionUUID->"8983b28f-8320-4b75-91b3-f4bb1f5c8b3c"],
Cell[687637, 18157, 9502, 258, 374, "Output",ExpressionUUID->"6a031d7f-4f2b-4724-9883-d6a482a280a9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[697176, 18420, 1554, 45, 189, "Input",ExpressionUUID->"93353b23-f80a-484a-9d06-76a2d8c11b41"],
Cell[698733, 18467, 4752, 135, 180, "Output",ExpressionUUID->"075a592c-bb3a-44c4-9851-9490228d72a3"],
Cell[703488, 18604, 9250, 250, 352, "Output",ExpressionUUID->"049d4ddc-a596-445b-ad23-b266a7912d83"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712775, 18859, 1531, 39, 133, "Input",ExpressionUUID->"0037f6e5-870d-4aae-b1d5-08b8fd094cfb"],
Cell[714309, 18900, 9963, 256, 376, "Output",ExpressionUUID->"a27ac201-9dd1-41b1-8b6c-bf9384525888"]
}, Open  ]],
Cell[CellGroupData[{
Cell[724309, 19161, 804, 18, 105, "Input",ExpressionUUID->"8b414c66-56d4-4ad9-879d-6c21e0198c6d"],
Cell[725116, 19181, 1380, 39, 72, "Output",ExpressionUUID->"b2bce6cb-f396-422b-9b07-003ecbb349eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[726533, 19225, 1062, 28, 148, "Input",ExpressionUUID->"515df7aa-fcd9-4585-8fdc-def173b1a52b"],
Cell[727598, 19255, 752, 21, 48, "Output",ExpressionUUID->"a95ec88a-0891-4064-acfd-bc5f686c4f52"]
}, Open  ]],
Cell[CellGroupData[{
Cell[728387, 19281, 633, 12, 48, "Input",ExpressionUUID->"8a53dd71-03ec-4f70-b7a0-f26e89296e7b"],
Cell[729023, 19295, 1213, 35, 57, "Output",ExpressionUUID->"c9e13e3b-8653-4661-81f0-e91defd6687c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[730273, 19335, 1095, 24, 124, "Input",ExpressionUUID->"8cb5ccea-6e41-4c92-849e-40d6e51736c6"],
Cell[731371, 19361, 1320, 37, 58, "Output",ExpressionUUID->"5475e3f5-cf87-4c60-b4ed-b96594be23c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[732728, 19403, 563, 17, 28, "Input",ExpressionUUID->"1a58fe96-0a20-4832-91ee-02fde24341a3"],
Cell[733294, 19422, 430, 10, 48, "Output",ExpressionUUID->"909ada84-3368-407c-b8d0-3245903f05f5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[733761, 19437, 517, 14, 48, "Input",ExpressionUUID->"14cb780e-c23a-4d75-8b04-ef4c6a2fe9c4"],
Cell[734281, 19453, 1811, 55, 109, "Output",ExpressionUUID->"dabbe2ff-4bfb-4681-9ccf-f20529547ae7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[736129, 19513, 515, 14, 48, "Input",ExpressionUUID->"23812c71-641e-466b-a877-17f7cc8be08a"],
Cell[736647, 19529, 5892, 171, 203, "Output",ExpressionUUID->"fb48bdbc-0172-41d2-b7c8-a25dc1e1a7f0"]
}, Open  ]]
}, Open  ]]
}
]
*)

